@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/AWSMigrationHub/MigrationHub_EXPORTS.h>
@@ -20,7 +30,6 @@
 #include <aws/AWSMigrationHub/model/DisassociateCreatedArtifactResult.h>
 #include <aws/AWSMigrationHub/model/DisassociateDiscoveredResourceResult.h>
 #include <aws/AWSMigrationHub/model/ImportMigrationTaskResult.h>
-#include <aws/AWSMigrationHub/model/ListApplicationStatesResult.h>
 #include <aws/AWSMigrationHub/model/ListCreatedArtifactsResult.h>
 #include <aws/AWSMigrationHub/model/ListDiscoveredResourcesResult.h>
 #include <aws/AWSMigrationHub/model/ListMigrationTasksResult.h>
@@ -45,6 +54,7 @@ namespace Http
 namespace Utils
 {
   template< typename R, typename E> class Outcome;
+
 namespace Threading
 {
   class Executor;
@@ -76,7 +86,6 @@ namespace Model
         class DisassociateCreatedArtifactRequest;
         class DisassociateDiscoveredResourceRequest;
         class ImportMigrationTaskRequest;
-        class ListApplicationStatesRequest;
         class ListCreatedArtifactsRequest;
         class ListDiscoveredResourcesRequest;
         class ListMigrationTasksRequest;
@@ -85,23 +94,22 @@ namespace Model
         class NotifyMigrationTaskStateRequest;
         class PutResourceAttributesRequest;
 
-        typedef Aws::Utils::Outcome<AssociateCreatedArtifactResult, MigrationHubError> AssociateCreatedArtifactOutcome;
-        typedef Aws::Utils::Outcome<AssociateDiscoveredResourceResult, MigrationHubError> AssociateDiscoveredResourceOutcome;
-        typedef Aws::Utils::Outcome<CreateProgressUpdateStreamResult, MigrationHubError> CreateProgressUpdateStreamOutcome;
-        typedef Aws::Utils::Outcome<DeleteProgressUpdateStreamResult, MigrationHubError> DeleteProgressUpdateStreamOutcome;
-        typedef Aws::Utils::Outcome<DescribeApplicationStateResult, MigrationHubError> DescribeApplicationStateOutcome;
-        typedef Aws::Utils::Outcome<DescribeMigrationTaskResult, MigrationHubError> DescribeMigrationTaskOutcome;
-        typedef Aws::Utils::Outcome<DisassociateCreatedArtifactResult, MigrationHubError> DisassociateCreatedArtifactOutcome;
-        typedef Aws::Utils::Outcome<DisassociateDiscoveredResourceResult, MigrationHubError> DisassociateDiscoveredResourceOutcome;
-        typedef Aws::Utils::Outcome<ImportMigrationTaskResult, MigrationHubError> ImportMigrationTaskOutcome;
-        typedef Aws::Utils::Outcome<ListApplicationStatesResult, MigrationHubError> ListApplicationStatesOutcome;
-        typedef Aws::Utils::Outcome<ListCreatedArtifactsResult, MigrationHubError> ListCreatedArtifactsOutcome;
-        typedef Aws::Utils::Outcome<ListDiscoveredResourcesResult, MigrationHubError> ListDiscoveredResourcesOutcome;
-        typedef Aws::Utils::Outcome<ListMigrationTasksResult, MigrationHubError> ListMigrationTasksOutcome;
-        typedef Aws::Utils::Outcome<ListProgressUpdateStreamsResult, MigrationHubError> ListProgressUpdateStreamsOutcome;
-        typedef Aws::Utils::Outcome<NotifyApplicationStateResult, MigrationHubError> NotifyApplicationStateOutcome;
-        typedef Aws::Utils::Outcome<NotifyMigrationTaskStateResult, MigrationHubError> NotifyMigrationTaskStateOutcome;
-        typedef Aws::Utils::Outcome<PutResourceAttributesResult, MigrationHubError> PutResourceAttributesOutcome;
+        typedef Aws::Utils::Outcome<AssociateCreatedArtifactResult, Aws::Client::AWSError<MigrationHubErrors>> AssociateCreatedArtifactOutcome;
+        typedef Aws::Utils::Outcome<AssociateDiscoveredResourceResult, Aws::Client::AWSError<MigrationHubErrors>> AssociateDiscoveredResourceOutcome;
+        typedef Aws::Utils::Outcome<CreateProgressUpdateStreamResult, Aws::Client::AWSError<MigrationHubErrors>> CreateProgressUpdateStreamOutcome;
+        typedef Aws::Utils::Outcome<DeleteProgressUpdateStreamResult, Aws::Client::AWSError<MigrationHubErrors>> DeleteProgressUpdateStreamOutcome;
+        typedef Aws::Utils::Outcome<DescribeApplicationStateResult, Aws::Client::AWSError<MigrationHubErrors>> DescribeApplicationStateOutcome;
+        typedef Aws::Utils::Outcome<DescribeMigrationTaskResult, Aws::Client::AWSError<MigrationHubErrors>> DescribeMigrationTaskOutcome;
+        typedef Aws::Utils::Outcome<DisassociateCreatedArtifactResult, Aws::Client::AWSError<MigrationHubErrors>> DisassociateCreatedArtifactOutcome;
+        typedef Aws::Utils::Outcome<DisassociateDiscoveredResourceResult, Aws::Client::AWSError<MigrationHubErrors>> DisassociateDiscoveredResourceOutcome;
+        typedef Aws::Utils::Outcome<ImportMigrationTaskResult, Aws::Client::AWSError<MigrationHubErrors>> ImportMigrationTaskOutcome;
+        typedef Aws::Utils::Outcome<ListCreatedArtifactsResult, Aws::Client::AWSError<MigrationHubErrors>> ListCreatedArtifactsOutcome;
+        typedef Aws::Utils::Outcome<ListDiscoveredResourcesResult, Aws::Client::AWSError<MigrationHubErrors>> ListDiscoveredResourcesOutcome;
+        typedef Aws::Utils::Outcome<ListMigrationTasksResult, Aws::Client::AWSError<MigrationHubErrors>> ListMigrationTasksOutcome;
+        typedef Aws::Utils::Outcome<ListProgressUpdateStreamsResult, Aws::Client::AWSError<MigrationHubErrors>> ListProgressUpdateStreamsOutcome;
+        typedef Aws::Utils::Outcome<NotifyApplicationStateResult, Aws::Client::AWSError<MigrationHubErrors>> NotifyApplicationStateOutcome;
+        typedef Aws::Utils::Outcome<NotifyMigrationTaskStateResult, Aws::Client::AWSError<MigrationHubErrors>> NotifyMigrationTaskStateOutcome;
+        typedef Aws::Utils::Outcome<PutResourceAttributesResult, Aws::Client::AWSError<MigrationHubErrors>> PutResourceAttributesOutcome;
 
         typedef std::future<AssociateCreatedArtifactOutcome> AssociateCreatedArtifactOutcomeCallable;
         typedef std::future<AssociateDiscoveredResourceOutcome> AssociateDiscoveredResourceOutcomeCallable;
@@ -112,7 +120,6 @@ namespace Model
         typedef std::future<DisassociateCreatedArtifactOutcome> DisassociateCreatedArtifactOutcomeCallable;
         typedef std::future<DisassociateDiscoveredResourceOutcome> DisassociateDiscoveredResourceOutcomeCallable;
         typedef std::future<ImportMigrationTaskOutcome> ImportMigrationTaskOutcomeCallable;
-        typedef std::future<ListApplicationStatesOutcome> ListApplicationStatesOutcomeCallable;
         typedef std::future<ListCreatedArtifactsOutcome> ListCreatedArtifactsOutcomeCallable;
         typedef std::future<ListDiscoveredResourcesOutcome> ListDiscoveredResourcesOutcomeCallable;
         typedef std::future<ListMigrationTasksOutcome> ListMigrationTasksOutcomeCallable;
@@ -133,7 +140,6 @@ namespace Model
     typedef std::function<void(const MigrationHubClient*, const Model::DisassociateCreatedArtifactRequest&, const Model::DisassociateCreatedArtifactOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DisassociateCreatedArtifactResponseReceivedHandler;
     typedef std::function<void(const MigrationHubClient*, const Model::DisassociateDiscoveredResourceRequest&, const Model::DisassociateDiscoveredResourceOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > DisassociateDiscoveredResourceResponseReceivedHandler;
     typedef std::function<void(const MigrationHubClient*, const Model::ImportMigrationTaskRequest&, const Model::ImportMigrationTaskOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ImportMigrationTaskResponseReceivedHandler;
-    typedef std::function<void(const MigrationHubClient*, const Model::ListApplicationStatesRequest&, const Model::ListApplicationStatesOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListApplicationStatesResponseReceivedHandler;
     typedef std::function<void(const MigrationHubClient*, const Model::ListCreatedArtifactsRequest&, const Model::ListCreatedArtifactsOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListCreatedArtifactsResponseReceivedHandler;
     typedef std::function<void(const MigrationHubClient*, const Model::ListDiscoveredResourcesRequest&, const Model::ListDiscoveredResourcesOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListDiscoveredResourcesResponseReceivedHandler;
     typedef std::function<void(const MigrationHubClient*, const Model::ListMigrationTasksRequest&, const Model::ListMigrationTasksOutcome&, const std::shared_ptr<const Aws::Client::AsyncCallerContext>&) > ListMigrationTasksResponseReceivedHandler;
@@ -145,10 +151,7 @@ namespace Model
   /**
    * <p>The AWS Migration Hub API methods help to obtain server and application
    * migration status and integrate your resource-specific migration tool by
-   * providing a programmatic interface to Migration Hub.</p> <p>Remember that you
-   * must set your AWS Migration Hub home region before you call any of these APIs,
-   * or a <code>HomeRegionNotSetException</code> error will be returned. Also, you
-   * must make the API calls while in your home region.</p>
+   * providing a programmatic interface to Migration Hub. </p>
    */
   class AWS_MIGRATIONHUB_API MigrationHubClient : public Aws::Client::AWSJsonClient
   {
@@ -176,6 +179,8 @@ namespace Model
 
         virtual ~MigrationHubClient();
 
+        inline virtual const char* GetServiceClientName() const override { return "mgh"; }
+
 
         /**
          * <p>Associates a created artifact of an AWS cloud resource, the target receiving
@@ -230,16 +235,16 @@ namespace Model
         virtual void AssociateCreatedArtifactAsync(const Model::AssociateCreatedArtifactRequest& request, const AssociateCreatedArtifactResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>Associates a discovered resource ID from Application Discovery Service with a
-         * migration task.</p><p><h3>See Also:</h3>   <a
+         * <p>Associates a discovered resource ID from Application Discovery Service (ADS)
+         * with a migration task.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/AssociateDiscoveredResource">AWS
          * API Reference</a></p>
          */
         virtual Model::AssociateDiscoveredResourceOutcome AssociateDiscoveredResource(const Model::AssociateDiscoveredResourceRequest& request) const;
 
         /**
-         * <p>Associates a discovered resource ID from Application Discovery Service with a
-         * migration task.</p><p><h3>See Also:</h3>   <a
+         * <p>Associates a discovered resource ID from Application Discovery Service (ADS)
+         * with a migration task.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/AssociateDiscoveredResource">AWS
          * API Reference</a></p>
          *
@@ -248,8 +253,8 @@ namespace Model
         virtual Model::AssociateDiscoveredResourceOutcomeCallable AssociateDiscoveredResourceCallable(const Model::AssociateDiscoveredResourceRequest& request) const;
 
         /**
-         * <p>Associates a discovered resource ID from Application Discovery Service with a
-         * migration task.</p><p><h3>See Also:</h3>   <a
+         * <p>Associates a discovered resource ID from Application Discovery Service (ADS)
+         * with a migration task.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/AssociateDiscoveredResource">AWS
          * API Reference</a></p>
          *
@@ -308,7 +313,7 @@ namespace Model
          * artifacts).</p> </li> <li> <p>If the stream takes time to be deleted, it might
          * still show up on a <code>ListProgressUpdateStreams</code> call.</p> </li> <li>
          * <p> <code>CreateProgressUpdateStream</code>, <code>ImportMigrationTask</code>,
-         * <code>NotifyMigrationTaskState</code>, and all Associate[*] APIs related to the
+         * <code>NotifyMigrationTaskState</code>, and all Associate[*] APIs realted to the
          * tasks belonging to the stream will throw "InvalidInputException" if the stream
          * of the same name is in the process of being deleted.</p> </li> <li> <p>Once the
          * stream and all of its resources are deleted,
@@ -332,7 +337,7 @@ namespace Model
          * artifacts).</p> </li> <li> <p>If the stream takes time to be deleted, it might
          * still show up on a <code>ListProgressUpdateStreams</code> call.</p> </li> <li>
          * <p> <code>CreateProgressUpdateStream</code>, <code>ImportMigrationTask</code>,
-         * <code>NotifyMigrationTaskState</code>, and all Associate[*] APIs related to the
+         * <code>NotifyMigrationTaskState</code>, and all Associate[*] APIs realted to the
          * tasks belonging to the stream will throw "InvalidInputException" if the stream
          * of the same name is in the process of being deleted.</p> </li> <li> <p>Once the
          * stream and all of its resources are deleted,
@@ -358,7 +363,7 @@ namespace Model
          * artifacts).</p> </li> <li> <p>If the stream takes time to be deleted, it might
          * still show up on a <code>ListProgressUpdateStreams</code> call.</p> </li> <li>
          * <p> <code>CreateProgressUpdateStream</code>, <code>ImportMigrationTask</code>,
-         * <code>NotifyMigrationTaskState</code>, and all Associate[*] APIs related to the
+         * <code>NotifyMigrationTaskState</code>, and all Associate[*] APIs realted to the
          * tasks belonging to the stream will throw "InvalidInputException" if the stream
          * of the same name is in the process of being deleted.</p> </li> <li> <p>Once the
          * stream and all of its resources are deleted,
@@ -479,16 +484,16 @@ namespace Model
         virtual void DisassociateCreatedArtifactAsync(const Model::DisassociateCreatedArtifactRequest& request, const DisassociateCreatedArtifactResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>Disassociate an Application Discovery Service discovered resource from a
-         * migration task.</p><p><h3>See Also:</h3>   <a
+         * <p>Disassociate an Application Discovery Service (ADS) discovered resource from
+         * a migration task.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/DisassociateDiscoveredResource">AWS
          * API Reference</a></p>
          */
         virtual Model::DisassociateDiscoveredResourceOutcome DisassociateDiscoveredResource(const Model::DisassociateDiscoveredResourceRequest& request) const;
 
         /**
-         * <p>Disassociate an Application Discovery Service discovered resource from a
-         * migration task.</p><p><h3>See Also:</h3>   <a
+         * <p>Disassociate an Application Discovery Service (ADS) discovered resource from
+         * a migration task.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/DisassociateDiscoveredResource">AWS
          * API Reference</a></p>
          *
@@ -497,8 +502,8 @@ namespace Model
         virtual Model::DisassociateDiscoveredResourceOutcomeCallable DisassociateDiscoveredResourceCallable(const Model::DisassociateDiscoveredResourceRequest& request) const;
 
         /**
-         * <p>Disassociate an Application Discovery Service discovered resource from a
-         * migration task.</p><p><h3>See Also:</h3>   <a
+         * <p>Disassociate an Application Discovery Service (ADS) discovered resource from
+         * a migration task.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/DisassociateDiscoveredResource">AWS
          * API Reference</a></p>
          *
@@ -543,37 +548,6 @@ namespace Model
          */
         virtual void ImportMigrationTaskAsync(const Model::ImportMigrationTaskRequest& request, const ImportMigrationTaskResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
-        /**
-         * <p>Lists all the migration statuses for your applications. If you use the
-         * optional <code>ApplicationIds</code> parameter, only the migration statuses for
-         * those applications will be returned.</p><p><h3>See Also:</h3>   <a
-         * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/ListApplicationStates">AWS
-         * API Reference</a></p>
-         */
-        virtual Model::ListApplicationStatesOutcome ListApplicationStates(const Model::ListApplicationStatesRequest& request) const;
-
-        /**
-         * <p>Lists all the migration statuses for your applications. If you use the
-         * optional <code>ApplicationIds</code> parameter, only the migration statuses for
-         * those applications will be returned.</p><p><h3>See Also:</h3>   <a
-         * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/ListApplicationStates">AWS
-         * API Reference</a></p>
-         *
-         * returns a future to the operation so that it can be executed in parallel to other requests.
-         */
-        virtual Model::ListApplicationStatesOutcomeCallable ListApplicationStatesCallable(const Model::ListApplicationStatesRequest& request) const;
-
-        /**
-         * <p>Lists all the migration statuses for your applications. If you use the
-         * optional <code>ApplicationIds</code> parameter, only the migration statuses for
-         * those applications will be returned.</p><p><h3>See Also:</h3>   <a
-         * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/ListApplicationStates">AWS
-         * API Reference</a></p>
-         *
-         * Queues the request into a thread executor and triggers associated callback when operation has finished.
-         */
-        virtual void ListApplicationStatesAsync(const Model::ListApplicationStatesRequest& request, const ListApplicationStatesResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
-
         /**
          * <p>Lists the created artifacts attached to a given migration task in an update
          * stream. This API has the following traits:</p> <ul> <li> <p>Gets the list of the
@@ -795,20 +769,20 @@ namespace Model
 
         /**
          * <p>Provides identifying details of the resource being migrated so that it can be
-         * associated in the Application Discovery Service repository. This association
-         * occurs asynchronously after <code>PutResourceAttributes</code> returns.</p>
-         *  <ul> <li> <p>Keep in mind that subsequent calls to
+         * associated in the Application Discovery Service (ADS)'s repository. This
+         * association occurs asynchronously after <code>PutResourceAttributes</code>
+         * returns.</p> <important> <ul> <li> <p>Keep in mind that subsequent calls to
          * PutResourceAttributes will override previously stored attributes. For example,
          * if it is first called with a MAC address, but later, it is desired to <i>add</i>
          * an IP address, it will then be required to call it with <i>both</i> the IP and
-         * MAC addresses to prevent overriding the MAC address.</p> </li> <li> <p>Note the
+         * MAC addresses to prevent overiding the MAC address.</p> </li> <li> <p>Note the
          * instructions regarding the special use case of the <a
          * href="https://docs.aws.amazon.com/migrationhub/latest/ug/API_PutResourceAttributes.html#migrationhub-PutResourceAttributes-request-ResourceAttributeList">
          * <code>ResourceAttributeList</code> </a> parameter when specifying any "VM"
-         * related value.</p> </li> </ul>   <p>Because this is an
+         * related value. </p> </li> </ul> </important> <note> <p>Because this is an
          * asynchronous call, it will always return 200, whether an association occurs or
          * not. To confirm if an association was found based on the provided details, call
-         * <code>ListDiscoveredResources</code>.</p> <p><h3>See Also:</h3>   <a
+         * <code>ListDiscoveredResources</code>.</p> </note><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/PutResourceAttributes">AWS
          * API Reference</a></p>
          */
@@ -816,20 +790,20 @@ namespace Model
 
         /**
          * <p>Provides identifying details of the resource being migrated so that it can be
-         * associated in the Application Discovery Service repository. This association
-         * occurs asynchronously after <code>PutResourceAttributes</code> returns.</p>
-         *  <ul> <li> <p>Keep in mind that subsequent calls to
+         * associated in the Application Discovery Service (ADS)'s repository. This
+         * association occurs asynchronously after <code>PutResourceAttributes</code>
+         * returns.</p> <important> <ul> <li> <p>Keep in mind that subsequent calls to
          * PutResourceAttributes will override previously stored attributes. For example,
          * if it is first called with a MAC address, but later, it is desired to <i>add</i>
          * an IP address, it will then be required to call it with <i>both</i> the IP and
-         * MAC addresses to prevent overriding the MAC address.</p> </li> <li> <p>Note the
+         * MAC addresses to prevent overiding the MAC address.</p> </li> <li> <p>Note the
          * instructions regarding the special use case of the <a
          * href="https://docs.aws.amazon.com/migrationhub/latest/ug/API_PutResourceAttributes.html#migrationhub-PutResourceAttributes-request-ResourceAttributeList">
          * <code>ResourceAttributeList</code> </a> parameter when specifying any "VM"
-         * related value.</p> </li> </ul>   <p>Because this is an
+         * related value. </p> </li> </ul> </important> <note> <p>Because this is an
          * asynchronous call, it will always return 200, whether an association occurs or
          * not. To confirm if an association was found based on the provided details, call
-         * <code>ListDiscoveredResources</code>.</p> <p><h3>See Also:</h3>   <a
+         * <code>ListDiscoveredResources</code>.</p> </note><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/PutResourceAttributes">AWS
          * API Reference</a></p>
          *
@@ -839,20 +813,20 @@ namespace Model
 
         /**
          * <p>Provides identifying details of the resource being migrated so that it can be
-         * associated in the Application Discovery Service repository. This association
-         * occurs asynchronously after <code>PutResourceAttributes</code> returns.</p>
-         *  <ul> <li> <p>Keep in mind that subsequent calls to
+         * associated in the Application Discovery Service (ADS)'s repository. This
+         * association occurs asynchronously after <code>PutResourceAttributes</code>
+         * returns.</p> <important> <ul> <li> <p>Keep in mind that subsequent calls to
          * PutResourceAttributes will override previously stored attributes. For example,
          * if it is first called with a MAC address, but later, it is desired to <i>add</i>
          * an IP address, it will then be required to call it with <i>both</i> the IP and
-         * MAC addresses to prevent overriding the MAC address.</p> </li> <li> <p>Note the
+         * MAC addresses to prevent overiding the MAC address.</p> </li> <li> <p>Note the
          * instructions regarding the special use case of the <a
          * href="https://docs.aws.amazon.com/migrationhub/latest/ug/API_PutResourceAttributes.html#migrationhub-PutResourceAttributes-request-ResourceAttributeList">
          * <code>ResourceAttributeList</code> </a> parameter when specifying any "VM"
-         * related value.</p> </li> </ul>   <p>Because this is an
+         * related value. </p> </li> </ul> </important> <note> <p>Because this is an
          * asynchronous call, it will always return 200, whether an association occurs or
          * not. To confirm if an association was found based on the provided details, call
-         * <code>ListDiscoveredResources</code>.</p> <p><h3>See Also:</h3>   <a
+         * <code>ListDiscoveredResources</code>.</p> </note><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31/PutResourceAttributes">AWS
          * API Reference</a></p>
          *
@@ -860,10 +834,11 @@ namespace Model
          */
         virtual void PutResourceAttributesAsync(const Model::PutResourceAttributesRequest& request, const PutResourceAttributesResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
-
+      
       void OverrideEndpoint(const Aws::String& endpoint);
     private:
       void init(const Aws::Client::ClientConfiguration& clientConfiguration);
+        /**Async helpers**/
         void AssociateCreatedArtifactAsyncHelper(const Model::AssociateCreatedArtifactRequest& request, const AssociateCreatedArtifactResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void AssociateDiscoveredResourceAsyncHelper(const Model::AssociateDiscoveredResourceRequest& request, const AssociateDiscoveredResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void CreateProgressUpdateStreamAsyncHelper(const Model::CreateProgressUpdateStreamRequest& request, const CreateProgressUpdateStreamResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
@@ -873,7 +848,6 @@ namespace Model
         void DisassociateCreatedArtifactAsyncHelper(const Model::DisassociateCreatedArtifactRequest& request, const DisassociateCreatedArtifactResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void DisassociateDiscoveredResourceAsyncHelper(const Model::DisassociateDiscoveredResourceRequest& request, const DisassociateDiscoveredResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void ImportMigrationTaskAsyncHelper(const Model::ImportMigrationTaskRequest& request, const ImportMigrationTaskResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
-        void ListApplicationStatesAsyncHelper(const Model::ListApplicationStatesRequest& request, const ListApplicationStatesResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void ListCreatedArtifactsAsyncHelper(const Model::ListCreatedArtifactsRequest& request, const ListCreatedArtifactsResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void ListDiscoveredResourcesAsyncHelper(const Model::ListDiscoveredResourcesRequest& request, const ListDiscoveredResourcesResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void ListMigrationTasksAsyncHelper(const Model::ListMigrationTasksRequest& request, const ListMigrationTasksResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
