@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/acm-pca/ACMPCA_EXPORTS.h>
@@ -34,16 +44,13 @@ namespace Model
    * private CA can issue and revoke X.509 digital certificates. Digital certificates
    * verify that the entity named in the certificate <b>Subject</b> field owns or
    * controls the public key contained in the <b>Subject Public Key Info</b> field.
-   * Call the <a
-   * href="https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_CreateCertificateAuthority.html">CreateCertificateAuthority</a>
-   * action to create your private CA. You must then call the <a
-   * href="https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_GetCertificateAuthorityCertificate.html">GetCertificateAuthorityCertificate</a>
-   * action to retrieve a private CA certificate signing request (CSR). Sign the CSR
-   * with your ACM Private CA-hosted or on-premises root or subordinate CA
-   * certificate. Call the <a
-   * href="https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_ImportCertificateAuthorityCertificate.html">ImportCertificateAuthorityCertificate</a>
-   * action to import the signed certificate into AWS Certificate Manager (ACM).
-   * </p><p><h3>See Also:</h3>   <a
+   * Call the <a>CreateCertificateAuthority</a> operation to create your private CA.
+   * You must then call the <a>GetCertificateAuthorityCertificate</a> operation to
+   * retrieve a private CA certificate signing request (CSR). Take the CSR to your
+   * on-premises CA and sign it with the root CA certificate or a subordinate
+   * certificate. Call the <a>ImportCertificateAuthorityCertificate</a> operation to
+   * import the signed certificate into AWS Certificate Manager (ACM). </p><p><h3>See
+   * Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/acm-pca-2017-08-22/CertificateAuthority">AWS
    * API Reference</a></p>
    */
@@ -105,47 +112,6 @@ namespace Model
     inline CertificateAuthority& WithArn(const char* value) { SetArn(value); return *this;}
 
 
-    /**
-     * <p>The AWS account ID that owns the certificate authority.</p>
-     */
-    inline const Aws::String& GetOwnerAccount() const{ return m_ownerAccount; }
-
-    /**
-     * <p>The AWS account ID that owns the certificate authority.</p>
-     */
-    inline bool OwnerAccountHasBeenSet() const { return m_ownerAccountHasBeenSet; }
-
-    /**
-     * <p>The AWS account ID that owns the certificate authority.</p>
-     */
-    inline void SetOwnerAccount(const Aws::String& value) { m_ownerAccountHasBeenSet = true; m_ownerAccount = value; }
-
-    /**
-     * <p>The AWS account ID that owns the certificate authority.</p>
-     */
-    inline void SetOwnerAccount(Aws::String&& value) { m_ownerAccountHasBeenSet = true; m_ownerAccount = std::move(value); }
-
-    /**
-     * <p>The AWS account ID that owns the certificate authority.</p>
-     */
-    inline void SetOwnerAccount(const char* value) { m_ownerAccountHasBeenSet = true; m_ownerAccount.assign(value); }
-
-    /**
-     * <p>The AWS account ID that owns the certificate authority.</p>
-     */
-    inline CertificateAuthority& WithOwnerAccount(const Aws::String& value) { SetOwnerAccount(value); return *this;}
-
-    /**
-     * <p>The AWS account ID that owns the certificate authority.</p>
-     */
-    inline CertificateAuthority& WithOwnerAccount(Aws::String&& value) { SetOwnerAccount(std::move(value)); return *this;}
-
-    /**
-     * <p>The AWS account ID that owns the certificate authority.</p>
-     */
-    inline CertificateAuthority& WithOwnerAccount(const char* value) { SetOwnerAccount(value); return *this;}
-
-
     /**
      * <p>Date and time at which your private CA was created.</p>
      */
@@ -474,49 +440,43 @@ namespace Model
 
     /**
      * <p>The period during which a deleted CA can be restored. For more information,
-     * see the <code>PermanentDeletionTimeInDays</code> parameter of the <a
-     * href="https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DeleteCertificateAuthorityRequest.html">DeleteCertificateAuthorityRequest</a>
-     * action. </p>
+     * see the <code>PermanentDeletionTimeInDays</code> parameter of the
+     * <a>DeleteCertificateAuthorityRequest</a> operation. </p>
      */
     inline const Aws::Utils::DateTime& GetRestorableUntil() const{ return m_restorableUntil; }
 
     /**
      * <p>The period during which a deleted CA can be restored. For more information,
-     * see the <code>PermanentDeletionTimeInDays</code> parameter of the <a
-     * href="https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DeleteCertificateAuthorityRequest.html">DeleteCertificateAuthorityRequest</a>
-     * action. </p>
+     * see the <code>PermanentDeletionTimeInDays</code> parameter of the
+     * <a>DeleteCertificateAuthorityRequest</a> operation. </p>
      */
     inline bool RestorableUntilHasBeenSet() const { return m_restorableUntilHasBeenSet; }
 
     /**
      * <p>The period during which a deleted CA can be restored. For more information,
-     * see the <code>PermanentDeletionTimeInDays</code> parameter of the <a
-     * href="https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DeleteCertificateAuthorityRequest.html">DeleteCertificateAuthorityRequest</a>
-     * action. </p>
+     * see the <code>PermanentDeletionTimeInDays</code> parameter of the
+     * <a>DeleteCertificateAuthorityRequest</a> operation. </p>
      */
     inline void SetRestorableUntil(const Aws::Utils::DateTime& value) { m_restorableUntilHasBeenSet = true; m_restorableUntil = value; }
 
     /**
      * <p>The period during which a deleted CA can be restored. For more information,
-     * see the <code>PermanentDeletionTimeInDays</code> parameter of the <a
-     * href="https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DeleteCertificateAuthorityRequest.html">DeleteCertificateAuthorityRequest</a>
-     * action. </p>
+     * see the <code>PermanentDeletionTimeInDays</code> parameter of the
+     * <a>DeleteCertificateAuthorityRequest</a> operation. </p>
      */
     inline void SetRestorableUntil(Aws::Utils::DateTime&& value) { m_restorableUntilHasBeenSet = true; m_restorableUntil = std::move(value); }
 
     /**
      * <p>The period during which a deleted CA can be restored. For more information,
-     * see the <code>PermanentDeletionTimeInDays</code> parameter of the <a
-     * href="https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DeleteCertificateAuthorityRequest.html">DeleteCertificateAuthorityRequest</a>
-     * action. </p>
+     * see the <code>PermanentDeletionTimeInDays</code> parameter of the
+     * <a>DeleteCertificateAuthorityRequest</a> operation. </p>
      */
     inline CertificateAuthority& WithRestorableUntil(const Aws::Utils::DateTime& value) { SetRestorableUntil(value); return *this;}
 
     /**
      * <p>The period during which a deleted CA can be restored. For more information,
-     * see the <code>PermanentDeletionTimeInDays</code> parameter of the <a
-     * href="https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DeleteCertificateAuthorityRequest.html">DeleteCertificateAuthorityRequest</a>
-     * action. </p>
+     * see the <code>PermanentDeletionTimeInDays</code> parameter of the
+     * <a>DeleteCertificateAuthorityRequest</a> operation. </p>
      */
     inline CertificateAuthority& WithRestorableUntil(Aws::Utils::DateTime&& value) { SetRestorableUntil(std::move(value)); return *this;}
 
@@ -525,9 +485,6 @@ namespace Model
     Aws::String m_arn;
     bool m_arnHasBeenSet;
 
-    Aws::String m_ownerAccount;
-    bool m_ownerAccountHasBeenSet;
-
     Aws::Utils::DateTime m_createdAt;
     bool m_createdAtHasBeenSet;
 
