@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/acm/ACM_EXPORTS.h>
@@ -36,6 +46,7 @@ namespace Http
 namespace Utils
 {
   template< typename R, typename E> class Outcome;
+
 namespace Threading
 {
   class Executor;
@@ -72,19 +83,19 @@ namespace Model
         class ResendValidationEmailRequest;
         class UpdateCertificateOptionsRequest;
 
-        typedef Aws::Utils::Outcome<Aws::NoResult, ACMError> AddTagsToCertificateOutcome;
-        typedef Aws::Utils::Outcome<Aws::NoResult, ACMError> DeleteCertificateOutcome;
-        typedef Aws::Utils::Outcome<DescribeCertificateResult, ACMError> DescribeCertificateOutcome;
-        typedef Aws::Utils::Outcome<ExportCertificateResult, ACMError> ExportCertificateOutcome;
-        typedef Aws::Utils::Outcome<GetCertificateResult, ACMError> GetCertificateOutcome;
-        typedef Aws::Utils::Outcome<ImportCertificateResult, ACMError> ImportCertificateOutcome;
-        typedef Aws::Utils::Outcome<ListCertificatesResult, ACMError> ListCertificatesOutcome;
-        typedef Aws::Utils::Outcome<ListTagsForCertificateResult, ACMError> ListTagsForCertificateOutcome;
-        typedef Aws::Utils::Outcome<Aws::NoResult, ACMError> RemoveTagsFromCertificateOutcome;
-        typedef Aws::Utils::Outcome<Aws::NoResult, ACMError> RenewCertificateOutcome;
-        typedef Aws::Utils::Outcome<RequestCertificateResult, ACMError> RequestCertificateOutcome;
-        typedef Aws::Utils::Outcome<Aws::NoResult, ACMError> ResendValidationEmailOutcome;
-        typedef Aws::Utils::Outcome<Aws::NoResult, ACMError> UpdateCertificateOptionsOutcome;
+        typedef Aws::Utils::Outcome<Aws::NoResult, Aws::Client::AWSError<ACMErrors>> AddTagsToCertificateOutcome;
+        typedef Aws::Utils::Outcome<Aws::NoResult, Aws::Client::AWSError<ACMErrors>> DeleteCertificateOutcome;
+        typedef Aws::Utils::Outcome<DescribeCertificateResult, Aws::Client::AWSError<ACMErrors>> DescribeCertificateOutcome;
+        typedef Aws::Utils::Outcome<ExportCertificateResult, Aws::Client::AWSError<ACMErrors>> ExportCertificateOutcome;
+        typedef Aws::Utils::Outcome<GetCertificateResult, Aws::Client::AWSError<ACMErrors>> GetCertificateOutcome;
+        typedef Aws::Utils::Outcome<ImportCertificateResult, Aws::Client::AWSError<ACMErrors>> ImportCertificateOutcome;
+        typedef Aws::Utils::Outcome<ListCertificatesResult, Aws::Client::AWSError<ACMErrors>> ListCertificatesOutcome;
+        typedef Aws::Utils::Outcome<ListTagsForCertificateResult, Aws::Client::AWSError<ACMErrors>> ListTagsForCertificateOutcome;
+        typedef Aws::Utils::Outcome<Aws::NoResult, Aws::Client::AWSError<ACMErrors>> RemoveTagsFromCertificateOutcome;
+        typedef Aws::Utils::Outcome<Aws::NoResult, Aws::Client::AWSError<ACMErrors>> RenewCertificateOutcome;
+        typedef Aws::Utils::Outcome<RequestCertificateResult, Aws::Client::AWSError<ACMErrors>> RequestCertificateOutcome;
+        typedef Aws::Utils::Outcome<Aws::NoResult, Aws::Client::AWSError<ACMErrors>> ResendValidationEmailOutcome;
+        typedef Aws::Utils::Outcome<Aws::NoResult, Aws::Client::AWSError<ACMErrors>> UpdateCertificateOptionsOutcome;
 
         typedef std::future<AddTagsToCertificateOutcome> AddTagsToCertificateOutcomeCallable;
         typedef std::future<DeleteCertificateOutcome> DeleteCertificateOutcomeCallable;
@@ -151,6 +162,8 @@ namespace Model
 
         virtual ~ACMClient();
 
+        inline virtual const char* GetServiceClientName() const override { return "ACM"; }
+
 
         /**
          * <p>Adds one or more tags to an ACM certificate. Tags are labels that you can use
@@ -230,10 +243,10 @@ namespace Model
          * succeeds, the certificate no longer appears in the list that can be displayed by
          * calling the <a>ListCertificates</a> action or be retrieved by calling the
          * <a>GetCertificate</a> action. The certificate will not be available for use by
-         * AWS services integrated with ACM. </p>  <p>You cannot delete an ACM
+         * AWS services integrated with ACM. </p> <note> <p>You cannot delete an ACM
          * certificate that is being used by another AWS service. To delete a certificate
          * that is in use, the certificate association must first be removed.</p>
-         * <p><h3>See Also:</h3>   <a
+         * </note><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/DeleteCertificate">AWS
          * API Reference</a></p>
          */
@@ -244,10 +257,10 @@ namespace Model
          * succeeds, the certificate no longer appears in the list that can be displayed by
          * calling the <a>ListCertificates</a> action or be retrieved by calling the
          * <a>GetCertificate</a> action. The certificate will not be available for use by
-         * AWS services integrated with ACM. </p>  <p>You cannot delete an ACM
+         * AWS services integrated with ACM. </p> <note> <p>You cannot delete an ACM
          * certificate that is being used by another AWS service. To delete a certificate
          * that is in use, the certificate association must first be removed.</p>
-         * <p><h3>See Also:</h3>   <a
+         * </note><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/DeleteCertificate">AWS
          * API Reference</a></p>
          *
@@ -260,10 +273,10 @@ namespace Model
          * succeeds, the certificate no longer appears in the list that can be displayed by
          * calling the <a>ListCertificates</a> action or be retrieved by calling the
          * <a>GetCertificate</a> action. The certificate will not be available for use by
-         * AWS services integrated with ACM. </p>  <p>You cannot delete an ACM
+         * AWS services integrated with ACM. </p> <note> <p>You cannot delete an ACM
          * certificate that is being used by another AWS service. To delete a certificate
          * that is in use, the certificate association must first be removed.</p>
-         * <p><h3>See Also:</h3>   <a
+         * </note><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/DeleteCertificate">AWS
          * API Reference</a></p>
          *
@@ -301,13 +314,13 @@ namespace Model
 
         /**
          * <p>Exports a private certificate issued by a private certificate authority (CA)
-         * for use anywhere. The exported file contains the certificate, the certificate
-         * chain, and the encrypted private 2048-bit RSA key associated with the public key
-         * that is embedded in the certificate. For security, you must assign a passphrase
-         * for the private key when exporting it. </p> <p>For information about exporting
-         * and formatting a certificate using the ACM console or CLI, see <a
-         * href="https://docs.aws.amazon.com/acm/latest/userguide/gs-acm-export-private.html">Export
-         * a Private Certificate</a>.</p><p><h3>See Also:</h3>   <a
+         * for use anywhere. You can export the certificate, the certificate chain, and the
+         * encrypted private key associated with the public key embedded in the
+         * certificate. You must store the private key securely. The private key is a 2048
+         * bit RSA key. You must provide a passphrase for the private key when exporting
+         * it. You can use the following OpenSSL command to decrypt it later. Provide the
+         * passphrase when prompted. </p> <p> <code>openssl rsa -in encrypted_key.pem -out
+         * decrypted_key.pem</code> </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/ExportCertificate">AWS
          * API Reference</a></p>
          */
@@ -315,13 +328,13 @@ namespace Model
 
         /**
          * <p>Exports a private certificate issued by a private certificate authority (CA)
-         * for use anywhere. The exported file contains the certificate, the certificate
-         * chain, and the encrypted private 2048-bit RSA key associated with the public key
-         * that is embedded in the certificate. For security, you must assign a passphrase
-         * for the private key when exporting it. </p> <p>For information about exporting
-         * and formatting a certificate using the ACM console or CLI, see <a
-         * href="https://docs.aws.amazon.com/acm/latest/userguide/gs-acm-export-private.html">Export
-         * a Private Certificate</a>.</p><p><h3>See Also:</h3>   <a
+         * for use anywhere. You can export the certificate, the certificate chain, and the
+         * encrypted private key associated with the public key embedded in the
+         * certificate. You must store the private key securely. The private key is a 2048
+         * bit RSA key. You must provide a passphrase for the private key when exporting
+         * it. You can use the following OpenSSL command to decrypt it later. Provide the
+         * passphrase when prompted. </p> <p> <code>openssl rsa -in encrypted_key.pem -out
+         * decrypted_key.pem</code> </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/ExportCertificate">AWS
          * API Reference</a></p>
          *
@@ -331,13 +344,13 @@ namespace Model
 
         /**
          * <p>Exports a private certificate issued by a private certificate authority (CA)
-         * for use anywhere. The exported file contains the certificate, the certificate
-         * chain, and the encrypted private 2048-bit RSA key associated with the public key
-         * that is embedded in the certificate. For security, you must assign a passphrase
-         * for the private key when exporting it. </p> <p>For information about exporting
-         * and formatting a certificate using the ACM console or CLI, see <a
-         * href="https://docs.aws.amazon.com/acm/latest/userguide/gs-acm-export-private.html">Export
-         * a Private Certificate</a>.</p><p><h3>See Also:</h3>   <a
+         * for use anywhere. You can export the certificate, the certificate chain, and the
+         * encrypted private key associated with the public key embedded in the
+         * certificate. You must store the private key securely. The private key is a 2048
+         * bit RSA key. You must provide a passphrase for the private key when exporting
+         * it. You can use the following OpenSSL command to decrypt it later. Provide the
+         * passphrase when prompted. </p> <p> <code>openssl rsa -in encrypted_key.pem -out
+         * decrypted_key.pem</code> </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/ExportCertificate">AWS
          * API Reference</a></p>
          *
@@ -346,26 +359,24 @@ namespace Model
         virtual void ExportCertificateAsync(const Model::ExportCertificateRequest& request, const ExportCertificateResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>Retrieves an Amazon-issued certificate and its certificate chain. The chain
-         * consists of the certificate of the issuing CA and the intermediate certificates
-         * of any other subordinate CAs. All of the certificates are base64 encoded. You
-         * can use <a
-         * href="https://wiki.openssl.org/index.php/Command_Line_Utilities">OpenSSL</a> to
-         * decode the certificates and inspect individual fields.</p><p><h3>See Also:</h3> 
-         * <a
+         * <p>Retrieves a certificate specified by an ARN and its certificate chain . The
+         * chain is an ordered list of certificates that contains the end entity
+         * certificate, intermediate certificates of subordinate CAs, and the root
+         * certificate in that order. The certificate and certificate chain are base64
+         * encoded. If you want to decode the certificate to see the individual fields, you
+         * can use OpenSSL.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/GetCertificate">AWS
          * API Reference</a></p>
          */
         virtual Model::GetCertificateOutcome GetCertificate(const Model::GetCertificateRequest& request) const;
 
         /**
-         * <p>Retrieves an Amazon-issued certificate and its certificate chain. The chain
-         * consists of the certificate of the issuing CA and the intermediate certificates
-         * of any other subordinate CAs. All of the certificates are base64 encoded. You
-         * can use <a
-         * href="https://wiki.openssl.org/index.php/Command_Line_Utilities">OpenSSL</a> to
-         * decode the certificates and inspect individual fields.</p><p><h3>See Also:</h3> 
-         * <a
+         * <p>Retrieves a certificate specified by an ARN and its certificate chain . The
+         * chain is an ordered list of certificates that contains the end entity
+         * certificate, intermediate certificates of subordinate CAs, and the root
+         * certificate in that order. The certificate and certificate chain are base64
+         * encoded. If you want to decode the certificate to see the individual fields, you
+         * can use OpenSSL.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/GetCertificate">AWS
          * API Reference</a></p>
          *
@@ -374,13 +385,12 @@ namespace Model
         virtual Model::GetCertificateOutcomeCallable GetCertificateCallable(const Model::GetCertificateRequest& request) const;
 
         /**
-         * <p>Retrieves an Amazon-issued certificate and its certificate chain. The chain
-         * consists of the certificate of the issuing CA and the intermediate certificates
-         * of any other subordinate CAs. All of the certificates are base64 encoded. You
-         * can use <a
-         * href="https://wiki.openssl.org/index.php/Command_Line_Utilities">OpenSSL</a> to
-         * decode the certificates and inspect individual fields.</p><p><h3>See Also:</h3> 
-         * <a
+         * <p>Retrieves a certificate specified by an ARN and its certificate chain . The
+         * chain is an ordered list of certificates that contains the end entity
+         * certificate, intermediate certificates of subordinate CAs, and the root
+         * certificate in that order. The certificate and certificate chain are base64
+         * encoded. If you want to decode the certificate to see the individual fields, you
+         * can use OpenSSL.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/GetCertificate">AWS
          * API Reference</a></p>
          *
@@ -398,10 +408,10 @@ namespace Model
          * documentation for each service. For more information about importing
          * certificates into ACM, see <a
          * href="https://docs.aws.amazon.com/acm/latest/userguide/import-certificate.html">Importing
-         * Certificates</a> in the <i>AWS Certificate Manager User Guide</i>. </p> 
+         * Certificates</a> in the <i>AWS Certificate Manager User Guide</i>. </p> <note>
          * <p>ACM does not provide <a
          * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-renewal.html">managed
-         * renewal</a> for certificates that you import.</p>  <p>Note the following
+         * renewal</a> for certificates that you import.</p> </note> <p>Note the following
          * guidelines when importing third party certificates:</p> <ul> <li> <p>You must
          * enter the private key that matches the certificate you are importing.</p> </li>
          * <li> <p>The private key must be unencrypted. You cannot import a private key
@@ -415,20 +425,17 @@ namespace Model
          * <code>Issuer</code> field must not be empty.</p> </li> <li> <p>The OCSP
          * authority URL, if present, must not exceed 1000 characters.</p> </li> <li> <p>To
          * import a new certificate, omit the <code>CertificateArn</code> argument. Include
-         * this argument only when you want to replace a previously imported certifica</p>
-         * </li> <li> <p>When you import a certificate by using the CLI, you must specify
-         * the certificate, the certificate chain, and the private key by their file names
-         * preceded by <code>file://</code>. For example, you can specify a certificate
-         * saved in the <code>C:\temp</code> folder as
+         * this argument only when you want to replace a previously imported
+         * certificate.</p> </li> <li> <p>When you import a certificate by using the CLI,
+         * you must specify the certificate, the certificate chain, and the private key by
+         * their file names preceded by <code>file://</code>. For example, you can specify
+         * a certificate saved in the <code>C:\temp</code> folder as
          * <code>file://C:\temp\certificate_to_import.pem</code>. If you are making an HTTP
          * or HTTPS Query request, include these arguments as BLOBs. </p> </li> <li>
          * <p>When you import a certificate by using an SDK, you must specify the
          * certificate, the certificate chain, and the private key files in the manner
-         * required by the programming language you're using. </p> </li> <li> <p>The
-         * cryptographic algorithm of an imported certificate must match the algorithm of
-         * the signing CA. For example, if the signing CA key type is RSA, then the
-         * certificate key type must also be RSA.</p> </li> </ul> <p>This operation returns
-         * the <a
+         * required by the programming language you're using. </p> </li> </ul> <p>This
+         * operation returns the <a
          * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">Amazon
          * Resource Name (ARN)</a> of the imported certificate.</p><p><h3>See Also:</h3>  
          * <a
@@ -447,10 +454,10 @@ namespace Model
          * documentation for each service. For more information about importing
          * certificates into ACM, see <a
          * href="https://docs.aws.amazon.com/acm/latest/userguide/import-certificate.html">Importing
-         * Certificates</a> in the <i>AWS Certificate Manager User Guide</i>. </p> 
+         * Certificates</a> in the <i>AWS Certificate Manager User Guide</i>. </p> <note>
          * <p>ACM does not provide <a
          * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-renewal.html">managed
-         * renewal</a> for certificates that you import.</p>  <p>Note the following
+         * renewal</a> for certificates that you import.</p> </note> <p>Note the following
          * guidelines when importing third party certificates:</p> <ul> <li> <p>You must
          * enter the private key that matches the certificate you are importing.</p> </li>
          * <li> <p>The private key must be unencrypted. You cannot import a private key
@@ -464,20 +471,17 @@ namespace Model
          * <code>Issuer</code> field must not be empty.</p> </li> <li> <p>The OCSP
          * authority URL, if present, must not exceed 1000 characters.</p> </li> <li> <p>To
          * import a new certificate, omit the <code>CertificateArn</code> argument. Include
-         * this argument only when you want to replace a previously imported certifica</p>
-         * </li> <li> <p>When you import a certificate by using the CLI, you must specify
-         * the certificate, the certificate chain, and the private key by their file names
-         * preceded by <code>file://</code>. For example, you can specify a certificate
-         * saved in the <code>C:\temp</code> folder as
+         * this argument only when you want to replace a previously imported
+         * certificate.</p> </li> <li> <p>When you import a certificate by using the CLI,
+         * you must specify the certificate, the certificate chain, and the private key by
+         * their file names preceded by <code>file://</code>. For example, you can specify
+         * a certificate saved in the <code>C:\temp</code> folder as
          * <code>file://C:\temp\certificate_to_import.pem</code>. If you are making an HTTP
          * or HTTPS Query request, include these arguments as BLOBs. </p> </li> <li>
          * <p>When you import a certificate by using an SDK, you must specify the
          * certificate, the certificate chain, and the private key files in the manner
-         * required by the programming language you're using. </p> </li> <li> <p>The
-         * cryptographic algorithm of an imported certificate must match the algorithm of
-         * the signing CA. For example, if the signing CA key type is RSA, then the
-         * certificate key type must also be RSA.</p> </li> </ul> <p>This operation returns
-         * the <a
+         * required by the programming language you're using. </p> </li> </ul> <p>This
+         * operation returns the <a
          * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">Amazon
          * Resource Name (ARN)</a> of the imported certificate.</p><p><h3>See Also:</h3>  
          * <a
@@ -498,10 +502,10 @@ namespace Model
          * documentation for each service. For more information about importing
          * certificates into ACM, see <a
          * href="https://docs.aws.amazon.com/acm/latest/userguide/import-certificate.html">Importing
-         * Certificates</a> in the <i>AWS Certificate Manager User Guide</i>. </p> 
+         * Certificates</a> in the <i>AWS Certificate Manager User Guide</i>. </p> <note>
          * <p>ACM does not provide <a
          * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-renewal.html">managed
-         * renewal</a> for certificates that you import.</p>  <p>Note the following
+         * renewal</a> for certificates that you import.</p> </note> <p>Note the following
          * guidelines when importing third party certificates:</p> <ul> <li> <p>You must
          * enter the private key that matches the certificate you are importing.</p> </li>
          * <li> <p>The private key must be unencrypted. You cannot import a private key
@@ -515,20 +519,17 @@ namespace Model
          * <code>Issuer</code> field must not be empty.</p> </li> <li> <p>The OCSP
          * authority URL, if present, must not exceed 1000 characters.</p> </li> <li> <p>To
          * import a new certificate, omit the <code>CertificateArn</code> argument. Include
-         * this argument only when you want to replace a previously imported certifica</p>
-         * </li> <li> <p>When you import a certificate by using the CLI, you must specify
-         * the certificate, the certificate chain, and the private key by their file names
-         * preceded by <code>file://</code>. For example, you can specify a certificate
-         * saved in the <code>C:\temp</code> folder as
+         * this argument only when you want to replace a previously imported
+         * certificate.</p> </li> <li> <p>When you import a certificate by using the CLI,
+         * you must specify the certificate, the certificate chain, and the private key by
+         * their file names preceded by <code>file://</code>. For example, you can specify
+         * a certificate saved in the <code>C:\temp</code> folder as
          * <code>file://C:\temp\certificate_to_import.pem</code>. If you are making an HTTP
          * or HTTPS Query request, include these arguments as BLOBs. </p> </li> <li>
          * <p>When you import a certificate by using an SDK, you must specify the
          * certificate, the certificate chain, and the private key files in the manner
-         * required by the programming language you're using. </p> </li> <li> <p>The
-         * cryptographic algorithm of an imported certificate must match the algorithm of
-         * the signing CA. For example, if the signing CA key type is RSA, then the
-         * certificate key type must also be RSA.</p> </li> </ul> <p>This operation returns
-         * the <a
+         * required by the programming language you're using. </p> </li> </ul> <p>This
+         * operation returns the <a
          * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">Amazon
          * Resource Name (ARN)</a> of the imported certificate.</p><p><h3>See Also:</h3>  
          * <a
@@ -542,9 +543,7 @@ namespace Model
         /**
          * <p>Retrieves a list of certificate ARNs and domain names. You can request that
          * only certificates that match a specific status be listed. You can also filter by
-         * specific attributes of the certificate. Default filtering returns only
-         * <code>RSA_2048</code> certificates. For more information, see
-         * <a>Filters</a>.</p><p><h3>See Also:</h3>   <a
+         * specific attributes of the certificate. </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/ListCertificates">AWS
          * API Reference</a></p>
          */
@@ -553,9 +552,7 @@ namespace Model
         /**
          * <p>Retrieves a list of certificate ARNs and domain names. You can request that
          * only certificates that match a specific status be listed. You can also filter by
-         * specific attributes of the certificate. Default filtering returns only
-         * <code>RSA_2048</code> certificates. For more information, see
-         * <a>Filters</a>.</p><p><h3>See Also:</h3>   <a
+         * specific attributes of the certificate. </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/ListCertificates">AWS
          * API Reference</a></p>
          *
@@ -566,9 +563,7 @@ namespace Model
         /**
          * <p>Retrieves a list of certificate ARNs and domain names. You can request that
          * only certificates that match a specific status be listed. You can also filter by
-         * specific attributes of the certificate. Default filtering returns only
-         * <code>RSA_2048</code> certificates. For more information, see
-         * <a>Filters</a>.</p><p><h3>See Also:</h3>   <a
+         * specific attributes of the certificate. </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/acm-2015-12-08/ListCertificates">AWS
          * API Reference</a></p>
          *
@@ -861,10 +856,11 @@ namespace Model
          */
         virtual void UpdateCertificateOptionsAsync(const Model::UpdateCertificateOptionsRequest& request, const UpdateCertificateOptionsResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
-
+      
       void OverrideEndpoint(const Aws::String& endpoint);
     private:
       void init(const Aws::Client::ClientConfiguration& clientConfiguration);
+        /**Async helpers**/
         void AddTagsToCertificateAsyncHelper(const Model::AddTagsToCertificateRequest& request, const AddTagsToCertificateResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void DeleteCertificateAsyncHelper(const Model::DeleteCertificateRequest& request, const DeleteCertificateResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void DescribeCertificateAsyncHelper(const Model::DescribeCertificateRequest& request, const DescribeCertificateResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
