@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/acm/ACM_EXPORTS.h>
@@ -11,7 +21,6 @@
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/acm/model/CertificateOptions.h>
 #include <aws/acm/model/DomainValidationOption.h>
-#include <aws/acm/model/Tag.h>
 #include <utility>
 
 namespace Aws
@@ -27,7 +36,7 @@ namespace Model
   {
   public:
     RequestCertificateRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -44,7 +53,7 @@ namespace Model
      * to secure with an ACM certificate. Use an asterisk (*) to create a wildcard
      * certificate that protects several sites in the same domain. For example,
      * *.example.com protects www.example.com, site.example.com, and
-     * images.example.com. </p> <p> The first domain name you enter cannot exceed 64
+     * images.example.com. </p> <p> The first domain name you enter cannot exceed 63
      * octets, including periods. Each subsequent Subject Alternative Name (SAN),
      * however, can be up to 253 octets in length. </p>
      */
@@ -55,7 +64,7 @@ namespace Model
      * to secure with an ACM certificate. Use an asterisk (*) to create a wildcard
      * certificate that protects several sites in the same domain. For example,
      * *.example.com protects www.example.com, site.example.com, and
-     * images.example.com. </p> <p> The first domain name you enter cannot exceed 64
+     * images.example.com. </p> <p> The first domain name you enter cannot exceed 63
      * octets, including periods. Each subsequent Subject Alternative Name (SAN),
      * however, can be up to 253 octets in length. </p>
      */
@@ -66,7 +75,7 @@ namespace Model
      * to secure with an ACM certificate. Use an asterisk (*) to create a wildcard
      * certificate that protects several sites in the same domain. For example,
      * *.example.com protects www.example.com, site.example.com, and
-     * images.example.com. </p> <p> The first domain name you enter cannot exceed 64
+     * images.example.com. </p> <p> The first domain name you enter cannot exceed 63
      * octets, including periods. Each subsequent Subject Alternative Name (SAN),
      * however, can be up to 253 octets in length. </p>
      */
@@ -77,7 +86,7 @@ namespace Model
      * to secure with an ACM certificate. Use an asterisk (*) to create a wildcard
      * certificate that protects several sites in the same domain. For example,
      * *.example.com protects www.example.com, site.example.com, and
-     * images.example.com. </p> <p> The first domain name you enter cannot exceed 64
+     * images.example.com. </p> <p> The first domain name you enter cannot exceed 63
      * octets, including periods. Each subsequent Subject Alternative Name (SAN),
      * however, can be up to 253 octets in length. </p>
      */
@@ -88,7 +97,7 @@ namespace Model
      * to secure with an ACM certificate. Use an asterisk (*) to create a wildcard
      * certificate that protects several sites in the same domain. For example,
      * *.example.com protects www.example.com, site.example.com, and
-     * images.example.com. </p> <p> The first domain name you enter cannot exceed 64
+     * images.example.com. </p> <p> The first domain name you enter cannot exceed 63
      * octets, including periods. Each subsequent Subject Alternative Name (SAN),
      * however, can be up to 253 octets in length. </p>
      */
@@ -99,7 +108,7 @@ namespace Model
      * to secure with an ACM certificate. Use an asterisk (*) to create a wildcard
      * certificate that protects several sites in the same domain. For example,
      * *.example.com protects www.example.com, site.example.com, and
-     * images.example.com. </p> <p> The first domain name you enter cannot exceed 64
+     * images.example.com. </p> <p> The first domain name you enter cannot exceed 63
      * octets, including periods. Each subsequent Subject Alternative Name (SAN),
      * however, can be up to 253 octets in length. </p>
      */
@@ -110,7 +119,7 @@ namespace Model
      * to secure with an ACM certificate. Use an asterisk (*) to create a wildcard
      * certificate that protects several sites in the same domain. For example,
      * *.example.com protects www.example.com, site.example.com, and
-     * images.example.com. </p> <p> The first domain name you enter cannot exceed 64
+     * images.example.com. </p> <p> The first domain name you enter cannot exceed 63
      * octets, including periods. Each subsequent Subject Alternative Name (SAN),
      * however, can be up to 253 octets in length. </p>
      */
@@ -121,7 +130,7 @@ namespace Model
      * to secure with an ACM certificate. Use an asterisk (*) to create a wildcard
      * certificate that protects several sites in the same domain. For example,
      * *.example.com protects www.example.com, site.example.com, and
-     * images.example.com. </p> <p> The first domain name you enter cannot exceed 64
+     * images.example.com. </p> <p> The first domain name you enter cannot exceed 63
      * octets, including periods. Each subsequent Subject Alternative Name (SAN),
      * however, can be up to 253 octets in length. </p>
      */
@@ -194,10 +203,10 @@ namespace Model
      * the ACM certificate. For example, add the name www.example.net to a certificate
      * for which the <code>DomainName</code> field is www.example.com if users can
      * reach your site by using either name. The maximum number of domain names that
-     * you can add to an ACM certificate is 100. However, the initial quota is 10
-     * domain names. If you need more than 10 names, you must request a quota increase.
+     * you can add to an ACM certificate is 100. However, the initial limit is 10
+     * domain names. If you need more than 10 names, you must request a limit increase.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Quotas</a>.</p>
+     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Limits</a>.</p>
      * <p> The maximum length of a SAN DNS name is 253 octets. The name is made up of
      * multiple labels separated by periods. No label can be longer than 63 octets.
      * Consider the following examples: </p> <ul> <li> <p> <code>(63 octets).(63
@@ -216,10 +225,10 @@ namespace Model
      * the ACM certificate. For example, add the name www.example.net to a certificate
      * for which the <code>DomainName</code> field is www.example.com if users can
      * reach your site by using either name. The maximum number of domain names that
-     * you can add to an ACM certificate is 100. However, the initial quota is 10
-     * domain names. If you need more than 10 names, you must request a quota increase.
+     * you can add to an ACM certificate is 100. However, the initial limit is 10
+     * domain names. If you need more than 10 names, you must request a limit increase.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Quotas</a>.</p>
+     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Limits</a>.</p>
      * <p> The maximum length of a SAN DNS name is 253 octets. The name is made up of
      * multiple labels separated by periods. No label can be longer than 63 octets.
      * Consider the following examples: </p> <ul> <li> <p> <code>(63 octets).(63
@@ -238,10 +247,10 @@ namespace Model
      * the ACM certificate. For example, add the name www.example.net to a certificate
      * for which the <code>DomainName</code> field is www.example.com if users can
      * reach your site by using either name. The maximum number of domain names that
-     * you can add to an ACM certificate is 100. However, the initial quota is 10
-     * domain names. If you need more than 10 names, you must request a quota increase.
+     * you can add to an ACM certificate is 100. However, the initial limit is 10
+     * domain names. If you need more than 10 names, you must request a limit increase.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Quotas</a>.</p>
+     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Limits</a>.</p>
      * <p> The maximum length of a SAN DNS name is 253 octets. The name is made up of
      * multiple labels separated by periods. No label can be longer than 63 octets.
      * Consider the following examples: </p> <ul> <li> <p> <code>(63 octets).(63
@@ -260,10 +269,10 @@ namespace Model
      * the ACM certificate. For example, add the name www.example.net to a certificate
      * for which the <code>DomainName</code> field is www.example.com if users can
      * reach your site by using either name. The maximum number of domain names that
-     * you can add to an ACM certificate is 100. However, the initial quota is 10
-     * domain names. If you need more than 10 names, you must request a quota increase.
+     * you can add to an ACM certificate is 100. However, the initial limit is 10
+     * domain names. If you need more than 10 names, you must request a limit increase.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Quotas</a>.</p>
+     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Limits</a>.</p>
      * <p> The maximum length of a SAN DNS name is 253 octets. The name is made up of
      * multiple labels separated by periods. No label can be longer than 63 octets.
      * Consider the following examples: </p> <ul> <li> <p> <code>(63 octets).(63
@@ -282,10 +291,10 @@ namespace Model
      * the ACM certificate. For example, add the name www.example.net to a certificate
      * for which the <code>DomainName</code> field is www.example.com if users can
      * reach your site by using either name. The maximum number of domain names that
-     * you can add to an ACM certificate is 100. However, the initial quota is 10
-     * domain names. If you need more than 10 names, you must request a quota increase.
+     * you can add to an ACM certificate is 100. However, the initial limit is 10
+     * domain names. If you need more than 10 names, you must request a limit increase.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Quotas</a>.</p>
+     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Limits</a>.</p>
      * <p> The maximum length of a SAN DNS name is 253 octets. The name is made up of
      * multiple labels separated by periods. No label can be longer than 63 octets.
      * Consider the following examples: </p> <ul> <li> <p> <code>(63 octets).(63
@@ -304,10 +313,10 @@ namespace Model
      * the ACM certificate. For example, add the name www.example.net to a certificate
      * for which the <code>DomainName</code> field is www.example.com if users can
      * reach your site by using either name. The maximum number of domain names that
-     * you can add to an ACM certificate is 100. However, the initial quota is 10
-     * domain names. If you need more than 10 names, you must request a quota increase.
+     * you can add to an ACM certificate is 100. However, the initial limit is 10
+     * domain names. If you need more than 10 names, you must request a limit increase.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Quotas</a>.</p>
+     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Limits</a>.</p>
      * <p> The maximum length of a SAN DNS name is 253 octets. The name is made up of
      * multiple labels separated by periods. No label can be longer than 63 octets.
      * Consider the following examples: </p> <ul> <li> <p> <code>(63 octets).(63
@@ -326,10 +335,10 @@ namespace Model
      * the ACM certificate. For example, add the name www.example.net to a certificate
      * for which the <code>DomainName</code> field is www.example.com if users can
      * reach your site by using either name. The maximum number of domain names that
-     * you can add to an ACM certificate is 100. However, the initial quota is 10
-     * domain names. If you need more than 10 names, you must request a quota increase.
+     * you can add to an ACM certificate is 100. However, the initial limit is 10
+     * domain names. If you need more than 10 names, you must request a limit increase.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Quotas</a>.</p>
+     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Limits</a>.</p>
      * <p> The maximum length of a SAN DNS name is 253 octets. The name is made up of
      * multiple labels separated by periods. No label can be longer than 63 octets.
      * Consider the following examples: </p> <ul> <li> <p> <code>(63 octets).(63
@@ -348,10 +357,10 @@ namespace Model
      * the ACM certificate. For example, add the name www.example.net to a certificate
      * for which the <code>DomainName</code> field is www.example.com if users can
      * reach your site by using either name. The maximum number of domain names that
-     * you can add to an ACM certificate is 100. However, the initial quota is 10
-     * domain names. If you need more than 10 names, you must request a quota increase.
+     * you can add to an ACM certificate is 100. However, the initial limit is 10
+     * domain names. If you need more than 10 names, you must request a limit increase.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Quotas</a>.</p>
+     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Limits</a>.</p>
      * <p> The maximum length of a SAN DNS name is 253 octets. The name is made up of
      * multiple labels separated by periods. No label can be longer than 63 octets.
      * Consider the following examples: </p> <ul> <li> <p> <code>(63 octets).(63
@@ -370,10 +379,10 @@ namespace Model
      * the ACM certificate. For example, add the name www.example.net to a certificate
      * for which the <code>DomainName</code> field is www.example.com if users can
      * reach your site by using either name. The maximum number of domain names that
-     * you can add to an ACM certificate is 100. However, the initial quota is 10
-     * domain names. If you need more than 10 names, you must request a quota increase.
+     * you can add to an ACM certificate is 100. However, the initial limit is 10
+     * domain names. If you need more than 10 names, you must request a limit increase.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Quotas</a>.</p>
+     * href="https://docs.aws.amazon.com/acm/latest/userguide/acm-limits.html">Limits</a>.</p>
      * <p> The maximum length of a SAN DNS name is 253 octets. The name is made up of
      * multiple labels separated by periods. No label can be longer than 63 octets.
      * Consider the following examples: </p> <ul> <li> <p> <code>(63 octets).(63
@@ -697,47 +706,6 @@ namespace Model
      */
     inline RequestCertificateRequest& WithCertificateAuthorityArn(const char* value) { SetCertificateAuthorityArn(value); return *this;}
 
-
-    /**
-     * <p>One or more resource tags to associate with the certificate.</p>
-     */
-    inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
-
-    /**
-     * <p>One or more resource tags to associate with the certificate.</p>
-     */
-    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
-
-    /**
-     * <p>One or more resource tags to associate with the certificate.</p>
-     */
-    inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
-
-    /**
-     * <p>One or more resource tags to associate with the certificate.</p>
-     */
-    inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
-
-    /**
-     * <p>One or more resource tags to associate with the certificate.</p>
-     */
-    inline RequestCertificateRequest& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
-
-    /**
-     * <p>One or more resource tags to associate with the certificate.</p>
-     */
-    inline RequestCertificateRequest& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
-
-    /**
-     * <p>One or more resource tags to associate with the certificate.</p>
-     */
-    inline RequestCertificateRequest& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
-
-    /**
-     * <p>One or more resource tags to associate with the certificate.</p>
-     */
-    inline RequestCertificateRequest& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
-
   private:
 
     Aws::String m_domainName;
@@ -760,9 +728,6 @@ namespace Model
 
     Aws::String m_certificateAuthorityArn;
     bool m_certificateAuthorityArnHasBeenSet;
-
-    Aws::Vector<Tag> m_tags;
-    bool m_tagsHasBeenSet;
   };
 
 } // namespace Model
