@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/alexaforbusiness/model/CreateProfileRequest.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -22,7 +32,6 @@ CreateProfileRequest::CreateProfileRequest() :
     m_temperatureUnitHasBeenSet(false),
     m_wakeWord(WakeWord::NOT_SET),
     m_wakeWordHasBeenSet(false),
-    m_localeHasBeenSet(false),
     m_clientRequestToken(Aws::Utils::UUID::RandomUUID()),
     m_clientRequestTokenHasBeenSet(true),
     m_setupModeDisabled(false),
@@ -30,11 +39,7 @@ CreateProfileRequest::CreateProfileRequest() :
     m_maxVolumeLimit(0),
     m_maxVolumeLimitHasBeenSet(false),
     m_pSTNEnabled(false),
-    m_pSTNEnabledHasBeenSet(false),
-    m_dataRetentionOptIn(false),
-    m_dataRetentionOptInHasBeenSet(false),
-    m_meetingRoomConfigurationHasBeenSet(false),
-    m_tagsHasBeenSet(false)
+    m_pSTNEnabledHasBeenSet(false)
 {
 }
 
@@ -75,12 +80,6 @@ Aws::String CreateProfileRequest::SerializePayload() const
    payload.WithString("WakeWord", WakeWordMapper::GetNameForWakeWord(m_wakeWord));
   }
 
-  if(m_localeHasBeenSet)
-  {
-   payload.WithString("Locale", m_locale);
-
-  }
-
   if(m_clientRequestTokenHasBeenSet)
   {
    payload.WithString("ClientRequestToken", m_clientRequestToken);
@@ -105,29 +104,6 @@ Aws::String CreateProfileRequest::SerializePayload() const
 
   }
 
-  if(m_dataRetentionOptInHasBeenSet)
-  {
-   payload.WithBool("DataRetentionOptIn", m_dataRetentionOptIn);
-
-  }
-
-  if(m_meetingRoomConfigurationHasBeenSet)
-  {
-   payload.WithObject("MeetingRoomConfiguration", m_meetingRoomConfiguration.Jsonize());
-
-  }
-
-  if(m_tagsHasBeenSet)
-  {
-   Array<JsonValue> tagsJsonList(m_tags.size());
-   for(unsigned tagsIndex = 0; tagsIndex < tagsJsonList.GetLength(); ++tagsIndex)
-   {
-     tagsJsonList[tagsIndex].AsObject(m_tags[tagsIndex].Jsonize());
-   }
-   payload.WithArray("Tags", std::move(tagsJsonList));
-
-  }
-
   return payload.View().WriteReadable();
 }
 
