@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/apigateway/APIGateway_EXPORTS.h>
@@ -10,7 +20,6 @@
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/apigateway/model/ApiKeySourceType.h>
 #include <aws/apigateway/model/EndpointConfiguration.h>
-#include <aws/core/utils/memory/stl/AWSMap.h>
 #include <utility>
 
 namespace Aws
@@ -30,7 +39,7 @@ namespace Model
   {
   public:
     CreateRestApiRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -301,7 +310,7 @@ namespace Model
      * Valid values are: <ul><li><code>HEADER</code> to read the API key from the
      * <code>X-API-Key</code> header of a request. </li><li><code>AUTHORIZER</code> to
      * read the API key from the <code>UsageIdentifierKey</code> from a custom
-     * authorizer.</li></ul></p>
+     * authorizer.</li></ul> </p>
      */
     inline const ApiKeySourceType& GetApiKeySource() const{ return m_apiKeySource; }
 
@@ -310,7 +319,7 @@ namespace Model
      * Valid values are: <ul><li><code>HEADER</code> to read the API key from the
      * <code>X-API-Key</code> header of a request. </li><li><code>AUTHORIZER</code> to
      * read the API key from the <code>UsageIdentifierKey</code> from a custom
-     * authorizer.</li></ul></p>
+     * authorizer.</li></ul> </p>
      */
     inline bool ApiKeySourceHasBeenSet() const { return m_apiKeySourceHasBeenSet; }
 
@@ -319,7 +328,7 @@ namespace Model
      * Valid values are: <ul><li><code>HEADER</code> to read the API key from the
      * <code>X-API-Key</code> header of a request. </li><li><code>AUTHORIZER</code> to
      * read the API key from the <code>UsageIdentifierKey</code> from a custom
-     * authorizer.</li></ul></p>
+     * authorizer.</li></ul> </p>
      */
     inline void SetApiKeySource(const ApiKeySourceType& value) { m_apiKeySourceHasBeenSet = true; m_apiKeySource = value; }
 
@@ -328,7 +337,7 @@ namespace Model
      * Valid values are: <ul><li><code>HEADER</code> to read the API key from the
      * <code>X-API-Key</code> header of a request. </li><li><code>AUTHORIZER</code> to
      * read the API key from the <code>UsageIdentifierKey</code> from a custom
-     * authorizer.</li></ul></p>
+     * authorizer.</li></ul> </p>
      */
     inline void SetApiKeySource(ApiKeySourceType&& value) { m_apiKeySourceHasBeenSet = true; m_apiKeySource = std::move(value); }
 
@@ -337,7 +346,7 @@ namespace Model
      * Valid values are: <ul><li><code>HEADER</code> to read the API key from the
      * <code>X-API-Key</code> header of a request. </li><li><code>AUTHORIZER</code> to
      * read the API key from the <code>UsageIdentifierKey</code> from a custom
-     * authorizer.</li></ul></p>
+     * authorizer.</li></ul> </p>
      */
     inline CreateRestApiRequest& WithApiKeySource(const ApiKeySourceType& value) { SetApiKeySource(value); return *this;}
 
@@ -346,44 +355,44 @@ namespace Model
      * Valid values are: <ul><li><code>HEADER</code> to read the API key from the
      * <code>X-API-Key</code> header of a request. </li><li><code>AUTHORIZER</code> to
      * read the API key from the <code>UsageIdentifierKey</code> from a custom
-     * authorizer.</li></ul></p>
+     * authorizer.</li></ul> </p>
      */
     inline CreateRestApiRequest& WithApiKeySource(ApiKeySourceType&& value) { SetApiKeySource(std::move(value)); return *this;}
 
 
     /**
      * <p>The endpoint configuration of this <a>RestApi</a> showing the endpoint types
-     * of the API.</p>
+     * of the API. </p>
      */
     inline const EndpointConfiguration& GetEndpointConfiguration() const{ return m_endpointConfiguration; }
 
     /**
      * <p>The endpoint configuration of this <a>RestApi</a> showing the endpoint types
-     * of the API.</p>
+     * of the API. </p>
      */
     inline bool EndpointConfigurationHasBeenSet() const { return m_endpointConfigurationHasBeenSet; }
 
     /**
      * <p>The endpoint configuration of this <a>RestApi</a> showing the endpoint types
-     * of the API.</p>
+     * of the API. </p>
      */
     inline void SetEndpointConfiguration(const EndpointConfiguration& value) { m_endpointConfigurationHasBeenSet = true; m_endpointConfiguration = value; }
 
     /**
      * <p>The endpoint configuration of this <a>RestApi</a> showing the endpoint types
-     * of the API.</p>
+     * of the API. </p>
      */
     inline void SetEndpointConfiguration(EndpointConfiguration&& value) { m_endpointConfigurationHasBeenSet = true; m_endpointConfiguration = std::move(value); }
 
     /**
      * <p>The endpoint configuration of this <a>RestApi</a> showing the endpoint types
-     * of the API.</p>
+     * of the API. </p>
      */
     inline CreateRestApiRequest& WithEndpointConfiguration(const EndpointConfiguration& value) { SetEndpointConfiguration(value); return *this;}
 
     /**
      * <p>The endpoint configuration of this <a>RestApi</a> showing the endpoint types
-     * of the API.</p>
+     * of the API. </p>
      */
     inline CreateRestApiRequest& WithEndpointConfiguration(EndpointConfiguration&& value) { SetEndpointConfiguration(std::move(value)); return *this;}
 
@@ -436,135 +445,6 @@ namespace Model
      */
     inline CreateRestApiRequest& WithPolicy(const char* value) { SetPolicy(value); return *this;}
 
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tagsHasBeenSet = true; m_tags = value; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline CreateRestApiRequest& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline CreateRestApiRequest& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline CreateRestApiRequest& AddTags(const Aws::String& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline CreateRestApiRequest& AddTags(Aws::String&& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline CreateRestApiRequest& AddTags(const Aws::String& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline CreateRestApiRequest& AddTags(Aws::String&& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), std::move(value)); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline CreateRestApiRequest& AddTags(const char* key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline CreateRestApiRequest& AddTags(Aws::String&& key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with <code>aws:</code>.
-     * The tag value can be up to 256 characters.</p>
-     */
-    inline CreateRestApiRequest& AddTags(const char* key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
-
-
-    /**
-     * <p>Specifies whether clients can invoke your API by using the default
-     * <code>execute-api</code> endpoint. By default, clients can invoke your API with
-     * the default https://{api_id}.execute-api.{region}.amazonaws.com endpoint. To
-     * require that clients use a custom domain name to invoke your API, disable the
-     * default endpoint.</p>
-     */
-    inline bool GetDisableExecuteApiEndpoint() const{ return m_disableExecuteApiEndpoint; }
-
-    /**
-     * <p>Specifies whether clients can invoke your API by using the default
-     * <code>execute-api</code> endpoint. By default, clients can invoke your API with
-     * the default https://{api_id}.execute-api.{region}.amazonaws.com endpoint. To
-     * require that clients use a custom domain name to invoke your API, disable the
-     * default endpoint.</p>
-     */
-    inline bool DisableExecuteApiEndpointHasBeenSet() const { return m_disableExecuteApiEndpointHasBeenSet; }
-
-    /**
-     * <p>Specifies whether clients can invoke your API by using the default
-     * <code>execute-api</code> endpoint. By default, clients can invoke your API with
-     * the default https://{api_id}.execute-api.{region}.amazonaws.com endpoint. To
-     * require that clients use a custom domain name to invoke your API, disable the
-     * default endpoint.</p>
-     */
-    inline void SetDisableExecuteApiEndpoint(bool value) { m_disableExecuteApiEndpointHasBeenSet = true; m_disableExecuteApiEndpoint = value; }
-
-    /**
-     * <p>Specifies whether clients can invoke your API by using the default
-     * <code>execute-api</code> endpoint. By default, clients can invoke your API with
-     * the default https://{api_id}.execute-api.{region}.amazonaws.com endpoint. To
-     * require that clients use a custom domain name to invoke your API, disable the
-     * default endpoint.</p>
-     */
-    inline CreateRestApiRequest& WithDisableExecuteApiEndpoint(bool value) { SetDisableExecuteApiEndpoint(value); return *this;}
-
   private:
 
     Aws::String m_name;
@@ -593,12 +473,6 @@ namespace Model
 
     Aws::String m_policy;
     bool m_policyHasBeenSet;
-
-    Aws::Map<Aws::String, Aws::String> m_tags;
-    bool m_tagsHasBeenSet;
-
-    bool m_disableExecuteApiEndpoint;
-    bool m_disableExecuteApiEndpointHasBeenSet;
   };
 
 } // namespace Model
