@@ -1,17 +1,23 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/apigateway/APIGateway_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/DateTime.h>
 #include <aws/apigateway/model/EndpointConfiguration.h>
-#include <aws/apigateway/model/DomainNameStatus.h>
-#include <aws/apigateway/model/SecurityPolicy.h>
-#include <aws/core/utils/memory/stl/AWSMap.h>
-#include <aws/apigateway/model/MutualTlsAuthentication.h>
 #include <utility>
 
 namespace Aws
@@ -622,240 +628,6 @@ namespace Model
      */
     inline GetDomainNameResult& WithEndpointConfiguration(EndpointConfiguration&& value) { SetEndpointConfiguration(std::move(value)); return *this;}
 
-
-    /**
-     * <p>The status of the <a>DomainName</a> migration. The valid values are
-     * <code>AVAILABLE</code> and <code>UPDATING</code>. If the status is
-     * <code>UPDATING</code>, the domain cannot be modified further until the existing
-     * operation is complete. If it is <code>AVAILABLE</code>, the domain can be
-     * updated.</p>
-     */
-    inline const DomainNameStatus& GetDomainNameStatus() const{ return m_domainNameStatus; }
-
-    /**
-     * <p>The status of the <a>DomainName</a> migration. The valid values are
-     * <code>AVAILABLE</code> and <code>UPDATING</code>. If the status is
-     * <code>UPDATING</code>, the domain cannot be modified further until the existing
-     * operation is complete. If it is <code>AVAILABLE</code>, the domain can be
-     * updated.</p>
-     */
-    inline void SetDomainNameStatus(const DomainNameStatus& value) { m_domainNameStatus = value; }
-
-    /**
-     * <p>The status of the <a>DomainName</a> migration. The valid values are
-     * <code>AVAILABLE</code> and <code>UPDATING</code>. If the status is
-     * <code>UPDATING</code>, the domain cannot be modified further until the existing
-     * operation is complete. If it is <code>AVAILABLE</code>, the domain can be
-     * updated.</p>
-     */
-    inline void SetDomainNameStatus(DomainNameStatus&& value) { m_domainNameStatus = std::move(value); }
-
-    /**
-     * <p>The status of the <a>DomainName</a> migration. The valid values are
-     * <code>AVAILABLE</code> and <code>UPDATING</code>. If the status is
-     * <code>UPDATING</code>, the domain cannot be modified further until the existing
-     * operation is complete. If it is <code>AVAILABLE</code>, the domain can be
-     * updated.</p>
-     */
-    inline GetDomainNameResult& WithDomainNameStatus(const DomainNameStatus& value) { SetDomainNameStatus(value); return *this;}
-
-    /**
-     * <p>The status of the <a>DomainName</a> migration. The valid values are
-     * <code>AVAILABLE</code> and <code>UPDATING</code>. If the status is
-     * <code>UPDATING</code>, the domain cannot be modified further until the existing
-     * operation is complete. If it is <code>AVAILABLE</code>, the domain can be
-     * updated.</p>
-     */
-    inline GetDomainNameResult& WithDomainNameStatus(DomainNameStatus&& value) { SetDomainNameStatus(std::move(value)); return *this;}
-
-
-    /**
-     * <p>An optional text message containing detailed information about status of the
-     * <a>DomainName</a> migration.</p>
-     */
-    inline const Aws::String& GetDomainNameStatusMessage() const{ return m_domainNameStatusMessage; }
-
-    /**
-     * <p>An optional text message containing detailed information about status of the
-     * <a>DomainName</a> migration.</p>
-     */
-    inline void SetDomainNameStatusMessage(const Aws::String& value) { m_domainNameStatusMessage = value; }
-
-    /**
-     * <p>An optional text message containing detailed information about status of the
-     * <a>DomainName</a> migration.</p>
-     */
-    inline void SetDomainNameStatusMessage(Aws::String&& value) { m_domainNameStatusMessage = std::move(value); }
-
-    /**
-     * <p>An optional text message containing detailed information about status of the
-     * <a>DomainName</a> migration.</p>
-     */
-    inline void SetDomainNameStatusMessage(const char* value) { m_domainNameStatusMessage.assign(value); }
-
-    /**
-     * <p>An optional text message containing detailed information about status of the
-     * <a>DomainName</a> migration.</p>
-     */
-    inline GetDomainNameResult& WithDomainNameStatusMessage(const Aws::String& value) { SetDomainNameStatusMessage(value); return *this;}
-
-    /**
-     * <p>An optional text message containing detailed information about status of the
-     * <a>DomainName</a> migration.</p>
-     */
-    inline GetDomainNameResult& WithDomainNameStatusMessage(Aws::String&& value) { SetDomainNameStatusMessage(std::move(value)); return *this;}
-
-    /**
-     * <p>An optional text message containing detailed information about status of the
-     * <a>DomainName</a> migration.</p>
-     */
-    inline GetDomainNameResult& WithDomainNameStatusMessage(const char* value) { SetDomainNameStatusMessage(value); return *this;}
-
-
-    /**
-     * <p>The Transport Layer Security (TLS) version + cipher suite for this
-     * <a>DomainName</a>. The valid values are <code>TLS_1_0</code> and
-     * <code>TLS_1_2</code>.</p>
-     */
-    inline const SecurityPolicy& GetSecurityPolicy() const{ return m_securityPolicy; }
-
-    /**
-     * <p>The Transport Layer Security (TLS) version + cipher suite for this
-     * <a>DomainName</a>. The valid values are <code>TLS_1_0</code> and
-     * <code>TLS_1_2</code>.</p>
-     */
-    inline void SetSecurityPolicy(const SecurityPolicy& value) { m_securityPolicy = value; }
-
-    /**
-     * <p>The Transport Layer Security (TLS) version + cipher suite for this
-     * <a>DomainName</a>. The valid values are <code>TLS_1_0</code> and
-     * <code>TLS_1_2</code>.</p>
-     */
-    inline void SetSecurityPolicy(SecurityPolicy&& value) { m_securityPolicy = std::move(value); }
-
-    /**
-     * <p>The Transport Layer Security (TLS) version + cipher suite for this
-     * <a>DomainName</a>. The valid values are <code>TLS_1_0</code> and
-     * <code>TLS_1_2</code>.</p>
-     */
-    inline GetDomainNameResult& WithSecurityPolicy(const SecurityPolicy& value) { SetSecurityPolicy(value); return *this;}
-
-    /**
-     * <p>The Transport Layer Security (TLS) version + cipher suite for this
-     * <a>DomainName</a>. The valid values are <code>TLS_1_0</code> and
-     * <code>TLS_1_2</code>.</p>
-     */
-    inline GetDomainNameResult& WithSecurityPolicy(SecurityPolicy&& value) { SetSecurityPolicy(std::move(value)); return *this;}
-
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tags = value; }
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tags = std::move(value); }
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline GetDomainNameResult& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline GetDomainNameResult& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline GetDomainNameResult& AddTags(const Aws::String& key, const Aws::String& value) { m_tags.emplace(key, value); return *this; }
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline GetDomainNameResult& AddTags(Aws::String&& key, const Aws::String& value) { m_tags.emplace(std::move(key), value); return *this; }
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline GetDomainNameResult& AddTags(const Aws::String& key, Aws::String&& value) { m_tags.emplace(key, std::move(value)); return *this; }
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline GetDomainNameResult& AddTags(Aws::String&& key, Aws::String&& value) { m_tags.emplace(std::move(key), std::move(value)); return *this; }
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline GetDomainNameResult& AddTags(const char* key, Aws::String&& value) { m_tags.emplace(key, std::move(value)); return *this; }
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline GetDomainNameResult& AddTags(Aws::String&& key, const char* value) { m_tags.emplace(std::move(key), value); return *this; }
-
-    /**
-     * <p>The collection of tags. Each tag element is associated with a given
-     * resource.</p>
-     */
-    inline GetDomainNameResult& AddTags(const char* key, const char* value) { m_tags.emplace(key, value); return *this; }
-
-
-    /**
-     * <p>The mutual TLS authentication configuration for a custom domain name. If
-     * specified, API Gateway performs two-way authentication between the client and
-     * the server. Clients must present a trusted certificate to access your API.</p>
-     */
-    inline const MutualTlsAuthentication& GetMutualTlsAuthentication() const{ return m_mutualTlsAuthentication; }
-
-    /**
-     * <p>The mutual TLS authentication configuration for a custom domain name. If
-     * specified, API Gateway performs two-way authentication between the client and
-     * the server. Clients must present a trusted certificate to access your API.</p>
-     */
-    inline void SetMutualTlsAuthentication(const MutualTlsAuthentication& value) { m_mutualTlsAuthentication = value; }
-
-    /**
-     * <p>The mutual TLS authentication configuration for a custom domain name. If
-     * specified, API Gateway performs two-way authentication between the client and
-     * the server. Clients must present a trusted certificate to access your API.</p>
-     */
-    inline void SetMutualTlsAuthentication(MutualTlsAuthentication&& value) { m_mutualTlsAuthentication = std::move(value); }
-
-    /**
-     * <p>The mutual TLS authentication configuration for a custom domain name. If
-     * specified, API Gateway performs two-way authentication between the client and
-     * the server. Clients must present a trusted certificate to access your API.</p>
-     */
-    inline GetDomainNameResult& WithMutualTlsAuthentication(const MutualTlsAuthentication& value) { SetMutualTlsAuthentication(value); return *this;}
-
-    /**
-     * <p>The mutual TLS authentication configuration for a custom domain name. If
-     * specified, API Gateway performs two-way authentication between the client and
-     * the server. Clients must present a trusted certificate to access your API.</p>
-     */
-    inline GetDomainNameResult& WithMutualTlsAuthentication(MutualTlsAuthentication&& value) { SetMutualTlsAuthentication(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_domainName;
@@ -879,16 +651,6 @@ namespace Model
     Aws::String m_distributionHostedZoneId;
 
     EndpointConfiguration m_endpointConfiguration;
-
-    DomainNameStatus m_domainNameStatus;
-
-    Aws::String m_domainNameStatusMessage;
-
-    SecurityPolicy m_securityPolicy;
-
-    Aws::Map<Aws::String, Aws::String> m_tags;
-
-    MutualTlsAuthentication m_mutualTlsAuthentication;
   };
 
 } // namespace Model
