@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/apigateway/APIGateway_EXPORTS.h>
@@ -11,7 +21,6 @@
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/apigateway/model/ContentHandlingStrategy.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/apigateway/model/TlsConfig.h>
 #include <aws/apigateway/model/IntegrationResponse.h>
 #include <utility>
 
@@ -1034,7 +1043,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline const ContentHandlingStrategy& GetContentHandling() const{ return m_contentHandling; }
@@ -1048,7 +1057,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline void SetContentHandling(const ContentHandlingStrategy& value) { m_contentHandling = value; }
@@ -1062,7 +1071,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline void SetContentHandling(ContentHandlingStrategy&& value) { m_contentHandling = std::move(value); }
@@ -1076,7 +1085,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline GetIntegrationResult& WithContentHandling(const ContentHandlingStrategy& value) { SetContentHandling(value); return *this;}
@@ -1090,7 +1099,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline GetIntegrationResult& WithContentHandling(ContentHandlingStrategy&& value) { SetContentHandling(std::move(value)); return *this;}
@@ -1116,115 +1125,78 @@ namespace Model
 
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies the integration's cache namespace.</p>
      */
     inline const Aws::String& GetCacheNamespace() const{ return m_cacheNamespace; }
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies the integration's cache namespace.</p>
      */
     inline void SetCacheNamespace(const Aws::String& value) { m_cacheNamespace = value; }
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies the integration's cache namespace.</p>
      */
     inline void SetCacheNamespace(Aws::String&& value) { m_cacheNamespace = std::move(value); }
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies the integration's cache namespace.</p>
      */
     inline void SetCacheNamespace(const char* value) { m_cacheNamespace.assign(value); }
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies the integration's cache namespace.</p>
      */
     inline GetIntegrationResult& WithCacheNamespace(const Aws::String& value) { SetCacheNamespace(value); return *this;}
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies the integration's cache namespace.</p>
      */
     inline GetIntegrationResult& WithCacheNamespace(Aws::String&& value) { SetCacheNamespace(std::move(value)); return *this;}
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies the integration's cache namespace.</p>
      */
     inline GetIntegrationResult& WithCacheNamespace(const char* value) { SetCacheNamespace(value); return *this;}
 
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies the integration's cache key parameters.</p>
      */
     inline const Aws::Vector<Aws::String>& GetCacheKeyParameters() const{ return m_cacheKeyParameters; }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies the integration's cache key parameters.</p>
      */
     inline void SetCacheKeyParameters(const Aws::Vector<Aws::String>& value) { m_cacheKeyParameters = value; }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies the integration's cache key parameters.</p>
      */
     inline void SetCacheKeyParameters(Aws::Vector<Aws::String>&& value) { m_cacheKeyParameters = std::move(value); }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies the integration's cache key parameters.</p>
      */
     inline GetIntegrationResult& WithCacheKeyParameters(const Aws::Vector<Aws::String>& value) { SetCacheKeyParameters(value); return *this;}
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies the integration's cache key parameters.</p>
      */
     inline GetIntegrationResult& WithCacheKeyParameters(Aws::Vector<Aws::String>&& value) { SetCacheKeyParameters(std::move(value)); return *this;}
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies the integration's cache key parameters.</p>
      */
     inline GetIntegrationResult& AddCacheKeyParameters(const Aws::String& value) { m_cacheKeyParameters.push_back(value); return *this; }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies the integration's cache key parameters.</p>
      */
     inline GetIntegrationResult& AddCacheKeyParameters(Aws::String&& value) { m_cacheKeyParameters.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies the integration's cache key parameters.</p>
      */
     inline GetIntegrationResult& AddCacheKeyParameters(const char* value) { m_cacheKeyParameters.push_back(value); return *this; }
 
@@ -1537,32 +1509,6 @@ namespace Model
      */
     inline GetIntegrationResult& AddIntegrationResponses(const char* key, const IntegrationResponse& value) { m_integrationResponses.emplace(key, value); return *this; }
 
-
-    /**
-     * <p>Specifies the TLS configuration for an integration.</p>
-     */
-    inline const TlsConfig& GetTlsConfig() const{ return m_tlsConfig; }
-
-    /**
-     * <p>Specifies the TLS configuration for an integration.</p>
-     */
-    inline void SetTlsConfig(const TlsConfig& value) { m_tlsConfig = value; }
-
-    /**
-     * <p>Specifies the TLS configuration for an integration.</p>
-     */
-    inline void SetTlsConfig(TlsConfig&& value) { m_tlsConfig = std::move(value); }
-
-    /**
-     * <p>Specifies the TLS configuration for an integration.</p>
-     */
-    inline GetIntegrationResult& WithTlsConfig(const TlsConfig& value) { SetTlsConfig(value); return *this;}
-
-    /**
-     * <p>Specifies the TLS configuration for an integration.</p>
-     */
-    inline GetIntegrationResult& WithTlsConfig(TlsConfig&& value) { SetTlsConfig(std::move(value)); return *this;}
-
   private:
 
     IntegrationType m_type;
@@ -1592,8 +1538,6 @@ namespace Model
     Aws::Vector<Aws::String> m_cacheKeyParameters;
 
     Aws::Map<Aws::String, IntegrationResponse> m_integrationResponses;
-
-    TlsConfig m_tlsConfig;
   };
 
 } // namespace Model
