@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/apigateway/APIGateway_EXPORTS.h>
@@ -12,7 +22,6 @@
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/apigateway/model/ContentHandlingStrategy.h>
-#include <aws/apigateway/model/TlsConfig.h>
 #include <utility>
 
 namespace Aws
@@ -31,7 +40,7 @@ namespace Model
   {
   public:
     PutIntegrationRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -1070,130 +1079,88 @@ namespace Model
 
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies a put integration input's cache namespace.</p>
      */
     inline const Aws::String& GetCacheNamespace() const{ return m_cacheNamespace; }
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies a put integration input's cache namespace.</p>
      */
     inline bool CacheNamespaceHasBeenSet() const { return m_cacheNamespaceHasBeenSet; }
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies a put integration input's cache namespace.</p>
      */
     inline void SetCacheNamespace(const Aws::String& value) { m_cacheNamespaceHasBeenSet = true; m_cacheNamespace = value; }
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies a put integration input's cache namespace.</p>
      */
     inline void SetCacheNamespace(Aws::String&& value) { m_cacheNamespaceHasBeenSet = true; m_cacheNamespace = std::move(value); }
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies a put integration input's cache namespace.</p>
      */
     inline void SetCacheNamespace(const char* value) { m_cacheNamespaceHasBeenSet = true; m_cacheNamespace.assign(value); }
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies a put integration input's cache namespace.</p>
      */
     inline PutIntegrationRequest& WithCacheNamespace(const Aws::String& value) { SetCacheNamespace(value); return *this;}
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies a put integration input's cache namespace.</p>
      */
     inline PutIntegrationRequest& WithCacheNamespace(Aws::String&& value) { SetCacheNamespace(std::move(value)); return *this;}
 
     /**
-     * <p>Specifies a group of related cached parameters. By default, API Gateway uses
-     * the resource ID as the <code>cacheNamespace</code>. You can specify the same
-     * <code>cacheNamespace</code> across resources to return the same cached data for
-     * requests to different resources.</p>
+     * <p>Specifies a put integration input's cache namespace.</p>
      */
     inline PutIntegrationRequest& WithCacheNamespace(const char* value) { SetCacheNamespace(value); return *this;}
 
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies a put integration input's cache key parameters.</p>
      */
     inline const Aws::Vector<Aws::String>& GetCacheKeyParameters() const{ return m_cacheKeyParameters; }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies a put integration input's cache key parameters.</p>
      */
     inline bool CacheKeyParametersHasBeenSet() const { return m_cacheKeyParametersHasBeenSet; }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies a put integration input's cache key parameters.</p>
      */
     inline void SetCacheKeyParameters(const Aws::Vector<Aws::String>& value) { m_cacheKeyParametersHasBeenSet = true; m_cacheKeyParameters = value; }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies a put integration input's cache key parameters.</p>
      */
     inline void SetCacheKeyParameters(Aws::Vector<Aws::String>&& value) { m_cacheKeyParametersHasBeenSet = true; m_cacheKeyParameters = std::move(value); }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies a put integration input's cache key parameters.</p>
      */
     inline PutIntegrationRequest& WithCacheKeyParameters(const Aws::Vector<Aws::String>& value) { SetCacheKeyParameters(value); return *this;}
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies a put integration input's cache key parameters.</p>
      */
     inline PutIntegrationRequest& WithCacheKeyParameters(Aws::Vector<Aws::String>&& value) { SetCacheKeyParameters(std::move(value)); return *this;}
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies a put integration input's cache key parameters.</p>
      */
     inline PutIntegrationRequest& AddCacheKeyParameters(const Aws::String& value) { m_cacheKeyParametersHasBeenSet = true; m_cacheKeyParameters.push_back(value); return *this; }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies a put integration input's cache key parameters.</p>
      */
     inline PutIntegrationRequest& AddCacheKeyParameters(Aws::String&& value) { m_cacheKeyParametersHasBeenSet = true; m_cacheKeyParameters.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>A list of request parameters whose values API Gateway caches. To be valid
-     * values for <code>cacheKeyParameters</code>, these parameters must also be
-     * specified for <a>Method</a> <code>requestParameters</code>.</p>
+     * <p>Specifies a put integration input's cache key parameters.</p>
      */
     inline PutIntegrationRequest& AddCacheKeyParameters(const char* value) { m_cacheKeyParametersHasBeenSet = true; m_cacheKeyParameters.push_back(value); return *this; }
 
@@ -1207,7 +1174,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline const ContentHandlingStrategy& GetContentHandling() const{ return m_contentHandling; }
@@ -1221,7 +1188,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline bool ContentHandlingHasBeenSet() const { return m_contentHandlingHasBeenSet; }
@@ -1235,7 +1202,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline void SetContentHandling(const ContentHandlingStrategy& value) { m_contentHandlingHasBeenSet = true; m_contentHandling = value; }
@@ -1249,7 +1216,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline void SetContentHandling(ContentHandlingStrategy&& value) { m_contentHandlingHasBeenSet = true; m_contentHandling = std::move(value); }
@@ -1263,7 +1230,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline PutIntegrationRequest& WithContentHandling(const ContentHandlingStrategy& value) { SetContentHandling(value); return *this;}
@@ -1277,7 +1244,7 @@ namespace Model
      * payload from a binary blob to a Base64-encoded string.</p></li> </ul> <p>If this
      * property is not defined, the request payload will be passed through from the
      * method request to integration request without modification, provided that the
-     * <code>passthroughBehavior</code> is configured to support payload
+     * <code>passthroughBehaviors</code> is configured to support payload
      * pass-through.</p>
      */
     inline PutIntegrationRequest& WithContentHandling(ContentHandlingStrategy&& value) { SetContentHandling(std::move(value)); return *this;}
@@ -1307,25 +1274,6 @@ namespace Model
      */
     inline PutIntegrationRequest& WithTimeoutInMillis(int value) { SetTimeoutInMillis(value); return *this;}
 
-
-    
-    inline const TlsConfig& GetTlsConfig() const{ return m_tlsConfig; }
-
-    
-    inline bool TlsConfigHasBeenSet() const { return m_tlsConfigHasBeenSet; }
-
-    
-    inline void SetTlsConfig(const TlsConfig& value) { m_tlsConfigHasBeenSet = true; m_tlsConfig = value; }
-
-    
-    inline void SetTlsConfig(TlsConfig&& value) { m_tlsConfigHasBeenSet = true; m_tlsConfig = std::move(value); }
-
-    
-    inline PutIntegrationRequest& WithTlsConfig(const TlsConfig& value) { SetTlsConfig(value); return *this;}
-
-    
-    inline PutIntegrationRequest& WithTlsConfig(TlsConfig&& value) { SetTlsConfig(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_restApiId;
@@ -1375,9 +1323,6 @@ namespace Model
 
     int m_timeoutInMillis;
     bool m_timeoutInMillisHasBeenSet;
-
-    TlsConfig m_tlsConfig;
-    bool m_tlsConfigHasBeenSet;
   };
 
 } // namespace Model
