@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/apigateway/model/CreateRestApiRequest.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -23,10 +33,7 @@ CreateRestApiRequest::CreateRestApiRequest() :
     m_apiKeySource(ApiKeySourceType::NOT_SET),
     m_apiKeySourceHasBeenSet(false),
     m_endpointConfigurationHasBeenSet(false),
-    m_policyHasBeenSet(false),
-    m_tagsHasBeenSet(false),
-    m_disableExecuteApiEndpoint(false),
-    m_disableExecuteApiEndpointHasBeenSet(false)
+    m_policyHasBeenSet(false)
 {
 }
 
@@ -92,23 +99,6 @@ Aws::String CreateRestApiRequest::SerializePayload() const
 
   }
 
-  if(m_tagsHasBeenSet)
-  {
-   JsonValue tagsJsonMap;
-   for(auto& tagsItem : m_tags)
-   {
-     tagsJsonMap.WithString(tagsItem.first, tagsItem.second);
-   }
-   payload.WithObject("tags", std::move(tagsJsonMap));
-
-  }
-
-  if(m_disableExecuteApiEndpointHasBeenSet)
-  {
-   payload.WithBool("disableExecuteApiEndpoint", m_disableExecuteApiEndpoint);
-
-  }
-
   return payload.View().WriteReadable();
 }
 
