@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/appmesh/AppMesh_EXPORTS.h>
@@ -27,7 +37,7 @@ namespace AppMesh
 namespace Model
 {
   /**
-   * <zonbook></zonbook><xhtml></xhtml><p><h3>See Also:</h3>   <a
+   * <p><h3>See Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/appmesh-2019-01-25/ListVirtualNodesOutput">AWS
    * API Reference</a></p>
    */
@@ -41,64 +51,92 @@ namespace Model
 
     /**
      * <p>The <code>nextToken</code> value to include in a future
-     * <code>ListVirtualNodes</code> request. When the results of a
-     * <code>ListVirtualNodes</code> request exceed <code>limit</code>, you can use
-     * this value to retrieve the next page of results. This value is <code>null</code>
-     * when there are no more results to return.</p>
+     * <code>ListVirtualNodes</code>
+         request. When the results of a
+     * <code>ListVirtualNodes</code> request exceed
+         <code>limit</code>, you
+     * can use this value to retrieve the next page of
+         results. This value is
+     * <code>null</code> when there are no more results to
+         return.</p>
      */
     inline const Aws::String& GetNextToken() const{ return m_nextToken; }
 
     /**
      * <p>The <code>nextToken</code> value to include in a future
-     * <code>ListVirtualNodes</code> request. When the results of a
-     * <code>ListVirtualNodes</code> request exceed <code>limit</code>, you can use
-     * this value to retrieve the next page of results. This value is <code>null</code>
-     * when there are no more results to return.</p>
+     * <code>ListVirtualNodes</code>
+         request. When the results of a
+     * <code>ListVirtualNodes</code> request exceed
+         <code>limit</code>, you
+     * can use this value to retrieve the next page of
+         results. This value is
+     * <code>null</code> when there are no more results to
+         return.</p>
      */
     inline void SetNextToken(const Aws::String& value) { m_nextToken = value; }
 
     /**
      * <p>The <code>nextToken</code> value to include in a future
-     * <code>ListVirtualNodes</code> request. When the results of a
-     * <code>ListVirtualNodes</code> request exceed <code>limit</code>, you can use
-     * this value to retrieve the next page of results. This value is <code>null</code>
-     * when there are no more results to return.</p>
+     * <code>ListVirtualNodes</code>
+         request. When the results of a
+     * <code>ListVirtualNodes</code> request exceed
+         <code>limit</code>, you
+     * can use this value to retrieve the next page of
+         results. This value is
+     * <code>null</code> when there are no more results to
+         return.</p>
      */
     inline void SetNextToken(Aws::String&& value) { m_nextToken = std::move(value); }
 
     /**
      * <p>The <code>nextToken</code> value to include in a future
-     * <code>ListVirtualNodes</code> request. When the results of a
-     * <code>ListVirtualNodes</code> request exceed <code>limit</code>, you can use
-     * this value to retrieve the next page of results. This value is <code>null</code>
-     * when there are no more results to return.</p>
+     * <code>ListVirtualNodes</code>
+         request. When the results of a
+     * <code>ListVirtualNodes</code> request exceed
+         <code>limit</code>, you
+     * can use this value to retrieve the next page of
+         results. This value is
+     * <code>null</code> when there are no more results to
+         return.</p>
      */
     inline void SetNextToken(const char* value) { m_nextToken.assign(value); }
 
     /**
      * <p>The <code>nextToken</code> value to include in a future
-     * <code>ListVirtualNodes</code> request. When the results of a
-     * <code>ListVirtualNodes</code> request exceed <code>limit</code>, you can use
-     * this value to retrieve the next page of results. This value is <code>null</code>
-     * when there are no more results to return.</p>
+     * <code>ListVirtualNodes</code>
+         request. When the results of a
+     * <code>ListVirtualNodes</code> request exceed
+         <code>limit</code>, you
+     * can use this value to retrieve the next page of
+         results. This value is
+     * <code>null</code> when there are no more results to
+         return.</p>
      */
     inline ListVirtualNodesResult& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}
 
     /**
      * <p>The <code>nextToken</code> value to include in a future
-     * <code>ListVirtualNodes</code> request. When the results of a
-     * <code>ListVirtualNodes</code> request exceed <code>limit</code>, you can use
-     * this value to retrieve the next page of results. This value is <code>null</code>
-     * when there are no more results to return.</p>
+     * <code>ListVirtualNodes</code>
+         request. When the results of a
+     * <code>ListVirtualNodes</code> request exceed
+         <code>limit</code>, you
+     * can use this value to retrieve the next page of
+         results. This value is
+     * <code>null</code> when there are no more results to
+         return.</p>
      */
     inline ListVirtualNodesResult& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}
 
     /**
      * <p>The <code>nextToken</code> value to include in a future
-     * <code>ListVirtualNodes</code> request. When the results of a
-     * <code>ListVirtualNodes</code> request exceed <code>limit</code>, you can use
-     * this value to retrieve the next page of results. This value is <code>null</code>
-     * when there are no more results to return.</p>
+     * <code>ListVirtualNodes</code>
+         request. When the results of a
+     * <code>ListVirtualNodes</code> request exceed
+         <code>limit</code>, you
+     * can use this value to retrieve the next page of
+         results. This value is
+     * <code>null</code> when there are no more results to
+         return.</p>
      */
     inline ListVirtualNodesResult& WithNextToken(const char* value) { SetNextToken(value); return *this;}
 
