@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/appstream/AppStream_EXPORTS.h>
@@ -12,7 +22,6 @@
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/appstream/model/StorageConnector.h>
 #include <aws/appstream/model/UserSetting.h>
-#include <aws/appstream/model/AccessEndpoint.h>
 #include <utility>
 
 namespace Aws
@@ -28,7 +37,7 @@ namespace Model
   {
   public:
     CreateStackRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -390,11 +399,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
 
@@ -402,11 +409,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
@@ -414,11 +419,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
@@ -426,11 +429,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
@@ -438,11 +439,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline CreateStackRequest& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
 
@@ -450,11 +449,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline CreateStackRequest& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
 
@@ -462,11 +459,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline CreateStackRequest& AddTags(const Aws::String& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
 
@@ -474,11 +469,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline CreateStackRequest& AddTags(Aws::String&& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
 
@@ -486,11 +479,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline CreateStackRequest& AddTags(const Aws::String& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
 
@@ -498,11 +489,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline CreateStackRequest& AddTags(Aws::String&& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), std::move(value)); return *this; }
 
@@ -510,11 +499,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline CreateStackRequest& AddTags(const char* key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
 
@@ -522,11 +509,9 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline CreateStackRequest& AddTags(Aws::String&& key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
 
@@ -534,127 +519,12 @@ namespace Model
      * <p>The tags to associate with the stack. A tag is a key-value pair, and the
      * value is optional. For example, Environment=Test. If you do not specify a value,
      * Environment=. </p> <p>If you do not specify a value, the value is set to an
-     * empty string.</p> <p>Generally allowed characters are: letters, numbers, and
-     * spaces representable in UTF-8, and the following special characters: </p> <p>_ .
-     * : / = + \ - @</p> <p>For more information about tags, see <a
+     * empty string.</p> <p>For more information about tags, see <a
      * href="https://docs.aws.amazon.com/appstream2/latest/developerguide/tagging-basic.html">Tagging
-     * Your Resources</a> in the <i>Amazon AppStream 2.0 Administration Guide</i>.</p>
+     * Your Resources</a> in the <i>Amazon AppStream 2.0 Developer Guide</i>.</p>
      */
     inline CreateStackRequest& AddTags(const char* key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
 
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline const Aws::Vector<AccessEndpoint>& GetAccessEndpoints() const{ return m_accessEndpoints; }
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline bool AccessEndpointsHasBeenSet() const { return m_accessEndpointsHasBeenSet; }
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline void SetAccessEndpoints(const Aws::Vector<AccessEndpoint>& value) { m_accessEndpointsHasBeenSet = true; m_accessEndpoints = value; }
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline void SetAccessEndpoints(Aws::Vector<AccessEndpoint>&& value) { m_accessEndpointsHasBeenSet = true; m_accessEndpoints = std::move(value); }
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline CreateStackRequest& WithAccessEndpoints(const Aws::Vector<AccessEndpoint>& value) { SetAccessEndpoints(value); return *this;}
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline CreateStackRequest& WithAccessEndpoints(Aws::Vector<AccessEndpoint>&& value) { SetAccessEndpoints(std::move(value)); return *this;}
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline CreateStackRequest& AddAccessEndpoints(const AccessEndpoint& value) { m_accessEndpointsHasBeenSet = true; m_accessEndpoints.push_back(value); return *this; }
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline CreateStackRequest& AddAccessEndpoints(AccessEndpoint&& value) { m_accessEndpointsHasBeenSet = true; m_accessEndpoints.push_back(std::move(value)); return *this; }
-
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline const Aws::Vector<Aws::String>& GetEmbedHostDomains() const{ return m_embedHostDomains; }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline bool EmbedHostDomainsHasBeenSet() const { return m_embedHostDomainsHasBeenSet; }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline void SetEmbedHostDomains(const Aws::Vector<Aws::String>& value) { m_embedHostDomainsHasBeenSet = true; m_embedHostDomains = value; }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline void SetEmbedHostDomains(Aws::Vector<Aws::String>&& value) { m_embedHostDomainsHasBeenSet = true; m_embedHostDomains = std::move(value); }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline CreateStackRequest& WithEmbedHostDomains(const Aws::Vector<Aws::String>& value) { SetEmbedHostDomains(value); return *this;}
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline CreateStackRequest& WithEmbedHostDomains(Aws::Vector<Aws::String>&& value) { SetEmbedHostDomains(std::move(value)); return *this;}
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline CreateStackRequest& AddEmbedHostDomains(const Aws::String& value) { m_embedHostDomainsHasBeenSet = true; m_embedHostDomains.push_back(value); return *this; }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline CreateStackRequest& AddEmbedHostDomains(Aws::String&& value) { m_embedHostDomainsHasBeenSet = true; m_embedHostDomains.push_back(std::move(value)); return *this; }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline CreateStackRequest& AddEmbedHostDomains(const char* value) { m_embedHostDomainsHasBeenSet = true; m_embedHostDomains.push_back(value); return *this; }
-
   private:
 
     Aws::String m_name;
@@ -683,12 +553,6 @@ namespace Model
 
     Aws::Map<Aws::String, Aws::String> m_tags;
     bool m_tagsHasBeenSet;
-
-    Aws::Vector<AccessEndpoint> m_accessEndpoints;
-    bool m_accessEndpointsHasBeenSet;
-
-    Aws::Vector<Aws::String> m_embedHostDomains;
-    bool m_embedHostDomainsHasBeenSet;
   };
 
 } // namespace Model
