@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/appstream/AppStream_EXPORTS.h>
@@ -304,55 +314,6 @@ namespace Model
     inline Image& WithImageBuilderSupported(bool value) { SetImageBuilderSupported(value); return *this;}
 
 
-    /**
-     * <p>The name of the image builder that was used to create the private image. If
-     * the image is shared, this value is null.</p>
-     */
-    inline const Aws::String& GetImageBuilderName() const{ return m_imageBuilderName; }
-
-    /**
-     * <p>The name of the image builder that was used to create the private image. If
-     * the image is shared, this value is null.</p>
-     */
-    inline bool ImageBuilderNameHasBeenSet() const { return m_imageBuilderNameHasBeenSet; }
-
-    /**
-     * <p>The name of the image builder that was used to create the private image. If
-     * the image is shared, this value is null.</p>
-     */
-    inline void SetImageBuilderName(const Aws::String& value) { m_imageBuilderNameHasBeenSet = true; m_imageBuilderName = value; }
-
-    /**
-     * <p>The name of the image builder that was used to create the private image. If
-     * the image is shared, this value is null.</p>
-     */
-    inline void SetImageBuilderName(Aws::String&& value) { m_imageBuilderNameHasBeenSet = true; m_imageBuilderName = std::move(value); }
-
-    /**
-     * <p>The name of the image builder that was used to create the private image. If
-     * the image is shared, this value is null.</p>
-     */
-    inline void SetImageBuilderName(const char* value) { m_imageBuilderNameHasBeenSet = true; m_imageBuilderName.assign(value); }
-
-    /**
-     * <p>The name of the image builder that was used to create the private image. If
-     * the image is shared, this value is null.</p>
-     */
-    inline Image& WithImageBuilderName(const Aws::String& value) { SetImageBuilderName(value); return *this;}
-
-    /**
-     * <p>The name of the image builder that was used to create the private image. If
-     * the image is shared, this value is null.</p>
-     */
-    inline Image& WithImageBuilderName(Aws::String&& value) { SetImageBuilderName(std::move(value)); return *this;}
-
-    /**
-     * <p>The name of the image builder that was used to create the private image. If
-     * the image is shared, this value is null.</p>
-     */
-    inline Image& WithImageBuilderName(const char* value) { SetImageBuilderName(value); return *this;}
-
-
     /**
      * <p>The operating system platform of the image.</p>
      */
@@ -673,9 +634,6 @@ namespace Model
     bool m_imageBuilderSupported;
     bool m_imageBuilderSupportedHasBeenSet;
 
-    Aws::String m_imageBuilderName;
-    bool m_imageBuilderNameHasBeenSet;
-
     PlatformType m_platform;
     bool m_platformHasBeenSet;
 
