@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/appstream/AppStream_EXPORTS.h>
@@ -9,11 +19,9 @@
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/appstream/model/ApplicationSettings.h>
-#include <aws/appstream/model/StreamingExperienceSettings.h>
 #include <aws/appstream/model/StorageConnector.h>
 #include <aws/appstream/model/StackAttribute.h>
 #include <aws/appstream/model/UserSetting.h>
-#include <aws/appstream/model/AccessEndpoint.h>
 #include <utility>
 
 namespace Aws
@@ -29,7 +37,7 @@ namespace Model
   {
   public:
     UpdateStackRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -427,193 +435,34 @@ namespace Model
      */
     inline UpdateStackRequest& WithApplicationSettings(ApplicationSettings&& value) { SetApplicationSettings(std::move(value)); return *this;}
 
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline const Aws::Vector<AccessEndpoint>& GetAccessEndpoints() const{ return m_accessEndpoints; }
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline bool AccessEndpointsHasBeenSet() const { return m_accessEndpointsHasBeenSet; }
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline void SetAccessEndpoints(const Aws::Vector<AccessEndpoint>& value) { m_accessEndpointsHasBeenSet = true; m_accessEndpoints = value; }
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline void SetAccessEndpoints(Aws::Vector<AccessEndpoint>&& value) { m_accessEndpointsHasBeenSet = true; m_accessEndpoints = std::move(value); }
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline UpdateStackRequest& WithAccessEndpoints(const Aws::Vector<AccessEndpoint>& value) { SetAccessEndpoints(value); return *this;}
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline UpdateStackRequest& WithAccessEndpoints(Aws::Vector<AccessEndpoint>&& value) { SetAccessEndpoints(std::move(value)); return *this;}
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline UpdateStackRequest& AddAccessEndpoints(const AccessEndpoint& value) { m_accessEndpointsHasBeenSet = true; m_accessEndpoints.push_back(value); return *this; }
-
-    /**
-     * <p>The list of interface VPC endpoint (interface endpoint) objects. Users of the
-     * stack can connect to AppStream 2.0 only through the specified endpoints.</p>
-     */
-    inline UpdateStackRequest& AddAccessEndpoints(AccessEndpoint&& value) { m_accessEndpointsHasBeenSet = true; m_accessEndpoints.push_back(std::move(value)); return *this; }
-
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline const Aws::Vector<Aws::String>& GetEmbedHostDomains() const{ return m_embedHostDomains; }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline bool EmbedHostDomainsHasBeenSet() const { return m_embedHostDomainsHasBeenSet; }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline void SetEmbedHostDomains(const Aws::Vector<Aws::String>& value) { m_embedHostDomainsHasBeenSet = true; m_embedHostDomains = value; }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline void SetEmbedHostDomains(Aws::Vector<Aws::String>&& value) { m_embedHostDomainsHasBeenSet = true; m_embedHostDomains = std::move(value); }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline UpdateStackRequest& WithEmbedHostDomains(const Aws::Vector<Aws::String>& value) { SetEmbedHostDomains(value); return *this;}
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline UpdateStackRequest& WithEmbedHostDomains(Aws::Vector<Aws::String>&& value) { SetEmbedHostDomains(std::move(value)); return *this;}
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline UpdateStackRequest& AddEmbedHostDomains(const Aws::String& value) { m_embedHostDomainsHasBeenSet = true; m_embedHostDomains.push_back(value); return *this; }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline UpdateStackRequest& AddEmbedHostDomains(Aws::String&& value) { m_embedHostDomainsHasBeenSet = true; m_embedHostDomains.push_back(std::move(value)); return *this; }
-
-    /**
-     * <p>The domains where AppStream 2.0 streaming sessions can be embedded in an
-     * iframe. You must approve the domains that you want to host embedded AppStream
-     * 2.0 streaming sessions. </p>
-     */
-    inline UpdateStackRequest& AddEmbedHostDomains(const char* value) { m_embedHostDomainsHasBeenSet = true; m_embedHostDomains.push_back(value); return *this; }
-
-
-    /**
-     * <p>The streaming protocol you want your stack to prefer. This can be UDP or TCP.
-     * Currently, UDP is only supported in the Windows native client.</p>
-     */
-    inline const StreamingExperienceSettings& GetStreamingExperienceSettings() const{ return m_streamingExperienceSettings; }
-
-    /**
-     * <p>The streaming protocol you want your stack to prefer. This can be UDP or TCP.
-     * Currently, UDP is only supported in the Windows native client.</p>
-     */
-    inline bool StreamingExperienceSettingsHasBeenSet() const { return m_streamingExperienceSettingsHasBeenSet; }
-
-    /**
-     * <p>The streaming protocol you want your stack to prefer. This can be UDP or TCP.
-     * Currently, UDP is only supported in the Windows native client.</p>
-     */
-    inline void SetStreamingExperienceSettings(const StreamingExperienceSettings& value) { m_streamingExperienceSettingsHasBeenSet = true; m_streamingExperienceSettings = value; }
-
-    /**
-     * <p>The streaming protocol you want your stack to prefer. This can be UDP or TCP.
-     * Currently, UDP is only supported in the Windows native client.</p>
-     */
-    inline void SetStreamingExperienceSettings(StreamingExperienceSettings&& value) { m_streamingExperienceSettingsHasBeenSet = true; m_streamingExperienceSettings = std::move(value); }
-
-    /**
-     * <p>The streaming protocol you want your stack to prefer. This can be UDP or TCP.
-     * Currently, UDP is only supported in the Windows native client.</p>
-     */
-    inline UpdateStackRequest& WithStreamingExperienceSettings(const StreamingExperienceSettings& value) { SetStreamingExperienceSettings(value); return *this;}
-
-    /**
-     * <p>The streaming protocol you want your stack to prefer. This can be UDP or TCP.
-     * Currently, UDP is only supported in the Windows native client.</p>
-     */
-    inline UpdateStackRequest& WithStreamingExperienceSettings(StreamingExperienceSettings&& value) { SetStreamingExperienceSettings(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_displayName;
-    bool m_displayNameHasBeenSet = false;
+    bool m_displayNameHasBeenSet;
 
     Aws::String m_description;
-    bool m_descriptionHasBeenSet = false;
+    bool m_descriptionHasBeenSet;
 
     Aws::String m_name;
-    bool m_nameHasBeenSet = false;
+    bool m_nameHasBeenSet;
 
     Aws::Vector<StorageConnector> m_storageConnectors;
-    bool m_storageConnectorsHasBeenSet = false;
+    bool m_storageConnectorsHasBeenSet;
 
     Aws::String m_redirectURL;
-    bool m_redirectURLHasBeenSet = false;
+    bool m_redirectURLHasBeenSet;
 
     Aws::String m_feedbackURL;
-    bool m_feedbackURLHasBeenSet = false;
+    bool m_feedbackURLHasBeenSet;
 
     Aws::Vector<StackAttribute> m_attributesToDelete;
-    bool m_attributesToDeleteHasBeenSet = false;
+    bool m_attributesToDeleteHasBeenSet;
 
     Aws::Vector<UserSetting> m_userSettings;
-    bool m_userSettingsHasBeenSet = false;
+    bool m_userSettingsHasBeenSet;
 
     ApplicationSettings m_applicationSettings;
-    bool m_applicationSettingsHasBeenSet = false;
-
-    Aws::Vector<AccessEndpoint> m_accessEndpoints;
-    bool m_accessEndpointsHasBeenSet = false;
-
-    Aws::Vector<Aws::String> m_embedHostDomains;
-    bool m_embedHostDomainsHasBeenSet = false;
-
-    StreamingExperienceSettings m_streamingExperienceSettings;
-    bool m_streamingExperienceSettingsHasBeenSet = false;
+    bool m_applicationSettingsHasBeenSet;
   };
 
 } // namespace Model
