@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/appstream/model/Image.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -29,7 +39,6 @@ Image::Image() :
     m_visibilityHasBeenSet(false),
     m_imageBuilderSupported(false),
     m_imageBuilderSupportedHasBeenSet(false),
-    m_imageBuilderNameHasBeenSet(false),
     m_platform(PlatformType::NOT_SET),
     m_platformHasBeenSet(false),
     m_descriptionHasBeenSet(false),
@@ -38,8 +47,7 @@ Image::Image() :
     m_createdTimeHasBeenSet(false),
     m_publicBaseImageReleasedDateHasBeenSet(false),
     m_appstreamAgentVersionHasBeenSet(false),
-    m_imagePermissionsHasBeenSet(false),
-    m_imageErrorsHasBeenSet(false)
+    m_imagePermissionsHasBeenSet(false)
 {
 }
 
@@ -54,7 +62,6 @@ Image::Image(JsonView jsonValue) :
     m_visibilityHasBeenSet(false),
     m_imageBuilderSupported(false),
     m_imageBuilderSupportedHasBeenSet(false),
-    m_imageBuilderNameHasBeenSet(false),
     m_platform(PlatformType::NOT_SET),
     m_platformHasBeenSet(false),
     m_descriptionHasBeenSet(false),
@@ -63,8 +70,7 @@ Image::Image(JsonView jsonValue) :
     m_createdTimeHasBeenSet(false),
     m_publicBaseImageReleasedDateHasBeenSet(false),
     m_appstreamAgentVersionHasBeenSet(false),
-    m_imagePermissionsHasBeenSet(false),
-    m_imageErrorsHasBeenSet(false)
+    m_imagePermissionsHasBeenSet(false)
 {
   *this = jsonValue;
 }
@@ -120,13 +126,6 @@ Image& Image::operator =(JsonView jsonValue)
     m_imageBuilderSupportedHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("ImageBuilderName"))
-  {
-    m_imageBuilderName = jsonValue.GetString("ImageBuilderName");
-
-    m_imageBuilderNameHasBeenSet = true;
-  }
-
   if(jsonValue.ValueExists("Platform"))
   {
     m_platform = PlatformTypeMapper::GetPlatformTypeForName(jsonValue.GetString("Platform"));
@@ -186,16 +185,6 @@ Image& Image::operator =(JsonView jsonValue)
     m_imagePermissionsHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("ImageErrors"))
-  {
-    Array<JsonView> imageErrorsJsonList = jsonValue.GetArray("ImageErrors");
-    for(unsigned imageErrorsIndex = 0; imageErrorsIndex < imageErrorsJsonList.GetLength(); ++imageErrorsIndex)
-    {
-      m_imageErrors.push_back(imageErrorsJsonList[imageErrorsIndex].AsObject());
-    }
-    m_imageErrorsHasBeenSet = true;
-  }
-
   return *this;
 }
 
@@ -243,12 +232,6 @@ JsonValue Image::Jsonize() const
 
   }
 
-  if(m_imageBuilderNameHasBeenSet)
-  {
-   payload.WithString("ImageBuilderName", m_imageBuilderName);
-
-  }
-
   if(m_platformHasBeenSet)
   {
    payload.WithString("Platform", PlatformTypeMapper::GetNameForPlatformType(m_platform));
@@ -299,17 +282,6 @@ JsonValue Image::Jsonize() const
 
   }
 
-  if(m_imageErrorsHasBeenSet)
-  {
-   Array<JsonValue> imageErrorsJsonList(m_imageErrors.size());
-   for(unsigned imageErrorsIndex = 0; imageErrorsIndex < imageErrorsJsonList.GetLength(); ++imageErrorsIndex)
-   {
-     imageErrorsJsonList[imageErrorsIndex].AsObject(m_imageErrors[imageErrorsIndex].Jsonize());
-   }
-   payload.WithArray("ImageErrors", std::move(imageErrorsJsonList));
-
-  }
-
   return payload;
 }
 
