@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/appsync/AppSync_EXPORTS.h>
@@ -9,8 +19,6 @@
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/appsync/model/ResolverKind.h>
 #include <aws/appsync/model/PipelineConfig.h>
-#include <aws/appsync/model/SyncConfig.h>
-#include <aws/appsync/model/CachingConfig.h>
 #include <utility>
 
 namespace Aws
@@ -26,7 +34,7 @@ namespace Model
   {
   public:
     CreateResolverRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -204,9 +212,7 @@ namespace Model
      * <p>The mapping template to be used for requests.</p> <p>A resolver uses a
      * request mapping template to convert a GraphQL expression into a format that a
      * data source can understand. Mapping templates are written in Apache Velocity
-     * Template Language (VTL).</p> <p>VTL request mapping templates are optional when
-     * using a Lambda data source. For all other data sources, VTL request and response
-     * mapping templates are required.</p>
+     * Template Language (VTL).</p>
      */
     inline const Aws::String& GetRequestMappingTemplate() const{ return m_requestMappingTemplate; }
 
@@ -214,9 +220,7 @@ namespace Model
      * <p>The mapping template to be used for requests.</p> <p>A resolver uses a
      * request mapping template to convert a GraphQL expression into a format that a
      * data source can understand. Mapping templates are written in Apache Velocity
-     * Template Language (VTL).</p> <p>VTL request mapping templates are optional when
-     * using a Lambda data source. For all other data sources, VTL request and response
-     * mapping templates are required.</p>
+     * Template Language (VTL).</p>
      */
     inline bool RequestMappingTemplateHasBeenSet() const { return m_requestMappingTemplateHasBeenSet; }
 
@@ -224,9 +228,7 @@ namespace Model
      * <p>The mapping template to be used for requests.</p> <p>A resolver uses a
      * request mapping template to convert a GraphQL expression into a format that a
      * data source can understand. Mapping templates are written in Apache Velocity
-     * Template Language (VTL).</p> <p>VTL request mapping templates are optional when
-     * using a Lambda data source. For all other data sources, VTL request and response
-     * mapping templates are required.</p>
+     * Template Language (VTL).</p>
      */
     inline void SetRequestMappingTemplate(const Aws::String& value) { m_requestMappingTemplateHasBeenSet = true; m_requestMappingTemplate = value; }
 
@@ -234,9 +236,7 @@ namespace Model
      * <p>The mapping template to be used for requests.</p> <p>A resolver uses a
      * request mapping template to convert a GraphQL expression into a format that a
      * data source can understand. Mapping templates are written in Apache Velocity
-     * Template Language (VTL).</p> <p>VTL request mapping templates are optional when
-     * using a Lambda data source. For all other data sources, VTL request and response
-     * mapping templates are required.</p>
+     * Template Language (VTL).</p>
      */
     inline void SetRequestMappingTemplate(Aws::String&& value) { m_requestMappingTemplateHasBeenSet = true; m_requestMappingTemplate = std::move(value); }
 
@@ -244,9 +244,7 @@ namespace Model
      * <p>The mapping template to be used for requests.</p> <p>A resolver uses a
      * request mapping template to convert a GraphQL expression into a format that a
      * data source can understand. Mapping templates are written in Apache Velocity
-     * Template Language (VTL).</p> <p>VTL request mapping templates are optional when
-     * using a Lambda data source. For all other data sources, VTL request and response
-     * mapping templates are required.</p>
+     * Template Language (VTL).</p>
      */
     inline void SetRequestMappingTemplate(const char* value) { m_requestMappingTemplateHasBeenSet = true; m_requestMappingTemplate.assign(value); }
 
@@ -254,9 +252,7 @@ namespace Model
      * <p>The mapping template to be used for requests.</p> <p>A resolver uses a
      * request mapping template to convert a GraphQL expression into a format that a
      * data source can understand. Mapping templates are written in Apache Velocity
-     * Template Language (VTL).</p> <p>VTL request mapping templates are optional when
-     * using a Lambda data source. For all other data sources, VTL request and response
-     * mapping templates are required.</p>
+     * Template Language (VTL).</p>
      */
     inline CreateResolverRequest& WithRequestMappingTemplate(const Aws::String& value) { SetRequestMappingTemplate(value); return *this;}
 
@@ -264,9 +260,7 @@ namespace Model
      * <p>The mapping template to be used for requests.</p> <p>A resolver uses a
      * request mapping template to convert a GraphQL expression into a format that a
      * data source can understand. Mapping templates are written in Apache Velocity
-     * Template Language (VTL).</p> <p>VTL request mapping templates are optional when
-     * using a Lambda data source. For all other data sources, VTL request and response
-     * mapping templates are required.</p>
+     * Template Language (VTL).</p>
      */
     inline CreateResolverRequest& WithRequestMappingTemplate(Aws::String&& value) { SetRequestMappingTemplate(std::move(value)); return *this;}
 
@@ -274,9 +268,7 @@ namespace Model
      * <p>The mapping template to be used for requests.</p> <p>A resolver uses a
      * request mapping template to convert a GraphQL expression into a format that a
      * data source can understand. Mapping templates are written in Apache Velocity
-     * Template Language (VTL).</p> <p>VTL request mapping templates are optional when
-     * using a Lambda data source. For all other data sources, VTL request and response
-     * mapping templates are required.</p>
+     * Template Language (VTL).</p>
      */
     inline CreateResolverRequest& WithRequestMappingTemplate(const char* value) { SetRequestMappingTemplate(value); return *this;}
 
@@ -419,74 +411,6 @@ namespace Model
      */
     inline CreateResolverRequest& WithPipelineConfig(PipelineConfig&& value) { SetPipelineConfig(std::move(value)); return *this;}
 
-
-    /**
-     * <p>The <code>SyncConfig</code> for a resolver attached to a versioned
-     * datasource.</p>
-     */
-    inline const SyncConfig& GetSyncConfig() const{ return m_syncConfig; }
-
-    /**
-     * <p>The <code>SyncConfig</code> for a resolver attached to a versioned
-     * datasource.</p>
-     */
-    inline bool SyncConfigHasBeenSet() const { return m_syncConfigHasBeenSet; }
-
-    /**
-     * <p>The <code>SyncConfig</code> for a resolver attached to a versioned
-     * datasource.</p>
-     */
-    inline void SetSyncConfig(const SyncConfig& value) { m_syncConfigHasBeenSet = true; m_syncConfig = value; }
-
-    /**
-     * <p>The <code>SyncConfig</code> for a resolver attached to a versioned
-     * datasource.</p>
-     */
-    inline void SetSyncConfig(SyncConfig&& value) { m_syncConfigHasBeenSet = true; m_syncConfig = std::move(value); }
-
-    /**
-     * <p>The <code>SyncConfig</code> for a resolver attached to a versioned
-     * datasource.</p>
-     */
-    inline CreateResolverRequest& WithSyncConfig(const SyncConfig& value) { SetSyncConfig(value); return *this;}
-
-    /**
-     * <p>The <code>SyncConfig</code> for a resolver attached to a versioned
-     * datasource.</p>
-     */
-    inline CreateResolverRequest& WithSyncConfig(SyncConfig&& value) { SetSyncConfig(std::move(value)); return *this;}
-
-
-    /**
-     * <p>The caching configuration for the resolver.</p>
-     */
-    inline const CachingConfig& GetCachingConfig() const{ return m_cachingConfig; }
-
-    /**
-     * <p>The caching configuration for the resolver.</p>
-     */
-    inline bool CachingConfigHasBeenSet() const { return m_cachingConfigHasBeenSet; }
-
-    /**
-     * <p>The caching configuration for the resolver.</p>
-     */
-    inline void SetCachingConfig(const CachingConfig& value) { m_cachingConfigHasBeenSet = true; m_cachingConfig = value; }
-
-    /**
-     * <p>The caching configuration for the resolver.</p>
-     */
-    inline void SetCachingConfig(CachingConfig&& value) { m_cachingConfigHasBeenSet = true; m_cachingConfig = std::move(value); }
-
-    /**
-     * <p>The caching configuration for the resolver.</p>
-     */
-    inline CreateResolverRequest& WithCachingConfig(const CachingConfig& value) { SetCachingConfig(value); return *this;}
-
-    /**
-     * <p>The caching configuration for the resolver.</p>
-     */
-    inline CreateResolverRequest& WithCachingConfig(CachingConfig&& value) { SetCachingConfig(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_apiId;
@@ -512,12 +436,6 @@ namespace Model
 
     PipelineConfig m_pipelineConfig;
     bool m_pipelineConfigHasBeenSet;
-
-    SyncConfig m_syncConfig;
-    bool m_syncConfigHasBeenSet;
-
-    CachingConfig m_cachingConfig;
-    bool m_cachingConfigHasBeenSet;
   };
 
 } // namespace Model
