@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/autoscaling/AutoScaling_EXPORTS.h>
@@ -167,162 +177,106 @@ namespace Model
 
 
     /**
-     * <p>One of the following policy types: </p> <ul> <li> <p>
-     * <code>TargetTrackingScaling</code> </p> </li> <li> <p> <code>StepScaling</code>
-     * </p> </li> <li> <p> <code>SimpleScaling</code> (default)</p> </li> </ul> <p>For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-target-tracking.html">Target
-     * Tracking Scaling Policies</a> and <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-simple-step.html">Step
-     * and Simple Scaling Policies</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * <p>The policy type. The valid values are <code>SimpleScaling</code> and
+     * <code>StepScaling</code>.</p>
      */
     inline const Aws::String& GetPolicyType() const{ return m_policyType; }
 
     /**
-     * <p>One of the following policy types: </p> <ul> <li> <p>
-     * <code>TargetTrackingScaling</code> </p> </li> <li> <p> <code>StepScaling</code>
-     * </p> </li> <li> <p> <code>SimpleScaling</code> (default)</p> </li> </ul> <p>For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-target-tracking.html">Target
-     * Tracking Scaling Policies</a> and <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-simple-step.html">Step
-     * and Simple Scaling Policies</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * <p>The policy type. The valid values are <code>SimpleScaling</code> and
+     * <code>StepScaling</code>.</p>
      */
     inline bool PolicyTypeHasBeenSet() const { return m_policyTypeHasBeenSet; }
 
     /**
-     * <p>One of the following policy types: </p> <ul> <li> <p>
-     * <code>TargetTrackingScaling</code> </p> </li> <li> <p> <code>StepScaling</code>
-     * </p> </li> <li> <p> <code>SimpleScaling</code> (default)</p> </li> </ul> <p>For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-target-tracking.html">Target
-     * Tracking Scaling Policies</a> and <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-simple-step.html">Step
-     * and Simple Scaling Policies</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * <p>The policy type. The valid values are <code>SimpleScaling</code> and
+     * <code>StepScaling</code>.</p>
      */
     inline void SetPolicyType(const Aws::String& value) { m_policyTypeHasBeenSet = true; m_policyType = value; }
 
     /**
-     * <p>One of the following policy types: </p> <ul> <li> <p>
-     * <code>TargetTrackingScaling</code> </p> </li> <li> <p> <code>StepScaling</code>
-     * </p> </li> <li> <p> <code>SimpleScaling</code> (default)</p> </li> </ul> <p>For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-target-tracking.html">Target
-     * Tracking Scaling Policies</a> and <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-simple-step.html">Step
-     * and Simple Scaling Policies</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * <p>The policy type. The valid values are <code>SimpleScaling</code> and
+     * <code>StepScaling</code>.</p>
      */
     inline void SetPolicyType(Aws::String&& value) { m_policyTypeHasBeenSet = true; m_policyType = std::move(value); }
 
     /**
-     * <p>One of the following policy types: </p> <ul> <li> <p>
-     * <code>TargetTrackingScaling</code> </p> </li> <li> <p> <code>StepScaling</code>
-     * </p> </li> <li> <p> <code>SimpleScaling</code> (default)</p> </li> </ul> <p>For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-target-tracking.html">Target
-     * Tracking Scaling Policies</a> and <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-simple-step.html">Step
-     * and Simple Scaling Policies</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * <p>The policy type. The valid values are <code>SimpleScaling</code> and
+     * <code>StepScaling</code>.</p>
      */
     inline void SetPolicyType(const char* value) { m_policyTypeHasBeenSet = true; m_policyType.assign(value); }
 
     /**
-     * <p>One of the following policy types: </p> <ul> <li> <p>
-     * <code>TargetTrackingScaling</code> </p> </li> <li> <p> <code>StepScaling</code>
-     * </p> </li> <li> <p> <code>SimpleScaling</code> (default)</p> </li> </ul> <p>For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-target-tracking.html">Target
-     * Tracking Scaling Policies</a> and <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-simple-step.html">Step
-     * and Simple Scaling Policies</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * <p>The policy type. The valid values are <code>SimpleScaling</code> and
+     * <code>StepScaling</code>.</p>
      */
     inline ScalingPolicy& WithPolicyType(const Aws::String& value) { SetPolicyType(value); return *this;}
 
     /**
-     * <p>One of the following policy types: </p> <ul> <li> <p>
-     * <code>TargetTrackingScaling</code> </p> </li> <li> <p> <code>StepScaling</code>
-     * </p> </li> <li> <p> <code>SimpleScaling</code> (default)</p> </li> </ul> <p>For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-target-tracking.html">Target
-     * Tracking Scaling Policies</a> and <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-simple-step.html">Step
-     * and Simple Scaling Policies</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * <p>The policy type. The valid values are <code>SimpleScaling</code> and
+     * <code>StepScaling</code>.</p>
      */
     inline ScalingPolicy& WithPolicyType(Aws::String&& value) { SetPolicyType(std::move(value)); return *this;}
 
     /**
-     * <p>One of the following policy types: </p> <ul> <li> <p>
-     * <code>TargetTrackingScaling</code> </p> </li> <li> <p> <code>StepScaling</code>
-     * </p> </li> <li> <p> <code>SimpleScaling</code> (default)</p> </li> </ul> <p>For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-target-tracking.html">Target
-     * Tracking Scaling Policies</a> and <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-simple-step.html">Step
-     * and Simple Scaling Policies</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * <p>The policy type. The valid values are <code>SimpleScaling</code> and
+     * <code>StepScaling</code>.</p>
      */
     inline ScalingPolicy& WithPolicyType(const char* value) { SetPolicyType(value); return *this;}
 
 
     /**
-     * <p>Specifies how the scaling adjustment is interpreted (for example, an absolute
-     * number or a percentage). The valid values are <code>ChangeInCapacity</code>,
+     * <p>The adjustment type, which specifies how <code>ScalingAdjustment</code> is
+     * interpreted. The valid values are <code>ChangeInCapacity</code>,
      * <code>ExactCapacity</code>, and <code>PercentChangeInCapacity</code>.</p>
      */
     inline const Aws::String& GetAdjustmentType() const{ return m_adjustmentType; }
 
     /**
-     * <p>Specifies how the scaling adjustment is interpreted (for example, an absolute
-     * number or a percentage). The valid values are <code>ChangeInCapacity</code>,
+     * <p>The adjustment type, which specifies how <code>ScalingAdjustment</code> is
+     * interpreted. The valid values are <code>ChangeInCapacity</code>,
      * <code>ExactCapacity</code>, and <code>PercentChangeInCapacity</code>.</p>
      */
     inline bool AdjustmentTypeHasBeenSet() const { return m_adjustmentTypeHasBeenSet; }
 
     /**
-     * <p>Specifies how the scaling adjustment is interpreted (for example, an absolute
-     * number or a percentage). The valid values are <code>ChangeInCapacity</code>,
+     * <p>The adjustment type, which specifies how <code>ScalingAdjustment</code> is
+     * interpreted. The valid values are <code>ChangeInCapacity</code>,
      * <code>ExactCapacity</code>, and <code>PercentChangeInCapacity</code>.</p>
      */
     inline void SetAdjustmentType(const Aws::String& value) { m_adjustmentTypeHasBeenSet = true; m_adjustmentType = value; }
 
     /**
-     * <p>Specifies how the scaling adjustment is interpreted (for example, an absolute
-     * number or a percentage). The valid values are <code>ChangeInCapacity</code>,
+     * <p>The adjustment type, which specifies how <code>ScalingAdjustment</code> is
+     * interpreted. The valid values are <code>ChangeInCapacity</code>,
      * <code>ExactCapacity</code>, and <code>PercentChangeInCapacity</code>.</p>
      */
     inline void SetAdjustmentType(Aws::String&& value) { m_adjustmentTypeHasBeenSet = true; m_adjustmentType = std::move(value); }
 
     /**
-     * <p>Specifies how the scaling adjustment is interpreted (for example, an absolute
-     * number or a percentage). The valid values are <code>ChangeInCapacity</code>,
+     * <p>The adjustment type, which specifies how <code>ScalingAdjustment</code> is
+     * interpreted. The valid values are <code>ChangeInCapacity</code>,
      * <code>ExactCapacity</code>, and <code>PercentChangeInCapacity</code>.</p>
      */
     inline void SetAdjustmentType(const char* value) { m_adjustmentTypeHasBeenSet = true; m_adjustmentType.assign(value); }
 
     /**
-     * <p>Specifies how the scaling adjustment is interpreted (for example, an absolute
-     * number or a percentage). The valid values are <code>ChangeInCapacity</code>,
+     * <p>The adjustment type, which specifies how <code>ScalingAdjustment</code> is
+     * interpreted. The valid values are <code>ChangeInCapacity</code>,
      * <code>ExactCapacity</code>, and <code>PercentChangeInCapacity</code>.</p>
      */
     inline ScalingPolicy& WithAdjustmentType(const Aws::String& value) { SetAdjustmentType(value); return *this;}
 
     /**
-     * <p>Specifies how the scaling adjustment is interpreted (for example, an absolute
-     * number or a percentage). The valid values are <code>ChangeInCapacity</code>,
+     * <p>The adjustment type, which specifies how <code>ScalingAdjustment</code> is
+     * interpreted. The valid values are <code>ChangeInCapacity</code>,
      * <code>ExactCapacity</code>, and <code>PercentChangeInCapacity</code>.</p>
      */
     inline ScalingPolicy& WithAdjustmentType(Aws::String&& value) { SetAdjustmentType(std::move(value)); return *this;}
 
     /**
-     * <p>Specifies how the scaling adjustment is interpreted (for example, an absolute
-     * number or a percentage). The valid values are <code>ChangeInCapacity</code>,
+     * <p>The adjustment type, which specifies how <code>ScalingAdjustment</code> is
+     * interpreted. The valid values are <code>ChangeInCapacity</code>,
      * <code>ExactCapacity</code>, and <code>PercentChangeInCapacity</code>.</p>
      */
     inline ScalingPolicy& WithAdjustmentType(const char* value) { SetAdjustmentType(value); return *this;}
@@ -354,26 +308,38 @@ namespace Model
 
 
     /**
-     * <p>The minimum value to scale by when the adjustment type is
-     * <code>PercentChangeInCapacity</code>. </p>
+     * <p>The minimum number of instances to scale. If the value of
+     * <code>AdjustmentType</code> is <code>PercentChangeInCapacity</code>, the scaling
+     * policy changes the <code>DesiredCapacity</code> of the Auto Scaling group by at
+     * least this many instances. Otherwise, the error is
+     * <code>ValidationError</code>.</p>
      */
     inline int GetMinAdjustmentMagnitude() const{ return m_minAdjustmentMagnitude; }
 
     /**
-     * <p>The minimum value to scale by when the adjustment type is
-     * <code>PercentChangeInCapacity</code>. </p>
+     * <p>The minimum number of instances to scale. If the value of
+     * <code>AdjustmentType</code> is <code>PercentChangeInCapacity</code>, the scaling
+     * policy changes the <code>DesiredCapacity</code> of the Auto Scaling group by at
+     * least this many instances. Otherwise, the error is
+     * <code>ValidationError</code>.</p>
      */
     inline bool MinAdjustmentMagnitudeHasBeenSet() const { return m_minAdjustmentMagnitudeHasBeenSet; }
 
     /**
-     * <p>The minimum value to scale by when the adjustment type is
-     * <code>PercentChangeInCapacity</code>. </p>
+     * <p>The minimum number of instances to scale. If the value of
+     * <code>AdjustmentType</code> is <code>PercentChangeInCapacity</code>, the scaling
+     * policy changes the <code>DesiredCapacity</code> of the Auto Scaling group by at
+     * least this many instances. Otherwise, the error is
+     * <code>ValidationError</code>.</p>
      */
     inline void SetMinAdjustmentMagnitude(int value) { m_minAdjustmentMagnitudeHasBeenSet = true; m_minAdjustmentMagnitude = value; }
 
     /**
-     * <p>The minimum value to scale by when the adjustment type is
-     * <code>PercentChangeInCapacity</code>. </p>
+     * <p>The minimum number of instances to scale. If the value of
+     * <code>AdjustmentType</code> is <code>PercentChangeInCapacity</code>, the scaling
+     * policy changes the <code>DesiredCapacity</code> of the Auto Scaling group by at
+     * least this many instances. Otherwise, the error is
+     * <code>ValidationError</code>.</p>
      */
     inline ScalingPolicy& WithMinAdjustmentMagnitude(int value) { SetMinAdjustmentMagnitude(value); return *this;}
 
@@ -408,22 +374,26 @@ namespace Model
 
 
     /**
-     * <p>The duration of the policy's cooldown period, in seconds.</p>
+     * <p>The amount of time, in seconds, after a scaling activity completes before any
+     * further dynamic scaling activities can start.</p>
      */
     inline int GetCooldown() const{ return m_cooldown; }
 
     /**
-     * <p>The duration of the policy's cooldown period, in seconds.</p>
+     * <p>The amount of time, in seconds, after a scaling activity completes before any
+     * further dynamic scaling activities can start.</p>
      */
     inline bool CooldownHasBeenSet() const { return m_cooldownHasBeenSet; }
 
     /**
-     * <p>The duration of the policy's cooldown period, in seconds.</p>
+     * <p>The amount of time, in seconds, after a scaling activity completes before any
+     * further dynamic scaling activities can start.</p>
      */
     inline void SetCooldown(int value) { m_cooldownHasBeenSet = true; m_cooldown = value; }
 
     /**
-     * <p>The duration of the policy's cooldown period, in seconds.</p>
+     * <p>The amount of time, in seconds, after a scaling activity completes before any
+     * further dynamic scaling activities can start.</p>
      */
     inline ScalingPolicy& WithCooldown(int value) { SetCooldown(value); return *this;}
 
@@ -622,31 +592,6 @@ namespace Model
      */
     inline ScalingPolicy& WithTargetTrackingConfiguration(TargetTrackingConfiguration&& value) { SetTargetTrackingConfiguration(std::move(value)); return *this;}
 
-
-    /**
-     * <p>Indicates whether the policy is enabled (<code>true</code>) or disabled
-     * (<code>false</code>).</p>
-     */
-    inline bool GetEnabled() const{ return m_enabled; }
-
-    /**
-     * <p>Indicates whether the policy is enabled (<code>true</code>) or disabled
-     * (<code>false</code>).</p>
-     */
-    inline bool EnabledHasBeenSet() const { return m_enabledHasBeenSet; }
-
-    /**
-     * <p>Indicates whether the policy is enabled (<code>true</code>) or disabled
-     * (<code>false</code>).</p>
-     */
-    inline void SetEnabled(bool value) { m_enabledHasBeenSet = true; m_enabled = value; }
-
-    /**
-     * <p>Indicates whether the policy is enabled (<code>true</code>) or disabled
-     * (<code>false</code>).</p>
-     */
-    inline ScalingPolicy& WithEnabled(bool value) { SetEnabled(value); return *this;}
-
   private:
 
     Aws::String m_autoScalingGroupName;
@@ -690,9 +635,6 @@ namespace Model
 
     TargetTrackingConfiguration m_targetTrackingConfiguration;
     bool m_targetTrackingConfigurationHasBeenSet;
-
-    bool m_enabled;
-    bool m_enabledHasBeenSet;
   };
 
 } // namespace Model
