@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/autoscaling/AutoScaling_EXPORTS.h>
@@ -25,7 +35,7 @@ namespace Model
   {
   public:
     UpdateAutoScalingGroupRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -81,130 +91,101 @@ namespace Model
 
 
     /**
-     * <p>The name of the launch configuration. If you specify
-     * <code>LaunchConfigurationName</code> in your update request, you can't specify
-     * <code>LaunchTemplate</code> or <code>MixedInstancesPolicy</code>.</p>
+     * <p>The name of the launch configuration. If you specify this parameter, you
+     * can't specify a launch template or a mixed instances policy.</p>
      */
     inline const Aws::String& GetLaunchConfigurationName() const{ return m_launchConfigurationName; }
 
     /**
-     * <p>The name of the launch configuration. If you specify
-     * <code>LaunchConfigurationName</code> in your update request, you can't specify
-     * <code>LaunchTemplate</code> or <code>MixedInstancesPolicy</code>.</p>
+     * <p>The name of the launch configuration. If you specify this parameter, you
+     * can't specify a launch template or a mixed instances policy.</p>
      */
     inline bool LaunchConfigurationNameHasBeenSet() const { return m_launchConfigurationNameHasBeenSet; }
 
     /**
-     * <p>The name of the launch configuration. If you specify
-     * <code>LaunchConfigurationName</code> in your update request, you can't specify
-     * <code>LaunchTemplate</code> or <code>MixedInstancesPolicy</code>.</p>
+     * <p>The name of the launch configuration. If you specify this parameter, you
+     * can't specify a launch template or a mixed instances policy.</p>
      */
     inline void SetLaunchConfigurationName(const Aws::String& value) { m_launchConfigurationNameHasBeenSet = true; m_launchConfigurationName = value; }
 
     /**
-     * <p>The name of the launch configuration. If you specify
-     * <code>LaunchConfigurationName</code> in your update request, you can't specify
-     * <code>LaunchTemplate</code> or <code>MixedInstancesPolicy</code>.</p>
+     * <p>The name of the launch configuration. If you specify this parameter, you
+     * can't specify a launch template or a mixed instances policy.</p>
      */
     inline void SetLaunchConfigurationName(Aws::String&& value) { m_launchConfigurationNameHasBeenSet = true; m_launchConfigurationName = std::move(value); }
 
     /**
-     * <p>The name of the launch configuration. If you specify
-     * <code>LaunchConfigurationName</code> in your update request, you can't specify
-     * <code>LaunchTemplate</code> or <code>MixedInstancesPolicy</code>.</p>
+     * <p>The name of the launch configuration. If you specify this parameter, you
+     * can't specify a launch template or a mixed instances policy.</p>
      */
     inline void SetLaunchConfigurationName(const char* value) { m_launchConfigurationNameHasBeenSet = true; m_launchConfigurationName.assign(value); }
 
     /**
-     * <p>The name of the launch configuration. If you specify
-     * <code>LaunchConfigurationName</code> in your update request, you can't specify
-     * <code>LaunchTemplate</code> or <code>MixedInstancesPolicy</code>.</p>
+     * <p>The name of the launch configuration. If you specify this parameter, you
+     * can't specify a launch template or a mixed instances policy.</p>
      */
     inline UpdateAutoScalingGroupRequest& WithLaunchConfigurationName(const Aws::String& value) { SetLaunchConfigurationName(value); return *this;}
 
     /**
-     * <p>The name of the launch configuration. If you specify
-     * <code>LaunchConfigurationName</code> in your update request, you can't specify
-     * <code>LaunchTemplate</code> or <code>MixedInstancesPolicy</code>.</p>
+     * <p>The name of the launch configuration. If you specify this parameter, you
+     * can't specify a launch template or a mixed instances policy.</p>
      */
     inline UpdateAutoScalingGroupRequest& WithLaunchConfigurationName(Aws::String&& value) { SetLaunchConfigurationName(std::move(value)); return *this;}
 
     /**
-     * <p>The name of the launch configuration. If you specify
-     * <code>LaunchConfigurationName</code> in your update request, you can't specify
-     * <code>LaunchTemplate</code> or <code>MixedInstancesPolicy</code>.</p>
+     * <p>The name of the launch configuration. If you specify this parameter, you
+     * can't specify a launch template or a mixed instances policy.</p>
      */
     inline UpdateAutoScalingGroupRequest& WithLaunchConfigurationName(const char* value) { SetLaunchConfigurationName(value); return *this;}
 
 
     /**
      * <p>The launch template and version to use to specify the updates. If you specify
-     * <code>LaunchTemplate</code> in your update request, you can't specify
-     * <code>LaunchConfigurationName</code> or <code>MixedInstancesPolicy</code>.</p>
-     * <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_LaunchTemplateSpecification.html">LaunchTemplateSpecification</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i>.</p>
+     * this parameter, you can't specify a launch configuration or a mixed instances
+     * policy.</p>
      */
     inline const LaunchTemplateSpecification& GetLaunchTemplate() const{ return m_launchTemplate; }
 
     /**
      * <p>The launch template and version to use to specify the updates. If you specify
-     * <code>LaunchTemplate</code> in your update request, you can't specify
-     * <code>LaunchConfigurationName</code> or <code>MixedInstancesPolicy</code>.</p>
-     * <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_LaunchTemplateSpecification.html">LaunchTemplateSpecification</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i>.</p>
+     * this parameter, you can't specify a launch configuration or a mixed instances
+     * policy.</p>
      */
     inline bool LaunchTemplateHasBeenSet() const { return m_launchTemplateHasBeenSet; }
 
     /**
      * <p>The launch template and version to use to specify the updates. If you specify
-     * <code>LaunchTemplate</code> in your update request, you can't specify
-     * <code>LaunchConfigurationName</code> or <code>MixedInstancesPolicy</code>.</p>
-     * <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_LaunchTemplateSpecification.html">LaunchTemplateSpecification</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i>.</p>
+     * this parameter, you can't specify a launch configuration or a mixed instances
+     * policy.</p>
      */
     inline void SetLaunchTemplate(const LaunchTemplateSpecification& value) { m_launchTemplateHasBeenSet = true; m_launchTemplate = value; }
 
     /**
      * <p>The launch template and version to use to specify the updates. If you specify
-     * <code>LaunchTemplate</code> in your update request, you can't specify
-     * <code>LaunchConfigurationName</code> or <code>MixedInstancesPolicy</code>.</p>
-     * <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_LaunchTemplateSpecification.html">LaunchTemplateSpecification</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i>.</p>
+     * this parameter, you can't specify a launch configuration or a mixed instances
+     * policy.</p>
      */
     inline void SetLaunchTemplate(LaunchTemplateSpecification&& value) { m_launchTemplateHasBeenSet = true; m_launchTemplate = std::move(value); }
 
     /**
      * <p>The launch template and version to use to specify the updates. If you specify
-     * <code>LaunchTemplate</code> in your update request, you can't specify
-     * <code>LaunchConfigurationName</code> or <code>MixedInstancesPolicy</code>.</p>
-     * <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_LaunchTemplateSpecification.html">LaunchTemplateSpecification</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i>.</p>
+     * this parameter, you can't specify a launch configuration or a mixed instances
+     * policy.</p>
      */
     inline UpdateAutoScalingGroupRequest& WithLaunchTemplate(const LaunchTemplateSpecification& value) { SetLaunchTemplate(value); return *this;}
 
     /**
      * <p>The launch template and version to use to specify the updates. If you specify
-     * <code>LaunchTemplate</code> in your update request, you can't specify
-     * <code>LaunchConfigurationName</code> or <code>MixedInstancesPolicy</code>.</p>
-     * <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_LaunchTemplateSpecification.html">LaunchTemplateSpecification</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i>.</p>
+     * this parameter, you can't specify a launch configuration or a mixed instances
+     * policy.</p>
      */
     inline UpdateAutoScalingGroupRequest& WithLaunchTemplate(LaunchTemplateSpecification&& value) { SetLaunchTemplate(std::move(value)); return *this;}
 
 
     /**
-     * <p>An embedded object that specifies a mixed instances policy.</p> <p>In your
-     * call to <code>UpdateAutoScalingGroup</code>, you can make changes to the policy
-     * that is specified. All optional parameters are left unchanged if not
-     * specified.</p> <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_MixedInstancesPolicy.html">MixedInstancesPolicy</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i> and <a
+     * <p>The mixed instances policy to use to specify the updates. If you specify this
+     * parameter, you can't specify a launch configuration or a launch template. </p>
+     * <p>For more information, see <a
      * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-purchase-options.html">Auto
      * Scaling Groups with Multiple Instance Types and Purchase Options</a> in the
      * <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
@@ -212,12 +193,9 @@ namespace Model
     inline const MixedInstancesPolicy& GetMixedInstancesPolicy() const{ return m_mixedInstancesPolicy; }
 
     /**
-     * <p>An embedded object that specifies a mixed instances policy.</p> <p>In your
-     * call to <code>UpdateAutoScalingGroup</code>, you can make changes to the policy
-     * that is specified. All optional parameters are left unchanged if not
-     * specified.</p> <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_MixedInstancesPolicy.html">MixedInstancesPolicy</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i> and <a
+     * <p>The mixed instances policy to use to specify the updates. If you specify this
+     * parameter, you can't specify a launch configuration or a launch template. </p>
+     * <p>For more information, see <a
      * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-purchase-options.html">Auto
      * Scaling Groups with Multiple Instance Types and Purchase Options</a> in the
      * <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
@@ -225,12 +203,9 @@ namespace Model
     inline bool MixedInstancesPolicyHasBeenSet() const { return m_mixedInstancesPolicyHasBeenSet; }
 
     /**
-     * <p>An embedded object that specifies a mixed instances policy.</p> <p>In your
-     * call to <code>UpdateAutoScalingGroup</code>, you can make changes to the policy
-     * that is specified. All optional parameters are left unchanged if not
-     * specified.</p> <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_MixedInstancesPolicy.html">MixedInstancesPolicy</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i> and <a
+     * <p>The mixed instances policy to use to specify the updates. If you specify this
+     * parameter, you can't specify a launch configuration or a launch template. </p>
+     * <p>For more information, see <a
      * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-purchase-options.html">Auto
      * Scaling Groups with Multiple Instance Types and Purchase Options</a> in the
      * <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
@@ -238,12 +213,9 @@ namespace Model
     inline void SetMixedInstancesPolicy(const MixedInstancesPolicy& value) { m_mixedInstancesPolicyHasBeenSet = true; m_mixedInstancesPolicy = value; }
 
     /**
-     * <p>An embedded object that specifies a mixed instances policy.</p> <p>In your
-     * call to <code>UpdateAutoScalingGroup</code>, you can make changes to the policy
-     * that is specified. All optional parameters are left unchanged if not
-     * specified.</p> <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_MixedInstancesPolicy.html">MixedInstancesPolicy</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i> and <a
+     * <p>The mixed instances policy to use to specify the updates. If you specify this
+     * parameter, you can't specify a launch configuration or a launch template. </p>
+     * <p>For more information, see <a
      * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-purchase-options.html">Auto
      * Scaling Groups with Multiple Instance Types and Purchase Options</a> in the
      * <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
@@ -251,12 +223,9 @@ namespace Model
     inline void SetMixedInstancesPolicy(MixedInstancesPolicy&& value) { m_mixedInstancesPolicyHasBeenSet = true; m_mixedInstancesPolicy = std::move(value); }
 
     /**
-     * <p>An embedded object that specifies a mixed instances policy.</p> <p>In your
-     * call to <code>UpdateAutoScalingGroup</code>, you can make changes to the policy
-     * that is specified. All optional parameters are left unchanged if not
-     * specified.</p> <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_MixedInstancesPolicy.html">MixedInstancesPolicy</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i> and <a
+     * <p>The mixed instances policy to use to specify the updates. If you specify this
+     * parameter, you can't specify a launch configuration or a launch template. </p>
+     * <p>For more information, see <a
      * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-purchase-options.html">Auto
      * Scaling Groups with Multiple Instance Types and Purchase Options</a> in the
      * <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
@@ -264,12 +233,9 @@ namespace Model
     inline UpdateAutoScalingGroupRequest& WithMixedInstancesPolicy(const MixedInstancesPolicy& value) { SetMixedInstancesPolicy(value); return *this;}
 
     /**
-     * <p>An embedded object that specifies a mixed instances policy.</p> <p>In your
-     * call to <code>UpdateAutoScalingGroup</code>, you can make changes to the policy
-     * that is specified. All optional parameters are left unchanged if not
-     * specified.</p> <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_MixedInstancesPolicy.html">MixedInstancesPolicy</a>
-     * in the <i>Amazon EC2 Auto Scaling API Reference</i> and <a
+     * <p>The mixed instances policy to use to specify the updates. If you specify this
+     * parameter, you can't specify a launch configuration or a launch template. </p>
+     * <p>For more information, see <a
      * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-purchase-options.html">Auto
      * Scaling Groups with Multiple Instance Types and Purchase Options</a> in the
      * <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
@@ -299,75 +265,51 @@ namespace Model
 
 
     /**
-     * <p>The maximum size of the Auto Scaling group.</p>  <p>With a mixed
-     * instances policy that uses instance weighting, Amazon EC2 Auto Scaling may need
-     * to go above <code>MaxSize</code> to meet your capacity requirements. In this
-     * event, Amazon EC2 Auto Scaling will never go above <code>MaxSize</code> by more
-     * than your largest instance weight (weights that define how many units each
-     * instance contributes to the desired capacity of the group).</p> 
+     * <p>The maximum size of the Auto Scaling group.</p>
      */
     inline int GetMaxSize() const{ return m_maxSize; }
 
     /**
-     * <p>The maximum size of the Auto Scaling group.</p>  <p>With a mixed
-     * instances policy that uses instance weighting, Amazon EC2 Auto Scaling may need
-     * to go above <code>MaxSize</code> to meet your capacity requirements. In this
-     * event, Amazon EC2 Auto Scaling will never go above <code>MaxSize</code> by more
-     * than your largest instance weight (weights that define how many units each
-     * instance contributes to the desired capacity of the group).</p> 
+     * <p>The maximum size of the Auto Scaling group.</p>
      */
     inline bool MaxSizeHasBeenSet() const { return m_maxSizeHasBeenSet; }
 
     /**
-     * <p>The maximum size of the Auto Scaling group.</p>  <p>With a mixed
-     * instances policy that uses instance weighting, Amazon EC2 Auto Scaling may need
-     * to go above <code>MaxSize</code> to meet your capacity requirements. In this
-     * event, Amazon EC2 Auto Scaling will never go above <code>MaxSize</code> by more
-     * than your largest instance weight (weights that define how many units each
-     * instance contributes to the desired capacity of the group).</p> 
+     * <p>The maximum size of the Auto Scaling group.</p>
      */
     inline void SetMaxSize(int value) { m_maxSizeHasBeenSet = true; m_maxSize = value; }
 
     /**
-     * <p>The maximum size of the Auto Scaling group.</p>  <p>With a mixed
-     * instances policy that uses instance weighting, Amazon EC2 Auto Scaling may need
-     * to go above <code>MaxSize</code> to meet your capacity requirements. In this
-     * event, Amazon EC2 Auto Scaling will never go above <code>MaxSize</code> by more
-     * than your largest instance weight (weights that define how many units each
-     * instance contributes to the desired capacity of the group).</p> 
+     * <p>The maximum size of the Auto Scaling group.</p>
      */
     inline UpdateAutoScalingGroupRequest& WithMaxSize(int value) { SetMaxSize(value); return *this;}
 
 
     /**
-     * <p>The desired capacity is the initial capacity of the Auto Scaling group after
-     * this operation completes and the capacity it attempts to maintain.</p> <p>This
-     * number must be greater than or equal to the minimum size of the group and less
-     * than or equal to the maximum size of the group.</p>
+     * <p>The number of EC2 instances that should be running in the Auto Scaling group.
+     * This number must be greater than or equal to the minimum size of the group and
+     * less than or equal to the maximum size of the group.</p>
      */
     inline int GetDesiredCapacity() const{ return m_desiredCapacity; }
 
     /**
-     * <p>The desired capacity is the initial capacity of the Auto Scaling group after
-     * this operation completes and the capacity it attempts to maintain.</p> <p>This
-     * number must be greater than or equal to the minimum size of the group and less
-     * than or equal to the maximum size of the group.</p>
+     * <p>The number of EC2 instances that should be running in the Auto Scaling group.
+     * This number must be greater than or equal to the minimum size of the group and
+     * less than or equal to the maximum size of the group.</p>
      */
     inline bool DesiredCapacityHasBeenSet() const { return m_desiredCapacityHasBeenSet; }
 
     /**
-     * <p>The desired capacity is the initial capacity of the Auto Scaling group after
-     * this operation completes and the capacity it attempts to maintain.</p> <p>This
-     * number must be greater than or equal to the minimum size of the group and less
-     * than or equal to the maximum size of the group.</p>
+     * <p>The number of EC2 instances that should be running in the Auto Scaling group.
+     * This number must be greater than or equal to the minimum size of the group and
+     * less than or equal to the maximum size of the group.</p>
      */
     inline void SetDesiredCapacity(int value) { m_desiredCapacityHasBeenSet = true; m_desiredCapacity = value; }
 
     /**
-     * <p>The desired capacity is the initial capacity of the Auto Scaling group after
-     * this operation completes and the capacity it attempts to maintain.</p> <p>This
-     * number must be greater than or equal to the minimum size of the group and less
-     * than or equal to the maximum size of the group.</p>
+     * <p>The number of EC2 instances that should be running in the Auto Scaling group.
+     * This number must be greater than or equal to the minimum size of the group and
+     * less than or equal to the maximum size of the group.</p>
      */
     inline UpdateAutoScalingGroupRequest& WithDesiredCapacity(int value) { SetDesiredCapacity(value); return *this;}
 
@@ -375,44 +317,36 @@ namespace Model
     /**
      * <p>The amount of time, in seconds, after a scaling activity completes before
      * another scaling activity can start. The default value is <code>300</code>.</p>
-     * <p>This setting applies when using simple scaling policies, but not when using
-     * other scaling policies or scheduled scaling. For more information, see <a
+     * <p>For more information, see <a
      * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/Cooldown.html">Scaling
-     * Cooldowns for Amazon EC2 Auto Scaling</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * Cooldowns</a> in the <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
      */
     inline int GetDefaultCooldown() const{ return m_defaultCooldown; }
 
     /**
      * <p>The amount of time, in seconds, after a scaling activity completes before
      * another scaling activity can start. The default value is <code>300</code>.</p>
-     * <p>This setting applies when using simple scaling policies, but not when using
-     * other scaling policies or scheduled scaling. For more information, see <a
+     * <p>For more information, see <a
      * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/Cooldown.html">Scaling
-     * Cooldowns for Amazon EC2 Auto Scaling</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * Cooldowns</a> in the <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
      */
     inline bool DefaultCooldownHasBeenSet() const { return m_defaultCooldownHasBeenSet; }
 
     /**
      * <p>The amount of time, in seconds, after a scaling activity completes before
      * another scaling activity can start. The default value is <code>300</code>.</p>
-     * <p>This setting applies when using simple scaling policies, but not when using
-     * other scaling policies or scheduled scaling. For more information, see <a
+     * <p>For more information, see <a
      * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/Cooldown.html">Scaling
-     * Cooldowns for Amazon EC2 Auto Scaling</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * Cooldowns</a> in the <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
      */
     inline void SetDefaultCooldown(int value) { m_defaultCooldownHasBeenSet = true; m_defaultCooldown = value; }
 
     /**
      * <p>The amount of time, in seconds, after a scaling activity completes before
      * another scaling activity can start. The default value is <code>300</code>.</p>
-     * <p>This setting applies when using simple scaling policies, but not when using
-     * other scaling policies or scheduled scaling. For more information, see <a
+     * <p>For more information, see <a
      * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/Cooldown.html">Scaling
-     * Cooldowns for Amazon EC2 Auto Scaling</a> in the <i>Amazon EC2 Auto Scaling User
-     * Guide</i>.</p>
+     * Cooldowns</a> in the <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
      */
     inline UpdateAutoScalingGroupRequest& WithDefaultCooldown(int value) { SetDefaultCooldown(value); return *this;}
 
@@ -532,9 +466,10 @@ namespace Model
      * <p>The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before
      * checking the health status of an EC2 instance that has come into service. The
      * default value is <code>0</code>.</p> <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/healthcheck.html#health-check-grace-period">Health
-     * Check Grace Period</a> in the <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
-     * <p>Required if you are adding an <code>ELB</code> health check.</p>
+     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/healthcheck.html">Health
+     * Checks for Auto Scaling Instances</a> in the <i>Amazon EC2 Auto Scaling User
+     * Guide</i>.</p> <p>Conditional: This parameter is required if you are adding an
+     * <code>ELB</code> health check.</p>
      */
     inline int GetHealthCheckGracePeriod() const{ return m_healthCheckGracePeriod; }
 
@@ -542,9 +477,10 @@ namespace Model
      * <p>The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before
      * checking the health status of an EC2 instance that has come into service. The
      * default value is <code>0</code>.</p> <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/healthcheck.html#health-check-grace-period">Health
-     * Check Grace Period</a> in the <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
-     * <p>Required if you are adding an <code>ELB</code> health check.</p>
+     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/healthcheck.html">Health
+     * Checks for Auto Scaling Instances</a> in the <i>Amazon EC2 Auto Scaling User
+     * Guide</i>.</p> <p>Conditional: This parameter is required if you are adding an
+     * <code>ELB</code> health check.</p>
      */
     inline bool HealthCheckGracePeriodHasBeenSet() const { return m_healthCheckGracePeriodHasBeenSet; }
 
@@ -552,9 +488,10 @@ namespace Model
      * <p>The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before
      * checking the health status of an EC2 instance that has come into service. The
      * default value is <code>0</code>.</p> <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/healthcheck.html#health-check-grace-period">Health
-     * Check Grace Period</a> in the <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
-     * <p>Required if you are adding an <code>ELB</code> health check.</p>
+     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/healthcheck.html">Health
+     * Checks for Auto Scaling Instances</a> in the <i>Amazon EC2 Auto Scaling User
+     * Guide</i>.</p> <p>Conditional: This parameter is required if you are adding an
+     * <code>ELB</code> health check.</p>
      */
     inline void SetHealthCheckGracePeriod(int value) { m_healthCheckGracePeriodHasBeenSet = true; m_healthCheckGracePeriod = value; }
 
@@ -562,9 +499,10 @@ namespace Model
      * <p>The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before
      * checking the health status of an EC2 instance that has come into service. The
      * default value is <code>0</code>.</p> <p>For more information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/healthcheck.html#health-check-grace-period">Health
-     * Check Grace Period</a> in the <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
-     * <p>Required if you are adding an <code>ELB</code> health check.</p>
+     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/healthcheck.html">Health
+     * Checks for Auto Scaling Instances</a> in the <i>Amazon EC2 Auto Scaling User
+     * Guide</i>.</p> <p>Conditional: This parameter is required if you are adding an
+     * <code>ELB</code> health check.</p>
      */
     inline UpdateAutoScalingGroupRequest& WithHealthCheckGracePeriod(int value) { SetHealthCheckGracePeriod(value); return *this;}
 
@@ -651,7 +589,7 @@ namespace Model
 
 
     /**
-     * <p>A comma-separated list of subnet IDs for virtual private cloud (VPC).</p>
+     * <p>A comma-separated list of subnet IDs, if you are launching into a VPC.</p>
      * <p>If you specify <code>VPCZoneIdentifier</code> with
      * <code>AvailabilityZones</code>, the subnets that you specify for this parameter
      * must reside in those Availability Zones.</p>
@@ -659,7 +597,7 @@ namespace Model
     inline const Aws::String& GetVPCZoneIdentifier() const{ return m_vPCZoneIdentifier; }
 
     /**
-     * <p>A comma-separated list of subnet IDs for virtual private cloud (VPC).</p>
+     * <p>A comma-separated list of subnet IDs, if you are launching into a VPC.</p>
      * <p>If you specify <code>VPCZoneIdentifier</code> with
      * <code>AvailabilityZones</code>, the subnets that you specify for this parameter
      * must reside in those Availability Zones.</p>
@@ -667,7 +605,7 @@ namespace Model
     inline bool VPCZoneIdentifierHasBeenSet() const { return m_vPCZoneIdentifierHasBeenSet; }
 
     /**
-     * <p>A comma-separated list of subnet IDs for virtual private cloud (VPC).</p>
+     * <p>A comma-separated list of subnet IDs, if you are launching into a VPC.</p>
      * <p>If you specify <code>VPCZoneIdentifier</code> with
      * <code>AvailabilityZones</code>, the subnets that you specify for this parameter
      * must reside in those Availability Zones.</p>
@@ -675,7 +613,7 @@ namespace Model
     inline void SetVPCZoneIdentifier(const Aws::String& value) { m_vPCZoneIdentifierHasBeenSet = true; m_vPCZoneIdentifier = value; }
 
     /**
-     * <p>A comma-separated list of subnet IDs for virtual private cloud (VPC).</p>
+     * <p>A comma-separated list of subnet IDs, if you are launching into a VPC.</p>
      * <p>If you specify <code>VPCZoneIdentifier</code> with
      * <code>AvailabilityZones</code>, the subnets that you specify for this parameter
      * must reside in those Availability Zones.</p>
@@ -683,7 +621,7 @@ namespace Model
     inline void SetVPCZoneIdentifier(Aws::String&& value) { m_vPCZoneIdentifierHasBeenSet = true; m_vPCZoneIdentifier = std::move(value); }
 
     /**
-     * <p>A comma-separated list of subnet IDs for virtual private cloud (VPC).</p>
+     * <p>A comma-separated list of subnet IDs, if you are launching into a VPC.</p>
      * <p>If you specify <code>VPCZoneIdentifier</code> with
      * <code>AvailabilityZones</code>, the subnets that you specify for this parameter
      * must reside in those Availability Zones.</p>
@@ -691,7 +629,7 @@ namespace Model
     inline void SetVPCZoneIdentifier(const char* value) { m_vPCZoneIdentifierHasBeenSet = true; m_vPCZoneIdentifier.assign(value); }
 
     /**
-     * <p>A comma-separated list of subnet IDs for virtual private cloud (VPC).</p>
+     * <p>A comma-separated list of subnet IDs, if you are launching into a VPC.</p>
      * <p>If you specify <code>VPCZoneIdentifier</code> with
      * <code>AvailabilityZones</code>, the subnets that you specify for this parameter
      * must reside in those Availability Zones.</p>
@@ -699,7 +637,7 @@ namespace Model
     inline UpdateAutoScalingGroupRequest& WithVPCZoneIdentifier(const Aws::String& value) { SetVPCZoneIdentifier(value); return *this;}
 
     /**
-     * <p>A comma-separated list of subnet IDs for virtual private cloud (VPC).</p>
+     * <p>A comma-separated list of subnet IDs, if you are launching into a VPC.</p>
      * <p>If you specify <code>VPCZoneIdentifier</code> with
      * <code>AvailabilityZones</code>, the subnets that you specify for this parameter
      * must reside in those Availability Zones.</p>
@@ -707,7 +645,7 @@ namespace Model
     inline UpdateAutoScalingGroupRequest& WithVPCZoneIdentifier(Aws::String&& value) { SetVPCZoneIdentifier(std::move(value)); return *this;}
 
     /**
-     * <p>A comma-separated list of subnet IDs for virtual private cloud (VPC).</p>
+     * <p>A comma-separated list of subnet IDs, if you are launching into a VPC.</p>
      * <p>If you specify <code>VPCZoneIdentifier</code> with
      * <code>AvailabilityZones</code>, the subnets that you specify for this parameter
      * must reside in those Availability Zones.</p>
@@ -915,55 +853,6 @@ namespace Model
      */
     inline UpdateAutoScalingGroupRequest& WithServiceLinkedRoleARN(const char* value) { SetServiceLinkedRoleARN(value); return *this;}
 
-
-    /**
-     * <p>The maximum amount of time, in seconds, that an instance can be in service.
-     * The default is null.</p> <p>This parameter is optional, but if you specify a
-     * value for it, you must specify a value of at least 604,800 seconds (7 days). To
-     * clear a previously set value, specify a new value of 0.</p> <p>For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-max-instance-lifetime.html">Replacing
-     * Auto Scaling Instances Based on Maximum Instance Lifetime</a> in the <i>Amazon
-     * EC2 Auto Scaling User Guide</i>.</p> <p>Valid Range: Minimum value of 0.</p>
-     */
-    inline int GetMaxInstanceLifetime() const{ return m_maxInstanceLifetime; }
-
-    /**
-     * <p>The maximum amount of time, in seconds, that an instance can be in service.
-     * The default is null.</p> <p>This parameter is optional, but if you specify a
-     * value for it, you must specify a value of at least 604,800 seconds (7 days). To
-     * clear a previously set value, specify a new value of 0.</p> <p>For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-max-instance-lifetime.html">Replacing
-     * Auto Scaling Instances Based on Maximum Instance Lifetime</a> in the <i>Amazon
-     * EC2 Auto Scaling User Guide</i>.</p> <p>Valid Range: Minimum value of 0.</p>
-     */
-    inline bool MaxInstanceLifetimeHasBeenSet() const { return m_maxInstanceLifetimeHasBeenSet; }
-
-    /**
-     * <p>The maximum amount of time, in seconds, that an instance can be in service.
-     * The default is null.</p> <p>This parameter is optional, but if you specify a
-     * value for it, you must specify a value of at least 604,800 seconds (7 days). To
-     * clear a previously set value, specify a new value of 0.</p> <p>For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-max-instance-lifetime.html">Replacing
-     * Auto Scaling Instances Based on Maximum Instance Lifetime</a> in the <i>Amazon
-     * EC2 Auto Scaling User Guide</i>.</p> <p>Valid Range: Minimum value of 0.</p>
-     */
-    inline void SetMaxInstanceLifetime(int value) { m_maxInstanceLifetimeHasBeenSet = true; m_maxInstanceLifetime = value; }
-
-    /**
-     * <p>The maximum amount of time, in seconds, that an instance can be in service.
-     * The default is null.</p> <p>This parameter is optional, but if you specify a
-     * value for it, you must specify a value of at least 604,800 seconds (7 days). To
-     * clear a previously set value, specify a new value of 0.</p> <p>For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/asg-max-instance-lifetime.html">Replacing
-     * Auto Scaling Instances Based on Maximum Instance Lifetime</a> in the <i>Amazon
-     * EC2 Auto Scaling User Guide</i>.</p> <p>Valid Range: Minimum value of 0.</p>
-     */
-    inline UpdateAutoScalingGroupRequest& WithMaxInstanceLifetime(int value) { SetMaxInstanceLifetime(value); return *this;}
-
   private:
 
     Aws::String m_autoScalingGroupName;
@@ -1013,9 +902,6 @@ namespace Model
 
     Aws::String m_serviceLinkedRoleARN;
     bool m_serviceLinkedRoleARNHasBeenSet;
-
-    int m_maxInstanceLifetime;
-    bool m_maxInstanceLifetimeHasBeenSet;
   };
 
 } // namespace Model
