@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/autoscaling/model/AutoScalingGroup.h>
 #include <aws/core/utils/xml/XmlSerializer.h>
@@ -51,14 +61,7 @@ AutoScalingGroup::AutoScalingGroup() :
     m_terminationPoliciesHasBeenSet(false),
     m_newInstancesProtectedFromScaleIn(false),
     m_newInstancesProtectedFromScaleInHasBeenSet(false),
-    m_serviceLinkedRoleARNHasBeenSet(false),
-    m_maxInstanceLifetime(0),
-    m_maxInstanceLifetimeHasBeenSet(false),
-    m_capacityRebalance(false),
-    m_capacityRebalanceHasBeenSet(false),
-    m_warmPoolConfigurationHasBeenSet(false),
-    m_warmPoolSize(0),
-    m_warmPoolSizeHasBeenSet(false)
+    m_serviceLinkedRoleARNHasBeenSet(false)
 {
 }
 
@@ -93,14 +96,7 @@ AutoScalingGroup::AutoScalingGroup(const XmlNode& xmlNode) :
     m_terminationPoliciesHasBeenSet(false),
     m_newInstancesProtectedFromScaleIn(false),
     m_newInstancesProtectedFromScaleInHasBeenSet(false),
-    m_serviceLinkedRoleARNHasBeenSet(false),
-    m_maxInstanceLifetime(0),
-    m_maxInstanceLifetimeHasBeenSet(false),
-    m_capacityRebalance(false),
-    m_capacityRebalanceHasBeenSet(false),
-    m_warmPoolConfigurationHasBeenSet(false),
-    m_warmPoolSize(0),
-    m_warmPoolSizeHasBeenSet(false)
+    m_serviceLinkedRoleARNHasBeenSet(false)
 {
   *this = xmlNode;
 }
@@ -114,19 +110,19 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
     XmlNode autoScalingGroupNameNode = resultNode.FirstChild("AutoScalingGroupName");
     if(!autoScalingGroupNameNode.IsNull())
     {
-      m_autoScalingGroupName = Aws::Utils::Xml::DecodeEscapedXmlText(autoScalingGroupNameNode.GetText());
+      m_autoScalingGroupName = StringUtils::Trim(autoScalingGroupNameNode.GetText().c_str());
       m_autoScalingGroupNameHasBeenSet = true;
     }
     XmlNode autoScalingGroupARNNode = resultNode.FirstChild("AutoScalingGroupARN");
     if(!autoScalingGroupARNNode.IsNull())
     {
-      m_autoScalingGroupARN = Aws::Utils::Xml::DecodeEscapedXmlText(autoScalingGroupARNNode.GetText());
+      m_autoScalingGroupARN = StringUtils::Trim(autoScalingGroupARNNode.GetText().c_str());
       m_autoScalingGroupARNHasBeenSet = true;
     }
     XmlNode launchConfigurationNameNode = resultNode.FirstChild("LaunchConfigurationName");
     if(!launchConfigurationNameNode.IsNull())
     {
-      m_launchConfigurationName = Aws::Utils::Xml::DecodeEscapedXmlText(launchConfigurationNameNode.GetText());
+      m_launchConfigurationName = StringUtils::Trim(launchConfigurationNameNode.GetText().c_str());
       m_launchConfigurationNameHasBeenSet = true;
     }
     XmlNode launchTemplateNode = resultNode.FirstChild("LaunchTemplate");
@@ -144,25 +140,25 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
     XmlNode minSizeNode = resultNode.FirstChild("MinSize");
     if(!minSizeNode.IsNull())
     {
-      m_minSize = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(minSizeNode.GetText()).c_str()).c_str());
+      m_minSize = StringUtils::ConvertToInt32(StringUtils::Trim(minSizeNode.GetText().c_str()).c_str());
       m_minSizeHasBeenSet = true;
     }
     XmlNode maxSizeNode = resultNode.FirstChild("MaxSize");
     if(!maxSizeNode.IsNull())
     {
-      m_maxSize = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(maxSizeNode.GetText()).c_str()).c_str());
+      m_maxSize = StringUtils::ConvertToInt32(StringUtils::Trim(maxSizeNode.GetText().c_str()).c_str());
       m_maxSizeHasBeenSet = true;
     }
     XmlNode desiredCapacityNode = resultNode.FirstChild("DesiredCapacity");
     if(!desiredCapacityNode.IsNull())
     {
-      m_desiredCapacity = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(desiredCapacityNode.GetText()).c_str()).c_str());
+      m_desiredCapacity = StringUtils::ConvertToInt32(StringUtils::Trim(desiredCapacityNode.GetText().c_str()).c_str());
       m_desiredCapacityHasBeenSet = true;
     }
     XmlNode defaultCooldownNode = resultNode.FirstChild("DefaultCooldown");
     if(!defaultCooldownNode.IsNull())
     {
-      m_defaultCooldown = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(defaultCooldownNode.GetText()).c_str()).c_str());
+      m_defaultCooldown = StringUtils::ConvertToInt32(StringUtils::Trim(defaultCooldownNode.GetText().c_str()).c_str());
       m_defaultCooldownHasBeenSet = true;
     }
     XmlNode availabilityZonesNode = resultNode.FirstChild("AvailabilityZones");
@@ -171,7 +167,7 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
       XmlNode availabilityZonesMember = availabilityZonesNode.FirstChild("member");
       while(!availabilityZonesMember.IsNull())
       {
-        m_availabilityZones.push_back(availabilityZonesMember.GetText());
+        m_availabilityZones.push_back(StringUtils::Trim(availabilityZonesMember.GetText().c_str()));
         availabilityZonesMember = availabilityZonesMember.NextNode("member");
       }
 
@@ -183,7 +179,7 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
       XmlNode loadBalancerNamesMember = loadBalancerNamesNode.FirstChild("member");
       while(!loadBalancerNamesMember.IsNull())
       {
-        m_loadBalancerNames.push_back(loadBalancerNamesMember.GetText());
+        m_loadBalancerNames.push_back(StringUtils::Trim(loadBalancerNamesMember.GetText().c_str()));
         loadBalancerNamesMember = loadBalancerNamesMember.NextNode("member");
       }
 
@@ -195,7 +191,7 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
       XmlNode targetGroupARNsMember = targetGroupARNsNode.FirstChild("member");
       while(!targetGroupARNsMember.IsNull())
       {
-        m_targetGroupARNs.push_back(targetGroupARNsMember.GetText());
+        m_targetGroupARNs.push_back(StringUtils::Trim(targetGroupARNsMember.GetText().c_str()));
         targetGroupARNsMember = targetGroupARNsMember.NextNode("member");
       }
 
@@ -204,13 +200,13 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
     XmlNode healthCheckTypeNode = resultNode.FirstChild("HealthCheckType");
     if(!healthCheckTypeNode.IsNull())
     {
-      m_healthCheckType = Aws::Utils::Xml::DecodeEscapedXmlText(healthCheckTypeNode.GetText());
+      m_healthCheckType = StringUtils::Trim(healthCheckTypeNode.GetText().c_str());
       m_healthCheckTypeHasBeenSet = true;
     }
     XmlNode healthCheckGracePeriodNode = resultNode.FirstChild("HealthCheckGracePeriod");
     if(!healthCheckGracePeriodNode.IsNull())
     {
-      m_healthCheckGracePeriod = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(healthCheckGracePeriodNode.GetText()).c_str()).c_str());
+      m_healthCheckGracePeriod = StringUtils::ConvertToInt32(StringUtils::Trim(healthCheckGracePeriodNode.GetText().c_str()).c_str());
       m_healthCheckGracePeriodHasBeenSet = true;
     }
     XmlNode instancesNode = resultNode.FirstChild("Instances");
@@ -228,7 +224,7 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
     XmlNode createdTimeNode = resultNode.FirstChild("CreatedTime");
     if(!createdTimeNode.IsNull())
     {
-      m_createdTime = DateTime(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(createdTimeNode.GetText()).c_str()).c_str(), DateFormat::ISO_8601);
+      m_createdTime = DateTime(StringUtils::Trim(createdTimeNode.GetText().c_str()).c_str(), DateFormat::ISO_8601);
       m_createdTimeHasBeenSet = true;
     }
     XmlNode suspendedProcessesNode = resultNode.FirstChild("SuspendedProcesses");
@@ -246,13 +242,13 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
     XmlNode placementGroupNode = resultNode.FirstChild("PlacementGroup");
     if(!placementGroupNode.IsNull())
     {
-      m_placementGroup = Aws::Utils::Xml::DecodeEscapedXmlText(placementGroupNode.GetText());
+      m_placementGroup = StringUtils::Trim(placementGroupNode.GetText().c_str());
       m_placementGroupHasBeenSet = true;
     }
     XmlNode vPCZoneIdentifierNode = resultNode.FirstChild("VPCZoneIdentifier");
     if(!vPCZoneIdentifierNode.IsNull())
     {
-      m_vPCZoneIdentifier = Aws::Utils::Xml::DecodeEscapedXmlText(vPCZoneIdentifierNode.GetText());
+      m_vPCZoneIdentifier = StringUtils::Trim(vPCZoneIdentifierNode.GetText().c_str());
       m_vPCZoneIdentifierHasBeenSet = true;
     }
     XmlNode enabledMetricsNode = resultNode.FirstChild("EnabledMetrics");
@@ -270,7 +266,7 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
     XmlNode statusNode = resultNode.FirstChild("Status");
     if(!statusNode.IsNull())
     {
-      m_status = Aws::Utils::Xml::DecodeEscapedXmlText(statusNode.GetText());
+      m_status = StringUtils::Trim(statusNode.GetText().c_str());
       m_statusHasBeenSet = true;
     }
     XmlNode tagsNode = resultNode.FirstChild("Tags");
@@ -291,7 +287,7 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
       XmlNode terminationPoliciesMember = terminationPoliciesNode.FirstChild("member");
       while(!terminationPoliciesMember.IsNull())
       {
-        m_terminationPolicies.push_back(terminationPoliciesMember.GetText());
+        m_terminationPolicies.push_back(StringUtils::Trim(terminationPoliciesMember.GetText().c_str()));
         terminationPoliciesMember = terminationPoliciesMember.NextNode("member");
       }
 
@@ -300,39 +296,15 @@ AutoScalingGroup& AutoScalingGroup::operator =(const XmlNode& xmlNode)
     XmlNode newInstancesProtectedFromScaleInNode = resultNode.FirstChild("NewInstancesProtectedFromScaleIn");
     if(!newInstancesProtectedFromScaleInNode.IsNull())
     {
-      m_newInstancesProtectedFromScaleIn = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(newInstancesProtectedFromScaleInNode.GetText()).c_str()).c_str());
+      m_newInstancesProtectedFromScaleIn = StringUtils::ConvertToBool(StringUtils::Trim(newInstancesProtectedFromScaleInNode.GetText().c_str()).c_str());
       m_newInstancesProtectedFromScaleInHasBeenSet = true;
     }
     XmlNode serviceLinkedRoleARNNode = resultNode.FirstChild("ServiceLinkedRoleARN");
     if(!serviceLinkedRoleARNNode.IsNull())
     {
-      m_serviceLinkedRoleARN = Aws::Utils::Xml::DecodeEscapedXmlText(serviceLinkedRoleARNNode.GetText());
+      m_serviceLinkedRoleARN = StringUtils::Trim(serviceLinkedRoleARNNode.GetText().c_str());
       m_serviceLinkedRoleARNHasBeenSet = true;
     }
-    XmlNode maxInstanceLifetimeNode = resultNode.FirstChild("MaxInstanceLifetime");
-    if(!maxInstanceLifetimeNode.IsNull())
-    {
-      m_maxInstanceLifetime = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(maxInstanceLifetimeNode.GetText()).c_str()).c_str());
-      m_maxInstanceLifetimeHasBeenSet = true;
-    }
-    XmlNode capacityRebalanceNode = resultNode.FirstChild("CapacityRebalance");
-    if(!capacityRebalanceNode.IsNull())
-    {
-      m_capacityRebalance = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(capacityRebalanceNode.GetText()).c_str()).c_str());
-      m_capacityRebalanceHasBeenSet = true;
-    }
-    XmlNode warmPoolConfigurationNode = resultNode.FirstChild("WarmPoolConfiguration");
-    if(!warmPoolConfigurationNode.IsNull())
-    {
-      m_warmPoolConfiguration = warmPoolConfigurationNode;
-      m_warmPoolConfigurationHasBeenSet = true;
-    }
-    XmlNode warmPoolSizeNode = resultNode.FirstChild("WarmPoolSize");
-    if(!warmPoolSizeNode.IsNull())
-    {
-      m_warmPoolSize = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(warmPoolSizeNode.GetText()).c_str()).c_str());
-      m_warmPoolSizeHasBeenSet = true;
-    }
   }
 
   return *this;
@@ -509,28 +481,6 @@ void AutoScalingGroup::OutputToStream(Aws::OStream& oStream, const char* locatio
       oStream << location << index << locationValue << ".ServiceLinkedRoleARN=" << StringUtils::URLEncode(m_serviceLinkedRoleARN.c_str()) << "&";
   }
 
-  if(m_maxInstanceLifetimeHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".MaxInstanceLifetime=" << m_maxInstanceLifetime << "&";
-  }
-
-  if(m_capacityRebalanceHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".CapacityRebalance=" << std::boolalpha << m_capacityRebalance << "&";
-  }
-
-  if(m_warmPoolConfigurationHasBeenSet)
-  {
-      Aws::StringStream warmPoolConfigurationLocationAndMemberSs;
-      warmPoolConfigurationLocationAndMemberSs << location << index << locationValue << ".WarmPoolConfiguration";
-      m_warmPoolConfiguration.OutputToStream(oStream, warmPoolConfigurationLocationAndMemberSs.str().c_str());
-  }
-
-  if(m_warmPoolSizeHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".WarmPoolSize=" << m_warmPoolSize << "&";
-  }
-
 }
 
 void AutoScalingGroup::OutputToStream(Aws::OStream& oStream, const char* location) const
@@ -679,24 +629,6 @@ void AutoScalingGroup::OutputToStream(Aws::OStream& oStream, const char* locatio
   {
       oStream << location << ".ServiceLinkedRoleARN=" << StringUtils::URLEncode(m_serviceLinkedRoleARN.c_str()) << "&";
   }
-  if(m_maxInstanceLifetimeHasBeenSet)
-  {
-      oStream << location << ".MaxInstanceLifetime=" << m_maxInstanceLifetime << "&";
-  }
-  if(m_capacityRebalanceHasBeenSet)
-  {
-      oStream << location << ".CapacityRebalance=" << std::boolalpha << m_capacityRebalance << "&";
-  }
-  if(m_warmPoolConfigurationHasBeenSet)
-  {
-      Aws::String warmPoolConfigurationLocationAndMember(location);
-      warmPoolConfigurationLocationAndMember += ".WarmPoolConfiguration";
-      m_warmPoolConfiguration.OutputToStream(oStream, warmPoolConfigurationLocationAndMember.c_str());
-  }
-  if(m_warmPoolSizeHasBeenSet)
-  {
-      oStream << location << ".WarmPoolSize=" << m_warmPoolSize << "&";
-  }
 }
 
 } // namespace Model
