@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/awstransfer/model/CreateServerRequest.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -13,19 +23,13 @@ using namespace Aws::Utils::Json;
 using namespace Aws::Utils;
 
 CreateServerRequest::CreateServerRequest() : 
-    m_certificateHasBeenSet(false),
-    m_domain(Domain::NOT_SET),
-    m_domainHasBeenSet(false),
     m_endpointDetailsHasBeenSet(false),
     m_endpointType(EndpointType::NOT_SET),
     m_endpointTypeHasBeenSet(false),
-    m_hostKeyHasBeenSet(false),
     m_identityProviderDetailsHasBeenSet(false),
     m_identityProviderType(IdentityProviderType::NOT_SET),
     m_identityProviderTypeHasBeenSet(false),
     m_loggingRoleHasBeenSet(false),
-    m_protocolsHasBeenSet(false),
-    m_securityPolicyNameHasBeenSet(false),
     m_tagsHasBeenSet(false)
 {
 }
@@ -34,17 +38,6 @@ Aws::String CreateServerRequest::SerializePayload() const
 {
   JsonValue payload;
 
-  if(m_certificateHasBeenSet)
-  {
-   payload.WithString("Certificate", m_certificate);
-
-  }
-
-  if(m_domainHasBeenSet)
-  {
-   payload.WithString("Domain", DomainMapper::GetNameForDomain(m_domain));
-  }
-
   if(m_endpointDetailsHasBeenSet)
   {
    payload.WithObject("EndpointDetails", m_endpointDetails.Jsonize());
@@ -56,12 +49,6 @@ Aws::String CreateServerRequest::SerializePayload() const
    payload.WithString("EndpointType", EndpointTypeMapper::GetNameForEndpointType(m_endpointType));
   }
 
-  if(m_hostKeyHasBeenSet)
-  {
-   payload.WithString("HostKey", m_hostKey);
-
-  }
-
   if(m_identityProviderDetailsHasBeenSet)
   {
    payload.WithObject("IdentityProviderDetails", m_identityProviderDetails.Jsonize());
@@ -79,23 +66,6 @@ Aws::String CreateServerRequest::SerializePayload() const
 
   }
 
-  if(m_protocolsHasBeenSet)
-  {
-   Array<JsonValue> protocolsJsonList(m_protocols.size());
-   for(unsigned protocolsIndex = 0; protocolsIndex < protocolsJsonList.GetLength(); ++protocolsIndex)
-   {
-     protocolsJsonList[protocolsIndex].AsString(ProtocolMapper::GetNameForProtocol(m_protocols[protocolsIndex]));
-   }
-   payload.WithArray("Protocols", std::move(protocolsJsonList));
-
-  }
-
-  if(m_securityPolicyNameHasBeenSet)
-  {
-   payload.WithString("SecurityPolicyName", m_securityPolicyName);
-
-  }
-
   if(m_tagsHasBeenSet)
   {
    Array<JsonValue> tagsJsonList(m_tags.size());
