@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/awstransfer/model/TestIdentityProviderResult.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -30,9 +40,9 @@ TestIdentityProviderResult::TestIdentityProviderResult(const Aws::AmazonWebServi
 TestIdentityProviderResult& TestIdentityProviderResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
 {
   JsonView jsonValue = result.GetPayload().View();
-  if(jsonValue.ValueExists("Response"))
+  if(jsonValue.ValueExists("Message"))
   {
-    m_response = jsonValue.GetString("Response");
+    m_message = jsonValue.GetString("Message");
 
   }
 
@@ -42,12 +52,6 @@ TestIdentityProviderResult& TestIdentityProviderResult::operator =(const Aws::Am
 
   }
 
-  if(jsonValue.ValueExists("Message"))
-  {
-    m_message = jsonValue.GetString("Message");
-
-  }
-
   if(jsonValue.ValueExists("Url"))
   {
     m_url = jsonValue.GetString("Url");
