@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/backup/model/ListRestoreJobsRequest.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -18,12 +28,7 @@ using namespace Aws::Http;
 ListRestoreJobsRequest::ListRestoreJobsRequest() : 
     m_nextTokenHasBeenSet(false),
     m_maxResults(0),
-    m_maxResultsHasBeenSet(false),
-    m_byAccountIdHasBeenSet(false),
-    m_byCreatedBeforeHasBeenSet(false),
-    m_byCreatedAfterHasBeenSet(false),
-    m_byStatus(RestoreJobStatus::NOT_SET),
-    m_byStatusHasBeenSet(false)
+    m_maxResultsHasBeenSet(false)
 {
 }
 
@@ -49,34 +54,6 @@ void ListRestoreJobsRequest::AddQueryStringParameters(URI& uri) const
       ss.str("");
     }
 
-    if(m_byAccountIdHasBeenSet)
-    {
-      ss << m_byAccountId;
-      uri.AddQueryStringParameter("accountId", ss.str());
-      ss.str("");
-    }
-
-    if(m_byCreatedBeforeHasBeenSet)
-    {
-      ss << m_byCreatedBefore.ToGmtString(DateFormat::ISO_8601);
-      uri.AddQueryStringParameter("createdBefore", ss.str());
-      ss.str("");
-    }
-
-    if(m_byCreatedAfterHasBeenSet)
-    {
-      ss << m_byCreatedAfter.ToGmtString(DateFormat::ISO_8601);
-      uri.AddQueryStringParameter("createdAfter", ss.str());
-      ss.str("");
-    }
-
-    if(m_byStatusHasBeenSet)
-    {
-      ss << RestoreJobStatusMapper::GetNameForRestoreJobStatus(m_byStatus);
-      uri.AddQueryStringParameter("status", ss.str());
-      ss.str("");
-    }
-
 }
 
 
