@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/core/utils/Outcome.h>
 #include <aws/core/auth/AWSAuthSigner.h>
@@ -52,7 +62,7 @@ static const char* ALLOCATION_TAG = "BatchClient";
 BatchClient::BatchClient(const Client::ClientConfiguration& clientConfiguration) :
   BASECLASS(clientConfiguration,
     Aws::MakeShared<AWSAuthV4Signer>(ALLOCATION_TAG, Aws::MakeShared<DefaultAWSCredentialsProviderChain>(ALLOCATION_TAG),
-        SERVICE_NAME, Aws::Region::ComputeSignerRegion(clientConfiguration.region)),
+        SERVICE_NAME, clientConfiguration.region),
     Aws::MakeShared<BatchErrorMarshaller>(ALLOCATION_TAG)),
     m_executor(clientConfiguration.executor)
 {
@@ -62,7 +72,7 @@ BatchClient::BatchClient(const Client::ClientConfiguration& clientConfiguration)
 BatchClient::BatchClient(const AWSCredentials& credentials, const Client::ClientConfiguration& clientConfiguration) :
   BASECLASS(clientConfiguration,
     Aws::MakeShared<AWSAuthV4Signer>(ALLOCATION_TAG, Aws::MakeShared<SimpleAWSCredentialsProvider>(ALLOCATION_TAG, credentials),
-         SERVICE_NAME, Aws::Region::ComputeSignerRegion(clientConfiguration.region)),
+         SERVICE_NAME, clientConfiguration.region),
     Aws::MakeShared<BatchErrorMarshaller>(ALLOCATION_TAG)),
     m_executor(clientConfiguration.executor)
 {
@@ -73,7 +83,7 @@ BatchClient::BatchClient(const std::shared_ptr<AWSCredentialsProvider>& credenti
   const Client::ClientConfiguration& clientConfiguration) :
   BASECLASS(clientConfiguration,
     Aws::MakeShared<AWSAuthV4Signer>(ALLOCATION_TAG, credentialsProvider,
-         SERVICE_NAME, Aws::Region::ComputeSignerRegion(clientConfiguration.region)),
+         SERVICE_NAME, clientConfiguration.region),
     Aws::MakeShared<BatchErrorMarshaller>(ALLOCATION_TAG)),
     m_executor(clientConfiguration.executor)
 {
@@ -86,7 +96,6 @@ BatchClient::~BatchClient()
 
 void BatchClient::init(const ClientConfiguration& config)
 {
-  SetServiceClientName("Batch");
   m_configScheme = SchemeMapper::ToString(config.scheme);
   if (config.endpointOverride.empty())
   {
@@ -109,14 +118,21 @@ void BatchClient::OverrideEndpoint(const Aws::String& endpoint)
       m_uri = m_configScheme + "://" + endpoint;
   }
 }
-
 CancelJobOutcome BatchClient::CancelJob(const CancelJobRequest& request) const
 {
   Aws::Http::URI uri = m_uri;
   Aws::StringStream ss;
   ss << "/v1/canceljob";
   uri.SetPath(uri.GetPath() + ss.str());
-  return CancelJobOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return CancelJobOutcome(CancelJobResult(outcome.GetResult()));
+  }
+  else
+  {
+    return CancelJobOutcome(outcome.GetError());
+  }
 }
 
 CancelJobOutcomeCallable BatchClient::CancelJobCallable(const CancelJobRequest& request) const
@@ -143,7 +159,15 @@ CreateComputeEnvironmentOutcome BatchClient::CreateComputeEnvironment(const Crea
   Aws::StringStream ss;
   ss << "/v1/createcomputeenvironment";
   uri.SetPath(uri.GetPath() + ss.str());
-  return CreateComputeEnvironmentOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return CreateComputeEnvironmentOutcome(CreateComputeEnvironmentResult(outcome.GetResult()));
+  }
+  else
+  {
+    return CreateComputeEnvironmentOutcome(outcome.GetError());
+  }
 }
 
 CreateComputeEnvironmentOutcomeCallable BatchClient::CreateComputeEnvironmentCallable(const CreateComputeEnvironmentRequest& request) const
@@ -170,7 +194,15 @@ CreateJobQueueOutcome BatchClient::CreateJobQueue(const CreateJobQueueRequest& r
   Aws::StringStream ss;
   ss << "/v1/createjobqueue";
   uri.SetPath(uri.GetPath() + ss.str());
-  return CreateJobQueueOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return CreateJobQueueOutcome(CreateJobQueueResult(outcome.GetResult()));
+  }
+  else
+  {
+    return CreateJobQueueOutcome(outcome.GetError());
+  }
 }
 
 CreateJobQueueOutcomeCallable BatchClient::CreateJobQueueCallable(const CreateJobQueueRequest& request) const
@@ -197,7 +229,15 @@ DeleteComputeEnvironmentOutcome BatchClient::DeleteComputeEnvironment(const Dele
   Aws::StringStream ss;
   ss << "/v1/deletecomputeenvironment";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DeleteComputeEnvironmentOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DeleteComputeEnvironmentOutcome(DeleteComputeEnvironmentResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DeleteComputeEnvironmentOutcome(outcome.GetError());
+  }
 }
 
 DeleteComputeEnvironmentOutcomeCallable BatchClient::DeleteComputeEnvironmentCallable(const DeleteComputeEnvironmentRequest& request) const
@@ -224,7 +264,15 @@ DeleteJobQueueOutcome BatchClient::DeleteJobQueue(const DeleteJobQueueRequest& r
   Aws::StringStream ss;
   ss << "/v1/deletejobqueue";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DeleteJobQueueOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DeleteJobQueueOutcome(DeleteJobQueueResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DeleteJobQueueOutcome(outcome.GetError());
+  }
 }
 
 DeleteJobQueueOutcomeCallable BatchClient::DeleteJobQueueCallable(const DeleteJobQueueRequest& request) const
@@ -251,7 +299,15 @@ DeregisterJobDefinitionOutcome BatchClient::DeregisterJobDefinition(const Deregi
   Aws::StringStream ss;
   ss << "/v1/deregisterjobdefinition";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DeregisterJobDefinitionOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DeregisterJobDefinitionOutcome(DeregisterJobDefinitionResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DeregisterJobDefinitionOutcome(outcome.GetError());
+  }
 }
 
 DeregisterJobDefinitionOutcomeCallable BatchClient::DeregisterJobDefinitionCallable(const DeregisterJobDefinitionRequest& request) const
@@ -278,7 +334,15 @@ DescribeComputeEnvironmentsOutcome BatchClient::DescribeComputeEnvironments(cons
   Aws::StringStream ss;
   ss << "/v1/describecomputeenvironments";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeComputeEnvironmentsOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeComputeEnvironmentsOutcome(DescribeComputeEnvironmentsResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeComputeEnvironmentsOutcome(outcome.GetError());
+  }
 }
 
 DescribeComputeEnvironmentsOutcomeCallable BatchClient::DescribeComputeEnvironmentsCallable(const DescribeComputeEnvironmentsRequest& request) const
@@ -305,7 +369,15 @@ DescribeJobDefinitionsOutcome BatchClient::DescribeJobDefinitions(const Describe
   Aws::StringStream ss;
   ss << "/v1/describejobdefinitions";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeJobDefinitionsOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeJobDefinitionsOutcome(DescribeJobDefinitionsResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeJobDefinitionsOutcome(outcome.GetError());
+  }
 }
 
 DescribeJobDefinitionsOutcomeCallable BatchClient::DescribeJobDefinitionsCallable(const DescribeJobDefinitionsRequest& request) const
@@ -332,7 +404,15 @@ DescribeJobQueuesOutcome BatchClient::DescribeJobQueues(const DescribeJobQueuesR
   Aws::StringStream ss;
   ss << "/v1/describejobqueues";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeJobQueuesOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeJobQueuesOutcome(DescribeJobQueuesResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeJobQueuesOutcome(outcome.GetError());
+  }
 }
 
 DescribeJobQueuesOutcomeCallable BatchClient::DescribeJobQueuesCallable(const DescribeJobQueuesRequest& request) const
@@ -359,7 +439,15 @@ DescribeJobsOutcome BatchClient::DescribeJobs(const DescribeJobsRequest& request
   Aws::StringStream ss;
   ss << "/v1/describejobs";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeJobsOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeJobsOutcome(DescribeJobsResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeJobsOutcome(outcome.GetError());
+  }
 }
 
 DescribeJobsOutcomeCallable BatchClient::DescribeJobsCallable(const DescribeJobsRequest& request) const
@@ -386,7 +474,15 @@ ListJobsOutcome BatchClient::ListJobs(const ListJobsRequest& request) const
   Aws::StringStream ss;
   ss << "/v1/listjobs";
   uri.SetPath(uri.GetPath() + ss.str());
-  return ListJobsOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return ListJobsOutcome(ListJobsResult(outcome.GetResult()));
+  }
+  else
+  {
+    return ListJobsOutcome(outcome.GetError());
+  }
 }
 
 ListJobsOutcomeCallable BatchClient::ListJobsCallable(const ListJobsRequest& request) const
@@ -413,7 +509,15 @@ RegisterJobDefinitionOutcome BatchClient::RegisterJobDefinition(const RegisterJo
   Aws::StringStream ss;
   ss << "/v1/registerjobdefinition";
   uri.SetPath(uri.GetPath() + ss.str());
-  return RegisterJobDefinitionOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return RegisterJobDefinitionOutcome(RegisterJobDefinitionResult(outcome.GetResult()));
+  }
+  else
+  {
+    return RegisterJobDefinitionOutcome(outcome.GetError());
+  }
 }
 
 RegisterJobDefinitionOutcomeCallable BatchClient::RegisterJobDefinitionCallable(const RegisterJobDefinitionRequest& request) const
@@ -440,7 +544,15 @@ SubmitJobOutcome BatchClient::SubmitJob(const SubmitJobRequest& request) const
   Aws::StringStream ss;
   ss << "/v1/submitjob";
   uri.SetPath(uri.GetPath() + ss.str());
-  return SubmitJobOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return SubmitJobOutcome(SubmitJobResult(outcome.GetResult()));
+  }
+  else
+  {
+    return SubmitJobOutcome(outcome.GetError());
+  }
 }
 
 SubmitJobOutcomeCallable BatchClient::SubmitJobCallable(const SubmitJobRequest& request) const
@@ -467,7 +579,15 @@ TerminateJobOutcome BatchClient::TerminateJob(const TerminateJobRequest& request
   Aws::StringStream ss;
   ss << "/v1/terminatejob";
   uri.SetPath(uri.GetPath() + ss.str());
-  return TerminateJobOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return TerminateJobOutcome(TerminateJobResult(outcome.GetResult()));
+  }
+  else
+  {
+    return TerminateJobOutcome(outcome.GetError());
+  }
 }
 
 TerminateJobOutcomeCallable BatchClient::TerminateJobCallable(const TerminateJobRequest& request) const
@@ -494,7 +614,15 @@ UpdateComputeEnvironmentOutcome BatchClient::UpdateComputeEnvironment(const Upda
   Aws::StringStream ss;
   ss << "/v1/updatecomputeenvironment";
   uri.SetPath(uri.GetPath() + ss.str());
-  return UpdateComputeEnvironmentOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return UpdateComputeEnvironmentOutcome(UpdateComputeEnvironmentResult(outcome.GetResult()));
+  }
+  else
+  {
+    return UpdateComputeEnvironmentOutcome(outcome.GetError());
+  }
 }
 
 UpdateComputeEnvironmentOutcomeCallable BatchClient::UpdateComputeEnvironmentCallable(const UpdateComputeEnvironmentRequest& request) const
@@ -521,7 +649,15 @@ UpdateJobQueueOutcome BatchClient::UpdateJobQueue(const UpdateJobQueueRequest& r
   Aws::StringStream ss;
   ss << "/v1/updatejobqueue";
   uri.SetPath(uri.GetPath() + ss.str());
-  return UpdateJobQueueOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return UpdateJobQueueOutcome(UpdateJobQueueResult(outcome.GetResult()));
+  }
+  else
+  {
+    return UpdateJobQueueOutcome(outcome.GetError());
+  }
 }
 
 UpdateJobQueueOutcomeCallable BatchClient::UpdateJobQueueCallable(const UpdateJobQueueRequest& request) const
