@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/budgets/Budgets_EXPORTS.h>
@@ -42,6 +52,7 @@ namespace Http
 namespace Utils
 {
   template< typename R, typename E> class Outcome;
+
 namespace Threading
 {
   class Executor;
@@ -79,20 +90,20 @@ namespace Model
         class UpdateNotificationRequest;
         class UpdateSubscriberRequest;
 
-        typedef Aws::Utils::Outcome<CreateBudgetResult, BudgetsError> CreateBudgetOutcome;
-        typedef Aws::Utils::Outcome<CreateNotificationResult, BudgetsError> CreateNotificationOutcome;
-        typedef Aws::Utils::Outcome<CreateSubscriberResult, BudgetsError> CreateSubscriberOutcome;
-        typedef Aws::Utils::Outcome<DeleteBudgetResult, BudgetsError> DeleteBudgetOutcome;
-        typedef Aws::Utils::Outcome<DeleteNotificationResult, BudgetsError> DeleteNotificationOutcome;
-        typedef Aws::Utils::Outcome<DeleteSubscriberResult, BudgetsError> DeleteSubscriberOutcome;
-        typedef Aws::Utils::Outcome<DescribeBudgetResult, BudgetsError> DescribeBudgetOutcome;
-        typedef Aws::Utils::Outcome<DescribeBudgetPerformanceHistoryResult, BudgetsError> DescribeBudgetPerformanceHistoryOutcome;
-        typedef Aws::Utils::Outcome<DescribeBudgetsResult, BudgetsError> DescribeBudgetsOutcome;
-        typedef Aws::Utils::Outcome<DescribeNotificationsForBudgetResult, BudgetsError> DescribeNotificationsForBudgetOutcome;
-        typedef Aws::Utils::Outcome<DescribeSubscribersForNotificationResult, BudgetsError> DescribeSubscribersForNotificationOutcome;
-        typedef Aws::Utils::Outcome<UpdateBudgetResult, BudgetsError> UpdateBudgetOutcome;
-        typedef Aws::Utils::Outcome<UpdateNotificationResult, BudgetsError> UpdateNotificationOutcome;
-        typedef Aws::Utils::Outcome<UpdateSubscriberResult, BudgetsError> UpdateSubscriberOutcome;
+        typedef Aws::Utils::Outcome<CreateBudgetResult, Aws::Client::AWSError<BudgetsErrors>> CreateBudgetOutcome;
+        typedef Aws::Utils::Outcome<CreateNotificationResult, Aws::Client::AWSError<BudgetsErrors>> CreateNotificationOutcome;
+        typedef Aws::Utils::Outcome<CreateSubscriberResult, Aws::Client::AWSError<BudgetsErrors>> CreateSubscriberOutcome;
+        typedef Aws::Utils::Outcome<DeleteBudgetResult, Aws::Client::AWSError<BudgetsErrors>> DeleteBudgetOutcome;
+        typedef Aws::Utils::Outcome<DeleteNotificationResult, Aws::Client::AWSError<BudgetsErrors>> DeleteNotificationOutcome;
+        typedef Aws::Utils::Outcome<DeleteSubscriberResult, Aws::Client::AWSError<BudgetsErrors>> DeleteSubscriberOutcome;
+        typedef Aws::Utils::Outcome<DescribeBudgetResult, Aws::Client::AWSError<BudgetsErrors>> DescribeBudgetOutcome;
+        typedef Aws::Utils::Outcome<DescribeBudgetPerformanceHistoryResult, Aws::Client::AWSError<BudgetsErrors>> DescribeBudgetPerformanceHistoryOutcome;
+        typedef Aws::Utils::Outcome<DescribeBudgetsResult, Aws::Client::AWSError<BudgetsErrors>> DescribeBudgetsOutcome;
+        typedef Aws::Utils::Outcome<DescribeNotificationsForBudgetResult, Aws::Client::AWSError<BudgetsErrors>> DescribeNotificationsForBudgetOutcome;
+        typedef Aws::Utils::Outcome<DescribeSubscribersForNotificationResult, Aws::Client::AWSError<BudgetsErrors>> DescribeSubscribersForNotificationOutcome;
+        typedef Aws::Utils::Outcome<UpdateBudgetResult, Aws::Client::AWSError<BudgetsErrors>> UpdateBudgetOutcome;
+        typedef Aws::Utils::Outcome<UpdateNotificationResult, Aws::Client::AWSError<BudgetsErrors>> UpdateNotificationOutcome;
+        typedef Aws::Utils::Outcome<UpdateSubscriberResult, Aws::Client::AWSError<BudgetsErrors>> UpdateSubscriberOutcome;
 
         typedef std::future<CreateBudgetOutcome> CreateBudgetOutcomeCallable;
         typedef std::future<CreateNotificationOutcome> CreateNotificationOutcomeCallable;
@@ -180,30 +191,20 @@ namespace Model
 
         virtual ~BudgetsClient();
 
+        inline virtual const char* GetServiceClientName() const override { return "Budgets"; }
+
 
         /**
-         * <p>Creates a budget and, if included, notifications and subscribers. </p>
-         *  <p>Only one of <code>BudgetLimit</code> or
-         * <code>PlannedBudgetLimits</code> can be present in the syntax at one time. Use
-         * the syntax that matches your case. The Request Syntax section shows the
-         * <code>BudgetLimit</code> syntax. For <code>PlannedBudgetLimits</code>, see the
-         * <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_CreateBudget.html#API_CreateBudget_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * <p>Creates a budget and, if included, notifications and subscribers.
+         * </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/CreateBudget">AWS
          * API Reference</a></p>
          */
         virtual Model::CreateBudgetOutcome CreateBudget(const Model::CreateBudgetRequest& request) const;
 
         /**
-         * <p>Creates a budget and, if included, notifications and subscribers. </p>
-         *  <p>Only one of <code>BudgetLimit</code> or
-         * <code>PlannedBudgetLimits</code> can be present in the syntax at one time. Use
-         * the syntax that matches your case. The Request Syntax section shows the
-         * <code>BudgetLimit</code> syntax. For <code>PlannedBudgetLimits</code>, see the
-         * <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_CreateBudget.html#API_CreateBudget_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * <p>Creates a budget and, if included, notifications and subscribers.
+         * </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/CreateBudget">AWS
          * API Reference</a></p>
          *
@@ -212,14 +213,8 @@ namespace Model
         virtual Model::CreateBudgetOutcomeCallable CreateBudgetCallable(const Model::CreateBudgetRequest& request) const;
 
         /**
-         * <p>Creates a budget and, if included, notifications and subscribers. </p>
-         *  <p>Only one of <code>BudgetLimit</code> or
-         * <code>PlannedBudgetLimits</code> can be present in the syntax at one time. Use
-         * the syntax that matches your case. The Request Syntax section shows the
-         * <code>BudgetLimit</code> syntax. For <code>PlannedBudgetLimits</code>, see the
-         * <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_CreateBudget.html#API_CreateBudget_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * <p>Creates a budget and, if included, notifications and subscribers.
+         * </p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/CreateBudget">AWS
          * API Reference</a></p>
          *
@@ -284,18 +279,18 @@ namespace Model
         virtual void CreateSubscriberAsync(const Model::CreateSubscriberRequest& request, const CreateSubscriberResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>Deletes a budget. You can delete your budget at any time.</p> 
+         * <p>Deletes a budget. You can delete your budget at any time.</p> <important>
          * <p>Deleting a budget also deletes the notifications and subscribers that are
-         * associated with that budget.</p> <p><h3>See Also:</h3>   <a
+         * associated with that budget.</p> </important><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DeleteBudget">AWS
          * API Reference</a></p>
          */
         virtual Model::DeleteBudgetOutcome DeleteBudget(const Model::DeleteBudgetRequest& request) const;
 
         /**
-         * <p>Deletes a budget. You can delete your budget at any time.</p> 
+         * <p>Deletes a budget. You can delete your budget at any time.</p> <important>
          * <p>Deleting a budget also deletes the notifications and subscribers that are
-         * associated with that budget.</p> <p><h3>See Also:</h3>   <a
+         * associated with that budget.</p> </important><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DeleteBudget">AWS
          * API Reference</a></p>
          *
@@ -304,9 +299,9 @@ namespace Model
         virtual Model::DeleteBudgetOutcomeCallable DeleteBudgetCallable(const Model::DeleteBudgetRequest& request) const;
 
         /**
-         * <p>Deletes a budget. You can delete your budget at any time.</p> 
+         * <p>Deletes a budget. You can delete your budget at any time.</p> <important>
          * <p>Deleting a budget also deletes the notifications and subscribers that are
-         * associated with that budget.</p> <p><h3>See Also:</h3>   <a
+         * associated with that budget.</p> </important><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DeleteBudget">AWS
          * API Reference</a></p>
          *
@@ -315,18 +310,18 @@ namespace Model
         virtual void DeleteBudgetAsync(const Model::DeleteBudgetRequest& request, const DeleteBudgetResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>Deletes a notification.</p>  <p>Deleting a notification also
+         * <p>Deletes a notification.</p> <important> <p>Deleting a notification also
          * deletes the subscribers that are associated with the notification.</p>
-         * <p><h3>See Also:</h3>   <a
+         * </important><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DeleteNotification">AWS
          * API Reference</a></p>
          */
         virtual Model::DeleteNotificationOutcome DeleteNotification(const Model::DeleteNotificationRequest& request) const;
 
         /**
-         * <p>Deletes a notification.</p>  <p>Deleting a notification also
+         * <p>Deletes a notification.</p> <important> <p>Deleting a notification also
          * deletes the subscribers that are associated with the notification.</p>
-         * <p><h3>See Also:</h3>   <a
+         * </important><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DeleteNotification">AWS
          * API Reference</a></p>
          *
@@ -335,9 +330,9 @@ namespace Model
         virtual Model::DeleteNotificationOutcomeCallable DeleteNotificationCallable(const Model::DeleteNotificationRequest& request) const;
 
         /**
-         * <p>Deletes a notification.</p>  <p>Deleting a notification also
+         * <p>Deletes a notification.</p> <important> <p>Deleting a notification also
          * deletes the subscribers that are associated with the notification.</p>
-         * <p><h3>See Also:</h3>   <a
+         * </important><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DeleteNotification">AWS
          * API Reference</a></p>
          *
@@ -346,8 +341,8 @@ namespace Model
         virtual void DeleteNotificationAsync(const Model::DeleteNotificationRequest& request, const DeleteNotificationResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>Deletes a subscriber.</p>  <p>Deleting the last subscriber to a
-         * notification also deletes the notification.</p> <p><h3>See
+         * <p>Deletes a subscriber.</p> <important> <p>Deleting the last subscriber to a
+         * notification also deletes the notification.</p> </important><p><h3>See
          * Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DeleteSubscriber">AWS
          * API Reference</a></p>
@@ -355,8 +350,8 @@ namespace Model
         virtual Model::DeleteSubscriberOutcome DeleteSubscriber(const Model::DeleteSubscriberRequest& request) const;
 
         /**
-         * <p>Deletes a subscriber.</p>  <p>Deleting the last subscriber to a
-         * notification also deletes the notification.</p> <p><h3>See
+         * <p>Deletes a subscriber.</p> <important> <p>Deleting the last subscriber to a
+         * notification also deletes the notification.</p> </important><p><h3>See
          * Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DeleteSubscriber">AWS
          * API Reference</a></p>
@@ -366,8 +361,8 @@ namespace Model
         virtual Model::DeleteSubscriberOutcomeCallable DeleteSubscriberCallable(const Model::DeleteSubscriberRequest& request) const;
 
         /**
-         * <p>Deletes a subscriber.</p>  <p>Deleting the last subscriber to a
-         * notification also deletes the notification.</p> <p><h3>See
+         * <p>Deletes a subscriber.</p> <important> <p>Deleting the last subscriber to a
+         * notification also deletes the notification.</p> </important><p><h3>See
          * Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DeleteSubscriber">AWS
          * API Reference</a></p>
@@ -377,22 +372,14 @@ namespace Model
         virtual void DeleteSubscriberAsync(const Model::DeleteSubscriberRequest& request, const DeleteSubscriberResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>Describes a budget.</p>  <p>The Request Syntax section shows the
-         * <code>BudgetLimit</code> syntax. For <code>PlannedBudgetLimits</code>, see the
-         * <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_DescribeBudget.html#API_DescribeBudget_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * <p>Describes a budget.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DescribeBudget">AWS
          * API Reference</a></p>
          */
         virtual Model::DescribeBudgetOutcome DescribeBudget(const Model::DescribeBudgetRequest& request) const;
 
         /**
-         * <p>Describes a budget.</p>  <p>The Request Syntax section shows the
-         * <code>BudgetLimit</code> syntax. For <code>PlannedBudgetLimits</code>, see the
-         * <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_DescribeBudget.html#API_DescribeBudget_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * <p>Describes a budget.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DescribeBudget">AWS
          * API Reference</a></p>
          *
@@ -401,11 +388,7 @@ namespace Model
         virtual Model::DescribeBudgetOutcomeCallable DescribeBudgetCallable(const Model::DescribeBudgetRequest& request) const;
 
         /**
-         * <p>Describes a budget.</p>  <p>The Request Syntax section shows the
-         * <code>BudgetLimit</code> syntax. For <code>PlannedBudgetLimits</code>, see the
-         * <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_DescribeBudget.html#API_DescribeBudget_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * <p>Describes a budget.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DescribeBudget">AWS
          * API Reference</a></p>
          *
@@ -445,22 +428,16 @@ namespace Model
         virtual void DescribeBudgetPerformanceHistoryAsync(const Model::DescribeBudgetPerformanceHistoryRequest& request, const DescribeBudgetPerformanceHistoryResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
         /**
-         * <p>Lists the budgets that are associated with an account.</p>  <p>The
-         * Request Syntax section shows the <code>BudgetLimit</code> syntax. For
-         * <code>PlannedBudgetLimits</code>, see the <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_DescribeBudgets.html#API_DescribeBudgets_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * <p>Lists the budgets that are associated with an account.</p><p><h3>See
+         * Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DescribeBudgets">AWS
          * API Reference</a></p>
          */
         virtual Model::DescribeBudgetsOutcome DescribeBudgets(const Model::DescribeBudgetsRequest& request) const;
 
         /**
-         * <p>Lists the budgets that are associated with an account.</p>  <p>The
-         * Request Syntax section shows the <code>BudgetLimit</code> syntax. For
-         * <code>PlannedBudgetLimits</code>, see the <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_DescribeBudgets.html#API_DescribeBudgets_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * <p>Lists the budgets that are associated with an account.</p><p><h3>See
+         * Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DescribeBudgets">AWS
          * API Reference</a></p>
          *
@@ -469,11 +446,8 @@ namespace Model
         virtual Model::DescribeBudgetsOutcomeCallable DescribeBudgetsCallable(const Model::DescribeBudgetsRequest& request) const;
 
         /**
-         * <p>Lists the budgets that are associated with an account.</p>  <p>The
-         * Request Syntax section shows the <code>BudgetLimit</code> syntax. For
-         * <code>PlannedBudgetLimits</code>, see the <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_DescribeBudgets.html#API_DescribeBudgets_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * <p>Lists the budgets that are associated with an account.</p><p><h3>See
+         * Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/DescribeBudgets">AWS
          * API Reference</a></p>
          *
@@ -541,13 +515,7 @@ namespace Model
          * <p>Updates a budget. You can change every part of a budget except for the
          * <code>budgetName</code> and the <code>calculatedSpend</code>. When you modify a
          * budget, the <code>calculatedSpend</code> drops to zero until AWS has new usage
-         * data to use for forecasting.</p>  <p>Only one of
-         * <code>BudgetLimit</code> or <code>PlannedBudgetLimits</code> can be present in
-         * the syntax at one time. Use the syntax that matches your case. The Request
-         * Syntax section shows the <code>BudgetLimit</code> syntax. For
-         * <code>PlannedBudgetLimits</code>, see the <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_UpdateBudget.html#API_UpdateBudget_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * data to use for forecasting.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/UpdateBudget">AWS
          * API Reference</a></p>
          */
@@ -557,13 +525,7 @@ namespace Model
          * <p>Updates a budget. You can change every part of a budget except for the
          * <code>budgetName</code> and the <code>calculatedSpend</code>. When you modify a
          * budget, the <code>calculatedSpend</code> drops to zero until AWS has new usage
-         * data to use for forecasting.</p>  <p>Only one of
-         * <code>BudgetLimit</code> or <code>PlannedBudgetLimits</code> can be present in
-         * the syntax at one time. Use the syntax that matches your case. The Request
-         * Syntax section shows the <code>BudgetLimit</code> syntax. For
-         * <code>PlannedBudgetLimits</code>, see the <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_UpdateBudget.html#API_UpdateBudget_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * data to use for forecasting.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/UpdateBudget">AWS
          * API Reference</a></p>
          *
@@ -575,13 +537,7 @@ namespace Model
          * <p>Updates a budget. You can change every part of a budget except for the
          * <code>budgetName</code> and the <code>calculatedSpend</code>. When you modify a
          * budget, the <code>calculatedSpend</code> drops to zero until AWS has new usage
-         * data to use for forecasting.</p>  <p>Only one of
-         * <code>BudgetLimit</code> or <code>PlannedBudgetLimits</code> can be present in
-         * the syntax at one time. Use the syntax that matches your case. The Request
-         * Syntax section shows the <code>BudgetLimit</code> syntax. For
-         * <code>PlannedBudgetLimits</code>, see the <a
-         * href="https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_UpdateBudget.html#API_UpdateBudget_Examples">Examples</a>
-         * section. </p> <p><h3>See Also:</h3>   <a
+         * data to use for forecasting.</p><p><h3>See Also:</h3>   <a
          * href="http://docs.aws.amazon.com/goto/WebAPI/budgets-2016-10-20/UpdateBudget">AWS
          * API Reference</a></p>
          *
@@ -639,10 +595,11 @@ namespace Model
          */
         virtual void UpdateSubscriberAsync(const Model::UpdateSubscriberRequest& request, const UpdateSubscriberResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
-
+      
       void OverrideEndpoint(const Aws::String& endpoint);
     private:
       void init(const Aws::Client::ClientConfiguration& clientConfiguration);
+        /**Async helpers**/
         void CreateBudgetAsyncHelper(const Model::CreateBudgetRequest& request, const CreateBudgetResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void CreateNotificationAsyncHelper(const Model::CreateNotificationRequest& request, const CreateNotificationResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void CreateSubscriberAsyncHelper(const Model::CreateSubscriberRequest& request, const CreateSubscriberResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
