@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/ce/CostExplorer_EXPORTS.h>
@@ -19,12 +29,10 @@ namespace Model
     AZ,
     INSTANCE_TYPE,
     LINKED_ACCOUNT,
-    LINKED_ACCOUNT_NAME,
     OPERATION,
     PURCHASE_TYPE,
     REGION,
     SERVICE,
-    SERVICE_CODE,
     USAGE_TYPE,
     USAGE_TYPE_GROUP,
     RECORD_TYPE,
@@ -39,14 +47,7 @@ namespace Model
     CACHE_ENGINE,
     INSTANCE_TYPE_FAMILY,
     BILLING_ENTITY,
-    RESERVATION_ID,
-    RESOURCE_ID,
-    RIGHTSIZING_TYPE,
-    SAVINGS_PLANS_TYPE,
-    SAVINGS_PLAN_ARN,
-    PAYMENT_OPTION,
-    AGREEMENT_END_DATE_TIME_AFTER,
-    AGREEMENT_END_DATE_TIME_BEFORE
+    RESERVATION_ID
   };
 
 namespace DimensionMapper
