@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/ce/CostExplorer_EXPORTS.h>
@@ -10,9 +20,6 @@
 #include <aws/ce/model/DateInterval.h>
 #include <aws/ce/model/Dimension.h>
 #include <aws/ce/model/Context.h>
-#include <aws/ce/model/Expression.h>
-#include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/ce/model/SortDefinition.h>
 #include <utility>
 
 namespace Aws
@@ -28,7 +35,7 @@ namespace Model
   {
   public:
     GetDimensionValuesRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -138,43 +145,43 @@ namespace Model
 
     /**
      * <p>The name of the dimension. Each <code>Dimension</code> is available for a
-     * different <code>Context</code>. For more information, see <code>Context</code>.
-     * </p>
+     * different <code>Context</code>. For more information, see
+     * <code>Context</code>.</p>
      */
     inline const Dimension& GetDimension() const{ return m_dimension; }
 
     /**
      * <p>The name of the dimension. Each <code>Dimension</code> is available for a
-     * different <code>Context</code>. For more information, see <code>Context</code>.
-     * </p>
+     * different <code>Context</code>. For more information, see
+     * <code>Context</code>.</p>
      */
     inline bool DimensionHasBeenSet() const { return m_dimensionHasBeenSet; }
 
     /**
      * <p>The name of the dimension. Each <code>Dimension</code> is available for a
-     * different <code>Context</code>. For more information, see <code>Context</code>.
-     * </p>
+     * different <code>Context</code>. For more information, see
+     * <code>Context</code>.</p>
      */
     inline void SetDimension(const Dimension& value) { m_dimensionHasBeenSet = true; m_dimension = value; }
 
     /**
      * <p>The name of the dimension. Each <code>Dimension</code> is available for a
-     * different <code>Context</code>. For more information, see <code>Context</code>.
-     * </p>
+     * different <code>Context</code>. For more information, see
+     * <code>Context</code>.</p>
      */
     inline void SetDimension(Dimension&& value) { m_dimensionHasBeenSet = true; m_dimension = std::move(value); }
 
     /**
      * <p>The name of the dimension. Each <code>Dimension</code> is available for a
-     * different <code>Context</code>. For more information, see <code>Context</code>.
-     * </p>
+     * different <code>Context</code>. For more information, see
+     * <code>Context</code>.</p>
      */
     inline GetDimensionValuesRequest& WithDimension(const Dimension& value) { SetDimension(value); return *this;}
 
     /**
      * <p>The name of the dimension. Each <code>Dimension</code> is available for a
-     * different <code>Context</code>. For more information, see <code>Context</code>.
-     * </p>
+     * different <code>Context</code>. For more information, see
+     * <code>Context</code>.</p>
      */
     inline GetDimensionValuesRequest& WithDimension(Dimension&& value) { SetDimension(std::move(value)); return *this;}
 
@@ -209,16 +216,14 @@ namespace Model
      * attribute. Examples include GB and Hrs.</p> </li> <li> <p>USAGE_TYPE_GROUP - The
      * grouping of common usage types. An example is Amazon EC2: CloudWatch – Alarms.
      * The response for this operation includes a unit attribute.</p> </li> <li>
-     * <p>REGION - The AWS Region.</p> </li> <li> <p>RECORD_TYPE - The different types
-     * of charges such as RI fees, usage costs, tax refunds, and credits.</p> </li>
-     * <li> <p>RESOURCE_ID - The unique identifier of the resource. ResourceId is an
-     * opt-in feature only available for last 14 days for EC2-Compute Service.</p>
-     * </li> </ul> <p>If you set the context to <code>RESERVATIONS</code>, you can use
-     * the following dimensions for searching:</p> <ul> <li> <p>AZ - The Availability
-     * Zone. An example is <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE -
-     * The Amazon ElastiCache operating system. Examples are Windows or Linux.</p>
-     * </li> <li> <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database
-     * Service deployments. Valid values are <code>SingleAZ</code> and
+     * <p>RECORD_TYPE - The different types of charges such as RI fees, usage costs,
+     * tax refunds, and credits.</p> </li> </ul> <p>If you set the context to
+     * <code>RESERVATIONS</code>, you can use the following dimensions for
+     * searching:</p> <ul> <li> <p>AZ - The Availability Zone. An example is
+     * <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE - The Amazon ElastiCache
+     * operating system. Examples are Windows or Linux.</p> </li> <li>
+     * <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database Service
+     * deployments. Valid values are <code>SingleAZ</code> and
      * <code>MultiAZ</code>.</p> </li> <li> <p>INSTANCE_TYPE - The type of Amazon EC2
      * instance. An example is <code>m4.xlarge</code>.</p> </li> <li> <p>LINKED_ACCOUNT
      * - The description in the attribute map that includes the full name of the member
@@ -229,16 +234,6 @@ namespace Model
      * or a single Availability Zone.</p> </li> <li> <p>TAG (Coverage only) - The tags
      * that are associated with a Reserved Instance (RI).</p> </li> <li> <p>TENANCY -
      * The tenancy of a resource. Examples are shared or dedicated.</p> </li> </ul>
-     * <p>If you set the context to <code>SAVINGS_PLANS</code>, you can use the
-     * following dimensions for searching:</p> <ul> <li> <p>SAVINGS_PLANS_TYPE - Type
-     * of Savings Plans (EC2 Instance or Compute)</p> </li> <li> <p>PAYMENT_OPTION -
-     * Payment option for the given Savings Plans (for example, All Upfront)</p> </li>
-     * <li> <p>REGION - The AWS Region.</p> </li> <li> <p>INSTANCE_TYPE_FAMILY - The
-     * family of instances (For example, <code>m5</code>)</p> </li> <li>
-     * <p>LINKED_ACCOUNT - The description in the attribute map that includes the full
-     * name of the member account. The value field contains the AWS ID of the member
-     * account.</p> </li> <li> <p>SAVINGS_PLAN_ARN - The unique identifier for your
-     * Savings Plan</p> </li> </ul>
      */
     inline const Context& GetContext() const{ return m_context; }
 
@@ -272,16 +267,14 @@ namespace Model
      * attribute. Examples include GB and Hrs.</p> </li> <li> <p>USAGE_TYPE_GROUP - The
      * grouping of common usage types. An example is Amazon EC2: CloudWatch – Alarms.
      * The response for this operation includes a unit attribute.</p> </li> <li>
-     * <p>REGION - The AWS Region.</p> </li> <li> <p>RECORD_TYPE - The different types
-     * of charges such as RI fees, usage costs, tax refunds, and credits.</p> </li>
-     * <li> <p>RESOURCE_ID - The unique identifier of the resource. ResourceId is an
-     * opt-in feature only available for last 14 days for EC2-Compute Service.</p>
-     * </li> </ul> <p>If you set the context to <code>RESERVATIONS</code>, you can use
-     * the following dimensions for searching:</p> <ul> <li> <p>AZ - The Availability
-     * Zone. An example is <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE -
-     * The Amazon ElastiCache operating system. Examples are Windows or Linux.</p>
-     * </li> <li> <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database
-     * Service deployments. Valid values are <code>SingleAZ</code> and
+     * <p>RECORD_TYPE - The different types of charges such as RI fees, usage costs,
+     * tax refunds, and credits.</p> </li> </ul> <p>If you set the context to
+     * <code>RESERVATIONS</code>, you can use the following dimensions for
+     * searching:</p> <ul> <li> <p>AZ - The Availability Zone. An example is
+     * <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE - The Amazon ElastiCache
+     * operating system. Examples are Windows or Linux.</p> </li> <li>
+     * <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database Service
+     * deployments. Valid values are <code>SingleAZ</code> and
      * <code>MultiAZ</code>.</p> </li> <li> <p>INSTANCE_TYPE - The type of Amazon EC2
      * instance. An example is <code>m4.xlarge</code>.</p> </li> <li> <p>LINKED_ACCOUNT
      * - The description in the attribute map that includes the full name of the member
@@ -292,16 +285,6 @@ namespace Model
      * or a single Availability Zone.</p> </li> <li> <p>TAG (Coverage only) - The tags
      * that are associated with a Reserved Instance (RI).</p> </li> <li> <p>TENANCY -
      * The tenancy of a resource. Examples are shared or dedicated.</p> </li> </ul>
-     * <p>If you set the context to <code>SAVINGS_PLANS</code>, you can use the
-     * following dimensions for searching:</p> <ul> <li> <p>SAVINGS_PLANS_TYPE - Type
-     * of Savings Plans (EC2 Instance or Compute)</p> </li> <li> <p>PAYMENT_OPTION -
-     * Payment option for the given Savings Plans (for example, All Upfront)</p> </li>
-     * <li> <p>REGION - The AWS Region.</p> </li> <li> <p>INSTANCE_TYPE_FAMILY - The
-     * family of instances (For example, <code>m5</code>)</p> </li> <li>
-     * <p>LINKED_ACCOUNT - The description in the attribute map that includes the full
-     * name of the member account. The value field contains the AWS ID of the member
-     * account.</p> </li> <li> <p>SAVINGS_PLAN_ARN - The unique identifier for your
-     * Savings Plan</p> </li> </ul>
      */
     inline bool ContextHasBeenSet() const { return m_contextHasBeenSet; }
 
@@ -335,16 +318,14 @@ namespace Model
      * attribute. Examples include GB and Hrs.</p> </li> <li> <p>USAGE_TYPE_GROUP - The
      * grouping of common usage types. An example is Amazon EC2: CloudWatch – Alarms.
      * The response for this operation includes a unit attribute.</p> </li> <li>
-     * <p>REGION - The AWS Region.</p> </li> <li> <p>RECORD_TYPE - The different types
-     * of charges such as RI fees, usage costs, tax refunds, and credits.</p> </li>
-     * <li> <p>RESOURCE_ID - The unique identifier of the resource. ResourceId is an
-     * opt-in feature only available for last 14 days for EC2-Compute Service.</p>
-     * </li> </ul> <p>If you set the context to <code>RESERVATIONS</code>, you can use
-     * the following dimensions for searching:</p> <ul> <li> <p>AZ - The Availability
-     * Zone. An example is <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE -
-     * The Amazon ElastiCache operating system. Examples are Windows or Linux.</p>
-     * </li> <li> <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database
-     * Service deployments. Valid values are <code>SingleAZ</code> and
+     * <p>RECORD_TYPE - The different types of charges such as RI fees, usage costs,
+     * tax refunds, and credits.</p> </li> </ul> <p>If you set the context to
+     * <code>RESERVATIONS</code>, you can use the following dimensions for
+     * searching:</p> <ul> <li> <p>AZ - The Availability Zone. An example is
+     * <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE - The Amazon ElastiCache
+     * operating system. Examples are Windows or Linux.</p> </li> <li>
+     * <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database Service
+     * deployments. Valid values are <code>SingleAZ</code> and
      * <code>MultiAZ</code>.</p> </li> <li> <p>INSTANCE_TYPE - The type of Amazon EC2
      * instance. An example is <code>m4.xlarge</code>.</p> </li> <li> <p>LINKED_ACCOUNT
      * - The description in the attribute map that includes the full name of the member
@@ -355,16 +336,6 @@ namespace Model
      * or a single Availability Zone.</p> </li> <li> <p>TAG (Coverage only) - The tags
      * that are associated with a Reserved Instance (RI).</p> </li> <li> <p>TENANCY -
      * The tenancy of a resource. Examples are shared or dedicated.</p> </li> </ul>
-     * <p>If you set the context to <code>SAVINGS_PLANS</code>, you can use the
-     * following dimensions for searching:</p> <ul> <li> <p>SAVINGS_PLANS_TYPE - Type
-     * of Savings Plans (EC2 Instance or Compute)</p> </li> <li> <p>PAYMENT_OPTION -
-     * Payment option for the given Savings Plans (for example, All Upfront)</p> </li>
-     * <li> <p>REGION - The AWS Region.</p> </li> <li> <p>INSTANCE_TYPE_FAMILY - The
-     * family of instances (For example, <code>m5</code>)</p> </li> <li>
-     * <p>LINKED_ACCOUNT - The description in the attribute map that includes the full
-     * name of the member account. The value field contains the AWS ID of the member
-     * account.</p> </li> <li> <p>SAVINGS_PLAN_ARN - The unique identifier for your
-     * Savings Plan</p> </li> </ul>
      */
     inline void SetContext(const Context& value) { m_contextHasBeenSet = true; m_context = value; }
 
@@ -398,16 +369,14 @@ namespace Model
      * attribute. Examples include GB and Hrs.</p> </li> <li> <p>USAGE_TYPE_GROUP - The
      * grouping of common usage types. An example is Amazon EC2: CloudWatch – Alarms.
      * The response for this operation includes a unit attribute.</p> </li> <li>
-     * <p>REGION - The AWS Region.</p> </li> <li> <p>RECORD_TYPE - The different types
-     * of charges such as RI fees, usage costs, tax refunds, and credits.</p> </li>
-     * <li> <p>RESOURCE_ID - The unique identifier of the resource. ResourceId is an
-     * opt-in feature only available for last 14 days for EC2-Compute Service.</p>
-     * </li> </ul> <p>If you set the context to <code>RESERVATIONS</code>, you can use
-     * the following dimensions for searching:</p> <ul> <li> <p>AZ - The Availability
-     * Zone. An example is <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE -
-     * The Amazon ElastiCache operating system. Examples are Windows or Linux.</p>
-     * </li> <li> <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database
-     * Service deployments. Valid values are <code>SingleAZ</code> and
+     * <p>RECORD_TYPE - The different types of charges such as RI fees, usage costs,
+     * tax refunds, and credits.</p> </li> </ul> <p>If you set the context to
+     * <code>RESERVATIONS</code>, you can use the following dimensions for
+     * searching:</p> <ul> <li> <p>AZ - The Availability Zone. An example is
+     * <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE - The Amazon ElastiCache
+     * operating system. Examples are Windows or Linux.</p> </li> <li>
+     * <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database Service
+     * deployments. Valid values are <code>SingleAZ</code> and
      * <code>MultiAZ</code>.</p> </li> <li> <p>INSTANCE_TYPE - The type of Amazon EC2
      * instance. An example is <code>m4.xlarge</code>.</p> </li> <li> <p>LINKED_ACCOUNT
      * - The description in the attribute map that includes the full name of the member
@@ -418,16 +387,6 @@ namespace Model
      * or a single Availability Zone.</p> </li> <li> <p>TAG (Coverage only) - The tags
      * that are associated with a Reserved Instance (RI).</p> </li> <li> <p>TENANCY -
      * The tenancy of a resource. Examples are shared or dedicated.</p> </li> </ul>
-     * <p>If you set the context to <code>SAVINGS_PLANS</code>, you can use the
-     * following dimensions for searching:</p> <ul> <li> <p>SAVINGS_PLANS_TYPE - Type
-     * of Savings Plans (EC2 Instance or Compute)</p> </li> <li> <p>PAYMENT_OPTION -
-     * Payment option for the given Savings Plans (for example, All Upfront)</p> </li>
-     * <li> <p>REGION - The AWS Region.</p> </li> <li> <p>INSTANCE_TYPE_FAMILY - The
-     * family of instances (For example, <code>m5</code>)</p> </li> <li>
-     * <p>LINKED_ACCOUNT - The description in the attribute map that includes the full
-     * name of the member account. The value field contains the AWS ID of the member
-     * account.</p> </li> <li> <p>SAVINGS_PLAN_ARN - The unique identifier for your
-     * Savings Plan</p> </li> </ul>
      */
     inline void SetContext(Context&& value) { m_contextHasBeenSet = true; m_context = std::move(value); }
 
@@ -461,16 +420,14 @@ namespace Model
      * attribute. Examples include GB and Hrs.</p> </li> <li> <p>USAGE_TYPE_GROUP - The
      * grouping of common usage types. An example is Amazon EC2: CloudWatch – Alarms.
      * The response for this operation includes a unit attribute.</p> </li> <li>
-     * <p>REGION - The AWS Region.</p> </li> <li> <p>RECORD_TYPE - The different types
-     * of charges such as RI fees, usage costs, tax refunds, and credits.</p> </li>
-     * <li> <p>RESOURCE_ID - The unique identifier of the resource. ResourceId is an
-     * opt-in feature only available for last 14 days for EC2-Compute Service.</p>
-     * </li> </ul> <p>If you set the context to <code>RESERVATIONS</code>, you can use
-     * the following dimensions for searching:</p> <ul> <li> <p>AZ - The Availability
-     * Zone. An example is <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE -
-     * The Amazon ElastiCache operating system. Examples are Windows or Linux.</p>
-     * </li> <li> <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database
-     * Service deployments. Valid values are <code>SingleAZ</code> and
+     * <p>RECORD_TYPE - The different types of charges such as RI fees, usage costs,
+     * tax refunds, and credits.</p> </li> </ul> <p>If you set the context to
+     * <code>RESERVATIONS</code>, you can use the following dimensions for
+     * searching:</p> <ul> <li> <p>AZ - The Availability Zone. An example is
+     * <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE - The Amazon ElastiCache
+     * operating system. Examples are Windows or Linux.</p> </li> <li>
+     * <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database Service
+     * deployments. Valid values are <code>SingleAZ</code> and
      * <code>MultiAZ</code>.</p> </li> <li> <p>INSTANCE_TYPE - The type of Amazon EC2
      * instance. An example is <code>m4.xlarge</code>.</p> </li> <li> <p>LINKED_ACCOUNT
      * - The description in the attribute map that includes the full name of the member
@@ -481,16 +438,6 @@ namespace Model
      * or a single Availability Zone.</p> </li> <li> <p>TAG (Coverage only) - The tags
      * that are associated with a Reserved Instance (RI).</p> </li> <li> <p>TENANCY -
      * The tenancy of a resource. Examples are shared or dedicated.</p> </li> </ul>
-     * <p>If you set the context to <code>SAVINGS_PLANS</code>, you can use the
-     * following dimensions for searching:</p> <ul> <li> <p>SAVINGS_PLANS_TYPE - Type
-     * of Savings Plans (EC2 Instance or Compute)</p> </li> <li> <p>PAYMENT_OPTION -
-     * Payment option for the given Savings Plans (for example, All Upfront)</p> </li>
-     * <li> <p>REGION - The AWS Region.</p> </li> <li> <p>INSTANCE_TYPE_FAMILY - The
-     * family of instances (For example, <code>m5</code>)</p> </li> <li>
-     * <p>LINKED_ACCOUNT - The description in the attribute map that includes the full
-     * name of the member account. The value field contains the AWS ID of the member
-     * account.</p> </li> <li> <p>SAVINGS_PLAN_ARN - The unique identifier for your
-     * Savings Plan</p> </li> </ul>
      */
     inline GetDimensionValuesRequest& WithContext(const Context& value) { SetContext(value); return *this;}
 
@@ -524,16 +471,14 @@ namespace Model
      * attribute. Examples include GB and Hrs.</p> </li> <li> <p>USAGE_TYPE_GROUP - The
      * grouping of common usage types. An example is Amazon EC2: CloudWatch – Alarms.
      * The response for this operation includes a unit attribute.</p> </li> <li>
-     * <p>REGION - The AWS Region.</p> </li> <li> <p>RECORD_TYPE - The different types
-     * of charges such as RI fees, usage costs, tax refunds, and credits.</p> </li>
-     * <li> <p>RESOURCE_ID - The unique identifier of the resource. ResourceId is an
-     * opt-in feature only available for last 14 days for EC2-Compute Service.</p>
-     * </li> </ul> <p>If you set the context to <code>RESERVATIONS</code>, you can use
-     * the following dimensions for searching:</p> <ul> <li> <p>AZ - The Availability
-     * Zone. An example is <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE -
-     * The Amazon ElastiCache operating system. Examples are Windows or Linux.</p>
-     * </li> <li> <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database
-     * Service deployments. Valid values are <code>SingleAZ</code> and
+     * <p>RECORD_TYPE - The different types of charges such as RI fees, usage costs,
+     * tax refunds, and credits.</p> </li> </ul> <p>If you set the context to
+     * <code>RESERVATIONS</code>, you can use the following dimensions for
+     * searching:</p> <ul> <li> <p>AZ - The Availability Zone. An example is
+     * <code>us-east-1a</code>.</p> </li> <li> <p>CACHE_ENGINE - The Amazon ElastiCache
+     * operating system. Examples are Windows or Linux.</p> </li> <li>
+     * <p>DEPLOYMENT_OPTION - The scope of Amazon Relational Database Service
+     * deployments. Valid values are <code>SingleAZ</code> and
      * <code>MultiAZ</code>.</p> </li> <li> <p>INSTANCE_TYPE - The type of Amazon EC2
      * instance. An example is <code>m4.xlarge</code>.</p> </li> <li> <p>LINKED_ACCOUNT
      * - The description in the attribute map that includes the full name of the member
@@ -544,205 +489,10 @@ namespace Model
      * or a single Availability Zone.</p> </li> <li> <p>TAG (Coverage only) - The tags
      * that are associated with a Reserved Instance (RI).</p> </li> <li> <p>TENANCY -
      * The tenancy of a resource. Examples are shared or dedicated.</p> </li> </ul>
-     * <p>If you set the context to <code>SAVINGS_PLANS</code>, you can use the
-     * following dimensions for searching:</p> <ul> <li> <p>SAVINGS_PLANS_TYPE - Type
-     * of Savings Plans (EC2 Instance or Compute)</p> </li> <li> <p>PAYMENT_OPTION -
-     * Payment option for the given Savings Plans (for example, All Upfront)</p> </li>
-     * <li> <p>REGION - The AWS Region.</p> </li> <li> <p>INSTANCE_TYPE_FAMILY - The
-     * family of instances (For example, <code>m5</code>)</p> </li> <li>
-     * <p>LINKED_ACCOUNT - The description in the attribute map that includes the full
-     * name of the member account. The value field contains the AWS ID of the member
-     * account.</p> </li> <li> <p>SAVINGS_PLAN_ARN - The unique identifier for your
-     * Savings Plan</p> </li> </ul>
      */
     inline GetDimensionValuesRequest& WithContext(Context&& value) { SetContext(std::move(value)); return *this;}
 
 
-    
-    inline const Expression& GetFilter() const{ return m_filter; }
-
-    
-    inline bool FilterHasBeenSet() const { return m_filterHasBeenSet; }
-
-    
-    inline void SetFilter(const Expression& value) { m_filterHasBeenSet = true; m_filter = value; }
-
-    
-    inline void SetFilter(Expression&& value) { m_filterHasBeenSet = true; m_filter = std::move(value); }
-
-    
-    inline GetDimensionValuesRequest& WithFilter(const Expression& value) { SetFilter(value); return *this;}
-
-    
-    inline GetDimensionValuesRequest& WithFilter(Expression&& value) { SetFilter(std::move(value)); return *this;}
-
-
-    /**
-     * <p>The value by which you want to sort the data.</p> <p>The key represents cost
-     * and usage metrics. The following values are supported:</p> <ul> <li> <p>
-     * <code>BlendedCost</code> </p> </li> <li> <p> <code>UnblendedCost</code> </p>
-     * </li> <li> <p> <code>AmortizedCost</code> </p> </li> <li> <p>
-     * <code>NetAmortizedCost</code> </p> </li> <li> <p> <code>NetUnblendedCost</code>
-     * </p> </li> <li> <p> <code>UsageQuantity</code> </p> </li> <li> <p>
-     * <code>NormalizedUsageAmount</code> </p> </li> </ul> <p>Supported values for
-     * <code>SortOrder</code> are <code>ASCENDING</code> or
-     * <code>DESCENDING</code>.</p> <p>When you specify a <code>SortBy</code>
-     * paramater, the context must be <code>COST_AND_USAGE</code>. Further, when using
-     * <code>SortBy</code>, <code>NextPageToken</code> and <code>SearchString</code>
-     * are not supported.</p>
-     */
-    inline const Aws::Vector<SortDefinition>& GetSortBy() const{ return m_sortBy; }
-
-    /**
-     * <p>The value by which you want to sort the data.</p> <p>The key represents cost
-     * and usage metrics. The following values are supported:</p> <ul> <li> <p>
-     * <code>BlendedCost</code> </p> </li> <li> <p> <code>UnblendedCost</code> </p>
-     * </li> <li> <p> <code>AmortizedCost</code> </p> </li> <li> <p>
-     * <code>NetAmortizedCost</code> </p> </li> <li> <p> <code>NetUnblendedCost</code>
-     * </p> </li> <li> <p> <code>UsageQuantity</code> </p> </li> <li> <p>
-     * <code>NormalizedUsageAmount</code> </p> </li> </ul> <p>Supported values for
-     * <code>SortOrder</code> are <code>ASCENDING</code> or
-     * <code>DESCENDING</code>.</p> <p>When you specify a <code>SortBy</code>
-     * paramater, the context must be <code>COST_AND_USAGE</code>. Further, when using
-     * <code>SortBy</code>, <code>NextPageToken</code> and <code>SearchString</code>
-     * are not supported.</p>
-     */
-    inline bool SortByHasBeenSet() const { return m_sortByHasBeenSet; }
-
-    /**
-     * <p>The value by which you want to sort the data.</p> <p>The key represents cost
-     * and usage metrics. The following values are supported:</p> <ul> <li> <p>
-     * <code>BlendedCost</code> </p> </li> <li> <p> <code>UnblendedCost</code> </p>
-     * </li> <li> <p> <code>AmortizedCost</code> </p> </li> <li> <p>
-     * <code>NetAmortizedCost</code> </p> </li> <li> <p> <code>NetUnblendedCost</code>
-     * </p> </li> <li> <p> <code>UsageQuantity</code> </p> </li> <li> <p>
-     * <code>NormalizedUsageAmount</code> </p> </li> </ul> <p>Supported values for
-     * <code>SortOrder</code> are <code>ASCENDING</code> or
-     * <code>DESCENDING</code>.</p> <p>When you specify a <code>SortBy</code>
-     * paramater, the context must be <code>COST_AND_USAGE</code>. Further, when using
-     * <code>SortBy</code>, <code>NextPageToken</code> and <code>SearchString</code>
-     * are not supported.</p>
-     */
-    inline void SetSortBy(const Aws::Vector<SortDefinition>& value) { m_sortByHasBeenSet = true; m_sortBy = value; }
-
-    /**
-     * <p>The value by which you want to sort the data.</p> <p>The key represents cost
-     * and usage metrics. The following values are supported:</p> <ul> <li> <p>
-     * <code>BlendedCost</code> </p> </li> <li> <p> <code>UnblendedCost</code> </p>
-     * </li> <li> <p> <code>AmortizedCost</code> </p> </li> <li> <p>
-     * <code>NetAmortizedCost</code> </p> </li> <li> <p> <code>NetUnblendedCost</code>
-     * </p> </li> <li> <p> <code>UsageQuantity</code> </p> </li> <li> <p>
-     * <code>NormalizedUsageAmount</code> </p> </li> </ul> <p>Supported values for
-     * <code>SortOrder</code> are <code>ASCENDING</code> or
-     * <code>DESCENDING</code>.</p> <p>When you specify a <code>SortBy</code>
-     * paramater, the context must be <code>COST_AND_USAGE</code>. Further, when using
-     * <code>SortBy</code>, <code>NextPageToken</code> and <code>SearchString</code>
-     * are not supported.</p>
-     */
-    inline void SetSortBy(Aws::Vector<SortDefinition>&& value) { m_sortByHasBeenSet = true; m_sortBy = std::move(value); }
-
-    /**
-     * <p>The value by which you want to sort the data.</p> <p>The key represents cost
-     * and usage metrics. The following values are supported:</p> <ul> <li> <p>
-     * <code>BlendedCost</code> </p> </li> <li> <p> <code>UnblendedCost</code> </p>
-     * </li> <li> <p> <code>AmortizedCost</code> </p> </li> <li> <p>
-     * <code>NetAmortizedCost</code> </p> </li> <li> <p> <code>NetUnblendedCost</code>
-     * </p> </li> <li> <p> <code>UsageQuantity</code> </p> </li> <li> <p>
-     * <code>NormalizedUsageAmount</code> </p> </li> </ul> <p>Supported values for
-     * <code>SortOrder</code> are <code>ASCENDING</code> or
-     * <code>DESCENDING</code>.</p> <p>When you specify a <code>SortBy</code>
-     * paramater, the context must be <code>COST_AND_USAGE</code>. Further, when using
-     * <code>SortBy</code>, <code>NextPageToken</code> and <code>SearchString</code>
-     * are not supported.</p>
-     */
-    inline GetDimensionValuesRequest& WithSortBy(const Aws::Vector<SortDefinition>& value) { SetSortBy(value); return *this;}
-
-    /**
-     * <p>The value by which you want to sort the data.</p> <p>The key represents cost
-     * and usage metrics. The following values are supported:</p> <ul> <li> <p>
-     * <code>BlendedCost</code> </p> </li> <li> <p> <code>UnblendedCost</code> </p>
-     * </li> <li> <p> <code>AmortizedCost</code> </p> </li> <li> <p>
-     * <code>NetAmortizedCost</code> </p> </li> <li> <p> <code>NetUnblendedCost</code>
-     * </p> </li> <li> <p> <code>UsageQuantity</code> </p> </li> <li> <p>
-     * <code>NormalizedUsageAmount</code> </p> </li> </ul> <p>Supported values for
-     * <code>SortOrder</code> are <code>ASCENDING</code> or
-     * <code>DESCENDING</code>.</p> <p>When you specify a <code>SortBy</code>
-     * paramater, the context must be <code>COST_AND_USAGE</code>. Further, when using
-     * <code>SortBy</code>, <code>NextPageToken</code> and <code>SearchString</code>
-     * are not supported.</p>
-     */
-    inline GetDimensionValuesRequest& WithSortBy(Aws::Vector<SortDefinition>&& value) { SetSortBy(std::move(value)); return *this;}
-
-    /**
-     * <p>The value by which you want to sort the data.</p> <p>The key represents cost
-     * and usage metrics. The following values are supported:</p> <ul> <li> <p>
-     * <code>BlendedCost</code> </p> </li> <li> <p> <code>UnblendedCost</code> </p>
-     * </li> <li> <p> <code>AmortizedCost</code> </p> </li> <li> <p>
-     * <code>NetAmortizedCost</code> </p> </li> <li> <p> <code>NetUnblendedCost</code>
-     * </p> </li> <li> <p> <code>UsageQuantity</code> </p> </li> <li> <p>
-     * <code>NormalizedUsageAmount</code> </p> </li> </ul> <p>Supported values for
-     * <code>SortOrder</code> are <code>ASCENDING</code> or
-     * <code>DESCENDING</code>.</p> <p>When you specify a <code>SortBy</code>
-     * paramater, the context must be <code>COST_AND_USAGE</code>. Further, when using
-     * <code>SortBy</code>, <code>NextPageToken</code> and <code>SearchString</code>
-     * are not supported.</p>
-     */
-    inline GetDimensionValuesRequest& AddSortBy(const SortDefinition& value) { m_sortByHasBeenSet = true; m_sortBy.push_back(value); return *this; }
-
-    /**
-     * <p>The value by which you want to sort the data.</p> <p>The key represents cost
-     * and usage metrics. The following values are supported:</p> <ul> <li> <p>
-     * <code>BlendedCost</code> </p> </li> <li> <p> <code>UnblendedCost</code> </p>
-     * </li> <li> <p> <code>AmortizedCost</code> </p> </li> <li> <p>
-     * <code>NetAmortizedCost</code> </p> </li> <li> <p> <code>NetUnblendedCost</code>
-     * </p> </li> <li> <p> <code>UsageQuantity</code> </p> </li> <li> <p>
-     * <code>NormalizedUsageAmount</code> </p> </li> </ul> <p>Supported values for
-     * <code>SortOrder</code> are <code>ASCENDING</code> or
-     * <code>DESCENDING</code>.</p> <p>When you specify a <code>SortBy</code>
-     * paramater, the context must be <code>COST_AND_USAGE</code>. Further, when using
-     * <code>SortBy</code>, <code>NextPageToken</code> and <code>SearchString</code>
-     * are not supported.</p>
-     */
-    inline GetDimensionValuesRequest& AddSortBy(SortDefinition&& value) { m_sortByHasBeenSet = true; m_sortBy.push_back(std::move(value)); return *this; }
-
-
-    /**
-     * <p>This field is only used when SortBy is provided in the request. The maximum
-     * number of objects that to be returned for this request. If MaxResults is not
-     * specified with SortBy, the request will return 1000 results as the default value
-     * for this parameter.</p> <p>For <code>GetDimensionValues</code>, MaxResults has
-     * an upper limit of 1000.</p>
-     */
-    inline int GetMaxResults() const{ return m_maxResults; }
-
-    /**
-     * <p>This field is only used when SortBy is provided in the request. The maximum
-     * number of objects that to be returned for this request. If MaxResults is not
-     * specified with SortBy, the request will return 1000 results as the default value
-     * for this parameter.</p> <p>For <code>GetDimensionValues</code>, MaxResults has
-     * an upper limit of 1000.</p>
-     */
-    inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }
-
-    /**
-     * <p>This field is only used when SortBy is provided in the request. The maximum
-     * number of objects that to be returned for this request. If MaxResults is not
-     * specified with SortBy, the request will return 1000 results as the default value
-     * for this parameter.</p> <p>For <code>GetDimensionValues</code>, MaxResults has
-     * an upper limit of 1000.</p>
-     */
-    inline void SetMaxResults(int value) { m_maxResultsHasBeenSet = true; m_maxResults = value; }
-
-    /**
-     * <p>This field is only used when SortBy is provided in the request. The maximum
-     * number of objects that to be returned for this request. If MaxResults is not
-     * specified with SortBy, the request will return 1000 results as the default value
-     * for this parameter.</p> <p>For <code>GetDimensionValues</code>, MaxResults has
-     * an upper limit of 1000.</p>
-     */
-    inline GetDimensionValuesRequest& WithMaxResults(int value) { SetMaxResults(value); return *this;}
-
-
     /**
      * <p>The token to retrieve the next set of results. AWS provides the token when
      * the response from a previous call has more results than the maximum page
@@ -813,15 +563,6 @@ namespace Model
     Context m_context;
     bool m_contextHasBeenSet;
 
-    Expression m_filter;
-    bool m_filterHasBeenSet;
-
-    Aws::Vector<SortDefinition> m_sortBy;
-    bool m_sortByHasBeenSet;
-
-    int m_maxResults;
-    bool m_maxResultsHasBeenSet;
-
     Aws::String m_nextPageToken;
     bool m_nextPageTokenHasBeenSet;
   };
