@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/cloudformation/CloudFormation_EXPORTS.h>
@@ -13,7 +23,6 @@
 #include <aws/cloudformation/model/Parameter.h>
 #include <aws/cloudformation/model/Capability.h>
 #include <aws/cloudformation/model/Tag.h>
-#include <aws/cloudformation/model/ResourceToImport.h>
 #include <utility>
 
 namespace Aws
@@ -33,7 +42,7 @@ namespace Model
   {
   public:
     CreateChangeSetRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -333,7 +342,7 @@ namespace Model
 
 
     /**
-     * <p>In some cases, you must explicitly acknowledge that your stack template
+     * <p>In some cases, you must explicity acknowledge that your stack template
      * contains certain capabilities in order for AWS CloudFormation to create the
      * stack.</p> <ul> <li> <p> <code>CAPABILITY_IAM</code> and
      * <code>CAPABILITY_NAMED_IAM</code> </p> <p>Some stack templates might include
@@ -379,13 +388,13 @@ namespace Model
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/create-reusable-transform-function-snippets-and-add-to-your-template-with-aws-include-transform.html">AWS::Include</a>
      * and <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/transform-aws-serverless.html">AWS::Serverless</a>
-     * transforms, which are macros hosted by AWS CloudFormation.</p>  <p>This
+     * transforms, which are macros hosted by AWS CloudFormation.</p> <note> <p>This
      * capacity does not apply to creating change sets, and specifying it when creating
      * change sets has no effect.</p> <p>Also, change sets do not currently support
      * nested stacks. If you want to create a stack from a stack template that contains
      * macros <i>and</i> nested stacks, you must create or update the stack directly
      * from the template using the <a>CreateStack</a> or <a>UpdateStack</a> action, and
-     * specifying this capability.</p>  <p>For more information on macros, see
+     * specifying this capability.</p> </note> <p>For more information on macros, see
      * <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-macros.html">Using
      * AWS CloudFormation Macros to Perform Custom Processing on Templates</a>.</p>
@@ -394,7 +403,7 @@ namespace Model
     inline const Aws::Vector<Capability>& GetCapabilities() const{ return m_capabilities; }
 
     /**
-     * <p>In some cases, you must explicitly acknowledge that your stack template
+     * <p>In some cases, you must explicity acknowledge that your stack template
      * contains certain capabilities in order for AWS CloudFormation to create the
      * stack.</p> <ul> <li> <p> <code>CAPABILITY_IAM</code> and
      * <code>CAPABILITY_NAMED_IAM</code> </p> <p>Some stack templates might include
@@ -440,13 +449,13 @@ namespace Model
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/create-reusable-transform-function-snippets-and-add-to-your-template-with-aws-include-transform.html">AWS::Include</a>
      * and <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/transform-aws-serverless.html">AWS::Serverless</a>
-     * transforms, which are macros hosted by AWS CloudFormation.</p>  <p>This
+     * transforms, which are macros hosted by AWS CloudFormation.</p> <note> <p>This
      * capacity does not apply to creating change sets, and specifying it when creating
      * change sets has no effect.</p> <p>Also, change sets do not currently support
      * nested stacks. If you want to create a stack from a stack template that contains
      * macros <i>and</i> nested stacks, you must create or update the stack directly
      * from the template using the <a>CreateStack</a> or <a>UpdateStack</a> action, and
-     * specifying this capability.</p>  <p>For more information on macros, see
+     * specifying this capability.</p> </note> <p>For more information on macros, see
      * <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-macros.html">Using
      * AWS CloudFormation Macros to Perform Custom Processing on Templates</a>.</p>
@@ -455,7 +464,7 @@ namespace Model
     inline bool CapabilitiesHasBeenSet() const { return m_capabilitiesHasBeenSet; }
 
     /**
-     * <p>In some cases, you must explicitly acknowledge that your stack template
+     * <p>In some cases, you must explicity acknowledge that your stack template
      * contains certain capabilities in order for AWS CloudFormation to create the
      * stack.</p> <ul> <li> <p> <code>CAPABILITY_IAM</code> and
      * <code>CAPABILITY_NAMED_IAM</code> </p> <p>Some stack templates might include
@@ -501,13 +510,13 @@ namespace Model
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/create-reusable-transform-function-snippets-and-add-to-your-template-with-aws-include-transform.html">AWS::Include</a>
      * and <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/transform-aws-serverless.html">AWS::Serverless</a>
-     * transforms, which are macros hosted by AWS CloudFormation.</p>  <p>This
+     * transforms, which are macros hosted by AWS CloudFormation.</p> <note> <p>This
      * capacity does not apply to creating change sets, and specifying it when creating
      * change sets has no effect.</p> <p>Also, change sets do not currently support
      * nested stacks. If you want to create a stack from a stack template that contains
      * macros <i>and</i> nested stacks, you must create or update the stack directly
      * from the template using the <a>CreateStack</a> or <a>UpdateStack</a> action, and
-     * specifying this capability.</p>  <p>For more information on macros, see
+     * specifying this capability.</p> </note> <p>For more information on macros, see
      * <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-macros.html">Using
      * AWS CloudFormation Macros to Perform Custom Processing on Templates</a>.</p>
@@ -516,7 +525,7 @@ namespace Model
     inline void SetCapabilities(const Aws::Vector<Capability>& value) { m_capabilitiesHasBeenSet = true; m_capabilities = value; }
 
     /**
-     * <p>In some cases, you must explicitly acknowledge that your stack template
+     * <p>In some cases, you must explicity acknowledge that your stack template
      * contains certain capabilities in order for AWS CloudFormation to create the
      * stack.</p> <ul> <li> <p> <code>CAPABILITY_IAM</code> and
      * <code>CAPABILITY_NAMED_IAM</code> </p> <p>Some stack templates might include
@@ -562,13 +571,13 @@ namespace Model
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/create-reusable-transform-function-snippets-and-add-to-your-template-with-aws-include-transform.html">AWS::Include</a>
      * and <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/transform-aws-serverless.html">AWS::Serverless</a>
-     * transforms, which are macros hosted by AWS CloudFormation.</p>  <p>This
+     * transforms, which are macros hosted by AWS CloudFormation.</p> <note> <p>This
      * capacity does not apply to creating change sets, and specifying it when creating
      * change sets has no effect.</p> <p>Also, change sets do not currently support
      * nested stacks. If you want to create a stack from a stack template that contains
      * macros <i>and</i> nested stacks, you must create or update the stack directly
      * from the template using the <a>CreateStack</a> or <a>UpdateStack</a> action, and
-     * specifying this capability.</p>  <p>For more information on macros, see
+     * specifying this capability.</p> </note> <p>For more information on macros, see
      * <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-macros.html">Using
      * AWS CloudFormation Macros to Perform Custom Processing on Templates</a>.</p>
@@ -577,7 +586,7 @@ namespace Model
     inline void SetCapabilities(Aws::Vector<Capability>&& value) { m_capabilitiesHasBeenSet = true; m_capabilities = std::move(value); }
 
     /**
-     * <p>In some cases, you must explicitly acknowledge that your stack template
+     * <p>In some cases, you must explicity acknowledge that your stack template
      * contains certain capabilities in order for AWS CloudFormation to create the
      * stack.</p> <ul> <li> <p> <code>CAPABILITY_IAM</code> and
      * <code>CAPABILITY_NAMED_IAM</code> </p> <p>Some stack templates might include
@@ -623,13 +632,13 @@ namespace Model
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/create-reusable-transform-function-snippets-and-add-to-your-template-with-aws-include-transform.html">AWS::Include</a>
      * and <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/transform-aws-serverless.html">AWS::Serverless</a>
-     * transforms, which are macros hosted by AWS CloudFormation.</p>  <p>This
+     * transforms, which are macros hosted by AWS CloudFormation.</p> <note> <p>This
      * capacity does not apply to creating change sets, and specifying it when creating
      * change sets has no effect.</p> <p>Also, change sets do not currently support
      * nested stacks. If you want to create a stack from a stack template that contains
      * macros <i>and</i> nested stacks, you must create or update the stack directly
      * from the template using the <a>CreateStack</a> or <a>UpdateStack</a> action, and
-     * specifying this capability.</p>  <p>For more information on macros, see
+     * specifying this capability.</p> </note> <p>For more information on macros, see
      * <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-macros.html">Using
      * AWS CloudFormation Macros to Perform Custom Processing on Templates</a>.</p>
@@ -638,7 +647,7 @@ namespace Model
     inline CreateChangeSetRequest& WithCapabilities(const Aws::Vector<Capability>& value) { SetCapabilities(value); return *this;}
 
     /**
-     * <p>In some cases, you must explicitly acknowledge that your stack template
+     * <p>In some cases, you must explicity acknowledge that your stack template
      * contains certain capabilities in order for AWS CloudFormation to create the
      * stack.</p> <ul> <li> <p> <code>CAPABILITY_IAM</code> and
      * <code>CAPABILITY_NAMED_IAM</code> </p> <p>Some stack templates might include
@@ -684,13 +693,13 @@ namespace Model
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/create-reusable-transform-function-snippets-and-add-to-your-template-with-aws-include-transform.html">AWS::Include</a>
      * and <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/transform-aws-serverless.html">AWS::Serverless</a>
-     * transforms, which are macros hosted by AWS CloudFormation.</p>  <p>This
+     * transforms, which are macros hosted by AWS CloudFormation.</p> <note> <p>This
      * capacity does not apply to creating change sets, and specifying it when creating
      * change sets has no effect.</p> <p>Also, change sets do not currently support
      * nested stacks. If you want to create a stack from a stack template that contains
      * macros <i>and</i> nested stacks, you must create or update the stack directly
      * from the template using the <a>CreateStack</a> or <a>UpdateStack</a> action, and
-     * specifying this capability.</p>  <p>For more information on macros, see
+     * specifying this capability.</p> </note> <p>For more information on macros, see
      * <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-macros.html">Using
      * AWS CloudFormation Macros to Perform Custom Processing on Templates</a>.</p>
@@ -699,7 +708,7 @@ namespace Model
     inline CreateChangeSetRequest& WithCapabilities(Aws::Vector<Capability>&& value) { SetCapabilities(std::move(value)); return *this;}
 
     /**
-     * <p>In some cases, you must explicitly acknowledge that your stack template
+     * <p>In some cases, you must explicity acknowledge that your stack template
      * contains certain capabilities in order for AWS CloudFormation to create the
      * stack.</p> <ul> <li> <p> <code>CAPABILITY_IAM</code> and
      * <code>CAPABILITY_NAMED_IAM</code> </p> <p>Some stack templates might include
@@ -745,13 +754,13 @@ namespace Model
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/create-reusable-transform-function-snippets-and-add-to-your-template-with-aws-include-transform.html">AWS::Include</a>
      * and <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/transform-aws-serverless.html">AWS::Serverless</a>
-     * transforms, which are macros hosted by AWS CloudFormation.</p>  <p>This
+     * transforms, which are macros hosted by AWS CloudFormation.</p> <note> <p>This
      * capacity does not apply to creating change sets, and specifying it when creating
      * change sets has no effect.</p> <p>Also, change sets do not currently support
      * nested stacks. If you want to create a stack from a stack template that contains
      * macros <i>and</i> nested stacks, you must create or update the stack directly
      * from the template using the <a>CreateStack</a> or <a>UpdateStack</a> action, and
-     * specifying this capability.</p>  <p>For more information on macros, see
+     * specifying this capability.</p> </note> <p>For more information on macros, see
      * <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-macros.html">Using
      * AWS CloudFormation Macros to Perform Custom Processing on Templates</a>.</p>
@@ -760,7 +769,7 @@ namespace Model
     inline CreateChangeSetRequest& AddCapabilities(const Capability& value) { m_capabilitiesHasBeenSet = true; m_capabilities.push_back(value); return *this; }
 
     /**
-     * <p>In some cases, you must explicitly acknowledge that your stack template
+     * <p>In some cases, you must explicity acknowledge that your stack template
      * contains certain capabilities in order for AWS CloudFormation to create the
      * stack.</p> <ul> <li> <p> <code>CAPABILITY_IAM</code> and
      * <code>CAPABILITY_NAMED_IAM</code> </p> <p>Some stack templates might include
@@ -806,13 +815,13 @@ namespace Model
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/create-reusable-transform-function-snippets-and-add-to-your-template-with-aws-include-transform.html">AWS::Include</a>
      * and <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/transform-aws-serverless.html">AWS::Serverless</a>
-     * transforms, which are macros hosted by AWS CloudFormation.</p>  <p>This
+     * transforms, which are macros hosted by AWS CloudFormation.</p> <note> <p>This
      * capacity does not apply to creating change sets, and specifying it when creating
      * change sets has no effect.</p> <p>Also, change sets do not currently support
      * nested stacks. If you want to create a stack from a stack template that contains
      * macros <i>and</i> nested stacks, you must create or update the stack directly
      * from the template using the <a>CreateStack</a> or <a>UpdateStack</a> action, and
-     * specifying this capability.</p>  <p>For more information on macros, see
+     * specifying this capability.</p> </note> <p>For more information on macros, see
      * <a
      * href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-macros.html">Using
      * AWS CloudFormation Macros to Perform Custom Processing on Templates</a>.</p>
@@ -1410,8 +1419,7 @@ namespace Model
     /**
      * <p>The type of change set operation. To create a change set for a new stack,
      * specify <code>CREATE</code>. To create a change set for an existing stack,
-     * specify <code>UPDATE</code>. To create a change set for an import operation,
-     * specify <code>IMPORT</code>.</p> <p>If you create a change set for a new stack,
+     * specify <code>UPDATE</code>.</p> <p>If you create a change set for a new stack,
      * AWS Cloudformation creates a stack with a unique stack ID, but no template or
      * resources. The stack will be in the <a
      * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-describing-stacks.html#d0e11995">
@@ -1425,8 +1433,7 @@ namespace Model
     /**
      * <p>The type of change set operation. To create a change set for a new stack,
      * specify <code>CREATE</code>. To create a change set for an existing stack,
-     * specify <code>UPDATE</code>. To create a change set for an import operation,
-     * specify <code>IMPORT</code>.</p> <p>If you create a change set for a new stack,
+     * specify <code>UPDATE</code>.</p> <p>If you create a change set for a new stack,
      * AWS Cloudformation creates a stack with a unique stack ID, but no template or
      * resources. The stack will be in the <a
      * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-describing-stacks.html#d0e11995">
@@ -1440,8 +1447,7 @@ namespace Model
     /**
      * <p>The type of change set operation. To create a change set for a new stack,
      * specify <code>CREATE</code>. To create a change set for an existing stack,
-     * specify <code>UPDATE</code>. To create a change set for an import operation,
-     * specify <code>IMPORT</code>.</p> <p>If you create a change set for a new stack,
+     * specify <code>UPDATE</code>.</p> <p>If you create a change set for a new stack,
      * AWS Cloudformation creates a stack with a unique stack ID, but no template or
      * resources. The stack will be in the <a
      * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-describing-stacks.html#d0e11995">
@@ -1455,8 +1461,7 @@ namespace Model
     /**
      * <p>The type of change set operation. To create a change set for a new stack,
      * specify <code>CREATE</code>. To create a change set for an existing stack,
-     * specify <code>UPDATE</code>. To create a change set for an import operation,
-     * specify <code>IMPORT</code>.</p> <p>If you create a change set for a new stack,
+     * specify <code>UPDATE</code>.</p> <p>If you create a change set for a new stack,
      * AWS Cloudformation creates a stack with a unique stack ID, but no template or
      * resources. The stack will be in the <a
      * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-describing-stacks.html#d0e11995">
@@ -1470,8 +1475,7 @@ namespace Model
     /**
      * <p>The type of change set operation. To create a change set for a new stack,
      * specify <code>CREATE</code>. To create a change set for an existing stack,
-     * specify <code>UPDATE</code>. To create a change set for an import operation,
-     * specify <code>IMPORT</code>.</p> <p>If you create a change set for a new stack,
+     * specify <code>UPDATE</code>.</p> <p>If you create a change set for a new stack,
      * AWS Cloudformation creates a stack with a unique stack ID, but no template or
      * resources. The stack will be in the <a
      * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-describing-stacks.html#d0e11995">
@@ -1485,8 +1489,7 @@ namespace Model
     /**
      * <p>The type of change set operation. To create a change set for a new stack,
      * specify <code>CREATE</code>. To create a change set for an existing stack,
-     * specify <code>UPDATE</code>. To create a change set for an import operation,
-     * specify <code>IMPORT</code>.</p> <p>If you create a change set for a new stack,
+     * specify <code>UPDATE</code>.</p> <p>If you create a change set for a new stack,
      * AWS Cloudformation creates a stack with a unique stack ID, but no template or
      * resources. The stack will be in the <a
      * href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-describing-stacks.html#d0e11995">
@@ -1497,47 +1500,6 @@ namespace Model
      */
     inline CreateChangeSetRequest& WithChangeSetType(ChangeSetType&& value) { SetChangeSetType(std::move(value)); return *this;}
 
-
-    /**
-     * <p>The resources to import into your stack.</p>
-     */
-    inline const Aws::Vector<ResourceToImport>& GetResourcesToImport() const{ return m_resourcesToImport; }
-
-    /**
-     * <p>The resources to import into your stack.</p>
-     */
-    inline bool ResourcesToImportHasBeenSet() const { return m_resourcesToImportHasBeenSet; }
-
-    /**
-     * <p>The resources to import into your stack.</p>
-     */
-    inline void SetResourcesToImport(const Aws::Vector<ResourceToImport>& value) { m_resourcesToImportHasBeenSet = true; m_resourcesToImport = value; }
-
-    /**
-     * <p>The resources to import into your stack.</p>
-     */
-    inline void SetResourcesToImport(Aws::Vector<ResourceToImport>&& value) { m_resourcesToImportHasBeenSet = true; m_resourcesToImport = std::move(value); }
-
-    /**
-     * <p>The resources to import into your stack.</p>
-     */
-    inline CreateChangeSetRequest& WithResourcesToImport(const Aws::Vector<ResourceToImport>& value) { SetResourcesToImport(value); return *this;}
-
-    /**
-     * <p>The resources to import into your stack.</p>
-     */
-    inline CreateChangeSetRequest& WithResourcesToImport(Aws::Vector<ResourceToImport>&& value) { SetResourcesToImport(std::move(value)); return *this;}
-
-    /**
-     * <p>The resources to import into your stack.</p>
-     */
-    inline CreateChangeSetRequest& AddResourcesToImport(const ResourceToImport& value) { m_resourcesToImportHasBeenSet = true; m_resourcesToImport.push_back(value); return *this; }
-
-    /**
-     * <p>The resources to import into your stack.</p>
-     */
-    inline CreateChangeSetRequest& AddResourcesToImport(ResourceToImport&& value) { m_resourcesToImportHasBeenSet = true; m_resourcesToImport.push_back(std::move(value)); return *this; }
-
   private:
 
     Aws::String m_stackName;
@@ -1584,9 +1546,6 @@ namespace Model
 
     ChangeSetType m_changeSetType;
     bool m_changeSetTypeHasBeenSet;
-
-    Aws::Vector<ResourceToImport> m_resourcesToImport;
-    bool m_resourcesToImportHasBeenSet;
   };
 
 } // namespace Model
