@@ -1,14 +1,23 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/cloudformation/CloudFormation_EXPORTS.h>
 #include <aws/cloudformation/CloudFormationRequest.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/cloudformation/model/DeploymentTargets.h>
 #include <aws/cloudformation/model/StackSetOperationPreferences.h>
 #include <aws/cloudformation/model/Parameter.h>
 #include <utility>
@@ -27,7 +36,7 @@ namespace Model
   {
   public:
     CreateStackInstancesRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -91,171 +100,110 @@ namespace Model
 
 
     /**
-     * <p>[<code>Self-managed</code> permissions] The names of one or more AWS accounts
-     * that you want to create stack instances in the specified Region(s) for.</p>
-     * <p>You can specify <code>Accounts</code> or <code>DeploymentTargets</code>, but
-     * not both.</p>
+     * <p>The names of one or more AWS accounts that you want to create stack instances
+     * in the specified region(s) for.</p>
      */
     inline const Aws::Vector<Aws::String>& GetAccounts() const{ return m_accounts; }
 
     /**
-     * <p>[<code>Self-managed</code> permissions] The names of one or more AWS accounts
-     * that you want to create stack instances in the specified Region(s) for.</p>
-     * <p>You can specify <code>Accounts</code> or <code>DeploymentTargets</code>, but
-     * not both.</p>
+     * <p>The names of one or more AWS accounts that you want to create stack instances
+     * in the specified region(s) for.</p>
      */
     inline bool AccountsHasBeenSet() const { return m_accountsHasBeenSet; }
 
     /**
-     * <p>[<code>Self-managed</code> permissions] The names of one or more AWS accounts
-     * that you want to create stack instances in the specified Region(s) for.</p>
-     * <p>You can specify <code>Accounts</code> or <code>DeploymentTargets</code>, but
-     * not both.</p>
+     * <p>The names of one or more AWS accounts that you want to create stack instances
+     * in the specified region(s) for.</p>
      */
     inline void SetAccounts(const Aws::Vector<Aws::String>& value) { m_accountsHasBeenSet = true; m_accounts = value; }
 
     /**
-     * <p>[<code>Self-managed</code> permissions] The names of one or more AWS accounts
-     * that you want to create stack instances in the specified Region(s) for.</p>
-     * <p>You can specify <code>Accounts</code> or <code>DeploymentTargets</code>, but
-     * not both.</p>
+     * <p>The names of one or more AWS accounts that you want to create stack instances
+     * in the specified region(s) for.</p>
      */
     inline void SetAccounts(Aws::Vector<Aws::String>&& value) { m_accountsHasBeenSet = true; m_accounts = std::move(value); }
 
     /**
-     * <p>[<code>Self-managed</code> permissions] The names of one or more AWS accounts
-     * that you want to create stack instances in the specified Region(s) for.</p>
-     * <p>You can specify <code>Accounts</code> or <code>DeploymentTargets</code>, but
-     * not both.</p>
+     * <p>The names of one or more AWS accounts that you want to create stack instances
+     * in the specified region(s) for.</p>
      */
     inline CreateStackInstancesRequest& WithAccounts(const Aws::Vector<Aws::String>& value) { SetAccounts(value); return *this;}
 
     /**
-     * <p>[<code>Self-managed</code> permissions] The names of one or more AWS accounts
-     * that you want to create stack instances in the specified Region(s) for.</p>
-     * <p>You can specify <code>Accounts</code> or <code>DeploymentTargets</code>, but
-     * not both.</p>
+     * <p>The names of one or more AWS accounts that you want to create stack instances
+     * in the specified region(s) for.</p>
      */
     inline CreateStackInstancesRequest& WithAccounts(Aws::Vector<Aws::String>&& value) { SetAccounts(std::move(value)); return *this;}
 
     /**
-     * <p>[<code>Self-managed</code> permissions] The names of one or more AWS accounts
-     * that you want to create stack instances in the specified Region(s) for.</p>
-     * <p>You can specify <code>Accounts</code> or <code>DeploymentTargets</code>, but
-     * not both.</p>
+     * <p>The names of one or more AWS accounts that you want to create stack instances
+     * in the specified region(s) for.</p>
      */
     inline CreateStackInstancesRequest& AddAccounts(const Aws::String& value) { m_accountsHasBeenSet = true; m_accounts.push_back(value); return *this; }
 
     /**
-     * <p>[<code>Self-managed</code> permissions] The names of one or more AWS accounts
-     * that you want to create stack instances in the specified Region(s) for.</p>
-     * <p>You can specify <code>Accounts</code> or <code>DeploymentTargets</code>, but
-     * not both.</p>
+     * <p>The names of one or more AWS accounts that you want to create stack instances
+     * in the specified region(s) for.</p>
      */
     inline CreateStackInstancesRequest& AddAccounts(Aws::String&& value) { m_accountsHasBeenSet = true; m_accounts.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>[<code>Self-managed</code> permissions] The names of one or more AWS accounts
-     * that you want to create stack instances in the specified Region(s) for.</p>
-     * <p>You can specify <code>Accounts</code> or <code>DeploymentTargets</code>, but
-     * not both.</p>
+     * <p>The names of one or more AWS accounts that you want to create stack instances
+     * in the specified region(s) for.</p>
      */
     inline CreateStackInstancesRequest& AddAccounts(const char* value) { m_accountsHasBeenSet = true; m_accounts.push_back(value); return *this; }
 
 
     /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts for
-     * which to create stack instances in the specified Regions.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
-     */
-    inline const DeploymentTargets& GetDeploymentTargets() const{ return m_deploymentTargets; }
-
-    /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts for
-     * which to create stack instances in the specified Regions.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
-     */
-    inline bool DeploymentTargetsHasBeenSet() const { return m_deploymentTargetsHasBeenSet; }
-
-    /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts for
-     * which to create stack instances in the specified Regions.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
-     */
-    inline void SetDeploymentTargets(const DeploymentTargets& value) { m_deploymentTargetsHasBeenSet = true; m_deploymentTargets = value; }
-
-    /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts for
-     * which to create stack instances in the specified Regions.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
-     */
-    inline void SetDeploymentTargets(DeploymentTargets&& value) { m_deploymentTargetsHasBeenSet = true; m_deploymentTargets = std::move(value); }
-
-    /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts for
-     * which to create stack instances in the specified Regions.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
-     */
-    inline CreateStackInstancesRequest& WithDeploymentTargets(const DeploymentTargets& value) { SetDeploymentTargets(value); return *this;}
-
-    /**
-     * <p>[<code>Service-managed</code> permissions] The AWS Organizations accounts for
-     * which to create stack instances in the specified Regions.</p> <p>You can specify
-     * <code>Accounts</code> or <code>DeploymentTargets</code>, but not both.</p>
-     */
-    inline CreateStackInstancesRequest& WithDeploymentTargets(DeploymentTargets&& value) { SetDeploymentTargets(std::move(value)); return *this;}
-
-
-    /**
-     * <p>The names of one or more Regions where you want to create stack instances
+     * <p>The names of one or more regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline const Aws::Vector<Aws::String>& GetRegions() const{ return m_regions; }
 
     /**
-     * <p>The names of one or more Regions where you want to create stack instances
+     * <p>The names of one or more regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline bool RegionsHasBeenSet() const { return m_regionsHasBeenSet; }
 
     /**
-     * <p>The names of one or more Regions where you want to create stack instances
+     * <p>The names of one or more regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline void SetRegions(const Aws::Vector<Aws::String>& value) { m_regionsHasBeenSet = true; m_regions = value; }
 
     /**
-     * <p>The names of one or more Regions where you want to create stack instances
+     * <p>The names of one or more regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline void SetRegions(Aws::Vector<Aws::String>&& value) { m_regionsHasBeenSet = true; m_regions = std::move(value); }
 
     /**
-     * <p>The names of one or more Regions where you want to create stack instances
+     * <p>The names of one or more regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline CreateStackInstancesRequest& WithRegions(const Aws::Vector<Aws::String>& value) { SetRegions(value); return *this;}
 
     /**
-     * <p>The names of one or more Regions where you want to create stack instances
+     * <p>The names of one or more regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline CreateStackInstancesRequest& WithRegions(Aws::Vector<Aws::String>&& value) { SetRegions(std::move(value)); return *this;}
 
     /**
-     * <p>The names of one or more Regions where you want to create stack instances
+     * <p>The names of one or more regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline CreateStackInstancesRequest& AddRegions(const Aws::String& value) { m_regionsHasBeenSet = true; m_regions.push_back(value); return *this; }
 
     /**
-     * <p>The names of one or more Regions where you want to create stack instances
+     * <p>The names of one or more regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline CreateStackInstancesRequest& AddRegions(Aws::String&& value) { m_regionsHasBeenSet = true; m_regions.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>The names of one or more Regions where you want to create stack instances
+     * <p>The names of one or more regions where you want to create stack instances
      * using the specified AWS account(s). </p>
      */
     inline CreateStackInstancesRequest& AddRegions(const char* value) { m_regionsHasBeenSet = true; m_regions.push_back(value); return *this; }
@@ -264,7 +212,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and Regions. When specifying
+     * to all stack instances in the specified accounts and regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -288,7 +236,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and Regions. When specifying
+     * to all stack instances in the specified accounts and regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -312,7 +260,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and Regions. When specifying
+     * to all stack instances in the specified accounts and regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -336,7 +284,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and Regions. When specifying
+     * to all stack instances in the specified accounts and regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -360,7 +308,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and Regions. When specifying
+     * to all stack instances in the specified accounts and regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -384,7 +332,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and Regions. When specifying
+     * to all stack instances in the specified accounts and regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -408,7 +356,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and Regions. When specifying
+     * to all stack instances in the specified accounts and regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -432,7 +380,7 @@ namespace Model
     /**
      * <p>A list of stack set parameters whose values you want to override in the
      * selected stack instances.</p> <p>Any overridden parameter values will be applied
-     * to all stack instances in the specified accounts and Regions. When specifying
+     * to all stack instances in the specified accounts and regions. When specifying
      * parameters and their values, be aware of how AWS CloudFormation sets parameter
      * values during stack instance operations:</p> <ul> <li> <p>To override the
      * current value for a parameter, include the parameter and specify its value.</p>
@@ -589,9 +537,6 @@ namespace Model
     Aws::Vector<Aws::String> m_accounts;
     bool m_accountsHasBeenSet;
 
-    DeploymentTargets m_deploymentTargets;
-    bool m_deploymentTargetsHasBeenSet;
-
     Aws::Vector<Aws::String> m_regions;
     bool m_regionsHasBeenSet;
 
