@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/cloudformation/model/ChangeSetSummary.h>
 #include <aws/core/utils/xml/XmlSerializer.h>
@@ -31,11 +41,7 @@ ChangeSetSummary::ChangeSetSummary() :
     m_statusHasBeenSet(false),
     m_statusReasonHasBeenSet(false),
     m_creationTimeHasBeenSet(false),
-    m_descriptionHasBeenSet(false),
-    m_includeNestedStacks(false),
-    m_includeNestedStacksHasBeenSet(false),
-    m_parentChangeSetIdHasBeenSet(false),
-    m_rootChangeSetIdHasBeenSet(false)
+    m_descriptionHasBeenSet(false)
 {
 }
 
@@ -50,11 +56,7 @@ ChangeSetSummary::ChangeSetSummary(const XmlNode& xmlNode) :
     m_statusHasBeenSet(false),
     m_statusReasonHasBeenSet(false),
     m_creationTimeHasBeenSet(false),
-    m_descriptionHasBeenSet(false),
-    m_includeNestedStacks(false),
-    m_includeNestedStacksHasBeenSet(false),
-    m_parentChangeSetIdHasBeenSet(false),
-    m_rootChangeSetIdHasBeenSet(false)
+    m_descriptionHasBeenSet(false)
 {
   *this = xmlNode;
 }
@@ -68,75 +70,57 @@ ChangeSetSummary& ChangeSetSummary::operator =(const XmlNode& xmlNode)
     XmlNode stackIdNode = resultNode.FirstChild("StackId");
     if(!stackIdNode.IsNull())
     {
-      m_stackId = Aws::Utils::Xml::DecodeEscapedXmlText(stackIdNode.GetText());
+      m_stackId = StringUtils::Trim(stackIdNode.GetText().c_str());
       m_stackIdHasBeenSet = true;
     }
     XmlNode stackNameNode = resultNode.FirstChild("StackName");
     if(!stackNameNode.IsNull())
     {
-      m_stackName = Aws::Utils::Xml::DecodeEscapedXmlText(stackNameNode.GetText());
+      m_stackName = StringUtils::Trim(stackNameNode.GetText().c_str());
       m_stackNameHasBeenSet = true;
     }
     XmlNode changeSetIdNode = resultNode.FirstChild("ChangeSetId");
     if(!changeSetIdNode.IsNull())
     {
-      m_changeSetId = Aws::Utils::Xml::DecodeEscapedXmlText(changeSetIdNode.GetText());
+      m_changeSetId = StringUtils::Trim(changeSetIdNode.GetText().c_str());
       m_changeSetIdHasBeenSet = true;
     }
     XmlNode changeSetNameNode = resultNode.FirstChild("ChangeSetName");
     if(!changeSetNameNode.IsNull())
     {
-      m_changeSetName = Aws::Utils::Xml::DecodeEscapedXmlText(changeSetNameNode.GetText());
+      m_changeSetName = StringUtils::Trim(changeSetNameNode.GetText().c_str());
       m_changeSetNameHasBeenSet = true;
     }
     XmlNode executionStatusNode = resultNode.FirstChild("ExecutionStatus");
     if(!executionStatusNode.IsNull())
     {
-      m_executionStatus = ExecutionStatusMapper::GetExecutionStatusForName(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(executionStatusNode.GetText()).c_str()).c_str());
+      m_executionStatus = ExecutionStatusMapper::GetExecutionStatusForName(StringUtils::Trim(executionStatusNode.GetText().c_str()).c_str());
       m_executionStatusHasBeenSet = true;
     }
     XmlNode statusNode = resultNode.FirstChild("Status");
     if(!statusNode.IsNull())
     {
-      m_status = ChangeSetStatusMapper::GetChangeSetStatusForName(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(statusNode.GetText()).c_str()).c_str());
+      m_status = ChangeSetStatusMapper::GetChangeSetStatusForName(StringUtils::Trim(statusNode.GetText().c_str()).c_str());
       m_statusHasBeenSet = true;
     }
     XmlNode statusReasonNode = resultNode.FirstChild("StatusReason");
     if(!statusReasonNode.IsNull())
     {
-      m_statusReason = Aws::Utils::Xml::DecodeEscapedXmlText(statusReasonNode.GetText());
+      m_statusReason = StringUtils::Trim(statusReasonNode.GetText().c_str());
       m_statusReasonHasBeenSet = true;
     }
     XmlNode creationTimeNode = resultNode.FirstChild("CreationTime");
     if(!creationTimeNode.IsNull())
     {
-      m_creationTime = DateTime(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(creationTimeNode.GetText()).c_str()).c_str(), DateFormat::ISO_8601);
+      m_creationTime = DateTime(StringUtils::Trim(creationTimeNode.GetText().c_str()).c_str(), DateFormat::ISO_8601);
       m_creationTimeHasBeenSet = true;
     }
     XmlNode descriptionNode = resultNode.FirstChild("Description");
     if(!descriptionNode.IsNull())
     {
-      m_description = Aws::Utils::Xml::DecodeEscapedXmlText(descriptionNode.GetText());
+      m_description = StringUtils::Trim(descriptionNode.GetText().c_str());
       m_descriptionHasBeenSet = true;
     }
-    XmlNode includeNestedStacksNode = resultNode.FirstChild("IncludeNestedStacks");
-    if(!includeNestedStacksNode.IsNull())
-    {
-      m_includeNestedStacks = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(includeNestedStacksNode.GetText()).c_str()).c_str());
-      m_includeNestedStacksHasBeenSet = true;
-    }
-    XmlNode parentChangeSetIdNode = resultNode.FirstChild("ParentChangeSetId");
-    if(!parentChangeSetIdNode.IsNull())
-    {
-      m_parentChangeSetId = Aws::Utils::Xml::DecodeEscapedXmlText(parentChangeSetIdNode.GetText());
-      m_parentChangeSetIdHasBeenSet = true;
-    }
-    XmlNode rootChangeSetIdNode = resultNode.FirstChild("RootChangeSetId");
-    if(!rootChangeSetIdNode.IsNull())
-    {
-      m_rootChangeSetId = Aws::Utils::Xml::DecodeEscapedXmlText(rootChangeSetIdNode.GetText());
-      m_rootChangeSetIdHasBeenSet = true;
-    }
   }
 
   return *this;
@@ -189,21 +173,6 @@ void ChangeSetSummary::OutputToStream(Aws::OStream& oStream, const char* locatio
       oStream << location << index << locationValue << ".Description=" << StringUtils::URLEncode(m_description.c_str()) << "&";
   }
 
-  if(m_includeNestedStacksHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".IncludeNestedStacks=" << std::boolalpha << m_includeNestedStacks << "&";
-  }
-
-  if(m_parentChangeSetIdHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".ParentChangeSetId=" << StringUtils::URLEncode(m_parentChangeSetId.c_str()) << "&";
-  }
-
-  if(m_rootChangeSetIdHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".RootChangeSetId=" << StringUtils::URLEncode(m_rootChangeSetId.c_str()) << "&";
-  }
-
 }
 
 void ChangeSetSummary::OutputToStream(Aws::OStream& oStream, const char* location) const
@@ -244,18 +213,6 @@ void ChangeSetSummary::OutputToStream(Aws::OStream& oStream, const char* locatio
   {
       oStream << location << ".Description=" << StringUtils::URLEncode(m_description.c_str()) << "&";
   }
-  if(m_includeNestedStacksHasBeenSet)
-  {
-      oStream << location << ".IncludeNestedStacks=" << std::boolalpha << m_includeNestedStacks << "&";
-  }
-  if(m_parentChangeSetIdHasBeenSet)
-  {
-      oStream << location << ".ParentChangeSetId=" << StringUtils::URLEncode(m_parentChangeSetId.c_str()) << "&";
-  }
-  if(m_rootChangeSetIdHasBeenSet)
-  {
-      oStream << location << ".RootChangeSetId=" << StringUtils::URLEncode(m_rootChangeSetId.c_str()) << "&";
-  }
 }
 
 } // namespace Model
