@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/cloudformation/model/DescribeStackInstanceRequest.h>
 #include <aws/core/utils/StringUtils.h>
@@ -13,9 +23,7 @@ using namespace Aws::Utils;
 DescribeStackInstanceRequest::DescribeStackInstanceRequest() : 
     m_stackSetNameHasBeenSet(false),
     m_stackInstanceAccountHasBeenSet(false),
-    m_stackInstanceRegionHasBeenSet(false),
-    m_callAs(CallAs::NOT_SET),
-    m_callAsHasBeenSet(false)
+    m_stackInstanceRegionHasBeenSet(false)
 {
 }
 
@@ -38,11 +46,6 @@ Aws::String DescribeStackInstanceRequest::SerializePayload() const
     ss << "StackInstanceRegion=" << StringUtils::URLEncode(m_stackInstanceRegion.c_str()) << "&";
   }
 
-  if(m_callAsHasBeenSet)
-  {
-    ss << "CallAs=" << CallAsMapper::GetNameForCallAs(m_callAs) << "&";
-  }
-
   ss << "Version=2010-05-15";
   return ss.str();
 }
