@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/cloudformation/model/Stack.h>
 #include <aws/core/utils/xml/XmlSerializer.h>
@@ -90,25 +100,25 @@ Stack& Stack::operator =(const XmlNode& xmlNode)
     XmlNode stackIdNode = resultNode.FirstChild("StackId");
     if(!stackIdNode.IsNull())
     {
-      m_stackId = Aws::Utils::Xml::DecodeEscapedXmlText(stackIdNode.GetText());
+      m_stackId = StringUtils::Trim(stackIdNode.GetText().c_str());
       m_stackIdHasBeenSet = true;
     }
     XmlNode stackNameNode = resultNode.FirstChild("StackName");
     if(!stackNameNode.IsNull())
     {
-      m_stackName = Aws::Utils::Xml::DecodeEscapedXmlText(stackNameNode.GetText());
+      m_stackName = StringUtils::Trim(stackNameNode.GetText().c_str());
       m_stackNameHasBeenSet = true;
     }
     XmlNode changeSetIdNode = resultNode.FirstChild("ChangeSetId");
     if(!changeSetIdNode.IsNull())
     {
-      m_changeSetId = Aws::Utils::Xml::DecodeEscapedXmlText(changeSetIdNode.GetText());
+      m_changeSetId = StringUtils::Trim(changeSetIdNode.GetText().c_str());
       m_changeSetIdHasBeenSet = true;
     }
     XmlNode descriptionNode = resultNode.FirstChild("Description");
     if(!descriptionNode.IsNull())
     {
-      m_description = Aws::Utils::Xml::DecodeEscapedXmlText(descriptionNode.GetText());
+      m_description = StringUtils::Trim(descriptionNode.GetText().c_str());
       m_descriptionHasBeenSet = true;
     }
     XmlNode parametersNode = resultNode.FirstChild("Parameters");
@@ -126,19 +136,19 @@ Stack& Stack::operator =(const XmlNode& xmlNode)
     XmlNode creationTimeNode = resultNode.FirstChild("CreationTime");
     if(!creationTimeNode.IsNull())
     {
-      m_creationTime = DateTime(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(creationTimeNode.GetText()).c_str()).c_str(), DateFormat::ISO_8601);
+      m_creationTime = DateTime(StringUtils::Trim(creationTimeNode.GetText().c_str()).c_str(), DateFormat::ISO_8601);
       m_creationTimeHasBeenSet = true;
     }
     XmlNode deletionTimeNode = resultNode.FirstChild("DeletionTime");
     if(!deletionTimeNode.IsNull())
     {
-      m_deletionTime = DateTime(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(deletionTimeNode.GetText()).c_str()).c_str(), DateFormat::ISO_8601);
+      m_deletionTime = DateTime(StringUtils::Trim(deletionTimeNode.GetText().c_str()).c_str(), DateFormat::ISO_8601);
       m_deletionTimeHasBeenSet = true;
     }
     XmlNode lastUpdatedTimeNode = resultNode.FirstChild("LastUpdatedTime");
     if(!lastUpdatedTimeNode.IsNull())
     {
-      m_lastUpdatedTime = DateTime(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(lastUpdatedTimeNode.GetText()).c_str()).c_str(), DateFormat::ISO_8601);
+      m_lastUpdatedTime = DateTime(StringUtils::Trim(lastUpdatedTimeNode.GetText().c_str()).c_str(), DateFormat::ISO_8601);
       m_lastUpdatedTimeHasBeenSet = true;
     }
     XmlNode rollbackConfigurationNode = resultNode.FirstChild("RollbackConfiguration");
@@ -150,19 +160,19 @@ Stack& Stack::operator =(const XmlNode& xmlNode)
     XmlNode stackStatusNode = resultNode.FirstChild("StackStatus");
     if(!stackStatusNode.IsNull())
     {
-      m_stackStatus = StackStatusMapper::GetStackStatusForName(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(stackStatusNode.GetText()).c_str()).c_str());
+      m_stackStatus = StackStatusMapper::GetStackStatusForName(StringUtils::Trim(stackStatusNode.GetText().c_str()).c_str());
       m_stackStatusHasBeenSet = true;
     }
     XmlNode stackStatusReasonNode = resultNode.FirstChild("StackStatusReason");
     if(!stackStatusReasonNode.IsNull())
     {
-      m_stackStatusReason = Aws::Utils::Xml::DecodeEscapedXmlText(stackStatusReasonNode.GetText());
+      m_stackStatusReason = StringUtils::Trim(stackStatusReasonNode.GetText().c_str());
       m_stackStatusReasonHasBeenSet = true;
     }
     XmlNode disableRollbackNode = resultNode.FirstChild("DisableRollback");
     if(!disableRollbackNode.IsNull())
     {
-      m_disableRollback = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(disableRollbackNode.GetText()).c_str()).c_str());
+      m_disableRollback = StringUtils::ConvertToBool(StringUtils::Trim(disableRollbackNode.GetText().c_str()).c_str());
       m_disableRollbackHasBeenSet = true;
     }
     XmlNode notificationARNsNode = resultNode.FirstChild("NotificationARNs");
@@ -171,7 +181,7 @@ Stack& Stack::operator =(const XmlNode& xmlNode)
       XmlNode notificationARNsMember = notificationARNsNode.FirstChild("member");
       while(!notificationARNsMember.IsNull())
       {
-        m_notificationARNs.push_back(notificationARNsMember.GetText());
+        m_notificationARNs.push_back(StringUtils::Trim(notificationARNsMember.GetText().c_str()));
         notificationARNsMember = notificationARNsMember.NextNode("member");
       }
 
@@ -180,7 +190,7 @@ Stack& Stack::operator =(const XmlNode& xmlNode)
     XmlNode timeoutInMinutesNode = resultNode.FirstChild("TimeoutInMinutes");
     if(!timeoutInMinutesNode.IsNull())
     {
-      m_timeoutInMinutes = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(timeoutInMinutesNode.GetText()).c_str()).c_str());
+      m_timeoutInMinutes = StringUtils::ConvertToInt32(StringUtils::Trim(timeoutInMinutesNode.GetText().c_str()).c_str());
       m_timeoutInMinutesHasBeenSet = true;
     }
     XmlNode capabilitiesNode = resultNode.FirstChild("Capabilities");
@@ -210,7 +220,7 @@ Stack& Stack::operator =(const XmlNode& xmlNode)
     XmlNode roleARNNode = resultNode.FirstChild("RoleARN");
     if(!roleARNNode.IsNull())
     {
-      m_roleARN = Aws::Utils::Xml::DecodeEscapedXmlText(roleARNNode.GetText());
+      m_roleARN = StringUtils::Trim(roleARNNode.GetText().c_str());
       m_roleARNHasBeenSet = true;
     }
     XmlNode tagsNode = resultNode.FirstChild("Tags");
@@ -228,19 +238,19 @@ Stack& Stack::operator =(const XmlNode& xmlNode)
     XmlNode enableTerminationProtectionNode = resultNode.FirstChild("EnableTerminationProtection");
     if(!enableTerminationProtectionNode.IsNull())
     {
-      m_enableTerminationProtection = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(enableTerminationProtectionNode.GetText()).c_str()).c_str());
+      m_enableTerminationProtection = StringUtils::ConvertToBool(StringUtils::Trim(enableTerminationProtectionNode.GetText().c_str()).c_str());
       m_enableTerminationProtectionHasBeenSet = true;
     }
     XmlNode parentIdNode = resultNode.FirstChild("ParentId");
     if(!parentIdNode.IsNull())
     {
-      m_parentId = Aws::Utils::Xml::DecodeEscapedXmlText(parentIdNode.GetText());
+      m_parentId = StringUtils::Trim(parentIdNode.GetText().c_str());
       m_parentIdHasBeenSet = true;
     }
     XmlNode rootIdNode = resultNode.FirstChild("RootId");
     if(!rootIdNode.IsNull())
     {
-      m_rootId = Aws::Utils::Xml::DecodeEscapedXmlText(rootIdNode.GetText());
+      m_rootId = StringUtils::Trim(rootIdNode.GetText().c_str());
       m_rootIdHasBeenSet = true;
     }
     XmlNode driftInformationNode = resultNode.FirstChild("DriftInformation");
