@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/codecommit/CodeCommit_EXPORTS.h>
@@ -26,7 +36,7 @@ namespace Model
   {
   public:
     CreateCommitRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -39,181 +49,181 @@ namespace Model
 
 
     /**
-     * <p>The name of the repository where you create the commit.</p>
+     * <p>The name of the repository where you will create the commit.</p>
      */
     inline const Aws::String& GetRepositoryName() const{ return m_repositoryName; }
 
     /**
-     * <p>The name of the repository where you create the commit.</p>
+     * <p>The name of the repository where you will create the commit.</p>
      */
     inline bool RepositoryNameHasBeenSet() const { return m_repositoryNameHasBeenSet; }
 
     /**
-     * <p>The name of the repository where you create the commit.</p>
+     * <p>The name of the repository where you will create the commit.</p>
      */
     inline void SetRepositoryName(const Aws::String& value) { m_repositoryNameHasBeenSet = true; m_repositoryName = value; }
 
     /**
-     * <p>The name of the repository where you create the commit.</p>
+     * <p>The name of the repository where you will create the commit.</p>
      */
     inline void SetRepositoryName(Aws::String&& value) { m_repositoryNameHasBeenSet = true; m_repositoryName = std::move(value); }
 
     /**
-     * <p>The name of the repository where you create the commit.</p>
+     * <p>The name of the repository where you will create the commit.</p>
      */
     inline void SetRepositoryName(const char* value) { m_repositoryNameHasBeenSet = true; m_repositoryName.assign(value); }
 
     /**
-     * <p>The name of the repository where you create the commit.</p>
+     * <p>The name of the repository where you will create the commit.</p>
      */
     inline CreateCommitRequest& WithRepositoryName(const Aws::String& value) { SetRepositoryName(value); return *this;}
 
     /**
-     * <p>The name of the repository where you create the commit.</p>
+     * <p>The name of the repository where you will create the commit.</p>
      */
     inline CreateCommitRequest& WithRepositoryName(Aws::String&& value) { SetRepositoryName(std::move(value)); return *this;}
 
     /**
-     * <p>The name of the repository where you create the commit.</p>
+     * <p>The name of the repository where you will create the commit.</p>
      */
     inline CreateCommitRequest& WithRepositoryName(const char* value) { SetRepositoryName(value); return *this;}
 
 
     /**
-     * <p>The name of the branch where you create the commit.</p>
+     * <p>The name of the branch where you will create the commit.</p>
      */
     inline const Aws::String& GetBranchName() const{ return m_branchName; }
 
     /**
-     * <p>The name of the branch where you create the commit.</p>
+     * <p>The name of the branch where you will create the commit.</p>
      */
     inline bool BranchNameHasBeenSet() const { return m_branchNameHasBeenSet; }
 
     /**
-     * <p>The name of the branch where you create the commit.</p>
+     * <p>The name of the branch where you will create the commit.</p>
      */
     inline void SetBranchName(const Aws::String& value) { m_branchNameHasBeenSet = true; m_branchName = value; }
 
     /**
-     * <p>The name of the branch where you create the commit.</p>
+     * <p>The name of the branch where you will create the commit.</p>
      */
     inline void SetBranchName(Aws::String&& value) { m_branchNameHasBeenSet = true; m_branchName = std::move(value); }
 
     /**
-     * <p>The name of the branch where you create the commit.</p>
+     * <p>The name of the branch where you will create the commit.</p>
      */
     inline void SetBranchName(const char* value) { m_branchNameHasBeenSet = true; m_branchName.assign(value); }
 
     /**
-     * <p>The name of the branch where you create the commit.</p>
+     * <p>The name of the branch where you will create the commit.</p>
      */
     inline CreateCommitRequest& WithBranchName(const Aws::String& value) { SetBranchName(value); return *this;}
 
     /**
-     * <p>The name of the branch where you create the commit.</p>
+     * <p>The name of the branch where you will create the commit.</p>
      */
     inline CreateCommitRequest& WithBranchName(Aws::String&& value) { SetBranchName(std::move(value)); return *this;}
 
     /**
-     * <p>The name of the branch where you create the commit.</p>
+     * <p>The name of the branch where you will create the commit.</p>
      */
     inline CreateCommitRequest& WithBranchName(const char* value) { SetBranchName(value); return *this;}
 
 
     /**
-     * <p>The ID of the commit that is the parent of the commit you create. Not
-     * required if this is an empty repository.</p>
+     * <p>The ID of the commit that is the parent of the commit you will create. If
+     * this is an empty repository, this is not required.</p>
      */
     inline const Aws::String& GetParentCommitId() const{ return m_parentCommitId; }
 
     /**
-     * <p>The ID of the commit that is the parent of the commit you create. Not
-     * required if this is an empty repository.</p>
+     * <p>The ID of the commit that is the parent of the commit you will create. If
+     * this is an empty repository, this is not required.</p>
      */
     inline bool ParentCommitIdHasBeenSet() const { return m_parentCommitIdHasBeenSet; }
 
     /**
-     * <p>The ID of the commit that is the parent of the commit you create. Not
-     * required if this is an empty repository.</p>
+     * <p>The ID of the commit that is the parent of the commit you will create. If
+     * this is an empty repository, this is not required.</p>
      */
     inline void SetParentCommitId(const Aws::String& value) { m_parentCommitIdHasBeenSet = true; m_parentCommitId = value; }
 
     /**
-     * <p>The ID of the commit that is the parent of the commit you create. Not
-     * required if this is an empty repository.</p>
+     * <p>The ID of the commit that is the parent of the commit you will create. If
+     * this is an empty repository, this is not required.</p>
      */
     inline void SetParentCommitId(Aws::String&& value) { m_parentCommitIdHasBeenSet = true; m_parentCommitId = std::move(value); }
 
     /**
-     * <p>The ID of the commit that is the parent of the commit you create. Not
-     * required if this is an empty repository.</p>
+     * <p>The ID of the commit that is the parent of the commit you will create. If
+     * this is an empty repository, this is not required.</p>
      */
     inline void SetParentCommitId(const char* value) { m_parentCommitIdHasBeenSet = true; m_parentCommitId.assign(value); }
 
     /**
-     * <p>The ID of the commit that is the parent of the commit you create. Not
-     * required if this is an empty repository.</p>
+     * <p>The ID of the commit that is the parent of the commit you will create. If
+     * this is an empty repository, this is not required.</p>
      */
     inline CreateCommitRequest& WithParentCommitId(const Aws::String& value) { SetParentCommitId(value); return *this;}
 
     /**
-     * <p>The ID of the commit that is the parent of the commit you create. Not
-     * required if this is an empty repository.</p>
+     * <p>The ID of the commit that is the parent of the commit you will create. If
+     * this is an empty repository, this is not required.</p>
      */
     inline CreateCommitRequest& WithParentCommitId(Aws::String&& value) { SetParentCommitId(std::move(value)); return *this;}
 
     /**
-     * <p>The ID of the commit that is the parent of the commit you create. Not
-     * required if this is an empty repository.</p>
+     * <p>The ID of the commit that is the parent of the commit you will create. If
+     * this is an empty repository, this is not required.</p>
      */
     inline CreateCommitRequest& WithParentCommitId(const char* value) { SetParentCommitId(value); return *this;}
 
 
     /**
-     * <p>The name of the author who created the commit. This information is used as
-     * both the author and committer for the commit.</p>
+     * <p>The name of the author who created the commit. This information will be used
+     * as both the author and committer for the commit.</p>
      */
     inline const Aws::String& GetAuthorName() const{ return m_authorName; }
 
     /**
-     * <p>The name of the author who created the commit. This information is used as
-     * both the author and committer for the commit.</p>
+     * <p>The name of the author who created the commit. This information will be used
+     * as both the author and committer for the commit.</p>
      */
     inline bool AuthorNameHasBeenSet() const { return m_authorNameHasBeenSet; }
 
     /**
-     * <p>The name of the author who created the commit. This information is used as
-     * both the author and committer for the commit.</p>
+     * <p>The name of the author who created the commit. This information will be used
+     * as both the author and committer for the commit.</p>
      */
     inline void SetAuthorName(const Aws::String& value) { m_authorNameHasBeenSet = true; m_authorName = value; }
 
     /**
-     * <p>The name of the author who created the commit. This information is used as
-     * both the author and committer for the commit.</p>
+     * <p>The name of the author who created the commit. This information will be used
+     * as both the author and committer for the commit.</p>
      */
     inline void SetAuthorName(Aws::String&& value) { m_authorNameHasBeenSet = true; m_authorName = std::move(value); }
 
     /**
-     * <p>The name of the author who created the commit. This information is used as
-     * both the author and committer for the commit.</p>
+     * <p>The name of the author who created the commit. This information will be used
+     * as both the author and committer for the commit.</p>
      */
     inline void SetAuthorName(const char* value) { m_authorNameHasBeenSet = true; m_authorName.assign(value); }
 
     /**
-     * <p>The name of the author who created the commit. This information is used as
-     * both the author and committer for the commit.</p>
+     * <p>The name of the author who created the commit. This information will be used
+     * as both the author and committer for the commit.</p>
      */
     inline CreateCommitRequest& WithAuthorName(const Aws::String& value) { SetAuthorName(value); return *this;}
 
     /**
-     * <p>The name of the author who created the commit. This information is used as
-     * both the author and committer for the commit.</p>
+     * <p>The name of the author who created the commit. This information will be used
+     * as both the author and committer for the commit.</p>
      */
     inline CreateCommitRequest& WithAuthorName(Aws::String&& value) { SetAuthorName(std::move(value)); return *this;}
 
     /**
-     * <p>The name of the author who created the commit. This information is used as
-     * both the author and committer for the commit.</p>
+     * <p>The name of the author who created the commit. This information will be used
+     * as both the author and committer for the commit.</p>
      */
     inline CreateCommitRequest& WithAuthorName(const char* value) { SetAuthorName(value); return *this;}
 
@@ -260,79 +270,87 @@ namespace Model
 
 
     /**
-     * <p>The commit message you want to include in the commit. Commit messages are
-     * limited to 256 KB. If no message is specified, a default message is used.</p>
+     * <p>The commit message you want to include as part of creating the commit. Commit
+     * messages are limited to 256 KB. If no message is specified, a default message
+     * will be used.</p>
      */
     inline const Aws::String& GetCommitMessage() const{ return m_commitMessage; }
 
     /**
-     * <p>The commit message you want to include in the commit. Commit messages are
-     * limited to 256 KB. If no message is specified, a default message is used.</p>
+     * <p>The commit message you want to include as part of creating the commit. Commit
+     * messages are limited to 256 KB. If no message is specified, a default message
+     * will be used.</p>
      */
     inline bool CommitMessageHasBeenSet() const { return m_commitMessageHasBeenSet; }
 
     /**
-     * <p>The commit message you want to include in the commit. Commit messages are
-     * limited to 256 KB. If no message is specified, a default message is used.</p>
+     * <p>The commit message you want to include as part of creating the commit. Commit
+     * messages are limited to 256 KB. If no message is specified, a default message
+     * will be used.</p>
      */
     inline void SetCommitMessage(const Aws::String& value) { m_commitMessageHasBeenSet = true; m_commitMessage = value; }
 
     /**
-     * <p>The commit message you want to include in the commit. Commit messages are
-     * limited to 256 KB. If no message is specified, a default message is used.</p>
+     * <p>The commit message you want to include as part of creating the commit. Commit
+     * messages are limited to 256 KB. If no message is specified, a default message
+     * will be used.</p>
      */
     inline void SetCommitMessage(Aws::String&& value) { m_commitMessageHasBeenSet = true; m_commitMessage = std::move(value); }
 
     /**
-     * <p>The commit message you want to include in the commit. Commit messages are
-     * limited to 256 KB. If no message is specified, a default message is used.</p>
+     * <p>The commit message you want to include as part of creating the commit. Commit
+     * messages are limited to 256 KB. If no message is specified, a default message
+     * will be used.</p>
      */
     inline void SetCommitMessage(const char* value) { m_commitMessageHasBeenSet = true; m_commitMessage.assign(value); }
 
     /**
-     * <p>The commit message you want to include in the commit. Commit messages are
-     * limited to 256 KB. If no message is specified, a default message is used.</p>
+     * <p>The commit message you want to include as part of creating the commit. Commit
+     * messages are limited to 256 KB. If no message is specified, a default message
+     * will be used.</p>
      */
     inline CreateCommitRequest& WithCommitMessage(const Aws::String& value) { SetCommitMessage(value); return *this;}
 
     /**
-     * <p>The commit message you want to include in the commit. Commit messages are
-     * limited to 256 KB. If no message is specified, a default message is used.</p>
+     * <p>The commit message you want to include as part of creating the commit. Commit
+     * messages are limited to 256 KB. If no message is specified, a default message
+     * will be used.</p>
      */
     inline CreateCommitRequest& WithCommitMessage(Aws::String&& value) { SetCommitMessage(std::move(value)); return *this;}
 
     /**
-     * <p>The commit message you want to include in the commit. Commit messages are
-     * limited to 256 KB. If no message is specified, a default message is used.</p>
+     * <p>The commit message you want to include as part of creating the commit. Commit
+     * messages are limited to 256 KB. If no message is specified, a default message
+     * will be used.</p>
      */
     inline CreateCommitRequest& WithCommitMessage(const char* value) { SetCommitMessage(value); return *this;}
 
 
     /**
      * <p>If the commit contains deletions, whether to keep a folder or folder
-     * structure if the changes leave the folders empty. If true, a ..gitkeep file is
-     * created for empty folders. The default is false.</p>
+     * structure if the changes leave the folders empty. If this is specified as true,
+     * a .gitkeep file will be created for empty folders.</p>
      */
     inline bool GetKeepEmptyFolders() const{ return m_keepEmptyFolders; }
 
     /**
      * <p>If the commit contains deletions, whether to keep a folder or folder
-     * structure if the changes leave the folders empty. If true, a ..gitkeep file is
-     * created for empty folders. The default is false.</p>
+     * structure if the changes leave the folders empty. If this is specified as true,
+     * a .gitkeep file will be created for empty folders.</p>
      */
     inline bool KeepEmptyFoldersHasBeenSet() const { return m_keepEmptyFoldersHasBeenSet; }
 
     /**
      * <p>If the commit contains deletions, whether to keep a folder or folder
-     * structure if the changes leave the folders empty. If true, a ..gitkeep file is
-     * created for empty folders. The default is false.</p>
+     * structure if the changes leave the folders empty. If this is specified as true,
+     * a .gitkeep file will be created for empty folders.</p>
      */
     inline void SetKeepEmptyFolders(bool value) { m_keepEmptyFoldersHasBeenSet = true; m_keepEmptyFolders = value; }
 
     /**
      * <p>If the commit contains deletions, whether to keep a folder or folder
-     * structure if the changes leave the folders empty. If true, a ..gitkeep file is
-     * created for empty folders. The default is false.</p>
+     * structure if the changes leave the folders empty. If this is specified as true,
+     * a .gitkeep file will be created for empty folders.</p>
      */
     inline CreateCommitRequest& WithKeepEmptyFolders(bool value) { SetKeepEmptyFolders(value); return *this;}
 
@@ -379,49 +397,49 @@ namespace Model
 
 
     /**
-     * <p>The files to delete in this commit. These files still exist in earlier
+     * <p>The files to delete in this commit. These files will still exist in prior
      * commits.</p>
      */
     inline const Aws::Vector<DeleteFileEntry>& GetDeleteFiles() const{ return m_deleteFiles; }
 
     /**
-     * <p>The files to delete in this commit. These files still exist in earlier
+     * <p>The files to delete in this commit. These files will still exist in prior
      * commits.</p>
      */
     inline bool DeleteFilesHasBeenSet() const { return m_deleteFilesHasBeenSet; }
 
     /**
-     * <p>The files to delete in this commit. These files still exist in earlier
+     * <p>The files to delete in this commit. These files will still exist in prior
      * commits.</p>
      */
     inline void SetDeleteFiles(const Aws::Vector<DeleteFileEntry>& value) { m_deleteFilesHasBeenSet = true; m_deleteFiles = value; }
 
     /**
-     * <p>The files to delete in this commit. These files still exist in earlier
+     * <p>The files to delete in this commit. These files will still exist in prior
      * commits.</p>
      */
     inline void SetDeleteFiles(Aws::Vector<DeleteFileEntry>&& value) { m_deleteFilesHasBeenSet = true; m_deleteFiles = std::move(value); }
 
     /**
-     * <p>The files to delete in this commit. These files still exist in earlier
+     * <p>The files to delete in this commit. These files will still exist in prior
      * commits.</p>
      */
     inline CreateCommitRequest& WithDeleteFiles(const Aws::Vector<DeleteFileEntry>& value) { SetDeleteFiles(value); return *this;}
 
     /**
-     * <p>The files to delete in this commit. These files still exist in earlier
+     * <p>The files to delete in this commit. These files will still exist in prior
      * commits.</p>
      */
     inline CreateCommitRequest& WithDeleteFiles(Aws::Vector<DeleteFileEntry>&& value) { SetDeleteFiles(std::move(value)); return *this;}
 
     /**
-     * <p>The files to delete in this commit. These files still exist in earlier
+     * <p>The files to delete in this commit. These files will still exist in prior
      * commits.</p>
      */
     inline CreateCommitRequest& AddDeleteFiles(const DeleteFileEntry& value) { m_deleteFilesHasBeenSet = true; m_deleteFiles.push_back(value); return *this; }
 
     /**
-     * <p>The files to delete in this commit. These files still exist in earlier
+     * <p>The files to delete in this commit. These files will still exist in prior
      * commits.</p>
      */
     inline CreateCommitRequest& AddDeleteFiles(DeleteFileEntry&& value) { m_deleteFilesHasBeenSet = true; m_deleteFiles.push_back(std::move(value)); return *this; }
@@ -470,34 +488,34 @@ namespace Model
   private:
 
     Aws::String m_repositoryName;
-    bool m_repositoryNameHasBeenSet = false;
+    bool m_repositoryNameHasBeenSet;
 
     Aws::String m_branchName;
-    bool m_branchNameHasBeenSet = false;
+    bool m_branchNameHasBeenSet;
 
     Aws::String m_parentCommitId;
-    bool m_parentCommitIdHasBeenSet = false;
+    bool m_parentCommitIdHasBeenSet;
 
     Aws::String m_authorName;
-    bool m_authorNameHasBeenSet = false;
+    bool m_authorNameHasBeenSet;
 
     Aws::String m_email;
-    bool m_emailHasBeenSet = false;
+    bool m_emailHasBeenSet;
 
     Aws::String m_commitMessage;
-    bool m_commitMessageHasBeenSet = false;
+    bool m_commitMessageHasBeenSet;
 
     bool m_keepEmptyFolders;
-    bool m_keepEmptyFoldersHasBeenSet = false;
+    bool m_keepEmptyFoldersHasBeenSet;
 
     Aws::Vector<PutFileEntry> m_putFiles;
-    bool m_putFilesHasBeenSet = false;
+    bool m_putFilesHasBeenSet;
 
     Aws::Vector<DeleteFileEntry> m_deleteFiles;
-    bool m_deleteFilesHasBeenSet = false;
+    bool m_deleteFilesHasBeenSet;
 
     Aws::Vector<SetFileModeEntry> m_setFileModes;
-    bool m_setFileModesHasBeenSet = false;
+    bool m_setFileModesHasBeenSet;
   };
 
 } // namespace Model
