@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/codedeploy/CodeDeploy_EXPORTS.h>
@@ -10,7 +20,6 @@
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/codedeploy/model/AlarmConfiguration.h>
 #include <aws/codedeploy/model/AutoRollbackConfiguration.h>
-#include <aws/codedeploy/model/OutdatedInstancesStrategy.h>
 #include <aws/codedeploy/model/DeploymentStyle.h>
 #include <aws/codedeploy/model/BlueGreenDeploymentConfiguration.h>
 #include <aws/codedeploy/model/LoadBalancerInfo.h>
@@ -30,8 +39,8 @@ namespace Model
 {
 
   /**
-   * <p>Represents the input of an <code>UpdateDeploymentGroup</code>
-   * operation.</p><p><h3>See Also:</h3>   <a
+   * <p>Represents the input of an UpdateDeploymentGroup operation.</p><p><h3>See
+   * Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/codedeploy-2014-10-06/UpdateDeploymentGroupInput">AWS
    * API Reference</a></p>
    */
@@ -39,7 +48,7 @@ namespace Model
   {
   public:
     UpdateDeploymentGroupRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -454,72 +463,72 @@ namespace Model
     /**
      * <p>Information about triggers to change when the deployment group is updated.
      * For examples, see <a
-     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Edit
-     * a Trigger in a CodeDeploy Deployment Group</a> in the <i>AWS CodeDeploy User
-     * Guide</i>.</p>
+     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Modify
+     * Triggers in an AWS CodeDeploy Deployment Group</a> in the AWS CodeDeploy User
+     * Guide.</p>
      */
     inline const Aws::Vector<TriggerConfig>& GetTriggerConfigurations() const{ return m_triggerConfigurations; }
 
     /**
      * <p>Information about triggers to change when the deployment group is updated.
      * For examples, see <a
-     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Edit
-     * a Trigger in a CodeDeploy Deployment Group</a> in the <i>AWS CodeDeploy User
-     * Guide</i>.</p>
+     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Modify
+     * Triggers in an AWS CodeDeploy Deployment Group</a> in the AWS CodeDeploy User
+     * Guide.</p>
      */
     inline bool TriggerConfigurationsHasBeenSet() const { return m_triggerConfigurationsHasBeenSet; }
 
     /**
      * <p>Information about triggers to change when the deployment group is updated.
      * For examples, see <a
-     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Edit
-     * a Trigger in a CodeDeploy Deployment Group</a> in the <i>AWS CodeDeploy User
-     * Guide</i>.</p>
+     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Modify
+     * Triggers in an AWS CodeDeploy Deployment Group</a> in the AWS CodeDeploy User
+     * Guide.</p>
      */
     inline void SetTriggerConfigurations(const Aws::Vector<TriggerConfig>& value) { m_triggerConfigurationsHasBeenSet = true; m_triggerConfigurations = value; }
 
     /**
      * <p>Information about triggers to change when the deployment group is updated.
      * For examples, see <a
-     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Edit
-     * a Trigger in a CodeDeploy Deployment Group</a> in the <i>AWS CodeDeploy User
-     * Guide</i>.</p>
+     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Modify
+     * Triggers in an AWS CodeDeploy Deployment Group</a> in the AWS CodeDeploy User
+     * Guide.</p>
      */
     inline void SetTriggerConfigurations(Aws::Vector<TriggerConfig>&& value) { m_triggerConfigurationsHasBeenSet = true; m_triggerConfigurations = std::move(value); }
 
     /**
      * <p>Information about triggers to change when the deployment group is updated.
      * For examples, see <a
-     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Edit
-     * a Trigger in a CodeDeploy Deployment Group</a> in the <i>AWS CodeDeploy User
-     * Guide</i>.</p>
+     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Modify
+     * Triggers in an AWS CodeDeploy Deployment Group</a> in the AWS CodeDeploy User
+     * Guide.</p>
      */
     inline UpdateDeploymentGroupRequest& WithTriggerConfigurations(const Aws::Vector<TriggerConfig>& value) { SetTriggerConfigurations(value); return *this;}
 
     /**
      * <p>Information about triggers to change when the deployment group is updated.
      * For examples, see <a
-     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Edit
-     * a Trigger in a CodeDeploy Deployment Group</a> in the <i>AWS CodeDeploy User
-     * Guide</i>.</p>
+     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Modify
+     * Triggers in an AWS CodeDeploy Deployment Group</a> in the AWS CodeDeploy User
+     * Guide.</p>
      */
     inline UpdateDeploymentGroupRequest& WithTriggerConfigurations(Aws::Vector<TriggerConfig>&& value) { SetTriggerConfigurations(std::move(value)); return *this;}
 
     /**
      * <p>Information about triggers to change when the deployment group is updated.
      * For examples, see <a
-     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Edit
-     * a Trigger in a CodeDeploy Deployment Group</a> in the <i>AWS CodeDeploy User
-     * Guide</i>.</p>
+     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Modify
+     * Triggers in an AWS CodeDeploy Deployment Group</a> in the AWS CodeDeploy User
+     * Guide.</p>
      */
     inline UpdateDeploymentGroupRequest& AddTriggerConfigurations(const TriggerConfig& value) { m_triggerConfigurationsHasBeenSet = true; m_triggerConfigurations.push_back(value); return *this; }
 
     /**
      * <p>Information about triggers to change when the deployment group is updated.
      * For examples, see <a
-     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Edit
-     * a Trigger in a CodeDeploy Deployment Group</a> in the <i>AWS CodeDeploy User
-     * Guide</i>.</p>
+     * href="https://docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html">Modify
+     * Triggers in an AWS CodeDeploy Deployment Group</a> in the AWS CodeDeploy User
+     * Guide.</p>
      */
     inline UpdateDeploymentGroupRequest& AddTriggerConfigurations(TriggerConfig&& value) { m_triggerConfigurationsHasBeenSet = true; m_triggerConfigurations.push_back(std::move(value)); return *this; }
 
@@ -598,73 +607,6 @@ namespace Model
     inline UpdateDeploymentGroupRequest& WithAutoRollbackConfiguration(AutoRollbackConfiguration&& value) { SetAutoRollbackConfiguration(std::move(value)); return *this;}
 
 
-    /**
-     * <p>Indicates what happens when new EC2 instances are launched mid-deployment and
-     * do not receive the deployed application revision.</p> <p>If this option is set
-     * to <code>UPDATE</code> or is unspecified, CodeDeploy initiates one or more
-     * 'auto-update outdated instances' deployments to apply the deployed application
-     * revision to the new EC2 instances.</p> <p>If this option is set to
-     * <code>IGNORE</code>, CodeDeploy does not initiate a deployment to update the new
-     * EC2 instances. This may result in instances having different revisions.</p>
-     */
-    inline const OutdatedInstancesStrategy& GetOutdatedInstancesStrategy() const{ return m_outdatedInstancesStrategy; }
-
-    /**
-     * <p>Indicates what happens when new EC2 instances are launched mid-deployment and
-     * do not receive the deployed application revision.</p> <p>If this option is set
-     * to <code>UPDATE</code> or is unspecified, CodeDeploy initiates one or more
-     * 'auto-update outdated instances' deployments to apply the deployed application
-     * revision to the new EC2 instances.</p> <p>If this option is set to
-     * <code>IGNORE</code>, CodeDeploy does not initiate a deployment to update the new
-     * EC2 instances. This may result in instances having different revisions.</p>
-     */
-    inline bool OutdatedInstancesStrategyHasBeenSet() const { return m_outdatedInstancesStrategyHasBeenSet; }
-
-    /**
-     * <p>Indicates what happens when new EC2 instances are launched mid-deployment and
-     * do not receive the deployed application revision.</p> <p>If this option is set
-     * to <code>UPDATE</code> or is unspecified, CodeDeploy initiates one or more
-     * 'auto-update outdated instances' deployments to apply the deployed application
-     * revision to the new EC2 instances.</p> <p>If this option is set to
-     * <code>IGNORE</code>, CodeDeploy does not initiate a deployment to update the new
-     * EC2 instances. This may result in instances having different revisions.</p>
-     */
-    inline void SetOutdatedInstancesStrategy(const OutdatedInstancesStrategy& value) { m_outdatedInstancesStrategyHasBeenSet = true; m_outdatedInstancesStrategy = value; }
-
-    /**
-     * <p>Indicates what happens when new EC2 instances are launched mid-deployment and
-     * do not receive the deployed application revision.</p> <p>If this option is set
-     * to <code>UPDATE</code> or is unspecified, CodeDeploy initiates one or more
-     * 'auto-update outdated instances' deployments to apply the deployed application
-     * revision to the new EC2 instances.</p> <p>If this option is set to
-     * <code>IGNORE</code>, CodeDeploy does not initiate a deployment to update the new
-     * EC2 instances. This may result in instances having different revisions.</p>
-     */
-    inline void SetOutdatedInstancesStrategy(OutdatedInstancesStrategy&& value) { m_outdatedInstancesStrategyHasBeenSet = true; m_outdatedInstancesStrategy = std::move(value); }
-
-    /**
-     * <p>Indicates what happens when new EC2 instances are launched mid-deployment and
-     * do not receive the deployed application revision.</p> <p>If this option is set
-     * to <code>UPDATE</code> or is unspecified, CodeDeploy initiates one or more
-     * 'auto-update outdated instances' deployments to apply the deployed application
-     * revision to the new EC2 instances.</p> <p>If this option is set to
-     * <code>IGNORE</code>, CodeDeploy does not initiate a deployment to update the new
-     * EC2 instances. This may result in instances having different revisions.</p>
-     */
-    inline UpdateDeploymentGroupRequest& WithOutdatedInstancesStrategy(const OutdatedInstancesStrategy& value) { SetOutdatedInstancesStrategy(value); return *this;}
-
-    /**
-     * <p>Indicates what happens when new EC2 instances are launched mid-deployment and
-     * do not receive the deployed application revision.</p> <p>If this option is set
-     * to <code>UPDATE</code> or is unspecified, CodeDeploy initiates one or more
-     * 'auto-update outdated instances' deployments to apply the deployed application
-     * revision to the new EC2 instances.</p> <p>If this option is set to
-     * <code>IGNORE</code>, CodeDeploy does not initiate a deployment to update the new
-     * EC2 instances. This may result in instances having different revisions.</p>
-     */
-    inline UpdateDeploymentGroupRequest& WithOutdatedInstancesStrategy(OutdatedInstancesStrategy&& value) { SetOutdatedInstancesStrategy(std::move(value)); return *this;}
-
-
     /**
      * <p>Information about the type of deployment, either in-place or blue/green, you
      * want to run and whether to route deployment traffic behind a load balancer.</p>
@@ -943,9 +885,6 @@ namespace Model
     AutoRollbackConfiguration m_autoRollbackConfiguration;
     bool m_autoRollbackConfigurationHasBeenSet;
 
-    OutdatedInstancesStrategy m_outdatedInstancesStrategy;
-    bool m_outdatedInstancesStrategyHasBeenSet;
-
     DeploymentStyle m_deploymentStyle;
     bool m_deploymentStyleHasBeenSet;
 
