@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/codepipeline/model/PutWebhookRequest.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -13,8 +23,7 @@ using namespace Aws::Utils::Json;
 using namespace Aws::Utils;
 
 PutWebhookRequest::PutWebhookRequest() : 
-    m_webhookHasBeenSet(false),
-    m_tagsHasBeenSet(false)
+    m_webhookHasBeenSet(false)
 {
 }
 
@@ -28,17 +37,6 @@ Aws::String PutWebhookRequest::SerializePayload() const
 
   }
 
-  if(m_tagsHasBeenSet)
-  {
-   Array<JsonValue> tagsJsonList(m_tags.size());
-   for(unsigned tagsIndex = 0; tagsIndex < tagsJsonList.GetLength(); ++tagsIndex)
-   {
-     tagsJsonList[tagsIndex].AsObject(m_tags[tagsIndex].Jsonize());
-   }
-   payload.WithArray("tags", std::move(tagsJsonList));
-
-  }
-
   return payload.View().WriteReadable();
 }
 
