@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/cognito-identity/CognitoIdentity_EXPORTS.h>
@@ -129,34 +139,6 @@ namespace Model
     inline UpdateIdentityPoolResult& WithAllowUnauthenticatedIdentities(bool value) { SetAllowUnauthenticatedIdentities(value); return *this;}
 
 
-    /**
-     * <p>Enables or disables the Basic (Classic) authentication flow. For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/cognito/latest/developerguide/authentication-flow.html">Identity
-     * Pools (Federated Identities) Authentication Flow</a> in the <i>Amazon Cognito
-     * Developer Guide</i>.</p>
-     */
-    inline bool GetAllowClassicFlow() const{ return m_allowClassicFlow; }
-
-    /**
-     * <p>Enables or disables the Basic (Classic) authentication flow. For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/cognito/latest/developerguide/authentication-flow.html">Identity
-     * Pools (Federated Identities) Authentication Flow</a> in the <i>Amazon Cognito
-     * Developer Guide</i>.</p>
-     */
-    inline void SetAllowClassicFlow(bool value) { m_allowClassicFlow = value; }
-
-    /**
-     * <p>Enables or disables the Basic (Classic) authentication flow. For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/cognito/latest/developerguide/authentication-flow.html">Identity
-     * Pools (Federated Identities) Authentication Flow</a> in the <i>Amazon Cognito
-     * Developer Guide</i>.</p>
-     */
-    inline UpdateIdentityPoolResult& WithAllowClassicFlow(bool value) { SetAllowClassicFlow(value); return *this;}
-
-
     /**
      * <p>Optional key:value pairs mapping provider names to provider app IDs.</p>
      */
@@ -472,8 +454,6 @@ namespace Model
 
     bool m_allowUnauthenticatedIdentities;
 
-    bool m_allowClassicFlow;
-
     Aws::Map<Aws::String, Aws::String> m_supportedLoginProviders;
 
     Aws::String m_developerProviderName;
