@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/cognito-sync/CognitoSync_EXPORTS.h>
@@ -26,7 +36,7 @@ namespace Model
   {
   public:
     RegisterDeviceRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -208,16 +218,16 @@ namespace Model
   private:
 
     Aws::String m_identityPoolId;
-    bool m_identityPoolIdHasBeenSet = false;
+    bool m_identityPoolIdHasBeenSet;
 
     Aws::String m_identityId;
-    bool m_identityIdHasBeenSet = false;
+    bool m_identityIdHasBeenSet;
 
     Platform m_platform;
-    bool m_platformHasBeenSet = false;
+    bool m_platformHasBeenSet;
 
     Aws::String m_token;
-    bool m_tokenHasBeenSet = false;
+    bool m_tokenHasBeenSet;
   };
 
 } // namespace Model
