@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/comprehend/Comprehend_EXPORTS.h>
@@ -11,7 +21,6 @@
 #include <aws/core/utils/DateTime.h>
 #include <aws/comprehend/model/EntityRecognizerInputDataConfig.h>
 #include <aws/comprehend/model/EntityRecognizerMetadata.h>
-#include <aws/comprehend/model/VpcConfig.h>
 #include <utility>
 
 namespace Aws
@@ -525,61 +534,6 @@ namespace Model
      */
     inline EntityRecognizerProperties& WithVolumeKmsKeyId(const char* value) { SetVolumeKmsKeyId(value); return *this;}
 
-
-    /**
-     * <p> Configuration parameters for a private Virtual Private Cloud (VPC)
-     * containing the resources you are using for your custom entity recognizer. For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline const VpcConfig& GetVpcConfig() const{ return m_vpcConfig; }
-
-    /**
-     * <p> Configuration parameters for a private Virtual Private Cloud (VPC)
-     * containing the resources you are using for your custom entity recognizer. For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline bool VpcConfigHasBeenSet() const { return m_vpcConfigHasBeenSet; }
-
-    /**
-     * <p> Configuration parameters for a private Virtual Private Cloud (VPC)
-     * containing the resources you are using for your custom entity recognizer. For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline void SetVpcConfig(const VpcConfig& value) { m_vpcConfigHasBeenSet = true; m_vpcConfig = value; }
-
-    /**
-     * <p> Configuration parameters for a private Virtual Private Cloud (VPC)
-     * containing the resources you are using for your custom entity recognizer. For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline void SetVpcConfig(VpcConfig&& value) { m_vpcConfigHasBeenSet = true; m_vpcConfig = std::move(value); }
-
-    /**
-     * <p> Configuration parameters for a private Virtual Private Cloud (VPC)
-     * containing the resources you are using for your custom entity recognizer. For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline EntityRecognizerProperties& WithVpcConfig(const VpcConfig& value) { SetVpcConfig(value); return *this;}
-
-    /**
-     * <p> Configuration parameters for a private Virtual Private Cloud (VPC)
-     * containing the resources you are using for your custom entity recognizer. For
-     * more information, see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline EntityRecognizerProperties& WithVpcConfig(VpcConfig&& value) { SetVpcConfig(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_entityRecognizerArn;
@@ -617,9 +571,6 @@ namespace Model
 
     Aws::String m_volumeKmsKeyId;
     bool m_volumeKmsKeyIdHasBeenSet;
-
-    VpcConfig m_vpcConfig;
-    bool m_vpcConfigHasBeenSet;
   };
 
 } // namespace Model
