@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/comprehend/Comprehend_EXPORTS.h>
@@ -10,7 +20,6 @@
 #include <aws/core/utils/DateTime.h>
 #include <aws/comprehend/model/InputDataConfig.h>
 #include <aws/comprehend/model/OutputDataConfig.h>
-#include <aws/comprehend/model/VpcConfig.h>
 #include <utility>
 
 namespace Aws
@@ -84,95 +93,6 @@ namespace Model
     inline TopicsDetectionJobProperties& WithJobId(const char* value) { SetJobId(value); return *this;}
 
 
-    /**
-     * <p>The Amazon Resource Name (ARN) of the topics detection job. It is a unique,
-     * fully qualified identifier for the job. It includes the AWS account, Region, and
-     * the job ID. The format of the ARN is as follows:</p> <p>
-     * <code>arn:&lt;partition&gt;:comprehend:&lt;region&gt;:&lt;account-id&gt;:topics-detection-job/&lt;job-id&gt;</code>
-     * </p> <p>The following is an example job ARN:</p> <p>
-     * <code>arn:aws:comprehend:us-west-2:111122223333:topics-detection-job/1234abcd12ab34cd56ef1234567890ab</code>
-     * </p>
-     */
-    inline const Aws::String& GetJobArn() const{ return m_jobArn; }
-
-    /**
-     * <p>The Amazon Resource Name (ARN) of the topics detection job. It is a unique,
-     * fully qualified identifier for the job. It includes the AWS account, Region, and
-     * the job ID. The format of the ARN is as follows:</p> <p>
-     * <code>arn:&lt;partition&gt;:comprehend:&lt;region&gt;:&lt;account-id&gt;:topics-detection-job/&lt;job-id&gt;</code>
-     * </p> <p>The following is an example job ARN:</p> <p>
-     * <code>arn:aws:comprehend:us-west-2:111122223333:topics-detection-job/1234abcd12ab34cd56ef1234567890ab</code>
-     * </p>
-     */
-    inline bool JobArnHasBeenSet() const { return m_jobArnHasBeenSet; }
-
-    /**
-     * <p>The Amazon Resource Name (ARN) of the topics detection job. It is a unique,
-     * fully qualified identifier for the job. It includes the AWS account, Region, and
-     * the job ID. The format of the ARN is as follows:</p> <p>
-     * <code>arn:&lt;partition&gt;:comprehend:&lt;region&gt;:&lt;account-id&gt;:topics-detection-job/&lt;job-id&gt;</code>
-     * </p> <p>The following is an example job ARN:</p> <p>
-     * <code>arn:aws:comprehend:us-west-2:111122223333:topics-detection-job/1234abcd12ab34cd56ef1234567890ab</code>
-     * </p>
-     */
-    inline void SetJobArn(const Aws::String& value) { m_jobArnHasBeenSet = true; m_jobArn = value; }
-
-    /**
-     * <p>The Amazon Resource Name (ARN) of the topics detection job. It is a unique,
-     * fully qualified identifier for the job. It includes the AWS account, Region, and
-     * the job ID. The format of the ARN is as follows:</p> <p>
-     * <code>arn:&lt;partition&gt;:comprehend:&lt;region&gt;:&lt;account-id&gt;:topics-detection-job/&lt;job-id&gt;</code>
-     * </p> <p>The following is an example job ARN:</p> <p>
-     * <code>arn:aws:comprehend:us-west-2:111122223333:topics-detection-job/1234abcd12ab34cd56ef1234567890ab</code>
-     * </p>
-     */
-    inline void SetJobArn(Aws::String&& value) { m_jobArnHasBeenSet = true; m_jobArn = std::move(value); }
-
-    /**
-     * <p>The Amazon Resource Name (ARN) of the topics detection job. It is a unique,
-     * fully qualified identifier for the job. It includes the AWS account, Region, and
-     * the job ID. The format of the ARN is as follows:</p> <p>
-     * <code>arn:&lt;partition&gt;:comprehend:&lt;region&gt;:&lt;account-id&gt;:topics-detection-job/&lt;job-id&gt;</code>
-     * </p> <p>The following is an example job ARN:</p> <p>
-     * <code>arn:aws:comprehend:us-west-2:111122223333:topics-detection-job/1234abcd12ab34cd56ef1234567890ab</code>
-     * </p>
-     */
-    inline void SetJobArn(const char* value) { m_jobArnHasBeenSet = true; m_jobArn.assign(value); }
-
-    /**
-     * <p>The Amazon Resource Name (ARN) of the topics detection job. It is a unique,
-     * fully qualified identifier for the job. It includes the AWS account, Region, and
-     * the job ID. The format of the ARN is as follows:</p> <p>
-     * <code>arn:&lt;partition&gt;:comprehend:&lt;region&gt;:&lt;account-id&gt;:topics-detection-job/&lt;job-id&gt;</code>
-     * </p> <p>The following is an example job ARN:</p> <p>
-     * <code>arn:aws:comprehend:us-west-2:111122223333:topics-detection-job/1234abcd12ab34cd56ef1234567890ab</code>
-     * </p>
-     */
-    inline TopicsDetectionJobProperties& WithJobArn(const Aws::String& value) { SetJobArn(value); return *this;}
-
-    /**
-     * <p>The Amazon Resource Name (ARN) of the topics detection job. It is a unique,
-     * fully qualified identifier for the job. It includes the AWS account, Region, and
-     * the job ID. The format of the ARN is as follows:</p> <p>
-     * <code>arn:&lt;partition&gt;:comprehend:&lt;region&gt;:&lt;account-id&gt;:topics-detection-job/&lt;job-id&gt;</code>
-     * </p> <p>The following is an example job ARN:</p> <p>
-     * <code>arn:aws:comprehend:us-west-2:111122223333:topics-detection-job/1234abcd12ab34cd56ef1234567890ab</code>
-     * </p>
-     */
-    inline TopicsDetectionJobProperties& WithJobArn(Aws::String&& value) { SetJobArn(std::move(value)); return *this;}
-
-    /**
-     * <p>The Amazon Resource Name (ARN) of the topics detection job. It is a unique,
-     * fully qualified identifier for the job. It includes the AWS account, Region, and
-     * the job ID. The format of the ARN is as follows:</p> <p>
-     * <code>arn:&lt;partition&gt;:comprehend:&lt;region&gt;:&lt;account-id&gt;:topics-detection-job/&lt;job-id&gt;</code>
-     * </p> <p>The following is an example job ARN:</p> <p>
-     * <code>arn:aws:comprehend:us-west-2:111122223333:topics-detection-job/1234abcd12ab34cd56ef1234567890ab</code>
-     * </p>
-     */
-    inline TopicsDetectionJobProperties& WithJobArn(const char* value) { SetJobArn(value); return *this;}
-
-
     /**
      * <p>The name of the topic detection job.</p>
      */
@@ -604,101 +524,40 @@ namespace Model
      */
     inline TopicsDetectionJobProperties& WithVolumeKmsKeyId(const char* value) { SetVolumeKmsKeyId(value); return *this;}
 
-
-    /**
-     * <p>Configuration parameters for a private Virtual Private Cloud (VPC) containing
-     * the resources you are using for your topic detection job. For more information,
-     * see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline const VpcConfig& GetVpcConfig() const{ return m_vpcConfig; }
-
-    /**
-     * <p>Configuration parameters for a private Virtual Private Cloud (VPC) containing
-     * the resources you are using for your topic detection job. For more information,
-     * see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline bool VpcConfigHasBeenSet() const { return m_vpcConfigHasBeenSet; }
-
-    /**
-     * <p>Configuration parameters for a private Virtual Private Cloud (VPC) containing
-     * the resources you are using for your topic detection job. For more information,
-     * see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline void SetVpcConfig(const VpcConfig& value) { m_vpcConfigHasBeenSet = true; m_vpcConfig = value; }
-
-    /**
-     * <p>Configuration parameters for a private Virtual Private Cloud (VPC) containing
-     * the resources you are using for your topic detection job. For more information,
-     * see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline void SetVpcConfig(VpcConfig&& value) { m_vpcConfigHasBeenSet = true; m_vpcConfig = std::move(value); }
-
-    /**
-     * <p>Configuration parameters for a private Virtual Private Cloud (VPC) containing
-     * the resources you are using for your topic detection job. For more information,
-     * see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline TopicsDetectionJobProperties& WithVpcConfig(const VpcConfig& value) { SetVpcConfig(value); return *this;}
-
-    /**
-     * <p>Configuration parameters for a private Virtual Private Cloud (VPC) containing
-     * the resources you are using for your topic detection job. For more information,
-     * see <a
-     * href="https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html">Amazon
-     * VPC</a>. </p>
-     */
-    inline TopicsDetectionJobProperties& WithVpcConfig(VpcConfig&& value) { SetVpcConfig(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_jobId;
-    bool m_jobIdHasBeenSet = false;
-
-    Aws::String m_jobArn;
-    bool m_jobArnHasBeenSet = false;
+    bool m_jobIdHasBeenSet;
 
     Aws::String m_jobName;
-    bool m_jobNameHasBeenSet = false;
+    bool m_jobNameHasBeenSet;
 
     JobStatus m_jobStatus;
-    bool m_jobStatusHasBeenSet = false;
+    bool m_jobStatusHasBeenSet;
 
     Aws::String m_message;
-    bool m_messageHasBeenSet = false;
+    bool m_messageHasBeenSet;
 
     Aws::Utils::DateTime m_submitTime;
-    bool m_submitTimeHasBeenSet = false;
+    bool m_submitTimeHasBeenSet;
 
     Aws::Utils::DateTime m_endTime;
-    bool m_endTimeHasBeenSet = false;
+    bool m_endTimeHasBeenSet;
 
     InputDataConfig m_inputDataConfig;
-    bool m_inputDataConfigHasBeenSet = false;
+    bool m_inputDataConfigHasBeenSet;
 
     OutputDataConfig m_outputDataConfig;
-    bool m_outputDataConfigHasBeenSet = false;
+    bool m_outputDataConfigHasBeenSet;
 
     int m_numberOfTopics;
-    bool m_numberOfTopicsHasBeenSet = false;
+    bool m_numberOfTopicsHasBeenSet;
 
     Aws::String m_dataAccessRoleArn;
-    bool m_dataAccessRoleArnHasBeenSet = false;
+    bool m_dataAccessRoleArnHasBeenSet;
 
     Aws::String m_volumeKmsKeyId;
-    bool m_volumeKmsKeyIdHasBeenSet = false;
-
-    VpcConfig m_vpcConfig;
-    bool m_vpcConfigHasBeenSet = false;
+    bool m_volumeKmsKeyIdHasBeenSet;
   };
 
 } // namespace Model
