@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/comprehend/model/EntityRecognizerProperties.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -32,9 +42,7 @@ EntityRecognizerProperties::EntityRecognizerProperties() :
     m_inputDataConfigHasBeenSet(false),
     m_recognizerMetadataHasBeenSet(false),
     m_dataAccessRoleArnHasBeenSet(false),
-    m_volumeKmsKeyIdHasBeenSet(false),
-    m_vpcConfigHasBeenSet(false),
-    m_modelKmsKeyIdHasBeenSet(false)
+    m_volumeKmsKeyIdHasBeenSet(false)
 {
 }
 
@@ -52,9 +60,7 @@ EntityRecognizerProperties::EntityRecognizerProperties(JsonView jsonValue) :
     m_inputDataConfigHasBeenSet(false),
     m_recognizerMetadataHasBeenSet(false),
     m_dataAccessRoleArnHasBeenSet(false),
-    m_volumeKmsKeyIdHasBeenSet(false),
-    m_vpcConfigHasBeenSet(false),
-    m_modelKmsKeyIdHasBeenSet(false)
+    m_volumeKmsKeyIdHasBeenSet(false)
 {
   *this = jsonValue;
 }
@@ -145,20 +151,6 @@ EntityRecognizerProperties& EntityRecognizerProperties::operator =(JsonView json
     m_volumeKmsKeyIdHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("VpcConfig"))
-  {
-    m_vpcConfig = jsonValue.GetObject("VpcConfig");
-
-    m_vpcConfigHasBeenSet = true;
-  }
-
-  if(jsonValue.ValueExists("ModelKmsKeyId"))
-  {
-    m_modelKmsKeyId = jsonValue.GetString("ModelKmsKeyId");
-
-    m_modelKmsKeyIdHasBeenSet = true;
-  }
-
   return *this;
 }
 
@@ -232,18 +224,6 @@ JsonValue EntityRecognizerProperties::Jsonize() const
 
   }
 
-  if(m_vpcConfigHasBeenSet)
-  {
-   payload.WithObject("VpcConfig", m_vpcConfig.Jsonize());
-
-  }
-
-  if(m_modelKmsKeyIdHasBeenSet)
-  {
-   payload.WithString("ModelKmsKeyId", m_modelKmsKeyId);
-
-  }
-
   return payload;
 }
 
