@@ -1,7 +1,17 @@
-/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+/*
+  * Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+  *
+  * Licensed under the Apache License, Version 2.0 (the "License").
+  * You may not use this file except in compliance with the License.
+  * A copy of the License is located at
+  *
+  *  http://aws.amazon.com/apache2.0
+  *
+  * or in the "license" file accompanying this file. This file is distributed
+  * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+  * express or implied. See the License for the specific language governing
+  * permissions and limitations under the License.
+  */
 
 
 #include <aws/core/utils/crypto/bcrypt/CryptoImpl.h>
@@ -12,9 +22,9 @@
 #include <aws/core/utils/crypto/Hash.h>
 #include <aws/core/utils/HashingUtils.h>
 #include <atomic>
-#include <bcrypt.h>
-#include <winternl.h>
-#include <winerror.h>
+#include <bcrypt.h> 
+#include <winternl.h> 
+#include <winerror.h> 
 
 #ifndef NT_SUCCESS
 #define NT_SUCCESS(Status) ((NTSTATUS)(Status) >= 0)
@@ -49,36 +59,31 @@ namespace Aws
 
             void SecureRandomBytes_BCrypt::GetBytes(unsigned char* buffer, size_t bufferSize)
             {
-                if (!m_algHandle)
+                assert(m_algHandle);
+                if(bufferSize)
                 {
-                    AWS_LOGSTREAM_FATAL(SecureRandom_BCrypt_Tag, "Secure Random Bytes generator can't generate bytes with empty algorithm handle.");
-                    m_failure = true;
-                    assert(m_algHandle);
-                    return;
-                }
-
-                if (!bufferSize)
-                {
-                    return;
-                }
-
-                if (!buffer)
-                {
-                    AWS_LOGSTREAM_FATAL(SecureRandom_BCrypt_Tag, "Secure Random Bytes generator can't generate: " << bufferSize << " bytes with nullptr buffer.");
                     assert(buffer);
-                    return;
-                }
+                    if (m_algHandle)
+                    {
+                        NTSTATUS status = BCryptGenRandom(m_algHandle, buffer, static_cast<ULONG>(bufferSize), 0);
 
-                NTSTATUS status = BCryptGenRandom(m_algHandle, buffer, static_cast<ULONG>(bufferSize), 0);
-
-                if (!NT_SUCCESS(status))
-                {
-                    m_failure = true;
-                    AWS_LOGSTREAM_FATAL(SecureRandom_BCrypt_Tag, "Failed to generate random number with status " << status);
+                        if (!NT_SUCCESS(status))
+                        {
+                            m_failure = true;
+                            AWS_LOGSTREAM_FATAL(SecureRandom_BCrypt_Tag, "Failed to generate random number with status " << status);
+                        }
+                    }
+                    else
+                    {
+                        m_failure = true;
+                        AWS_LOGSTREAM_FATAL(SecureRandom_BCrypt_Tag, "Algorithm handle not initialized ");
+                    }
                 }
             }
 
+
             static const char* logTag = "CryptoHash";
+
             // RAII class for one-use-per-hash-call data used in Windows cryptographic hash implementations
             // Useful so we don't have to call a Cleanup function for every failure point
             class BCryptHashContext
@@ -115,6 +120,8 @@ namespace Aws
                 bool m_isValid;
             };
 
+
+
             BCryptHashImpl::BCryptHashImpl(LPCWSTR algorithmName, bool isHMAC) :
                 m_algorithmHandle(nullptr),
                 m_hashBufferLength(0),
@@ -318,21 +325,6 @@ namespace Aws
                 return m_impl.Calculate(stream);
             }
 
-            Sha1BcryptImpl::Sha1BcryptImpl() :
-                    m_impl(BCRYPT_SHA1_ALGORITHM, false)
-            {
-            }
-
-            HashResult Sha1BcryptImpl::Calculate(const Aws::String& str)
-            {
-                return m_impl.Calculate(str);
-            }
-
-            HashResult Sha1BcryptImpl::Calculate(Aws::IStream& stream)
-            {
-                return m_impl.Calculate(stream);
-            }
-
             Sha256BcryptImpl::Sha256BcryptImpl() :
                 m_impl(BCRYPT_SHA256_ALGORITHM, false)
             {
@@ -399,7 +391,6 @@ namespace Aws
             void BCryptSymmetricCipher::Init()
             {
                 m_workingIv = m_initializationVector;
-                m_encryptDecryptCalled = false;
             }
 
             BCRYPT_KEY_HANDLE BCryptSymmetricCipher::ImportKeyBlob(BCRYPT_ALG_HANDLE algHandle, CryptoBuffer& key)
@@ -428,28 +419,26 @@ namespace Aws
 
             void BCryptSymmetricCipher::InitKey()
             {
-                if (m_failure || !m_algHandle)
+                if (m_algHandle)
                 {
-                    return;
-                }
-
-                m_keyHandle = ImportKeyBlob(m_algHandle, m_key);
-                if (!m_keyHandle)
-                {
-                    m_failure = true;
-                    return;
-                }
-
-                if(!m_authInfoPtr && m_initializationVector.GetLength() > 0)
-                {
-                    NTSTATUS status = BCryptSetProperty(m_keyHandle, BCRYPT_INITIALIZATION_VECTOR, m_initializationVector.GetUnderlyingData(), static_cast<ULONG>(m_initializationVector.GetLength()), 0);
-
-                    if (!NT_SUCCESS(status))
+                    m_keyHandle = ImportKeyBlob(m_algHandle, m_key);
+                    if (!m_keyHandle)
                     {
-                        m_failure = true;
-                        AWS_LOGSTREAM_ERROR(SYM_CIPHER_TAG, "Failed to set symmetric key initialization vector with status code " << status);
+                        m_failure = true;                        
                         return;
                     }
+
+                    if(!m_authInfoPtr && m_initializationVector.GetLength() > 0)
+                    {              
+                        NTSTATUS status = BCryptSetProperty(m_keyHandle, BCRYPT_INITIALIZATION_VECTOR, m_initializationVector.GetUnderlyingData(), static_cast<ULONG>(m_initializationVector.GetLength()), 0);
+
+                        if (!NT_SUCCESS(status))
+                        {
+                            m_failure = true;
+                            AWS_LOGSTREAM_ERROR(SYM_CIPHER_TAG, "Failed to set symetric key initialization vector with status code " << status);
+                            return;
+                        }
+                    }
                 }
             }
 
@@ -461,7 +450,7 @@ namespace Aws
                     return CryptoBuffer();
                 }
 
-                if (unEncryptedData.GetLength() == 0 && m_encryptDecryptCalled)
+                if (unEncryptedData.GetLength() == 0)
                 {
                     return CryptoBuffer();
                 }
@@ -484,7 +473,7 @@ namespace Aws
                 //iv was set on the key itself, so we don't need to pass it here.
                 NTSTATUS status = BCryptEncrypt(m_keyHandle, unEncryptedData.GetUnderlyingData(), (ULONG)unEncryptedData.GetLength(),
                     m_authInfoPtr, iv, ivSize, encryptedText.GetUnderlyingData(), (ULONG)encryptedText.GetLength(), &lengthWritten, m_flags);
-                m_encryptDecryptCalled = true;
+
                 if (!NT_SUCCESS(status))
                 {
                     m_failure = true;
@@ -513,7 +502,7 @@ namespace Aws
                     return CryptoBuffer();
                 }
 
-                if (encryptedData.GetLength() == 0 && m_encryptDecryptCalled)
+                if (encryptedData.GetLength() == 0)
                 {
                     return CryptoBuffer();
                 }
@@ -534,7 +523,7 @@ namespace Aws
                 //iv was set on the key itself, so we don't need to pass it here.
                 NTSTATUS status = BCryptDecrypt(m_keyHandle, encryptedData.GetUnderlyingData(), (ULONG)encryptedData.GetLength(),
                     m_authInfoPtr, iv, ivSize, decryptedText.GetUnderlyingData(), (ULONG)decryptedText.GetLength(), &lengthWritten, m_flags);
-                m_encryptDecryptCalled = true;
+
                 if (!NT_SUCCESS(status))
                 {
                     m_failure = true;
@@ -580,16 +569,6 @@ namespace Aws
                 m_failure = false;
             }
 
-            bool BCryptSymmetricCipher::CheckKeyAndIVLength(size_t expectedKeyLength, size_t expectedIVLength)
-            {
-                if (!m_failure && ((m_key.GetLength() != expectedKeyLength) || m_initializationVector.GetLength() != expectedIVLength))
-                {
-                    AWS_LOGSTREAM_ERROR(SYM_CIPHER_TAG, "Expected Key size is: " << expectedKeyLength << " and expected IV size is: " << expectedIVLength);
-                    m_failure = true;
-                }
-                return !m_failure;
-            }
-
             size_t AES_CBC_Cipher_BCrypt::BlockSizeBytes = 16;
             size_t AES_CBC_Cipher_BCrypt::KeyLengthBits = 256;
 
@@ -615,10 +594,6 @@ namespace Aws
 
             void AES_CBC_Cipher_BCrypt::InitCipher()
             {
-                if (m_failure || !CheckKeyAndIVLength(KeyLengthBits/8, BlockSizeBytes))
-                {
-                    return;
-                }
                 //due to odd BCrypt api behavior, we have to manually handle the padding, however we are producing padded output.
                 m_flags = 0;
                 NTSTATUS status = BCryptOpenAlgorithmProvider(&m_algHandle, BCRYPT_AES_ALGORITHM, nullptr, 0);
@@ -627,7 +602,6 @@ namespace Aws
                 {
                     m_failure = true;
                     AWS_LOGSTREAM_ERROR(CBC_LOG_TAG, "Failed to initialize encryptor/decryptor with status code " << status);
-                    return;
                 }
 
                 status = BCryptSetProperty(m_algHandle, BCRYPT_CHAINING_MODE, (PUCHAR)BCRYPT_CHAIN_MODE_CBC, static_cast<ULONG>(wcslen(BCRYPT_CHAIN_MODE_CBC) + 1), 0);
@@ -646,11 +620,6 @@ namespace Aws
              */
             CryptoBuffer AES_CBC_Cipher_BCrypt::FillInOverflow(const CryptoBuffer& buffer)
             {
-                if (m_failure)
-                {
-                    return CryptoBuffer();
-                }
-
                 static const size_t RESERVE_SIZE = BlockSizeBytes * 2;
                 m_flags = 0;
 
@@ -681,10 +650,10 @@ namespace Aws
                     return CryptoBuffer();
                 }
             }
-
+            
             CryptoBuffer AES_CBC_Cipher_BCrypt::EncryptBuffer(const CryptoBuffer& unEncryptedData)
-            {
-                return BCryptSymmetricCipher::EncryptBuffer(FillInOverflow(unEncryptedData));
+            {                    
+                return BCryptSymmetricCipher::EncryptBuffer(FillInOverflow(unEncryptedData));              
             }
 
             /**
@@ -693,14 +662,15 @@ namespace Aws
              */
             CryptoBuffer AES_CBC_Cipher_BCrypt::FinalizeEncryption()
             {
-                if (!m_failure && m_blockOverflow.GetLength() > 0)
+                if (m_blockOverflow.GetLength() > 0)
                 {
                     m_flags = BCRYPT_BLOCK_PADDING;
                     return BCryptSymmetricCipher::EncryptBuffer(m_blockOverflow);
-                }
+                }               
+
                 return CryptoBuffer();
             }
-
+            
             CryptoBuffer AES_CBC_Cipher_BCrypt::DecryptBuffer(const CryptoBuffer& encryptedData)
             {
                 return BCryptSymmetricCipher::DecryptBuffer(FillInOverflow(encryptedData));
@@ -708,8 +678,8 @@ namespace Aws
 
             CryptoBuffer AES_CBC_Cipher_BCrypt::FinalizeDecryption()
             {
-                if (!m_failure && m_blockOverflow.GetLength() > 0)
-                {
+                if ( m_blockOverflow.GetLength() > 0)
+                {                   
                     m_flags = BCRYPT_BLOCK_PADDING;
                     return BCryptSymmetricCipher::DecryptBuffer(m_blockOverflow);
                 }
@@ -763,6 +733,7 @@ namespace Aws
                     AWS_LOGSTREAM_FATAL(CTR_LOG_TAG, "Cipher not properly initialized for encryption. Aborting");
                     return CryptoBuffer();
                 }
+
                 return EncryptWithCtr(unEncryptedData);
             }
 
@@ -772,12 +743,13 @@ namespace Aws
              */
             CryptoBuffer AES_CTR_Cipher_BCrypt::FinalizeEncryption()
             {
-                if (!m_failure && m_blockOverflow.GetLength())
+                if (m_blockOverflow.GetLength())
                 {
                     CryptoBuffer const& returnBuffer = EncryptBuffer(m_blockOverflow);
                     m_blockOverflow = CryptoBuffer();
                     return returnBuffer;
                 }
+
                 return CryptoBuffer();
             }
 
@@ -788,6 +760,7 @@ namespace Aws
                     AWS_LOGSTREAM_FATAL(CTR_LOG_TAG, "Cipher not properly initialized for encryption. Aborting");
                     return CryptoBuffer();
                 }
+
                 //Encryption and decryption are identical in CTR mode.
                 return EncryptWithCtr(encryptedData);
             }
@@ -798,21 +771,18 @@ namespace Aws
             */
             CryptoBuffer AES_CTR_Cipher_BCrypt::FinalizeDecryption()
             {
-                if (!m_failure && m_blockOverflow.GetLength())
+                if (m_blockOverflow.GetLength())
                 {
                     CryptoBuffer const& returnBuffer = DecryptBuffer(m_blockOverflow);
                     m_blockOverflow = CryptoBuffer();
                     return returnBuffer;
                 }
+
                 return CryptoBuffer();
             }
 
             void AES_CTR_Cipher_BCrypt::InitCipher()
             {
-                if (m_failure || !CheckKeyAndIVLength(KeyLengthBits/8, BlockSizeBytes))
-                {
-                    return;
-                }
                 m_flags = 0;
                 NTSTATUS status = BCryptOpenAlgorithmProvider(&m_algHandle, BCRYPT_AES_ALGORITHM, nullptr, 0);
 
@@ -837,10 +807,6 @@ namespace Aws
             */
             CryptoBuffer AES_CTR_Cipher_BCrypt::EncryptWithCtr(const CryptoBuffer& buffer)
             {
-                if (m_failure)
-                {
-                    return CryptoBuffer();
-                }
                 size_t bytesWritten = 0;
                 Aws::Vector<ByteBuffer*> finalBufferSet(0);
 
@@ -874,7 +840,7 @@ namespace Aws
                 for (size_t i = 0; i < slicedBuffers.GetLength(); ++i)
                 {
                     if (slicedBuffers[i].GetLength() == BlockSizeBytes || (m_blockOverflow.GetLength() > 0 && slicedBuffers.GetLength() == 1))
-                    {
+                    {                       
                         ULONG lengthWritten = static_cast<ULONG>(BlockSizeBytes);
                         CryptoBuffer encryptedText(BlockSizeBytes);
 
@@ -925,7 +891,7 @@ namespace Aws
             size_t AES_CTR_Cipher_BCrypt::GetKeyLengthBits() const
             {
                 return KeyLengthBits;
-            }
+            }           
 
             void AES_CTR_Cipher_BCrypt::InitBuffersToNull(Aws::Vector<ByteBuffer*>& initBuffers)
             {
@@ -948,29 +914,20 @@ namespace Aws
 
             static const char* GCM_LOG_TAG = "BCrypt_AES_GCM_Cipher";
             size_t AES_GCM_Cipher_BCrypt::BlockSizeBytes = 16;
-            size_t AES_GCM_Cipher_BCrypt::IVLengthBytes = 12;
+            size_t AES_GCM_Cipher_BCrypt::NonceSizeBytes = 12;
             size_t AES_GCM_Cipher_BCrypt::KeyLengthBits = 256;
             size_t AES_GCM_Cipher_BCrypt::TagLengthBytes = 16;
 
             AES_GCM_Cipher_BCrypt::AES_GCM_Cipher_BCrypt(const CryptoBuffer& key) :
-                    BCryptSymmetricCipher(key, IVLengthBytes), m_macBuffer(TagLengthBytes)
+                    BCryptSymmetricCipher(key, NonceSizeBytes), m_macBuffer(TagLengthBytes)
             {
                 m_tag = CryptoBuffer(TagLengthBytes);
                 InitCipher();
                 InitKey();
             }
 
-            AES_GCM_Cipher_BCrypt::AES_GCM_Cipher_BCrypt(const CryptoBuffer& key, const CryptoBuffer* aad) :
-                    BCryptSymmetricCipher(key, IVLengthBytes), m_macBuffer(TagLengthBytes), m_aad(*aad)
-            {
-                m_tag = CryptoBuffer(TagLengthBytes);
-                InitCipher();
-                InitKey();
-            }
-
-            AES_GCM_Cipher_BCrypt::AES_GCM_Cipher_BCrypt(CryptoBuffer&& key, CryptoBuffer&& initializationVector,
-                CryptoBuffer&& tag, CryptoBuffer&& aad) :
-                    BCryptSymmetricCipher(std::move(key), std::move(initializationVector), std::move(tag)), m_macBuffer(TagLengthBytes), m_aad(std::move(aad))
+            AES_GCM_Cipher_BCrypt::AES_GCM_Cipher_BCrypt(CryptoBuffer&& key, CryptoBuffer&& initializationVector, CryptoBuffer&& tag) :
+                    BCryptSymmetricCipher(std::move(key), std::move(initializationVector), std::move(tag)), m_macBuffer(TagLengthBytes)
             {
                 if (m_tag.GetLength() == 0)
                 {
@@ -980,9 +937,8 @@ namespace Aws
                 InitKey();
             }
 
-            AES_GCM_Cipher_BCrypt::AES_GCM_Cipher_BCrypt(const CryptoBuffer& key, const CryptoBuffer& initializationVector,
-                const CryptoBuffer& tag, const CryptoBuffer& aad) :
-                    BCryptSymmetricCipher(key, initializationVector, tag), m_macBuffer(TagLengthBytes), m_aad(aad)
+            AES_GCM_Cipher_BCrypt::AES_GCM_Cipher_BCrypt(const CryptoBuffer& key, const CryptoBuffer& initializationVector, const CryptoBuffer& tag) :
+                    BCryptSymmetricCipher(key, initializationVector, tag), m_macBuffer(TagLengthBytes)
             {
                 if (m_tag.GetLength() == 0)
                 {
@@ -1013,10 +969,7 @@ namespace Aws
              */
             CryptoBuffer AES_GCM_Cipher_BCrypt::EncryptBuffer(const CryptoBuffer& toEncrypt)
             {
-                if (m_failure)
-                {
-                    return CryptoBuffer();
-                }
+                assert(!m_failure);
 
                 CryptoBuffer workingBuffer;
 
@@ -1036,7 +989,6 @@ namespace Aws
 
                     m_finalBuffer = CryptoBuffer(workingBuffer.GetUnderlyingData() + workingBuffer.GetLength() - (TagLengthBytes +  offset), TagLengthBytes + offset);
                     workingBuffer = CryptoBuffer(workingBuffer.GetUnderlyingData(), workingBuffer.GetLength() - (TagLengthBytes + offset));
-                    m_encryptDecryptCalled = true;
                     return BCryptSymmetricCipher::EncryptBuffer(workingBuffer);
                 }
                 else
@@ -1055,10 +1007,7 @@ namespace Aws
              */
             CryptoBuffer AES_GCM_Cipher_BCrypt::DecryptBuffer(const CryptoBuffer& toDecrypt)
             {
-                if (m_failure)
-                {
-                    return CryptoBuffer();
-                }
+                assert(!m_failure);
 
                 CryptoBuffer workingBuffer;
 
@@ -1077,7 +1026,6 @@ namespace Aws
                     auto offset = workingBuffer.GetLength() % TagLengthBytes;
                     m_finalBuffer = CryptoBuffer(workingBuffer.GetUnderlyingData() + workingBuffer.GetLength() - (TagLengthBytes + offset), TagLengthBytes + offset);
                     workingBuffer = CryptoBuffer(workingBuffer.GetUnderlyingData(), workingBuffer.GetLength() - (TagLengthBytes + offset));
-                    m_encryptDecryptCalled = true;
                     return BCryptSymmetricCipher::DecryptBuffer(workingBuffer);
                 }
                 else
@@ -1108,11 +1056,6 @@ namespace Aws
              */
             void AES_GCM_Cipher_BCrypt::InitCipher()
             {
-                if (m_failure || !CheckKeyAndIVLength(KeyLengthBits/8, IVLengthBytes))
-                {
-                    return;
-                }
-
                 m_flags = 0;
                 NTSTATUS status = BCryptOpenAlgorithmProvider(&m_algHandle, BCRYPT_AES_ALGORITHM, nullptr, 0);
 
@@ -1120,7 +1063,6 @@ namespace Aws
                 {
                     m_failure = true;
                     AWS_LOGSTREAM_ERROR(GCM_LOG_TAG, "Failed to initialize encryptor/decryptor with status code " << status);
-                    return;
                 }
 
                 status = BCryptSetProperty(m_algHandle, BCRYPT_CHAINING_MODE, (PUCHAR)BCRYPT_CHAIN_MODE_GCM, static_cast<ULONG>(wcslen(BCRYPT_CHAIN_MODE_GCM) + 1), 0);
@@ -1128,7 +1070,6 @@ namespace Aws
                 {
                     m_failure = true;
                     AWS_LOGSTREAM_ERROR(GCM_LOG_TAG, "Failed to initialize encryptor/decryptor chaining mode with status code " << status);
-                    return;
                 }
 
                 BCRYPT_INIT_AUTH_MODE_INFO(m_authInfo);
@@ -1139,13 +1080,6 @@ namespace Aws
                 m_authInfo.pbMacContext = m_macBuffer.GetUnderlyingData();
                 m_authInfo.cbMacContext = static_cast<ULONG>(m_macBuffer.GetLength());
                 m_authInfo.cbData = 0;
-
-                if (m_aad.GetLength() > 0)
-                {
-                    m_authInfo.pbAuthData = m_aad.GetUnderlyingData();
-                    m_authInfo.cbAuthData = static_cast<ULONG>(m_aad.GetLength());
-                }
-
                 m_authInfo.dwFlags = BCRYPT_AUTH_MODE_CHAIN_CALLS_FLAG;
 
                 m_authInfoPtr = &m_authInfo;
@@ -1192,30 +1126,25 @@ namespace Aws
 
             CryptoBuffer AES_KeyWrap_Cipher_BCrypt::EncryptBuffer(const CryptoBuffer& unEncryptedData)
             {
-                if (!m_failure)
-                {
-                    m_operatingKeyBuffer = CryptoBuffer({(ByteBuffer*)&m_operatingKeyBuffer, (ByteBuffer*)&unEncryptedData});
-                }
+                assert(!m_failure);
+
+                m_operatingKeyBuffer = CryptoBuffer({(ByteBuffer*)&m_operatingKeyBuffer, (ByteBuffer*)&unEncryptedData});
+
                 return CryptoBuffer();
             }
 
             CryptoBuffer AES_KeyWrap_Cipher_BCrypt::DecryptBuffer(const CryptoBuffer& encryptedData)
             {
-                if (!m_failure)
-                {
-                    m_operatingKeyBuffer = CryptoBuffer({ (ByteBuffer*)&m_operatingKeyBuffer, (ByteBuffer*)&encryptedData });
-                }
+                assert(!m_failure);
+
+                m_operatingKeyBuffer = CryptoBuffer({ (ByteBuffer*)&m_operatingKeyBuffer, (ByteBuffer*)&encryptedData });
+
                 return CryptoBuffer();
             }
 
 
             void AES_KeyWrap_Cipher_BCrypt::InitCipher()
             {
-                if (m_failure || !CheckKeyAndIVLength(KeyLengthBits/8, 0))
-                {
-                    return;
-                }
-
                 NTSTATUS status = BCryptOpenAlgorithmProvider(&m_algHandle, BCRYPT_AES_ALGORITHM, nullptr, 0);
 
                 if (!NT_SUCCESS(status))
@@ -1234,11 +1163,11 @@ namespace Aws
                 }
 
                 BCRYPT_KEY_HANDLE keyHandleToEncrypt = ImportKeyBlob(m_algHandle, m_operatingKeyBuffer);
-
+                
                 NTSTATUS status = 0;
 
                 ULONG sizeOfCipherText;
-                status = BCryptExportKey(keyHandleToEncrypt, m_keyHandle, BCRYPT_AES_WRAP_KEY_BLOB,
+                status = BCryptExportKey(keyHandleToEncrypt, m_keyHandle, BCRYPT_AES_WRAP_KEY_BLOB, 
                     nullptr, 0, &sizeOfCipherText, 0);
 
                 if (!NT_SUCCESS(status))
@@ -1247,7 +1176,7 @@ namespace Aws
                     AWS_LOGSTREAM_ERROR(KEYWRAP_LOG_TAG, "Failed to export symmetric key size with status code " << status);
                     return CryptoBuffer();
                 }
-
+                
                 CryptoBuffer cipherText(static_cast<size_t>(sizeOfCipherText));
                 status = BCryptExportKey(keyHandleToEncrypt, m_keyHandle, BCRYPT_AES_WRAP_KEY_BLOB,
                     cipherText.GetUnderlyingData(), static_cast<ULONG>(cipherText.GetLength()), &sizeOfCipherText, 0);
@@ -1275,8 +1204,8 @@ namespace Aws
                     return CryptoBuffer();
                 }
 
-                CryptoBuffer returnBuffer;
-
+                CryptoBuffer returnBuffer;    
+                
                 BCRYPT_KEY_HANDLE importKey(nullptr);
                 NTSTATUS status = BCryptImportKey(m_algHandle, m_keyHandle, BCRYPT_AES_WRAP_KEY_BLOB, &importKey,
                     nullptr, 0,
@@ -1286,7 +1215,7 @@ namespace Aws
                 {
                     ULONG exportSize(0);
                     CryptoBuffer outputBuffer(sizeof(BCRYPT_KEY_DATA_BLOB_HEADER) + m_operatingKeyBuffer.GetLength());
-                    status = BCryptExportKey(importKey, nullptr, BCRYPT_KEY_DATA_BLOB,
+                    status = BCryptExportKey(importKey, nullptr, BCRYPT_KEY_DATA_BLOB, 
                                 outputBuffer.GetUnderlyingData(), static_cast<ULONG>(outputBuffer.GetLength()), &exportSize, 0);
 
                     if (NT_SUCCESS(status))
@@ -1298,16 +1227,14 @@ namespace Aws
                     {
                         m_failure = true;
                         AWS_LOGSTREAM_ERROR(KEYWRAP_LOG_TAG, "Failed to re-export key with status code " << status);
-                        return CryptoBuffer();
                     }
 
                     BCryptDestroyKey(importKey);
                 }
-                else
+                else               
                 {
                     m_failure = true;
                     AWS_LOGSTREAM_ERROR(KEYWRAP_LOG_TAG, "Failed to import symmetric key with status code " << status);
-                    return CryptoBuffer();
                 }
 
                 return returnBuffer;
