@@ -1,7 +1,17 @@
-/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+/*
+  * Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+  * 
+  * Licensed under the Apache License, Version 2.0 (the "License").
+  * You may not use this file except in compliance with the License.
+  * A copy of the License is located at
+  * 
+  *  http://aws.amazon.com/apache2.0
+  * 
+  * or in the "license" file accompanying this file. This file is distributed
+  * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+  * express or implied. See the License for the specific language governing
+  * permissions and limitations under the License.
+  */
 
 #include <cstring>
 
@@ -9,21 +19,7 @@
 #include <aws/core/utils/crypto/openssl/CryptoImpl.h>
 #include <aws/core/utils/Outcome.h>
 #include <openssl/md5.h>
-
-#ifdef OPENSSL_IS_BORINGSSL
-#ifdef _MSC_VER
-AWS_SUPPRESS_WARNING_PUSH(4201)
-#else
-AWS_SUPPRESS_WARNING_PUSH("-Wpedantic")
-#endif
-#endif
-
 #include <openssl/sha.h>
-
-#ifdef OPENSSL_IS_BORINGSSL
-AWS_SUPPRESS_WARNING_POP
-#endif
-
 #include <openssl/err.h>
 #include <aws/core/utils/logging/LogMacros.h>
 #include <thread>
@@ -41,7 +37,7 @@ namespace Aws
             {
 /**
  * openssl with OPENSSL_VERSION_NUMBER < 0x10100003L made data type details unavailable
- * libressl use openssl with data type details available, but mandatorily set
+ * libressl use openssl with data type details available, but mandatorily set 
  * OPENSSL_VERSION_NUMBER = 0x20000000L, insane!
  * https://github.com/aws/aws-sdk-cpp/pull/507/commits/2c99f1fe0c4b4683280caeb161538d4724d6a179
  */
@@ -60,14 +56,9 @@ namespace Aws
 
                 void init_static_state()
                 {
-#if OPENSSL_VERSION_LESS_1_1 || defined(OPENSSL_IS_BORINGSSL)
-                    ERR_load_crypto_strings();
-#else
-                    OPENSSL_init_crypto(OPENSSL_INIT_LOAD_CRYPTO_STRINGS /*options*/ ,NULL /* OpenSSL init settings*/ );
-#endif
-#if !defined(OPENSSL_IS_BORINGSSL)
+                    ERR_load_CRYPTO_strings();
                     OPENSSL_add_all_algorithms_noconf();
-#endif
+
 #if OPENSSL_VERSION_LESS_1_1
                     if (!CRYPTO_get_locking_callback())
                     {
@@ -122,21 +113,9 @@ namespace Aws
 #endif
             }
 
-            static const char* OPENSSL_LOG_TAG = "OpenSSLCipher";
-
             void SecureRandomBytes_OpenSSLImpl::GetBytes(unsigned char* buffer, size_t bufferSize)
             {
-                if (!bufferSize)
-                {
-                    return;
-                }
-
-                if (!buffer)
-                {
-                    AWS_LOGSTREAM_FATAL(OPENSSL_LOG_TAG, "Secure Random Bytes generator can't generate: " << bufferSize << " bytes with nullptr buffer.");
-                    assert(buffer);
-                    return;
-                }
+                assert(buffer);
 
                 int success = RAND_bytes(buffer, static_cast<int>(bufferSize));
                 if (success != 1)
@@ -145,22 +124,22 @@ namespace Aws
                 }
             }
 
-            class OpensslCtxRAIIGuard
+            class OpensslCtxRAIIGuard 
             {
-            public:
-                OpensslCtxRAIIGuard()
+                public:
+                OpensslCtxRAIIGuard() 
                 {
                     m_ctx = EVP_MD_CTX_create();
                     assert(m_ctx != nullptr);
                 }
 
-                ~OpensslCtxRAIIGuard()
+                ~OpensslCtxRAIIGuard() 
                 {
                     EVP_MD_CTX_destroy(m_ctx);
                     m_ctx = nullptr;
                 }
 
-                EVP_MD_CTX* getResource()
+                EVP_MD_CTX* getResource() 
                 {
                     return m_ctx;
                 }
@@ -172,9 +151,7 @@ namespace Aws
             {
                 OpensslCtxRAIIGuard guard;
                 auto ctx = guard.getResource();
-#if !defined(OPENSSL_IS_BORINGSSL)
                 EVP_MD_CTX_set_flags(ctx, EVP_MD_CTX_FLAG_NON_FIPS_ALLOW);
-#endif
                 EVP_DigestInit_ex(ctx, EVP_md5(), nullptr);
                 EVP_DigestUpdate(ctx, str.c_str(), str.size());
 
@@ -188,9 +165,7 @@ namespace Aws
             {
                 OpensslCtxRAIIGuard guard;
                 auto ctx = guard.getResource();
-#if !defined(OPENSSL_IS_BORINGSSL)
                 EVP_MD_CTX_set_flags(ctx, EVP_MD_CTX_FLAG_NON_FIPS_ALLOW);
-#endif
                 EVP_DigestInit_ex(ctx, EVP_md5(), nullptr);
 
                 auto currentPos = stream.tellg();
@@ -222,56 +197,6 @@ namespace Aws
                 return HashResult(std::move(hash));
             }
 
-            HashResult Sha1OpenSSLImpl::Calculate(const Aws::String& str)
-            {
-                OpensslCtxRAIIGuard guard;
-                auto ctx = guard.getResource();
-                EVP_DigestInit_ex(ctx, EVP_sha1(), nullptr);
-                EVP_DigestUpdate(ctx, str.c_str(), str.size());
-
-                ByteBuffer hash(EVP_MD_size(EVP_sha1()));
-                EVP_DigestFinal(ctx, hash.GetUnderlyingData(), nullptr);
-
-                return HashResult(std::move(hash));
-            }
-
-            HashResult Sha1OpenSSLImpl::Calculate(Aws::IStream& stream)
-            {
-                OpensslCtxRAIIGuard guard;
-                auto ctx = guard.getResource();
-
-                EVP_DigestInit_ex(ctx, EVP_sha1(), nullptr);
-
-                auto currentPos = stream.tellg();
-                if (currentPos == -1)
-                {
-                    currentPos = 0;
-                    stream.clear();
-                }
-
-                stream.seekg(0, stream.beg);
-
-                char streamBuffer[Aws::Utils::Crypto::Hash::INTERNAL_HASH_STREAM_BUFFER_SIZE];
-                while (stream.good())
-                {
-                    stream.read(streamBuffer, Aws::Utils::Crypto::Hash::INTERNAL_HASH_STREAM_BUFFER_SIZE);
-                    auto bytesRead = stream.gcount();
-
-                    if (bytesRead > 0)
-                    {
-                        EVP_DigestUpdate(ctx, streamBuffer, static_cast<size_t>(bytesRead));
-                    }
-                }
-
-                stream.clear();
-                stream.seekg(currentPos, stream.beg);
-
-                ByteBuffer hash(EVP_MD_size(EVP_sha1()));
-                EVP_DigestFinal(ctx, hash.GetUnderlyingData(), nullptr);
-
-                return HashResult(std::move(hash));
-            }
-
             HashResult Sha256OpenSSLImpl::Calculate(const Aws::String& str)
             {
                 OpensslCtxRAIIGuard guard;
@@ -354,7 +279,7 @@ namespace Aws
                 unsigned int length = SHA256_DIGEST_LENGTH;
                 ByteBuffer digest(length);
                 memset(digest.GetUnderlyingData(), 0, length);
-
+                
                 HMACRAIIGuard guard;
                 HMAC_CTX* m_ctx = guard.getResource();
 
@@ -375,6 +300,8 @@ namespace Aws
                 return HashResult(std::move(digest));
             }
 
+            static const char* OPENSSL_LOG_TAG = "OpenSSLCipher";
+
             void LogErrors(const char* logTag = OPENSSL_LOG_TAG)
             {
                 unsigned long errorCode = ERR_get_error();
@@ -431,11 +358,6 @@ namespace Aws
 
             void OpenSSLCipher::Init()
             {
-                if (m_failure)
-                {
-                    return;
-                }
-
                 if (!m_encryptor_ctx)
                 {
                     // EVP_CIPHER_CTX_init() will be called inside EVP_CIPHER_CTX_new().
@@ -456,7 +378,6 @@ namespace Aws
                 {   // _init is the same as _reset after openssl 1.1
                     EVP_CIPHER_CTX_init(m_decryptor_ctx);
                 }
-                m_emptyPlaintext = false;
             }
 
             CryptoBuffer OpenSSLCipher::EncryptBuffer(const CryptoBuffer& unEncryptedData)
@@ -483,6 +404,7 @@ namespace Aws
                 {
                     return CryptoBuffer(encryptedText.GetUnderlyingData(), static_cast<size_t>(lengthWritten));
                 }
+
                 return encryptedText;
             }
 
@@ -490,7 +412,8 @@ namespace Aws
             {
                 if (m_failure)
                 {
-                    AWS_LOGSTREAM_FATAL(OPENSSL_LOG_TAG, "Cipher not properly initialized for encryption finalization. Aborting");
+                    AWS_LOGSTREAM_FATAL(OPENSSL_LOG_TAG,
+                                        "Cipher not properly initialized for encryption finalization. Aborting");
                     return CryptoBuffer();
                 }
 
@@ -525,14 +448,11 @@ namespace Aws
                     return CryptoBuffer();
                 }
 
-                if (lengthWritten == 0)
-                {
-                    m_emptyPlaintext = true;
-                }
                 if (static_cast<size_t>(lengthWritten) < decryptedText.GetLength())
                 {
                     return CryptoBuffer(decryptedText.GetUnderlyingData(), static_cast<size_t>(lengthWritten));
                 }
+
                 return decryptedText;
             }
 
@@ -540,18 +460,14 @@ namespace Aws
             {
                 if (m_failure)
                 {
-                    AWS_LOGSTREAM_FATAL(OPENSSL_LOG_TAG, "Cipher not properly initialized for decryption finalization. Aborting");
+                    AWS_LOGSTREAM_FATAL(OPENSSL_LOG_TAG,
+                                        "Cipher not properly initialized for decryption finalization. Aborting");
                     return CryptoBuffer();
                 }
 
                 CryptoBuffer finalBlock(GetBlockSizeBytes());
                 int writtenSize = static_cast<int>(finalBlock.GetLength());
-                int ret = EVP_DecryptFinal_ex(m_decryptor_ctx, finalBlock.GetUnderlyingData(), &writtenSize);
-#if OPENSSL_VERSION_NUMBER > 0x1010104fL //1.1.1d
-                if (ret <= 0)
-#else
-                if (ret <= 0 && !m_emptyPlaintext) // see details why making exception for empty string at: https://github.com/aws/aws-sdk-cpp/issues/1413
-#endif
+                if (!EVP_DecryptFinal_ex(m_decryptor_ctx, finalBlock.GetUnderlyingData(), &writtenSize))
                 {
                     m_failure = true;
                     LogErrors();
@@ -569,18 +485,9 @@ namespace Aws
             void OpenSSLCipher::Cleanup()
             {
                 m_failure = false;
-                if (m_encryptor_ctx) EVP_CIPHER_CTX_cleanup(m_encryptor_ctx);
-                if (m_decryptor_ctx) EVP_CIPHER_CTX_cleanup(m_decryptor_ctx);
-            }
 
-            bool OpenSSLCipher::CheckKeyAndIVLength(size_t expectedKeyLength, size_t expectedIVLength)
-            {
-                if (!m_failure && ((m_key.GetLength() != expectedKeyLength) || m_initializationVector.GetLength() != expectedIVLength))
-                {
-                    AWS_LOGSTREAM_ERROR(OPENSSL_LOG_TAG, "Expected Key size is: " << expectedKeyLength << " and expected IV size is: " << expectedIVLength);
-                    m_failure = true;
-                }
-                return !m_failure;
+                EVP_CIPHER_CTX_cleanup(m_encryptor_ctx);
+                EVP_CIPHER_CTX_cleanup(m_decryptor_ctx);
             }
 
             size_t AES_CBC_Cipher_OpenSSL::BlockSizeBytes = 16;
@@ -607,11 +514,6 @@ namespace Aws
 
             void AES_CBC_Cipher_OpenSSL::InitCipher()
             {
-                if (m_failure || !CheckKeyAndIVLength(KeyLengthBits/8, BlockSizeBytes))
-                {
-                    return;
-                }
-
                 if (!EVP_EncryptInit_ex(m_encryptor_ctx, EVP_aes_256_cbc(), nullptr, m_key.GetUnderlyingData(),
                                         m_initializationVector.GetUnderlyingData()) ||
                     !EVP_DecryptInit_ex(m_decryptor_ctx, EVP_aes_256_cbc(), nullptr, m_key.GetUnderlyingData(),
@@ -663,11 +565,6 @@ namespace Aws
 
             void AES_CTR_Cipher_OpenSSL::InitCipher()
             {
-                if (m_failure || !CheckKeyAndIVLength(KeyLengthBits/8, BlockSizeBytes))
-                {
-                    return;
-                }
-
                 if (!(EVP_EncryptInit_ex(m_encryptor_ctx, EVP_aes_256_ctr(), nullptr, m_key.GetUnderlyingData(),
                                          m_initializationVector.GetUnderlyingData())
                         && EVP_CIPHER_CTX_set_padding(m_encryptor_ctx, 0)) ||
@@ -703,62 +600,43 @@ namespace Aws
 
             static const char* GCM_LOG_TAG = "AES_GCM_Cipher_OpenSSL";
 
-            AES_GCM_Cipher_OpenSSL::AES_GCM_Cipher_OpenSSL(const CryptoBuffer& key)
-                : OpenSSLCipher(key, IVLengthBytes)
-            {
-                InitCipher();
-            }
-
-            AES_GCM_Cipher_OpenSSL::AES_GCM_Cipher_OpenSSL(const CryptoBuffer& key, const CryptoBuffer* aad)
-                : OpenSSLCipher(key, IVLengthBytes), m_aad(*aad)
+            AES_GCM_Cipher_OpenSSL::AES_GCM_Cipher_OpenSSL(const CryptoBuffer& key) : OpenSSLCipher(key, IVLengthBytes)
             {
                 InitCipher();
             }
 
             AES_GCM_Cipher_OpenSSL::AES_GCM_Cipher_OpenSSL(CryptoBuffer&& key, CryptoBuffer&& initializationVector,
-                                                           CryptoBuffer&& tag, CryptoBuffer&& aad) :
-                    OpenSSLCipher(std::move(key), std::move(initializationVector), std::move(tag)), m_aad(std::move(aad))
+                                                           CryptoBuffer&& tag) :
+                    OpenSSLCipher(std::move(key), std::move(initializationVector), std::move(tag))
             {
                 InitCipher();
             }
 
-            AES_GCM_Cipher_OpenSSL::AES_GCM_Cipher_OpenSSL(const CryptoBuffer& key, const CryptoBuffer& initializationVector,
-                                                           const CryptoBuffer& tag, const CryptoBuffer& aad) :
-                    OpenSSLCipher(key, initializationVector, tag), m_aad(std::move(aad))
+            AES_GCM_Cipher_OpenSSL::AES_GCM_Cipher_OpenSSL(const CryptoBuffer& key,
+                                                           const CryptoBuffer& initializationVector,
+                                                           const CryptoBuffer& tag) :
+                    OpenSSLCipher(key, initializationVector, tag)
             {
                 InitCipher();
             }
 
             CryptoBuffer AES_GCM_Cipher_OpenSSL::FinalizeEncryption()
             {
-                if (m_failure)
-                {
-                    AWS_LOGSTREAM_FATAL(GCM_LOG_TAG, "Cipher not properly initialized for encryption finalization. Aborting");
-                    return CryptoBuffer();
-                }
-
-                int writtenSize = 0;
-                CryptoBuffer finalBlock(GetBlockSizeBytes());
-                EVP_EncryptFinal_ex(m_encryptor_ctx, finalBlock.GetUnderlyingData(), &writtenSize);
-
+                CryptoBuffer const& finalBuffer = OpenSSLCipher::FinalizeEncryption();
                 m_tag = CryptoBuffer(TagLengthBytes);
-                if (!EVP_CIPHER_CTX_ctrl(m_encryptor_ctx, EVP_CTRL_GCM_GET_TAG, static_cast<int>(m_tag.GetLength()),
+                if (!EVP_CIPHER_CTX_ctrl(m_encryptor_ctx, EVP_CTRL_CCM_GET_TAG, static_cast<int>(m_tag.GetLength()),
                                          m_tag.GetUnderlyingData()))
                 {
                     m_failure = true;
                     LogErrors(GCM_LOG_TAG);
+                    return CryptoBuffer();
                 }
 
-                return CryptoBuffer();
+                return finalBuffer;
             }
 
             void AES_GCM_Cipher_OpenSSL::InitCipher()
             {
-                if (m_failure || !CheckKeyAndIVLength(KeyLengthBits/8, IVLengthBytes))
-                {
-                    return;
-                }
-
                 if (!(EVP_EncryptInit_ex(m_encryptor_ctx, EVP_aes_256_gcm(), nullptr, nullptr, nullptr) &&
                         EVP_EncryptInit_ex(m_encryptor_ctx, nullptr, nullptr, m_key.GetUnderlyingData(),
                                            m_initializationVector.GetUnderlyingData()) &&
@@ -773,29 +651,20 @@ namespace Aws
                     return;
                 }
 
-                if (m_aad.GetLength() > 0)
-                {
-                    int outLen = 0;
-                    if(!EVP_EncryptUpdate(m_encryptor_ctx, nullptr, &outLen, m_aad.GetUnderlyingData(), m_aad.GetLength())
-                    || !EVP_DecryptUpdate(m_decryptor_ctx, nullptr, &outLen, m_aad.GetUnderlyingData(), m_aad.GetLength()))
-                    {
-                        m_failure = true;
-                        LogErrors(GCM_LOG_TAG);
-                        return;
-                    }
-                }
-
                 //tag should always be set in GCM decrypt mode
                 if (m_tag.GetLength() > 0)
                 {
                     if (m_tag.GetLength() < TagLengthBytes)
                     {
-                        AWS_LOGSTREAM_ERROR(GCM_LOG_TAG, "Illegal attempt to decrypt an AES GCM payload without a valid tag set: tag length=" << m_tag.GetLength());
+                        AWS_LOGSTREAM_ERROR(GCM_LOG_TAG,
+                                            "Illegal attempt to decrypt an AES GCM payload without a valid tag set: tag length=" <<
+                                                    m_tag.GetLength());
                         m_failure = true;
                         return;
                     }
 
-                    if (!EVP_CIPHER_CTX_ctrl(m_decryptor_ctx, EVP_CTRL_GCM_SET_TAG, static_cast<int>(m_tag.GetLength()), m_tag.GetUnderlyingData()))
+                    if (!EVP_CIPHER_CTX_ctrl(m_decryptor_ctx, EVP_CTRL_GCM_SET_TAG, static_cast<int>(m_tag.GetLength()),
+                                             m_tag.GetUnderlyingData()))
                     {
                         m_failure = true;
                         LogErrors(GCM_LOG_TAG);
@@ -838,10 +707,9 @@ namespace Aws
 
             CryptoBuffer AES_KeyWrap_Cipher_OpenSSL::EncryptBuffer(const CryptoBuffer& plainText)
             {
-                if (!m_failure)
-                {
-                    m_workingKeyBuffer = CryptoBuffer({&m_workingKeyBuffer, (CryptoBuffer*) &plainText});
-                }
+                assert(!m_failure);
+
+                m_workingKeyBuffer = CryptoBuffer({&m_workingKeyBuffer, (CryptoBuffer*) &plainText});
                 return CryptoBuffer();
             }
 
@@ -861,7 +729,7 @@ namespace Aws
                 }
 
                 //the following is an in place implementation of
-                //RFC 3394 using the alternate in-place implementation.
+                //RFC 3394 using the alternate in-place implementation.	
                 //we use one in-place buffer instead of the copy at the end.
                 //the one letter variable names are meant to directly reflect the variables in the RFC
                 CryptoBuffer cipherText(m_workingKeyBuffer.GetLength() + BlockSizeBytes);
@@ -919,10 +787,10 @@ namespace Aws
 
             CryptoBuffer AES_KeyWrap_Cipher_OpenSSL::DecryptBuffer(const CryptoBuffer& cipherText)
             {
-                if (!m_failure)
-                {
-                    m_workingKeyBuffer = CryptoBuffer({&m_workingKeyBuffer, (CryptoBuffer*)&cipherText});
-                }
+                assert(!m_failure);
+
+                m_workingKeyBuffer = CryptoBuffer({&m_workingKeyBuffer, (CryptoBuffer*)&cipherText});
+
                 return CryptoBuffer();
             }
 
@@ -1011,11 +879,6 @@ namespace Aws
 
             void AES_KeyWrap_Cipher_OpenSSL::InitCipher()
             {
-                if (m_failure || !CheckKeyAndIVLength(KeyLengthBits/8, 0))
-                {
-                    return;
-                }
-
                 if (!(EVP_EncryptInit_ex(m_encryptor_ctx, EVP_aes_256_ecb(), nullptr, m_key.GetUnderlyingData(), nullptr) &&
                         EVP_CIPHER_CTX_set_padding(m_encryptor_ctx, 0)) ||
                     !(EVP_DecryptInit_ex(m_decryptor_ctx, EVP_aes_256_ecb(), nullptr, m_key.GetUnderlyingData(), nullptr) &&
