@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/datasync/DataSync_EXPORTS.h>
@@ -9,8 +19,6 @@
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/datasync/model/Options.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/datasync/model/TaskSchedule.h>
-#include <aws/datasync/model/FilterRule.h>
 #include <aws/datasync/model/TagListEntry.h>
 #include <utility>
 
@@ -30,7 +38,7 @@ namespace Model
   {
   public:
     CreateTaskRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -126,49 +134,105 @@ namespace Model
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that is
-     * used to monitor and log events in the task. </p>
+     * used to monitor and log events in the task. For more information on these
+     * groups, see <a
+     * href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html">Working
+     * with Log Groups and Log Streams</a> in the <i>Amazon CloudWatch User Guide. </i>
+     * </p> <p>For more information about how to useCloudWatchLogs with DataSync, see
+     * <a
+     * href="https://docs.aws.amazon.com/datasync/latest/userguide/monitor-datasync.html">Monitoring
+     * Your Task</a>.</p>
      */
     inline const Aws::String& GetCloudWatchLogGroupArn() const{ return m_cloudWatchLogGroupArn; }
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that is
-     * used to monitor and log events in the task. </p>
+     * used to monitor and log events in the task. For more information on these
+     * groups, see <a
+     * href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html">Working
+     * with Log Groups and Log Streams</a> in the <i>Amazon CloudWatch User Guide. </i>
+     * </p> <p>For more information about how to useCloudWatchLogs with DataSync, see
+     * <a
+     * href="https://docs.aws.amazon.com/datasync/latest/userguide/monitor-datasync.html">Monitoring
+     * Your Task</a>.</p>
      */
     inline bool CloudWatchLogGroupArnHasBeenSet() const { return m_cloudWatchLogGroupArnHasBeenSet; }
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that is
-     * used to monitor and log events in the task. </p>
+     * used to monitor and log events in the task. For more information on these
+     * groups, see <a
+     * href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html">Working
+     * with Log Groups and Log Streams</a> in the <i>Amazon CloudWatch User Guide. </i>
+     * </p> <p>For more information about how to useCloudWatchLogs with DataSync, see
+     * <a
+     * href="https://docs.aws.amazon.com/datasync/latest/userguide/monitor-datasync.html">Monitoring
+     * Your Task</a>.</p>
      */
     inline void SetCloudWatchLogGroupArn(const Aws::String& value) { m_cloudWatchLogGroupArnHasBeenSet = true; m_cloudWatchLogGroupArn = value; }
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that is
-     * used to monitor and log events in the task. </p>
+     * used to monitor and log events in the task. For more information on these
+     * groups, see <a
+     * href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html">Working
+     * with Log Groups and Log Streams</a> in the <i>Amazon CloudWatch User Guide. </i>
+     * </p> <p>For more information about how to useCloudWatchLogs with DataSync, see
+     * <a
+     * href="https://docs.aws.amazon.com/datasync/latest/userguide/monitor-datasync.html">Monitoring
+     * Your Task</a>.</p>
      */
     inline void SetCloudWatchLogGroupArn(Aws::String&& value) { m_cloudWatchLogGroupArnHasBeenSet = true; m_cloudWatchLogGroupArn = std::move(value); }
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that is
-     * used to monitor and log events in the task. </p>
+     * used to monitor and log events in the task. For more information on these
+     * groups, see <a
+     * href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html">Working
+     * with Log Groups and Log Streams</a> in the <i>Amazon CloudWatch User Guide. </i>
+     * </p> <p>For more information about how to useCloudWatchLogs with DataSync, see
+     * <a
+     * href="https://docs.aws.amazon.com/datasync/latest/userguide/monitor-datasync.html">Monitoring
+     * Your Task</a>.</p>
      */
     inline void SetCloudWatchLogGroupArn(const char* value) { m_cloudWatchLogGroupArnHasBeenSet = true; m_cloudWatchLogGroupArn.assign(value); }
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that is
-     * used to monitor and log events in the task. </p>
+     * used to monitor and log events in the task. For more information on these
+     * groups, see <a
+     * href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html">Working
+     * with Log Groups and Log Streams</a> in the <i>Amazon CloudWatch User Guide. </i>
+     * </p> <p>For more information about how to useCloudWatchLogs with DataSync, see
+     * <a
+     * href="https://docs.aws.amazon.com/datasync/latest/userguide/monitor-datasync.html">Monitoring
+     * Your Task</a>.</p>
      */
     inline CreateTaskRequest& WithCloudWatchLogGroupArn(const Aws::String& value) { SetCloudWatchLogGroupArn(value); return *this;}
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that is
-     * used to monitor and log events in the task. </p>
+     * used to monitor and log events in the task. For more information on these
+     * groups, see <a
+     * href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html">Working
+     * with Log Groups and Log Streams</a> in the <i>Amazon CloudWatch User Guide. </i>
+     * </p> <p>For more information about how to useCloudWatchLogs with DataSync, see
+     * <a
+     * href="https://docs.aws.amazon.com/datasync/latest/userguide/monitor-datasync.html">Monitoring
+     * Your Task</a>.</p>
      */
     inline CreateTaskRequest& WithCloudWatchLogGroupArn(Aws::String&& value) { SetCloudWatchLogGroupArn(std::move(value)); return *this;}
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that is
-     * used to monitor and log events in the task. </p>
+     * used to monitor and log events in the task. For more information on these
+     * groups, see <a
+     * href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html">Working
+     * with Log Groups and Log Streams</a> in the <i>Amazon CloudWatch User Guide. </i>
+     * </p> <p>For more information about how to useCloudWatchLogs with DataSync, see
+     * <a
+     * href="https://docs.aws.amazon.com/datasync/latest/userguide/monitor-datasync.html">Monitoring
+     * Your Task</a>.</p>
      */
     inline CreateTaskRequest& WithCloudWatchLogGroupArn(const char* value) { SetCloudWatchLogGroupArn(value); return *this;}
 
@@ -228,8 +292,8 @@ namespace Model
      * You can configure these options to preserve metadata such as user ID (UID) and
      * group ID (GID), file permissions, data integrity verification, and so on.</p>
      * <p>For each individual task execution, you can override these options by
-     * specifying the <code>OverrideOptions</code> before starting the task execution.
-     * For more information, see the operation. </p>
+     * specifying the <code>OverrideOptions</code> before starting a the task
+     * execution. For more information, see the operation. </p>
      */
     inline const Options& GetOptions() const{ return m_options; }
 
@@ -239,8 +303,8 @@ namespace Model
      * You can configure these options to preserve metadata such as user ID (UID) and
      * group ID (GID), file permissions, data integrity verification, and so on.</p>
      * <p>For each individual task execution, you can override these options by
-     * specifying the <code>OverrideOptions</code> before starting the task execution.
-     * For more information, see the operation. </p>
+     * specifying the <code>OverrideOptions</code> before starting a the task
+     * execution. For more information, see the operation. </p>
      */
     inline bool OptionsHasBeenSet() const { return m_optionsHasBeenSet; }
 
@@ -250,8 +314,8 @@ namespace Model
      * You can configure these options to preserve metadata such as user ID (UID) and
      * group ID (GID), file permissions, data integrity verification, and so on.</p>
      * <p>For each individual task execution, you can override these options by
-     * specifying the <code>OverrideOptions</code> before starting the task execution.
-     * For more information, see the operation. </p>
+     * specifying the <code>OverrideOptions</code> before starting a the task
+     * execution. For more information, see the operation. </p>
      */
     inline void SetOptions(const Options& value) { m_optionsHasBeenSet = true; m_options = value; }
 
@@ -261,8 +325,8 @@ namespace Model
      * You can configure these options to preserve metadata such as user ID (UID) and
      * group ID (GID), file permissions, data integrity verification, and so on.</p>
      * <p>For each individual task execution, you can override these options by
-     * specifying the <code>OverrideOptions</code> before starting the task execution.
-     * For more information, see the operation. </p>
+     * specifying the <code>OverrideOptions</code> before starting a the task
+     * execution. For more information, see the operation. </p>
      */
     inline void SetOptions(Options&& value) { m_optionsHasBeenSet = true; m_options = std::move(value); }
 
@@ -272,8 +336,8 @@ namespace Model
      * You can configure these options to preserve metadata such as user ID (UID) and
      * group ID (GID), file permissions, data integrity verification, and so on.</p>
      * <p>For each individual task execution, you can override these options by
-     * specifying the <code>OverrideOptions</code> before starting the task execution.
-     * For more information, see the operation. </p>
+     * specifying the <code>OverrideOptions</code> before starting a the task
+     * execution. For more information, see the operation. </p>
      */
     inline CreateTaskRequest& WithOptions(const Options& value) { SetOptions(value); return *this;}
 
@@ -283,120 +347,12 @@ namespace Model
      * You can configure these options to preserve metadata such as user ID (UID) and
      * group ID (GID), file permissions, data integrity verification, and so on.</p>
      * <p>For each individual task execution, you can override these options by
-     * specifying the <code>OverrideOptions</code> before starting the task execution.
-     * For more information, see the operation. </p>
+     * specifying the <code>OverrideOptions</code> before starting a the task
+     * execution. For more information, see the operation. </p>
      */
     inline CreateTaskRequest& WithOptions(Options&& value) { SetOptions(std::move(value)); return *this;}
 
 
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example,
-     * <code>"/folder1|/folder2"</code> </p> <p> </p>
-     */
-    inline const Aws::Vector<FilterRule>& GetExcludes() const{ return m_excludes; }
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example,
-     * <code>"/folder1|/folder2"</code> </p> <p> </p>
-     */
-    inline bool ExcludesHasBeenSet() const { return m_excludesHasBeenSet; }
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example,
-     * <code>"/folder1|/folder2"</code> </p> <p> </p>
-     */
-    inline void SetExcludes(const Aws::Vector<FilterRule>& value) { m_excludesHasBeenSet = true; m_excludes = value; }
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example,
-     * <code>"/folder1|/folder2"</code> </p> <p> </p>
-     */
-    inline void SetExcludes(Aws::Vector<FilterRule>&& value) { m_excludesHasBeenSet = true; m_excludes = std::move(value); }
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example,
-     * <code>"/folder1|/folder2"</code> </p> <p> </p>
-     */
-    inline CreateTaskRequest& WithExcludes(const Aws::Vector<FilterRule>& value) { SetExcludes(value); return *this;}
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example,
-     * <code>"/folder1|/folder2"</code> </p> <p> </p>
-     */
-    inline CreateTaskRequest& WithExcludes(Aws::Vector<FilterRule>&& value) { SetExcludes(std::move(value)); return *this;}
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example,
-     * <code>"/folder1|/folder2"</code> </p> <p> </p>
-     */
-    inline CreateTaskRequest& AddExcludes(const FilterRule& value) { m_excludesHasBeenSet = true; m_excludes.push_back(value); return *this; }
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example,
-     * <code>"/folder1|/folder2"</code> </p> <p> </p>
-     */
-    inline CreateTaskRequest& AddExcludes(FilterRule&& value) { m_excludesHasBeenSet = true; m_excludes.push_back(std::move(value)); return *this; }
-
-
-    /**
-     * <p>Specifies a schedule used to periodically transfer files from a source to a
-     * destination location. The schedule should be specified in UTC time. For more
-     * information, see <a>task-scheduling</a>.</p>
-     */
-    inline const TaskSchedule& GetSchedule() const{ return m_schedule; }
-
-    /**
-     * <p>Specifies a schedule used to periodically transfer files from a source to a
-     * destination location. The schedule should be specified in UTC time. For more
-     * information, see <a>task-scheduling</a>.</p>
-     */
-    inline bool ScheduleHasBeenSet() const { return m_scheduleHasBeenSet; }
-
-    /**
-     * <p>Specifies a schedule used to periodically transfer files from a source to a
-     * destination location. The schedule should be specified in UTC time. For more
-     * information, see <a>task-scheduling</a>.</p>
-     */
-    inline void SetSchedule(const TaskSchedule& value) { m_scheduleHasBeenSet = true; m_schedule = value; }
-
-    /**
-     * <p>Specifies a schedule used to periodically transfer files from a source to a
-     * destination location. The schedule should be specified in UTC time. For more
-     * information, see <a>task-scheduling</a>.</p>
-     */
-    inline void SetSchedule(TaskSchedule&& value) { m_scheduleHasBeenSet = true; m_schedule = std::move(value); }
-
-    /**
-     * <p>Specifies a schedule used to periodically transfer files from a source to a
-     * destination location. The schedule should be specified in UTC time. For more
-     * information, see <a>task-scheduling</a>.</p>
-     */
-    inline CreateTaskRequest& WithSchedule(const TaskSchedule& value) { SetSchedule(value); return *this;}
-
-    /**
-     * <p>Specifies a schedule used to periodically transfer files from a source to a
-     * destination location. The schedule should be specified in UTC time. For more
-     * information, see <a>task-scheduling</a>.</p>
-     */
-    inline CreateTaskRequest& WithSchedule(TaskSchedule&& value) { SetSchedule(std::move(value)); return *this;}
-
-
     /**
      * <p>The key-value pair that represents the tag that you want to add to the
      * resource. The value can be an empty string. </p>
@@ -462,12 +418,6 @@ namespace Model
     Options m_options;
     bool m_optionsHasBeenSet;
 
-    Aws::Vector<FilterRule> m_excludes;
-    bool m_excludesHasBeenSet;
-
-    TaskSchedule m_schedule;
-    bool m_scheduleHasBeenSet;
-
     Aws::Vector<TagListEntry> m_tags;
     bool m_tagsHasBeenSet;
   };
