@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/datasync/DataSync_EXPORTS.h>
@@ -25,7 +35,7 @@ namespace Model
   {
   public:
     DescribeLocationEfsRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -38,57 +48,49 @@ namespace Model
 
 
     /**
-     * <p>The Amazon Resource Name (ARN) of the Amazon EFS file system location that
-     * you want information about.</p>
+     * <p>The Amazon Resource Name (ARN) of the EFS location to describe.</p>
      */
     inline const Aws::String& GetLocationArn() const{ return m_locationArn; }
 
     /**
-     * <p>The Amazon Resource Name (ARN) of the Amazon EFS file system location that
-     * you want information about.</p>
+     * <p>The Amazon Resource Name (ARN) of the EFS location to describe.</p>
      */
     inline bool LocationArnHasBeenSet() const { return m_locationArnHasBeenSet; }
 
     /**
-     * <p>The Amazon Resource Name (ARN) of the Amazon EFS file system location that
-     * you want information about.</p>
+     * <p>The Amazon Resource Name (ARN) of the EFS location to describe.</p>
      */
     inline void SetLocationArn(const Aws::String& value) { m_locationArnHasBeenSet = true; m_locationArn = value; }
 
     /**
-     * <p>The Amazon Resource Name (ARN) of the Amazon EFS file system location that
-     * you want information about.</p>
+     * <p>The Amazon Resource Name (ARN) of the EFS location to describe.</p>
      */
     inline void SetLocationArn(Aws::String&& value) { m_locationArnHasBeenSet = true; m_locationArn = std::move(value); }
 
     /**
-     * <p>The Amazon Resource Name (ARN) of the Amazon EFS file system location that
-     * you want information about.</p>
+     * <p>The Amazon Resource Name (ARN) of the EFS location to describe.</p>
      */
     inline void SetLocationArn(const char* value) { m_locationArnHasBeenSet = true; m_locationArn.assign(value); }
 
     /**
-     * <p>The Amazon Resource Name (ARN) of the Amazon EFS file system location that
-     * you want information about.</p>
+     * <p>The Amazon Resource Name (ARN) of the EFS location to describe.</p>
      */
     inline DescribeLocationEfsRequest& WithLocationArn(const Aws::String& value) { SetLocationArn(value); return *this;}
 
     /**
-     * <p>The Amazon Resource Name (ARN) of the Amazon EFS file system location that
-     * you want information about.</p>
+     * <p>The Amazon Resource Name (ARN) of the EFS location to describe.</p>
      */
     inline DescribeLocationEfsRequest& WithLocationArn(Aws::String&& value) { SetLocationArn(std::move(value)); return *this;}
 
     /**
-     * <p>The Amazon Resource Name (ARN) of the Amazon EFS file system location that
-     * you want information about.</p>
+     * <p>The Amazon Resource Name (ARN) of the EFS location to describe.</p>
      */
     inline DescribeLocationEfsRequest& WithLocationArn(const char* value) { SetLocationArn(value); return *this;}
 
   private:
 
     Aws::String m_locationArn;
-    bool m_locationArnHasBeenSet = false;
+    bool m_locationArnHasBeenSet;
   };
 
 } // namespace Model
