@@ -1,17 +1,25 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/datasync/DataSync_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/datasync/model/TaskExecutionStatus.h>
 #include <aws/datasync/model/Options.h>
-#include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/core/utils/DateTime.h>
 #include <aws/datasync/model/TaskExecutionResultDetail.h>
-#include <aws/datasync/model/FilterRule.h>
 #include <utility>
 
 namespace Aws
@@ -48,9 +56,9 @@ namespace Model
      * <code>TaskExecutionArn</code> is hierarchical and includes <code>TaskArn</code>
      * for the task that was executed. </p> <p>For example, a
      * <code>TaskExecution</code> value with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
      * executed the task with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2</code>.
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2</code>.
      * </p>
      */
     inline const Aws::String& GetTaskExecutionArn() const{ return m_taskExecutionArn; }
@@ -60,9 +68,9 @@ namespace Model
      * <code>TaskExecutionArn</code> is hierarchical and includes <code>TaskArn</code>
      * for the task that was executed. </p> <p>For example, a
      * <code>TaskExecution</code> value with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
      * executed the task with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2</code>.
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2</code>.
      * </p>
      */
     inline void SetTaskExecutionArn(const Aws::String& value) { m_taskExecutionArn = value; }
@@ -72,9 +80,9 @@ namespace Model
      * <code>TaskExecutionArn</code> is hierarchical and includes <code>TaskArn</code>
      * for the task that was executed. </p> <p>For example, a
      * <code>TaskExecution</code> value with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
      * executed the task with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2</code>.
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2</code>.
      * </p>
      */
     inline void SetTaskExecutionArn(Aws::String&& value) { m_taskExecutionArn = std::move(value); }
@@ -84,9 +92,9 @@ namespace Model
      * <code>TaskExecutionArn</code> is hierarchical and includes <code>TaskArn</code>
      * for the task that was executed. </p> <p>For example, a
      * <code>TaskExecution</code> value with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
      * executed the task with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2</code>.
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2</code>.
      * </p>
      */
     inline void SetTaskExecutionArn(const char* value) { m_taskExecutionArn.assign(value); }
@@ -96,9 +104,9 @@ namespace Model
      * <code>TaskExecutionArn</code> is hierarchical and includes <code>TaskArn</code>
      * for the task that was executed. </p> <p>For example, a
      * <code>TaskExecution</code> value with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
      * executed the task with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2</code>.
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2</code>.
      * </p>
      */
     inline DescribeTaskExecutionResult& WithTaskExecutionArn(const Aws::String& value) { SetTaskExecutionArn(value); return *this;}
@@ -108,9 +116,9 @@ namespace Model
      * <code>TaskExecutionArn</code> is hierarchical and includes <code>TaskArn</code>
      * for the task that was executed. </p> <p>For example, a
      * <code>TaskExecution</code> value with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
      * executed the task with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2</code>.
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2</code>.
      * </p>
      */
     inline DescribeTaskExecutionResult& WithTaskExecutionArn(Aws::String&& value) { SetTaskExecutionArn(std::move(value)); return *this;}
@@ -120,46 +128,46 @@ namespace Model
      * <code>TaskExecutionArn</code> is hierarchical and includes <code>TaskArn</code>
      * for the task that was executed. </p> <p>For example, a
      * <code>TaskExecution</code> value with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019b</code>
      * executed the task with the ARN
-     * <code>arn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2</code>.
+     * <code>arn:aws:sync:us-east-1:209870788375:task/task-0208075f79cedf4a2</code>.
      * </p>
      */
     inline DescribeTaskExecutionResult& WithTaskExecutionArn(const char* value) { SetTaskExecutionArn(value); return *this;}
 
 
     /**
-     * <p>The status of the task execution. </p> <p>For detailed information about task
-     * execution statuses, see Understanding Task Statuses in the <i>DataSync User
-     * Guide.</i> </p>
+     * <p>The status of the task. For detailed information about sync statuses, see <a
+     * href="https://docs.aws.amazon.com/sync-service/latest/userguide/understand-sync-task-statuses.html">Understanding
+     * Sync Task Statuses</a>.</p>
      */
     inline const TaskExecutionStatus& GetStatus() const{ return m_status; }
 
     /**
-     * <p>The status of the task execution. </p> <p>For detailed information about task
-     * execution statuses, see Understanding Task Statuses in the <i>DataSync User
-     * Guide.</i> </p>
+     * <p>The status of the task. For detailed information about sync statuses, see <a
+     * href="https://docs.aws.amazon.com/sync-service/latest/userguide/understand-sync-task-statuses.html">Understanding
+     * Sync Task Statuses</a>.</p>
      */
     inline void SetStatus(const TaskExecutionStatus& value) { m_status = value; }
 
     /**
-     * <p>The status of the task execution. </p> <p>For detailed information about task
-     * execution statuses, see Understanding Task Statuses in the <i>DataSync User
-     * Guide.</i> </p>
+     * <p>The status of the task. For detailed information about sync statuses, see <a
+     * href="https://docs.aws.amazon.com/sync-service/latest/userguide/understand-sync-task-statuses.html">Understanding
+     * Sync Task Statuses</a>.</p>
      */
     inline void SetStatus(TaskExecutionStatus&& value) { m_status = std::move(value); }
 
     /**
-     * <p>The status of the task execution. </p> <p>For detailed information about task
-     * execution statuses, see Understanding Task Statuses in the <i>DataSync User
-     * Guide.</i> </p>
+     * <p>The status of the task. For detailed information about sync statuses, see <a
+     * href="https://docs.aws.amazon.com/sync-service/latest/userguide/understand-sync-task-statuses.html">Understanding
+     * Sync Task Statuses</a>.</p>
      */
     inline DescribeTaskExecutionResult& WithStatus(const TaskExecutionStatus& value) { SetStatus(value); return *this;}
 
     /**
-     * <p>The status of the task execution. </p> <p>For detailed information about task
-     * execution statuses, see Understanding Task Statuses in the <i>DataSync User
-     * Guide.</i> </p>
+     * <p>The status of the task. For detailed information about sync statuses, see <a
+     * href="https://docs.aws.amazon.com/sync-service/latest/userguide/understand-sync-task-statuses.html">Understanding
+     * Sync Task Statuses</a>.</p>
      */
     inline DescribeTaskExecutionResult& WithStatus(TaskExecutionStatus&& value) { SetStatus(std::move(value)); return *this;}
 
@@ -180,120 +188,6 @@ namespace Model
     inline DescribeTaskExecutionResult& WithOptions(Options&& value) { SetOptions(std::move(value)); return *this;}
 
 
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example:
-     * <code>"/folder1|/folder2"</code> </p>
-     */
-    inline const Aws::Vector<FilterRule>& GetExcludes() const{ return m_excludes; }
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example:
-     * <code>"/folder1|/folder2"</code> </p>
-     */
-    inline void SetExcludes(const Aws::Vector<FilterRule>& value) { m_excludes = value; }
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example:
-     * <code>"/folder1|/folder2"</code> </p>
-     */
-    inline void SetExcludes(Aws::Vector<FilterRule>&& value) { m_excludes = std::move(value); }
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example:
-     * <code>"/folder1|/folder2"</code> </p>
-     */
-    inline DescribeTaskExecutionResult& WithExcludes(const Aws::Vector<FilterRule>& value) { SetExcludes(value); return *this;}
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example:
-     * <code>"/folder1|/folder2"</code> </p>
-     */
-    inline DescribeTaskExecutionResult& WithExcludes(Aws::Vector<FilterRule>&& value) { SetExcludes(std::move(value)); return *this;}
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example:
-     * <code>"/folder1|/folder2"</code> </p>
-     */
-    inline DescribeTaskExecutionResult& AddExcludes(const FilterRule& value) { m_excludes.push_back(value); return *this; }
-
-    /**
-     * <p>A list of filter rules that determines which files to exclude from a task.
-     * The list should contain a single filter string that consists of the patterns to
-     * exclude. The patterns are delimited by "|" (that is, a pipe), for example:
-     * <code>"/folder1|/folder2"</code> </p>
-     */
-    inline DescribeTaskExecutionResult& AddExcludes(FilterRule&& value) { m_excludes.push_back(std::move(value)); return *this; }
-
-
-    /**
-     * <p>A list of filter rules that determines which files to include when running a
-     * task. The list should contain a single filter string that consists of the
-     * patterns to include. The patterns are delimited by "|" (that is, a pipe), for
-     * example: <code>"/folder1|/folder2"</code> </p>
-     */
-    inline const Aws::Vector<FilterRule>& GetIncludes() const{ return m_includes; }
-
-    /**
-     * <p>A list of filter rules that determines which files to include when running a
-     * task. The list should contain a single filter string that consists of the
-     * patterns to include. The patterns are delimited by "|" (that is, a pipe), for
-     * example: <code>"/folder1|/folder2"</code> </p>
-     */
-    inline void SetIncludes(const Aws::Vector<FilterRule>& value) { m_includes = value; }
-
-    /**
-     * <p>A list of filter rules that determines which files to include when running a
-     * task. The list should contain a single filter string that consists of the
-     * patterns to include. The patterns are delimited by "|" (that is, a pipe), for
-     * example: <code>"/folder1|/folder2"</code> </p>
-     */
-    inline void SetIncludes(Aws::Vector<FilterRule>&& value) { m_includes = std::move(value); }
-
-    /**
-     * <p>A list of filter rules that determines which files to include when running a
-     * task. The list should contain a single filter string that consists of the
-     * patterns to include. The patterns are delimited by "|" (that is, a pipe), for
-     * example: <code>"/folder1|/folder2"</code> </p>
-     */
-    inline DescribeTaskExecutionResult& WithIncludes(const Aws::Vector<FilterRule>& value) { SetIncludes(value); return *this;}
-
-    /**
-     * <p>A list of filter rules that determines which files to include when running a
-     * task. The list should contain a single filter string that consists of the
-     * patterns to include. The patterns are delimited by "|" (that is, a pipe), for
-     * example: <code>"/folder1|/folder2"</code> </p>
-     */
-    inline DescribeTaskExecutionResult& WithIncludes(Aws::Vector<FilterRule>&& value) { SetIncludes(std::move(value)); return *this;}
-
-    /**
-     * <p>A list of filter rules that determines which files to include when running a
-     * task. The list should contain a single filter string that consists of the
-     * patterns to include. The patterns are delimited by "|" (that is, a pipe), for
-     * example: <code>"/folder1|/folder2"</code> </p>
-     */
-    inline DescribeTaskExecutionResult& AddIncludes(const FilterRule& value) { m_includes.push_back(value); return *this; }
-
-    /**
-     * <p>A list of filter rules that determines which files to include when running a
-     * task. The list should contain a single filter string that consists of the
-     * patterns to include. The patterns are delimited by "|" (that is, a pipe), for
-     * example: <code>"/folder1|/folder2"</code> </p>
-     */
-    inline DescribeTaskExecutionResult& AddIncludes(FilterRule&& value) { m_includes.push_back(std::move(value)); return *this; }
-
-
     /**
      * <p>The time that the task execution was started.</p>
      */
@@ -405,20 +299,20 @@ namespace Model
 
 
     /**
-     * <p>The number of logical bytes written to the destination Amazon Web Services
-     * storage resource.</p>
+     * <p>The number of logical bytes written to the destination AWS storage
+     * resource.</p>
      */
     inline long long GetBytesWritten() const{ return m_bytesWritten; }
 
     /**
-     * <p>The number of logical bytes written to the destination Amazon Web Services
-     * storage resource.</p>
+     * <p>The number of logical bytes written to the destination AWS storage
+     * resource.</p>
      */
     inline void SetBytesWritten(long long value) { m_bytesWritten = value; }
 
     /**
-     * <p>The number of logical bytes written to the destination Amazon Web Services
-     * storage resource.</p>
+     * <p>The number of logical bytes written to the destination AWS storage
+     * resource.</p>
      */
     inline DescribeTaskExecutionResult& WithBytesWritten(long long value) { SetBytesWritten(value); return *this;}
 
@@ -464,28 +358,6 @@ namespace Model
      */
     inline DescribeTaskExecutionResult& WithResult(TaskExecutionResultDetail&& value) { SetResult(std::move(value)); return *this;}
 
-
-    /**
-     * <p>The physical number of bytes transferred over the network after compression
-     * was applied. In most cases, this number is less than
-     * <code>BytesTransferred</code>.</p>
-     */
-    inline long long GetBytesCompressed() const{ return m_bytesCompressed; }
-
-    /**
-     * <p>The physical number of bytes transferred over the network after compression
-     * was applied. In most cases, this number is less than
-     * <code>BytesTransferred</code>.</p>
-     */
-    inline void SetBytesCompressed(long long value) { m_bytesCompressed = value; }
-
-    /**
-     * <p>The physical number of bytes transferred over the network after compression
-     * was applied. In most cases, this number is less than
-     * <code>BytesTransferred</code>.</p>
-     */
-    inline DescribeTaskExecutionResult& WithBytesCompressed(long long value) { SetBytesCompressed(value); return *this;}
-
   private:
 
     Aws::String m_taskExecutionArn;
@@ -494,10 +366,6 @@ namespace Model
 
     Options m_options;
 
-    Aws::Vector<FilterRule> m_excludes;
-
-    Aws::Vector<FilterRule> m_includes;
-
     Aws::Utils::DateTime m_startTime;
 
     long long m_estimatedFilesToTransfer;
@@ -511,8 +379,6 @@ namespace Model
     long long m_bytesTransferred;
 
     TaskExecutionResultDetail m_result;
-
-    long long m_bytesCompressed;
   };
 
 } // namespace Model
