@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/datasync/DataSync_EXPORTS.h>
@@ -40,54 +50,54 @@ namespace Model
 
 
     /**
-     * <p>ARNs of the agents to use for an NFS location.</p>
+     * <p>ARNs)of the agents to use for an NFS location.</p>
      */
     inline const Aws::Vector<Aws::String>& GetAgentArns() const{ return m_agentArns; }
 
     /**
-     * <p>ARNs of the agents to use for an NFS location.</p>
+     * <p>ARNs)of the agents to use for an NFS location.</p>
      */
     inline bool AgentArnsHasBeenSet() const { return m_agentArnsHasBeenSet; }
 
     /**
-     * <p>ARNs of the agents to use for an NFS location.</p>
+     * <p>ARNs)of the agents to use for an NFS location.</p>
      */
     inline void SetAgentArns(const Aws::Vector<Aws::String>& value) { m_agentArnsHasBeenSet = true; m_agentArns = value; }
 
     /**
-     * <p>ARNs of the agents to use for an NFS location.</p>
+     * <p>ARNs)of the agents to use for an NFS location.</p>
      */
     inline void SetAgentArns(Aws::Vector<Aws::String>&& value) { m_agentArnsHasBeenSet = true; m_agentArns = std::move(value); }
 
     /**
-     * <p>ARNs of the agents to use for an NFS location.</p>
+     * <p>ARNs)of the agents to use for an NFS location.</p>
      */
     inline OnPremConfig& WithAgentArns(const Aws::Vector<Aws::String>& value) { SetAgentArns(value); return *this;}
 
     /**
-     * <p>ARNs of the agents to use for an NFS location.</p>
+     * <p>ARNs)of the agents to use for an NFS location.</p>
      */
     inline OnPremConfig& WithAgentArns(Aws::Vector<Aws::String>&& value) { SetAgentArns(std::move(value)); return *this;}
 
     /**
-     * <p>ARNs of the agents to use for an NFS location.</p>
+     * <p>ARNs)of the agents to use for an NFS location.</p>
      */
     inline OnPremConfig& AddAgentArns(const Aws::String& value) { m_agentArnsHasBeenSet = true; m_agentArns.push_back(value); return *this; }
 
     /**
-     * <p>ARNs of the agents to use for an NFS location.</p>
+     * <p>ARNs)of the agents to use for an NFS location.</p>
      */
     inline OnPremConfig& AddAgentArns(Aws::String&& value) { m_agentArnsHasBeenSet = true; m_agentArns.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>ARNs of the agents to use for an NFS location.</p>
+     * <p>ARNs)of the agents to use for an NFS location.</p>
      */
     inline OnPremConfig& AddAgentArns(const char* value) { m_agentArnsHasBeenSet = true; m_agentArns.push_back(value); return *this; }
 
   private:
 
     Aws::Vector<Aws::String> m_agentArns;
-    bool m_agentArnsHasBeenSet = false;
+    bool m_agentArnsHasBeenSet;
   };
 
 } // namespace Model
