@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/datasync/model/ListLocationsRequest.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -15,8 +25,7 @@ using namespace Aws::Utils;
 ListLocationsRequest::ListLocationsRequest() : 
     m_maxResults(0),
     m_maxResultsHasBeenSet(false),
-    m_nextTokenHasBeenSet(false),
-    m_filtersHasBeenSet(false)
+    m_nextTokenHasBeenSet(false)
 {
 }
 
@@ -36,17 +45,6 @@ Aws::String ListLocationsRequest::SerializePayload() const
 
   }
 
-  if(m_filtersHasBeenSet)
-  {
-   Array<JsonValue> filtersJsonList(m_filters.size());
-   for(unsigned filtersIndex = 0; filtersIndex < filtersJsonList.GetLength(); ++filtersIndex)
-   {
-     filtersJsonList[filtersIndex].AsObject(m_filters[filtersIndex].Jsonize());
-   }
-   payload.WithArray("Filters", std::move(filtersJsonList));
-
-  }
-
   return payload.View().WriteReadable();
 }
 
