@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/directconnect/DirectConnect_EXPORTS.h>
@@ -9,8 +19,6 @@
 #include <aws/directconnect/model/ConnectionState.h>
 #include <aws/core/utils/DateTime.h>
 #include <aws/directconnect/model/HasLogicalRedundancy.h>
-#include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/directconnect/model/Tag.h>
 #include <utility>
 
 namespace Aws
@@ -604,78 +612,6 @@ namespace Model
      */
     inline CreateConnectionResult& WithHasLogicalRedundancy(HasLogicalRedundancy&& value) { SetHasLogicalRedundancy(std::move(value)); return *this;}
 
-
-    /**
-     * <p>The tags associated with the connection.</p>
-     */
-    inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
-
-    /**
-     * <p>The tags associated with the connection.</p>
-     */
-    inline void SetTags(const Aws::Vector<Tag>& value) { m_tags = value; }
-
-    /**
-     * <p>The tags associated with the connection.</p>
-     */
-    inline void SetTags(Aws::Vector<Tag>&& value) { m_tags = std::move(value); }
-
-    /**
-     * <p>The tags associated with the connection.</p>
-     */
-    inline CreateConnectionResult& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
-
-    /**
-     * <p>The tags associated with the connection.</p>
-     */
-    inline CreateConnectionResult& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
-
-    /**
-     * <p>The tags associated with the connection.</p>
-     */
-    inline CreateConnectionResult& AddTags(const Tag& value) { m_tags.push_back(value); return *this; }
-
-    /**
-     * <p>The tags associated with the connection.</p>
-     */
-    inline CreateConnectionResult& AddTags(Tag&& value) { m_tags.push_back(std::move(value)); return *this; }
-
-
-    /**
-     * <p>The name of the service provider associated with the connection.</p>
-     */
-    inline const Aws::String& GetProviderName() const{ return m_providerName; }
-
-    /**
-     * <p>The name of the service provider associated with the connection.</p>
-     */
-    inline void SetProviderName(const Aws::String& value) { m_providerName = value; }
-
-    /**
-     * <p>The name of the service provider associated with the connection.</p>
-     */
-    inline void SetProviderName(Aws::String&& value) { m_providerName = std::move(value); }
-
-    /**
-     * <p>The name of the service provider associated with the connection.</p>
-     */
-    inline void SetProviderName(const char* value) { m_providerName.assign(value); }
-
-    /**
-     * <p>The name of the service provider associated with the connection.</p>
-     */
-    inline CreateConnectionResult& WithProviderName(const Aws::String& value) { SetProviderName(value); return *this;}
-
-    /**
-     * <p>The name of the service provider associated with the connection.</p>
-     */
-    inline CreateConnectionResult& WithProviderName(Aws::String&& value) { SetProviderName(std::move(value)); return *this;}
-
-    /**
-     * <p>The name of the service provider associated with the connection.</p>
-     */
-    inline CreateConnectionResult& WithProviderName(const char* value) { SetProviderName(value); return *this;}
-
   private:
 
     Aws::String m_ownerAccount;
@@ -707,10 +643,6 @@ namespace Model
     Aws::String m_awsDeviceV2;
 
     HasLogicalRedundancy m_hasLogicalRedundancy;
-
-    Aws::Vector<Tag> m_tags;
-
-    Aws::String m_providerName;
   };
 
 } // namespace Model
