@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/dlm/model/CreateLifecyclePolicyRequest.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -17,8 +27,7 @@ CreateLifecyclePolicyRequest::CreateLifecyclePolicyRequest() :
     m_descriptionHasBeenSet(false),
     m_state(SettablePolicyStateValues::NOT_SET),
     m_stateHasBeenSet(false),
-    m_policyDetailsHasBeenSet(false),
-    m_tagsHasBeenSet(false)
+    m_policyDetailsHasBeenSet(false)
 {
 }
 
@@ -49,17 +58,6 @@ Aws::String CreateLifecyclePolicyRequest::SerializePayload() const
 
   }
 
-  if(m_tagsHasBeenSet)
-  {
-   JsonValue tagsJsonMap;
-   for(auto& tagsItem : m_tags)
-   {
-     tagsJsonMap.WithString(tagsItem.first, tagsItem.second);
-   }
-   payload.WithObject("Tags", std::move(tagsJsonMap));
-
-  }
-
   return payload.View().WriteReadable();
 }
 
