@@ -1,7 +1,17 @@
-/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+/*
+  * Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+  * 
+  * Licensed under the Apache License, Version 2.0 (the "License").
+  * You may not use this file except in compliance with the License.
+  * A copy of the License is located at
+  * 
+  *  http://aws.amazon.com/apache2.0
+  * 
+  * or in the "license" file accompanying this file. This file is distributed
+  * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+  * express or implied. See the License for the specific language governing
+  * permissions and limitations under the License.
+  */
 
 
 #include <aws/external/gtest.h>
@@ -44,20 +54,17 @@ using namespace Aws::DynamoDB::Model;
 #define TEST_TABLE_PREFIX  "IntegrationTest_"
 
 //fill these in before running the test.
-static const char HASH_KEY_NAME[] = "HashKey";
-static const char ENDPOINT_OVERRIDE[] = ""; // Use localhost:8000 for DynamoDb Local
+static const char* HASH_KEY_NAME = "HashKey";
+static const char* ENDPOINT_OVERRIDE = ""; // Use localhost:8000 for DynamoDb Local
 
-static const char BASE_SIMPLE_TABLE[] = "Simple";
-static const char BASE_THROUGHPUT_TABLE[] = "Throughput";
-static const char BASE_CONDITION_TABLE[] = "ConditionCheck";
-static const char BASE_VALIDATION_TABLE[] = "Validation";
-static const char BASE_CRUD_TEST_TABLE[] = "Crud";
-static const char BASE_CRUD_CALLBACKS_TEST_TABLE[] = "Crud_WithCallbacks";
-static const char BASE_THROTTLED_TEST_TABLE[] = "Throttled";
-static const char BASE_LIMITER_TEST_TABLE[] = "Limiter";
-static const char BASE_ATTRIBUTEVALUE_TEST_TABLE[] = "AttributeValue";
+static const char* BASE_SIMPLE_TABLE = "Simple";
+static const char* BASE_CRUD_TEST_TABLE = "Crud";
+static const char* BASE_CRUD_CALLBACKS_TEST_TABLE = "Crud_WithCallbacks";
+static const char* BASE_THROTTLED_TEST_TABLE = "Throttled";
+static const char* BASE_LIMITER_TEST_TABLE = "Limiter";
+static const char* BASE_ATTRIBUTEVALUE_TEST_TABLE = "AttributeValue";
 
-static const char ALLOCATION_TAG[] = "TableOperationTest";
+static const char* ALLOCATION_TAG = "TableOperationTest";
 
 namespace {
 
@@ -186,6 +193,8 @@ protected:
         m_limiter = Aws::MakeShared<Aws::Utils::RateLimits::DefaultRateLimiter<>>(ALLOCATION_TAG, 200000);
         SetUpClient(Aws::Http::TransferLibType::DEFAULT_CLIENT);
         DYNAMODB_INTEGRATION_TEST_ID = Aws::String(Aws::Utils::UUID::RandomUUID()).c_str();
+        // delete all tables, just in case
+        DeleteAllTables();
     }
 
     static void TearDownTestCase()
@@ -198,9 +207,6 @@ protected:
     static void DeleteAllTables()
     {
         DeleteTable(BuildTableName(BASE_SIMPLE_TABLE));
-        DeleteTable(BuildTableName(BASE_THROUGHPUT_TABLE));
-        DeleteTable(BuildTableName(BASE_CONDITION_TABLE));
-        DeleteTable(BuildTableName(BASE_VALIDATION_TABLE));
         DeleteTable(BuildTableName(BASE_CRUD_TEST_TABLE));
         DeleteTable(BuildTableName(BASE_CRUD_CALLBACKS_TEST_TABLE));
         DeleteTable(BuildTableName(BASE_THROTTLED_TEST_TABLE));
@@ -245,7 +251,31 @@ protected:
         deleteTableRequest.SetTableName(tableName);
 
         DeleteTableOutcome deleteTableOutcome = m_client->DeleteTable(deleteTableRequest);
-        ASSERT_TRUE(deleteTableOutcome.IsSuccess());
+
+        if (!deleteTableOutcome.IsSuccess())
+        {
+            // It's okay if the table has already beed deleted
+            EXPECT_EQ(DynamoDBErrors::RESOURCE_NOT_FOUND, deleteTableOutcome.GetError().GetErrorType());
+            return;
+        }
+
+        DescribeTableRequest describeTableRequest;
+        describeTableRequest.SetTableName(tableName);
+        bool shouldContinue = true;
+        while (shouldContinue) 
+        {
+            DescribeTableOutcome outcome = m_client->DescribeTable(describeTableRequest);
+            if (outcome.IsSuccess())
+            {
+                EXPECT_EQ(TableStatus::DELETING, outcome.GetResult().GetTable().GetTableStatus());
+                std::this_thread::sleep_for(std::chrono::seconds(1));
+            }
+            else
+            {
+                EXPECT_EQ(DynamoDBErrors::RESOURCE_NOT_FOUND, outcome.GetError().GetErrorType());
+                break;
+            }
+        }
     }
 
     DescribeTableResult WaitUntilActive(const Aws::String tableName)
@@ -256,7 +286,7 @@ protected:
         DescribeTableOutcome outcome = m_client->DescribeTable(describeTableRequest);
 
         while (shouldContinue)
-        {
+        {     
             if (outcome.IsSuccess() && outcome.GetResult().GetTable().GetTableStatus() == TableStatus::ACTIVE)
             {
                 break;
@@ -280,6 +310,7 @@ TEST_F(TableOperationTest, TestListTable)
 {
     AWS_LOGSTREAM_TRACE(ALLOCATION_TAG, "TestListTable")
 
+    DeleteAllTables();
     Aws::String simpleTableName = BuildTableName(BASE_SIMPLE_TABLE);
     CreateTable(simpleTableName, 10, 10);
 
@@ -315,7 +346,7 @@ TEST_F(TableOperationTest, TestUpdateThroughput)
 {
     AWS_LOGSTREAM_TRACE(ALLOCATION_TAG, "TestUpdateThroughput")
 
-    Aws::String simpleTableName = BuildTableName(BASE_THROUGHPUT_TABLE);
+    Aws::String simpleTableName = BuildTableName(BASE_SIMPLE_TABLE);
     CreateTable(simpleTableName, 10, 10);
 
     // Update the table and make sure it works.
@@ -339,7 +370,7 @@ TEST_F(TableOperationTest, TestConditionalCheckFailure)
 {
     AWS_LOGSTREAM_TRACE(ALLOCATION_TAG, "TestConditionalCheckFailure")
 
-    Aws::String simpleTableName = BuildTableName(BASE_CONDITION_TABLE);
+    Aws::String simpleTableName = BuildTableName(BASE_SIMPLE_TABLE);
     CreateTable(simpleTableName, 10, 10);
 
     AttributeValue homer;
@@ -371,10 +402,6 @@ TEST_F(TableOperationTest, TestConditionalCheckFailure)
     badRequest.AddExpected("Simpson", expected);
     PutItemOutcome result = m_client->PutItem(badRequest);
     ASSERT_FALSE(result.IsSuccess());
-#if ENABLE_CURL_CLIENT
-    ASSERT_FALSE(result.GetError().GetRemoteHostIpAddress().empty());
-#endif
-    ASSERT_FALSE(result.GetError().GetRequestId().empty());
     ASSERT_EQ(DynamoDBErrors::CONDITIONAL_CHECK_FAILED, result.GetError().GetErrorType());
 }
 
@@ -382,7 +409,7 @@ TEST_F(TableOperationTest, TestValidationError)
 {
     AWS_LOGSTREAM_TRACE(ALLOCATION_TAG, "TestValidationError")
 
-    Aws::String simpleTableName = BuildTableName(BASE_VALIDATION_TABLE);
+    Aws::String simpleTableName = BuildTableName(BASE_SIMPLE_TABLE);
     CreateTable(simpleTableName, 10, 10);
 
     AttributeValue hashKeyAttribute;
@@ -394,10 +421,6 @@ TEST_F(TableOperationTest, TestValidationError)
 
     PutItemOutcome result = m_client->PutItem(request);
     ASSERT_FALSE(result.IsSuccess());
-#if ENABLE_CURL_CLIENT
-    ASSERT_FALSE(result.GetError().GetRemoteHostIpAddress().empty());
-#endif
-    ASSERT_FALSE(result.GetError().GetRequestId().empty());
     ASSERT_EQ(DynamoDBErrors::VALIDATION, result.GetError().GetErrorType());
 }
 
@@ -873,7 +896,7 @@ TEST_F(TableOperationTest, TestLimiter)
 
     // set limiter to 1k/sec
     // each request is a Put of 1k of data + >600 from headers/misc and response data
-    // so we expect 20 requests to take at least 30 seconds
+    // so we expect 20 requests to take at least 30 seconds 
     m_limiter->SetRate(1000, true);
 
     auto startTime = CLOCK::now();
@@ -988,41 +1011,6 @@ TEST_F(TableOperationTest, TestAttributeValues)
         EXPECT_EQ("String Value", returnedItemCollection["String"].GetS());
         EXPECT_EQ("1001", returnedItemCollection["Number"].GetN());
     }
-    // Number Value (numeric type)
-    {
-        // Update
-        UpdateItemRequest updateItemRequest;
-        updateItemRequest.SetTableName(attributeValueTestTableName);
-        updateItemRequest.AddKey(HASH_KEY_NAME, hashKey);
-
-        AttributeValue valueAttribute;
-        valueAttribute.SetN(1001);
-
-        AttributeValueUpdate testValueAttribute;
-        testValueAttribute.SetValue(valueAttribute);
-
-        updateItemRequest.AddAttributeUpdates("Number", testValueAttribute);
-
-        UpdateItemOutcome updateOutcome = m_client->UpdateItem(updateItemRequest);
-        ASSERT_TRUE(updateOutcome.IsSuccess());
-
-        // Get
-        GetItemRequest getItemRequest;
-        getItemRequest.AddKey(HASH_KEY_NAME, hashKey);
-        getItemRequest.SetTableName(attributeValueTestTableName);
-
-        Aws::Vector<Aws::String> attributesToGet;
-        attributesToGet.push_back(HASH_KEY_NAME);
-        GetItemOutcome getOutcome = m_client->GetItem(getItemRequest);
-        ASSERT_TRUE(getOutcome.IsSuccess());
-
-        // Parse
-        GetItemResult result = getOutcome.GetResult();
-        auto returnedItemCollection = result.GetItem();
-        EXPECT_EQ("TestValue", returnedItemCollection[HASH_KEY_NAME].GetS());
-        EXPECT_EQ("String Value", returnedItemCollection["String"].GetS());
-        EXPECT_EQ("1001", returnedItemCollection["Number"].GetN());
-    }
 
     // ByteBuffer
     {
