@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/ec2/EC2_EXPORTS.h>
@@ -12,7 +22,6 @@
 #include <aws/ec2/model/VpnProtocol.h>
 #include <aws/ec2/model/TransportProtocol.h>
 #include <aws/ec2/model/ConnectionLogResponseOptions.h>
-#include <aws/ec2/model/ClientConnectResponseOptions.h>
 #include <aws/ec2/model/ClientVpnAuthentication.h>
 #include <aws/ec2/model/Tag.h>
 #include <utility>
@@ -387,38 +396,22 @@ namespace Model
 
 
     /**
-     * <p>Indicates whether split-tunnel is enabled in the AWS Client VPN endpoint.</p>
-     * <p>For information about split-tunnel VPN endpoints, see <a
-     * href="https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/split-tunnel-vpn.html">Split-Tunnel
-     * AWS Client VPN Endpoint</a> in the <i>AWS Client VPN Administrator
-     * Guide</i>.</p>
+     * <p>Indicates whether VPN split tunneling is supported.</p>
      */
     inline bool GetSplitTunnel() const{ return m_splitTunnel; }
 
     /**
-     * <p>Indicates whether split-tunnel is enabled in the AWS Client VPN endpoint.</p>
-     * <p>For information about split-tunnel VPN endpoints, see <a
-     * href="https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/split-tunnel-vpn.html">Split-Tunnel
-     * AWS Client VPN Endpoint</a> in the <i>AWS Client VPN Administrator
-     * Guide</i>.</p>
+     * <p>Indicates whether VPN split tunneling is supported.</p>
      */
     inline bool SplitTunnelHasBeenSet() const { return m_splitTunnelHasBeenSet; }
 
     /**
-     * <p>Indicates whether split-tunnel is enabled in the AWS Client VPN endpoint.</p>
-     * <p>For information about split-tunnel VPN endpoints, see <a
-     * href="https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/split-tunnel-vpn.html">Split-Tunnel
-     * AWS Client VPN Endpoint</a> in the <i>AWS Client VPN Administrator
-     * Guide</i>.</p>
+     * <p>Indicates whether VPN split tunneling is supported.</p>
      */
     inline void SetSplitTunnel(bool value) { m_splitTunnelHasBeenSet = true; m_splitTunnel = value; }
 
     /**
-     * <p>Indicates whether split-tunnel is enabled in the AWS Client VPN endpoint.</p>
-     * <p>For information about split-tunnel VPN endpoints, see <a
-     * href="https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/split-tunnel-vpn.html">Split-Tunnel
-     * AWS Client VPN Endpoint</a> in the <i>AWS Client VPN Administrator
-     * Guide</i>.</p>
+     * <p>Indicates whether VPN split tunneling is supported.</p>
      */
     inline ClientVpnEndpoint& WithSplitTunnel(bool value) { SetSplitTunnel(value); return *this;}
 
@@ -485,27 +478,6 @@ namespace Model
     inline ClientVpnEndpoint& WithTransportProtocol(TransportProtocol&& value) { SetTransportProtocol(std::move(value)); return *this;}
 
 
-    /**
-     * <p>The port number for the Client VPN endpoint.</p>
-     */
-    inline int GetVpnPort() const{ return m_vpnPort; }
-
-    /**
-     * <p>The port number for the Client VPN endpoint.</p>
-     */
-    inline bool VpnPortHasBeenSet() const { return m_vpnPortHasBeenSet; }
-
-    /**
-     * <p>The port number for the Client VPN endpoint.</p>
-     */
-    inline void SetVpnPort(int value) { m_vpnPortHasBeenSet = true; m_vpnPort = value; }
-
-    /**
-     * <p>The port number for the Client VPN endpoint.</p>
-     */
-    inline ClientVpnEndpoint& WithVpnPort(int value) { SetVpnPort(value); return *this;}
-
-
     /**
      * <p>The ARN of the server certificate.</p>
      */
@@ -673,171 +645,6 @@ namespace Model
      */
     inline ClientVpnEndpoint& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
-
-    /**
-     * <p>The IDs of the security groups for the target network.</p>
-     */
-    inline const Aws::Vector<Aws::String>& GetSecurityGroupIds() const{ return m_securityGroupIds; }
-
-    /**
-     * <p>The IDs of the security groups for the target network.</p>
-     */
-    inline bool SecurityGroupIdsHasBeenSet() const { return m_securityGroupIdsHasBeenSet; }
-
-    /**
-     * <p>The IDs of the security groups for the target network.</p>
-     */
-    inline void SetSecurityGroupIds(const Aws::Vector<Aws::String>& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds = value; }
-
-    /**
-     * <p>The IDs of the security groups for the target network.</p>
-     */
-    inline void SetSecurityGroupIds(Aws::Vector<Aws::String>&& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds = std::move(value); }
-
-    /**
-     * <p>The IDs of the security groups for the target network.</p>
-     */
-    inline ClientVpnEndpoint& WithSecurityGroupIds(const Aws::Vector<Aws::String>& value) { SetSecurityGroupIds(value); return *this;}
-
-    /**
-     * <p>The IDs of the security groups for the target network.</p>
-     */
-    inline ClientVpnEndpoint& WithSecurityGroupIds(Aws::Vector<Aws::String>&& value) { SetSecurityGroupIds(std::move(value)); return *this;}
-
-    /**
-     * <p>The IDs of the security groups for the target network.</p>
-     */
-    inline ClientVpnEndpoint& AddSecurityGroupIds(const Aws::String& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds.push_back(value); return *this; }
-
-    /**
-     * <p>The IDs of the security groups for the target network.</p>
-     */
-    inline ClientVpnEndpoint& AddSecurityGroupIds(Aws::String&& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds.push_back(std::move(value)); return *this; }
-
-    /**
-     * <p>The IDs of the security groups for the target network.</p>
-     */
-    inline ClientVpnEndpoint& AddSecurityGroupIds(const char* value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds.push_back(value); return *this; }
-
-
-    /**
-     * <p>The ID of the VPC.</p>
-     */
-    inline const Aws::String& GetVpcId() const{ return m_vpcId; }
-
-    /**
-     * <p>The ID of the VPC.</p>
-     */
-    inline bool VpcIdHasBeenSet() const { return m_vpcIdHasBeenSet; }
-
-    /**
-     * <p>The ID of the VPC.</p>
-     */
-    inline void SetVpcId(const Aws::String& value) { m_vpcIdHasBeenSet = true; m_vpcId = value; }
-
-    /**
-     * <p>The ID of the VPC.</p>
-     */
-    inline void SetVpcId(Aws::String&& value) { m_vpcIdHasBeenSet = true; m_vpcId = std::move(value); }
-
-    /**
-     * <p>The ID of the VPC.</p>
-     */
-    inline void SetVpcId(const char* value) { m_vpcIdHasBeenSet = true; m_vpcId.assign(value); }
-
-    /**
-     * <p>The ID of the VPC.</p>
-     */
-    inline ClientVpnEndpoint& WithVpcId(const Aws::String& value) { SetVpcId(value); return *this;}
-
-    /**
-     * <p>The ID of the VPC.</p>
-     */
-    inline ClientVpnEndpoint& WithVpcId(Aws::String&& value) { SetVpcId(std::move(value)); return *this;}
-
-    /**
-     * <p>The ID of the VPC.</p>
-     */
-    inline ClientVpnEndpoint& WithVpcId(const char* value) { SetVpcId(value); return *this;}
-
-
-    /**
-     * <p>The URL of the self-service portal.</p>
-     */
-    inline const Aws::String& GetSelfServicePortalUrl() const{ return m_selfServicePortalUrl; }
-
-    /**
-     * <p>The URL of the self-service portal.</p>
-     */
-    inline bool SelfServicePortalUrlHasBeenSet() const { return m_selfServicePortalUrlHasBeenSet; }
-
-    /**
-     * <p>The URL of the self-service portal.</p>
-     */
-    inline void SetSelfServicePortalUrl(const Aws::String& value) { m_selfServicePortalUrlHasBeenSet = true; m_selfServicePortalUrl = value; }
-
-    /**
-     * <p>The URL of the self-service portal.</p>
-     */
-    inline void SetSelfServicePortalUrl(Aws::String&& value) { m_selfServicePortalUrlHasBeenSet = true; m_selfServicePortalUrl = std::move(value); }
-
-    /**
-     * <p>The URL of the self-service portal.</p>
-     */
-    inline void SetSelfServicePortalUrl(const char* value) { m_selfServicePortalUrlHasBeenSet = true; m_selfServicePortalUrl.assign(value); }
-
-    /**
-     * <p>The URL of the self-service portal.</p>
-     */
-    inline ClientVpnEndpoint& WithSelfServicePortalUrl(const Aws::String& value) { SetSelfServicePortalUrl(value); return *this;}
-
-    /**
-     * <p>The URL of the self-service portal.</p>
-     */
-    inline ClientVpnEndpoint& WithSelfServicePortalUrl(Aws::String&& value) { SetSelfServicePortalUrl(std::move(value)); return *this;}
-
-    /**
-     * <p>The URL of the self-service portal.</p>
-     */
-    inline ClientVpnEndpoint& WithSelfServicePortalUrl(const char* value) { SetSelfServicePortalUrl(value); return *this;}
-
-
-    /**
-     * <p>The options for managing connection authorization for new client
-     * connections.</p>
-     */
-    inline const ClientConnectResponseOptions& GetClientConnectOptions() const{ return m_clientConnectOptions; }
-
-    /**
-     * <p>The options for managing connection authorization for new client
-     * connections.</p>
-     */
-    inline bool ClientConnectOptionsHasBeenSet() const { return m_clientConnectOptionsHasBeenSet; }
-
-    /**
-     * <p>The options for managing connection authorization for new client
-     * connections.</p>
-     */
-    inline void SetClientConnectOptions(const ClientConnectResponseOptions& value) { m_clientConnectOptionsHasBeenSet = true; m_clientConnectOptions = value; }
-
-    /**
-     * <p>The options for managing connection authorization for new client
-     * connections.</p>
-     */
-    inline void SetClientConnectOptions(ClientConnectResponseOptions&& value) { m_clientConnectOptionsHasBeenSet = true; m_clientConnectOptions = std::move(value); }
-
-    /**
-     * <p>The options for managing connection authorization for new client
-     * connections.</p>
-     */
-    inline ClientVpnEndpoint& WithClientConnectOptions(const ClientConnectResponseOptions& value) { SetClientConnectOptions(value); return *this;}
-
-    /**
-     * <p>The options for managing connection authorization for new client
-     * connections.</p>
-     */
-    inline ClientVpnEndpoint& WithClientConnectOptions(ClientConnectResponseOptions&& value) { SetClientConnectOptions(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_clientVpnEndpointId;
@@ -873,9 +680,6 @@ namespace Model
     TransportProtocol m_transportProtocol;
     bool m_transportProtocolHasBeenSet;
 
-    int m_vpnPort;
-    bool m_vpnPortHasBeenSet;
-
     Aws::String m_serverCertificateArn;
     bool m_serverCertificateArnHasBeenSet;
 
@@ -887,18 +691,6 @@ namespace Model
 
     Aws::Vector<Tag> m_tags;
     bool m_tagsHasBeenSet;
-
-    Aws::Vector<Aws::String> m_securityGroupIds;
-    bool m_securityGroupIdsHasBeenSet;
-
-    Aws::String m_vpcId;
-    bool m_vpcIdHasBeenSet;
-
-    Aws::String m_selfServicePortalUrl;
-    bool m_selfServicePortalUrlHasBeenSet;
-
-    ClientConnectResponseOptions m_clientConnectOptions;
-    bool m_clientConnectOptionsHasBeenSet;
   };
 
 } // namespace Model
