@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/ec2/EC2_EXPORTS.h>
@@ -9,8 +19,6 @@
 #include <aws/ec2/model/ClientData.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/ec2/model/SnapshotDiskContainer.h>
-#include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/ec2/model/TagSpecification.h>
 #include <utility>
 
 namespace Aws
@@ -21,12 +29,15 @@ namespace Model
 {
 
   /**
+   * <p>Contains the parameters for ImportSnapshot.</p><p><h3>See Also:</h3>   <a
+   * href="http://docs.aws.amazon.com/goto/WebAPI/ec2-2016-11-15/ImportSnapshotRequest">AWS
+   * API Reference</a></p>
    */
   class AWS_EC2_API ImportSnapshotRequest : public EC2Request
   {
   public:
     ImportSnapshotRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -259,234 +270,226 @@ namespace Model
 
 
     /**
-     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
-     * master key (CMK) to use when creating the encrypted snapshot. This parameter is
-     * only required if you want to use a non-default CMK; if this parameter is not
+     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
+     * key (CMK) to use when creating the encrypted snapshot. This parameter is only
+     * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
      * identifier may be provided in any of the following formats: </p> <ul> <li>
      * <p>Key ID</p> </li> <li> <p>Key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>.</p>
      * </li> <li> <p>ARN using key ID. The ID ARN contains the <code>arn:aws:kms</code>
-     * namespace, followed by the Region of the CMK, the AWS account ID of the CMK
+     * namespace, followed by the region of the CMK, the AWS account ID of the CMK
      * owner, the <code>key</code> namespace, and then the CMK ID. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:key/<i>abcd1234-a123-456a-a12b-a123b4cd56ef</i>.</p>
      * </li> <li> <p>ARN using key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>. </p>
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the snapshot is being copied to.</p> <p>Amazon
-     * EBS does not support asymmetric CMKs.</p>
+     * CMK must exist in the region that the snapshot is being copied to. </p>
      */
     inline const Aws::String& GetKmsKeyId() const{ return m_kmsKeyId; }
 
     /**
-     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
-     * master key (CMK) to use when creating the encrypted snapshot. This parameter is
-     * only required if you want to use a non-default CMK; if this parameter is not
+     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
+     * key (CMK) to use when creating the encrypted snapshot. This parameter is only
+     * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
      * identifier may be provided in any of the following formats: </p> <ul> <li>
      * <p>Key ID</p> </li> <li> <p>Key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>.</p>
      * </li> <li> <p>ARN using key ID. The ID ARN contains the <code>arn:aws:kms</code>
-     * namespace, followed by the Region of the CMK, the AWS account ID of the CMK
+     * namespace, followed by the region of the CMK, the AWS account ID of the CMK
      * owner, the <code>key</code> namespace, and then the CMK ID. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:key/<i>abcd1234-a123-456a-a12b-a123b4cd56ef</i>.</p>
      * </li> <li> <p>ARN using key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>. </p>
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the snapshot is being copied to.</p> <p>Amazon
-     * EBS does not support asymmetric CMKs.</p>
+     * CMK must exist in the region that the snapshot is being copied to. </p>
      */
     inline bool KmsKeyIdHasBeenSet() const { return m_kmsKeyIdHasBeenSet; }
 
     /**
-     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
-     * master key (CMK) to use when creating the encrypted snapshot. This parameter is
-     * only required if you want to use a non-default CMK; if this parameter is not
+     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
+     * key (CMK) to use when creating the encrypted snapshot. This parameter is only
+     * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
      * identifier may be provided in any of the following formats: </p> <ul> <li>
      * <p>Key ID</p> </li> <li> <p>Key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>.</p>
      * </li> <li> <p>ARN using key ID. The ID ARN contains the <code>arn:aws:kms</code>
-     * namespace, followed by the Region of the CMK, the AWS account ID of the CMK
+     * namespace, followed by the region of the CMK, the AWS account ID of the CMK
      * owner, the <code>key</code> namespace, and then the CMK ID. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:key/<i>abcd1234-a123-456a-a12b-a123b4cd56ef</i>.</p>
      * </li> <li> <p>ARN using key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>. </p>
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the snapshot is being copied to.</p> <p>Amazon
-     * EBS does not support asymmetric CMKs.</p>
+     * CMK must exist in the region that the snapshot is being copied to. </p>
      */
     inline void SetKmsKeyId(const Aws::String& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = value; }
 
     /**
-     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
-     * master key (CMK) to use when creating the encrypted snapshot. This parameter is
-     * only required if you want to use a non-default CMK; if this parameter is not
+     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
+     * key (CMK) to use when creating the encrypted snapshot. This parameter is only
+     * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
      * identifier may be provided in any of the following formats: </p> <ul> <li>
      * <p>Key ID</p> </li> <li> <p>Key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>.</p>
      * </li> <li> <p>ARN using key ID. The ID ARN contains the <code>arn:aws:kms</code>
-     * namespace, followed by the Region of the CMK, the AWS account ID of the CMK
+     * namespace, followed by the region of the CMK, the AWS account ID of the CMK
      * owner, the <code>key</code> namespace, and then the CMK ID. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:key/<i>abcd1234-a123-456a-a12b-a123b4cd56ef</i>.</p>
      * </li> <li> <p>ARN using key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>. </p>
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the snapshot is being copied to.</p> <p>Amazon
-     * EBS does not support asymmetric CMKs.</p>
+     * CMK must exist in the region that the snapshot is being copied to. </p>
      */
     inline void SetKmsKeyId(Aws::String&& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = std::move(value); }
 
     /**
-     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
-     * master key (CMK) to use when creating the encrypted snapshot. This parameter is
-     * only required if you want to use a non-default CMK; if this parameter is not
+     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
+     * key (CMK) to use when creating the encrypted snapshot. This parameter is only
+     * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
      * identifier may be provided in any of the following formats: </p> <ul> <li>
      * <p>Key ID</p> </li> <li> <p>Key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>.</p>
      * </li> <li> <p>ARN using key ID. The ID ARN contains the <code>arn:aws:kms</code>
-     * namespace, followed by the Region of the CMK, the AWS account ID of the CMK
+     * namespace, followed by the region of the CMK, the AWS account ID of the CMK
      * owner, the <code>key</code> namespace, and then the CMK ID. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:key/<i>abcd1234-a123-456a-a12b-a123b4cd56ef</i>.</p>
      * </li> <li> <p>ARN using key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>. </p>
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the snapshot is being copied to.</p> <p>Amazon
-     * EBS does not support asymmetric CMKs.</p>
+     * CMK must exist in the region that the snapshot is being copied to. </p>
      */
     inline void SetKmsKeyId(const char* value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId.assign(value); }
 
     /**
-     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
-     * master key (CMK) to use when creating the encrypted snapshot. This parameter is
-     * only required if you want to use a non-default CMK; if this parameter is not
+     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
+     * key (CMK) to use when creating the encrypted snapshot. This parameter is only
+     * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
      * identifier may be provided in any of the following formats: </p> <ul> <li>
      * <p>Key ID</p> </li> <li> <p>Key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>.</p>
      * </li> <li> <p>ARN using key ID. The ID ARN contains the <code>arn:aws:kms</code>
-     * namespace, followed by the Region of the CMK, the AWS account ID of the CMK
+     * namespace, followed by the region of the CMK, the AWS account ID of the CMK
      * owner, the <code>key</code> namespace, and then the CMK ID. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:key/<i>abcd1234-a123-456a-a12b-a123b4cd56ef</i>.</p>
      * </li> <li> <p>ARN using key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>. </p>
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the snapshot is being copied to.</p> <p>Amazon
-     * EBS does not support asymmetric CMKs.</p>
+     * CMK must exist in the region that the snapshot is being copied to. </p>
      */
     inline ImportSnapshotRequest& WithKmsKeyId(const Aws::String& value) { SetKmsKeyId(value); return *this;}
 
     /**
-     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
-     * master key (CMK) to use when creating the encrypted snapshot. This parameter is
-     * only required if you want to use a non-default CMK; if this parameter is not
+     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
+     * key (CMK) to use when creating the encrypted snapshot. This parameter is only
+     * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
      * identifier may be provided in any of the following formats: </p> <ul> <li>
      * <p>Key ID</p> </li> <li> <p>Key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>.</p>
      * </li> <li> <p>ARN using key ID. The ID ARN contains the <code>arn:aws:kms</code>
-     * namespace, followed by the Region of the CMK, the AWS account ID of the CMK
+     * namespace, followed by the region of the CMK, the AWS account ID of the CMK
      * owner, the <code>key</code> namespace, and then the CMK ID. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:key/<i>abcd1234-a123-456a-a12b-a123b4cd56ef</i>.</p>
      * </li> <li> <p>ARN using key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>. </p>
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the snapshot is being copied to.</p> <p>Amazon
-     * EBS does not support asymmetric CMKs.</p>
+     * CMK must exist in the region that the snapshot is being copied to. </p>
      */
     inline ImportSnapshotRequest& WithKmsKeyId(Aws::String&& value) { SetKmsKeyId(std::move(value)); return *this;}
 
     /**
-     * <p>An identifier for the symmetric AWS Key Management Service (AWS KMS) customer
-     * master key (CMK) to use when creating the encrypted snapshot. This parameter is
-     * only required if you want to use a non-default CMK; if this parameter is not
+     * <p>An identifier for the AWS Key Management Service (AWS KMS) customer master
+     * key (CMK) to use when creating the encrypted snapshot. This parameter is only
+     * required if you want to use a non-default CMK; if this parameter is not
      * specified, the default CMK for EBS is used. If a <code>KmsKeyId</code> is
      * specified, the <code>Encrypted</code> flag must also be set. </p> <p>The CMK
      * identifier may be provided in any of the following formats: </p> <ul> <li>
      * <p>Key ID</p> </li> <li> <p>Key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>.</p>
      * </li> <li> <p>ARN using key ID. The ID ARN contains the <code>arn:aws:kms</code>
-     * namespace, followed by the Region of the CMK, the AWS account ID of the CMK
+     * namespace, followed by the region of the CMK, the AWS account ID of the CMK
      * owner, the <code>key</code> namespace, and then the CMK ID. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:key/<i>abcd1234-a123-456a-a12b-a123b4cd56ef</i>.</p>
      * </li> <li> <p>ARN using key alias. The alias ARN contains the
-     * <code>arn:aws:kms</code> namespace, followed by the Region of the CMK, the AWS
+     * <code>arn:aws:kms</code> namespace, followed by the region of the CMK, the AWS
      * account ID of the CMK owner, the <code>alias</code> namespace, and then the CMK
      * alias. For example,
      * arn:aws:kms:<i>us-east-1</i>:<i>012345678910</i>:alias/<i>ExampleAlias</i>. </p>
      * </li> </ul> <p>AWS parses <code>KmsKeyId</code> asynchronously, meaning that the
      * action you call may appear to complete even though you provided an invalid
      * identifier. This action will eventually report failure. </p> <p>The specified
-     * CMK must exist in the Region that the snapshot is being copied to.</p> <p>Amazon
-     * EBS does not support asymmetric CMKs.</p>
+     * CMK must exist in the region that the snapshot is being copied to. </p>
      */
     inline ImportSnapshotRequest& WithKmsKeyId(const char* value) { SetKmsKeyId(value); return *this;}
 
@@ -531,47 +534,6 @@ namespace Model
      */
     inline ImportSnapshotRequest& WithRoleName(const char* value) { SetRoleName(value); return *this;}
 
-
-    /**
-     * <p>The tags to apply to the import snapshot task during creation.</p>
-     */
-    inline const Aws::Vector<TagSpecification>& GetTagSpecifications() const{ return m_tagSpecifications; }
-
-    /**
-     * <p>The tags to apply to the import snapshot task during creation.</p>
-     */
-    inline bool TagSpecificationsHasBeenSet() const { return m_tagSpecificationsHasBeenSet; }
-
-    /**
-     * <p>The tags to apply to the import snapshot task during creation.</p>
-     */
-    inline void SetTagSpecifications(const Aws::Vector<TagSpecification>& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications = value; }
-
-    /**
-     * <p>The tags to apply to the import snapshot task during creation.</p>
-     */
-    inline void SetTagSpecifications(Aws::Vector<TagSpecification>&& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications = std::move(value); }
-
-    /**
-     * <p>The tags to apply to the import snapshot task during creation.</p>
-     */
-    inline ImportSnapshotRequest& WithTagSpecifications(const Aws::Vector<TagSpecification>& value) { SetTagSpecifications(value); return *this;}
-
-    /**
-     * <p>The tags to apply to the import snapshot task during creation.</p>
-     */
-    inline ImportSnapshotRequest& WithTagSpecifications(Aws::Vector<TagSpecification>&& value) { SetTagSpecifications(std::move(value)); return *this;}
-
-    /**
-     * <p>The tags to apply to the import snapshot task during creation.</p>
-     */
-    inline ImportSnapshotRequest& AddTagSpecifications(const TagSpecification& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications.push_back(value); return *this; }
-
-    /**
-     * <p>The tags to apply to the import snapshot task during creation.</p>
-     */
-    inline ImportSnapshotRequest& AddTagSpecifications(TagSpecification&& value) { m_tagSpecificationsHasBeenSet = true; m_tagSpecifications.push_back(std::move(value)); return *this; }
-
   private:
 
     ClientData m_clientData;
@@ -597,9 +559,6 @@ namespace Model
 
     Aws::String m_roleName;
     bool m_roleNameHasBeenSet;
-
-    Aws::Vector<TagSpecification> m_tagSpecifications;
-    bool m_tagSpecificationsHasBeenSet;
   };
 
 } // namespace Model
