@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/ec2/model/LaunchTemplateInstanceNetworkInterfaceSpecificationRequest.h>
 #include <aws/core/utils/xml/XmlSerializer.h>
@@ -21,8 +31,6 @@ namespace Model
 {
 
 LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::LaunchTemplateInstanceNetworkInterfaceSpecificationRequest() : 
-    m_associateCarrierIpAddress(false),
-    m_associateCarrierIpAddressHasBeenSet(false),
     m_associatePublicIpAddress(false),
     m_associatePublicIpAddressHasBeenSet(false),
     m_deleteOnTermination(false),
@@ -31,7 +39,6 @@ LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::LaunchTemplateInstan
     m_deviceIndex(0),
     m_deviceIndexHasBeenSet(false),
     m_groupsHasBeenSet(false),
-    m_interfaceTypeHasBeenSet(false),
     m_ipv6AddressCount(0),
     m_ipv6AddressCountHasBeenSet(false),
     m_ipv6AddressesHasBeenSet(false),
@@ -40,15 +47,11 @@ LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::LaunchTemplateInstan
     m_privateIpAddressesHasBeenSet(false),
     m_secondaryPrivateIpAddressCount(0),
     m_secondaryPrivateIpAddressCountHasBeenSet(false),
-    m_subnetIdHasBeenSet(false),
-    m_networkCardIndex(0),
-    m_networkCardIndexHasBeenSet(false)
+    m_subnetIdHasBeenSet(false)
 {
 }
 
 LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::LaunchTemplateInstanceNetworkInterfaceSpecificationRequest(const XmlNode& xmlNode) : 
-    m_associateCarrierIpAddress(false),
-    m_associateCarrierIpAddressHasBeenSet(false),
     m_associatePublicIpAddress(false),
     m_associatePublicIpAddressHasBeenSet(false),
     m_deleteOnTermination(false),
@@ -57,7 +60,6 @@ LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::LaunchTemplateInstan
     m_deviceIndex(0),
     m_deviceIndexHasBeenSet(false),
     m_groupsHasBeenSet(false),
-    m_interfaceTypeHasBeenSet(false),
     m_ipv6AddressCount(0),
     m_ipv6AddressCountHasBeenSet(false),
     m_ipv6AddressesHasBeenSet(false),
@@ -66,9 +68,7 @@ LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::LaunchTemplateInstan
     m_privateIpAddressesHasBeenSet(false),
     m_secondaryPrivateIpAddressCount(0),
     m_secondaryPrivateIpAddressCountHasBeenSet(false),
-    m_subnetIdHasBeenSet(false),
-    m_networkCardIndex(0),
-    m_networkCardIndexHasBeenSet(false)
+    m_subnetIdHasBeenSet(false)
 {
   *this = xmlNode;
 }
@@ -79,34 +79,28 @@ LaunchTemplateInstanceNetworkInterfaceSpecificationRequest& LaunchTemplateInstan
 
   if(!resultNode.IsNull())
   {
-    XmlNode associateCarrierIpAddressNode = resultNode.FirstChild("AssociateCarrierIpAddress");
-    if(!associateCarrierIpAddressNode.IsNull())
-    {
-      m_associateCarrierIpAddress = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(associateCarrierIpAddressNode.GetText()).c_str()).c_str());
-      m_associateCarrierIpAddressHasBeenSet = true;
-    }
     XmlNode associatePublicIpAddressNode = resultNode.FirstChild("AssociatePublicIpAddress");
     if(!associatePublicIpAddressNode.IsNull())
     {
-      m_associatePublicIpAddress = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(associatePublicIpAddressNode.GetText()).c_str()).c_str());
+      m_associatePublicIpAddress = StringUtils::ConvertToBool(StringUtils::Trim(associatePublicIpAddressNode.GetText().c_str()).c_str());
       m_associatePublicIpAddressHasBeenSet = true;
     }
     XmlNode deleteOnTerminationNode = resultNode.FirstChild("DeleteOnTermination");
     if(!deleteOnTerminationNode.IsNull())
     {
-      m_deleteOnTermination = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(deleteOnTerminationNode.GetText()).c_str()).c_str());
+      m_deleteOnTermination = StringUtils::ConvertToBool(StringUtils::Trim(deleteOnTerminationNode.GetText().c_str()).c_str());
       m_deleteOnTerminationHasBeenSet = true;
     }
     XmlNode descriptionNode = resultNode.FirstChild("Description");
     if(!descriptionNode.IsNull())
     {
-      m_description = Aws::Utils::Xml::DecodeEscapedXmlText(descriptionNode.GetText());
+      m_description = StringUtils::Trim(descriptionNode.GetText().c_str());
       m_descriptionHasBeenSet = true;
     }
     XmlNode deviceIndexNode = resultNode.FirstChild("DeviceIndex");
     if(!deviceIndexNode.IsNull())
     {
-      m_deviceIndex = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(deviceIndexNode.GetText()).c_str()).c_str());
+      m_deviceIndex = StringUtils::ConvertToInt32(StringUtils::Trim(deviceIndexNode.GetText().c_str()).c_str());
       m_deviceIndexHasBeenSet = true;
     }
     XmlNode groupsNode = resultNode.FirstChild("SecurityGroupId");
@@ -115,22 +109,16 @@ LaunchTemplateInstanceNetworkInterfaceSpecificationRequest& LaunchTemplateInstan
       XmlNode groupsMember = groupsNode.FirstChild("SecurityGroupId");
       while(!groupsMember.IsNull())
       {
-        m_groups.push_back(groupsMember.GetText());
+        m_groups.push_back(StringUtils::Trim(groupsMember.GetText().c_str()));
         groupsMember = groupsMember.NextNode("SecurityGroupId");
       }
 
       m_groupsHasBeenSet = true;
     }
-    XmlNode interfaceTypeNode = resultNode.FirstChild("InterfaceType");
-    if(!interfaceTypeNode.IsNull())
-    {
-      m_interfaceType = Aws::Utils::Xml::DecodeEscapedXmlText(interfaceTypeNode.GetText());
-      m_interfaceTypeHasBeenSet = true;
-    }
     XmlNode ipv6AddressCountNode = resultNode.FirstChild("Ipv6AddressCount");
     if(!ipv6AddressCountNode.IsNull())
     {
-      m_ipv6AddressCount = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(ipv6AddressCountNode.GetText()).c_str()).c_str());
+      m_ipv6AddressCount = StringUtils::ConvertToInt32(StringUtils::Trim(ipv6AddressCountNode.GetText().c_str()).c_str());
       m_ipv6AddressCountHasBeenSet = true;
     }
     XmlNode ipv6AddressesNode = resultNode.FirstChild("Ipv6Addresses");
@@ -148,13 +136,13 @@ LaunchTemplateInstanceNetworkInterfaceSpecificationRequest& LaunchTemplateInstan
     XmlNode networkInterfaceIdNode = resultNode.FirstChild("NetworkInterfaceId");
     if(!networkInterfaceIdNode.IsNull())
     {
-      m_networkInterfaceId = Aws::Utils::Xml::DecodeEscapedXmlText(networkInterfaceIdNode.GetText());
+      m_networkInterfaceId = StringUtils::Trim(networkInterfaceIdNode.GetText().c_str());
       m_networkInterfaceIdHasBeenSet = true;
     }
     XmlNode privateIpAddressNode = resultNode.FirstChild("PrivateIpAddress");
     if(!privateIpAddressNode.IsNull())
     {
-      m_privateIpAddress = Aws::Utils::Xml::DecodeEscapedXmlText(privateIpAddressNode.GetText());
+      m_privateIpAddress = StringUtils::Trim(privateIpAddressNode.GetText().c_str());
       m_privateIpAddressHasBeenSet = true;
     }
     XmlNode privateIpAddressesNode = resultNode.FirstChild("PrivateIpAddresses");
@@ -172,21 +160,15 @@ LaunchTemplateInstanceNetworkInterfaceSpecificationRequest& LaunchTemplateInstan
     XmlNode secondaryPrivateIpAddressCountNode = resultNode.FirstChild("SecondaryPrivateIpAddressCount");
     if(!secondaryPrivateIpAddressCountNode.IsNull())
     {
-      m_secondaryPrivateIpAddressCount = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(secondaryPrivateIpAddressCountNode.GetText()).c_str()).c_str());
+      m_secondaryPrivateIpAddressCount = StringUtils::ConvertToInt32(StringUtils::Trim(secondaryPrivateIpAddressCountNode.GetText().c_str()).c_str());
       m_secondaryPrivateIpAddressCountHasBeenSet = true;
     }
     XmlNode subnetIdNode = resultNode.FirstChild("SubnetId");
     if(!subnetIdNode.IsNull())
     {
-      m_subnetId = Aws::Utils::Xml::DecodeEscapedXmlText(subnetIdNode.GetText());
+      m_subnetId = StringUtils::Trim(subnetIdNode.GetText().c_str());
       m_subnetIdHasBeenSet = true;
     }
-    XmlNode networkCardIndexNode = resultNode.FirstChild("NetworkCardIndex");
-    if(!networkCardIndexNode.IsNull())
-    {
-      m_networkCardIndex = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(networkCardIndexNode.GetText()).c_str()).c_str());
-      m_networkCardIndexHasBeenSet = true;
-    }
   }
 
   return *this;
@@ -194,11 +176,6 @@ LaunchTemplateInstanceNetworkInterfaceSpecificationRequest& LaunchTemplateInstan
 
 void LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::OutputToStream(Aws::OStream& oStream, const char* location, unsigned index, const char* locationValue) const
 {
-  if(m_associateCarrierIpAddressHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".AssociateCarrierIpAddress=" << std::boolalpha << m_associateCarrierIpAddress << "&";
-  }
-
   if(m_associatePublicIpAddressHasBeenSet)
   {
       oStream << location << index << locationValue << ".AssociatePublicIpAddress=" << std::boolalpha << m_associatePublicIpAddress << "&";
@@ -228,11 +205,6 @@ void LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::OutputToStream(
       }
   }
 
-  if(m_interfaceTypeHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".InterfaceType=" << StringUtils::URLEncode(m_interfaceType.c_str()) << "&";
-  }
-
   if(m_ipv6AddressCountHasBeenSet)
   {
       oStream << location << index << locationValue << ".Ipv6AddressCount=" << m_ipv6AddressCount << "&";
@@ -280,19 +252,10 @@ void LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::OutputToStream(
       oStream << location << index << locationValue << ".SubnetId=" << StringUtils::URLEncode(m_subnetId.c_str()) << "&";
   }
 
-  if(m_networkCardIndexHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".NetworkCardIndex=" << m_networkCardIndex << "&";
-  }
-
 }
 
 void LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::OutputToStream(Aws::OStream& oStream, const char* location) const
 {
-  if(m_associateCarrierIpAddressHasBeenSet)
-  {
-      oStream << location << ".AssociateCarrierIpAddress=" << std::boolalpha << m_associateCarrierIpAddress << "&";
-  }
   if(m_associatePublicIpAddressHasBeenSet)
   {
       oStream << location << ".AssociatePublicIpAddress=" << std::boolalpha << m_associatePublicIpAddress << "&";
@@ -317,10 +280,6 @@ void LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::OutputToStream(
         oStream << location << ".SecurityGroupId." << groupsIdx++ << "=" << StringUtils::URLEncode(item.c_str()) << "&";
       }
   }
-  if(m_interfaceTypeHasBeenSet)
-  {
-      oStream << location << ".InterfaceType=" << StringUtils::URLEncode(m_interfaceType.c_str()) << "&";
-  }
   if(m_ipv6AddressCountHasBeenSet)
   {
       oStream << location << ".Ipv6AddressCount=" << m_ipv6AddressCount << "&";
@@ -361,10 +320,6 @@ void LaunchTemplateInstanceNetworkInterfaceSpecificationRequest::OutputToStream(
   {
       oStream << location << ".SubnetId=" << StringUtils::URLEncode(m_subnetId.c_str()) << "&";
   }
-  if(m_networkCardIndexHasBeenSet)
-  {
-      oStream << location << ".NetworkCardIndex=" << m_networkCardIndex << "&";
-  }
 }
 
 } // namespace Model
