@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/ec2/model/ReplaceRouteRequest.h>
 #include <aws/core/utils/StringUtils.h>
@@ -13,19 +23,13 @@ using namespace Aws::Utils;
 ReplaceRouteRequest::ReplaceRouteRequest() : 
     m_destinationCidrBlockHasBeenSet(false),
     m_destinationIpv6CidrBlockHasBeenSet(false),
-    m_destinationPrefixListIdHasBeenSet(false),
     m_dryRun(false),
     m_dryRunHasBeenSet(false),
-    m_vpcEndpointIdHasBeenSet(false),
     m_egressOnlyInternetGatewayIdHasBeenSet(false),
     m_gatewayIdHasBeenSet(false),
     m_instanceIdHasBeenSet(false),
-    m_localTarget(false),
-    m_localTargetHasBeenSet(false),
     m_natGatewayIdHasBeenSet(false),
     m_transitGatewayIdHasBeenSet(false),
-    m_localGatewayIdHasBeenSet(false),
-    m_carrierGatewayIdHasBeenSet(false),
     m_networkInterfaceIdHasBeenSet(false),
     m_routeTableIdHasBeenSet(false),
     m_vpcPeeringConnectionIdHasBeenSet(false)
@@ -46,21 +50,11 @@ Aws::String ReplaceRouteRequest::SerializePayload() const
     ss << "DestinationIpv6CidrBlock=" << StringUtils::URLEncode(m_destinationIpv6CidrBlock.c_str()) << "&";
   }
 
-  if(m_destinationPrefixListIdHasBeenSet)
-  {
-    ss << "DestinationPrefixListId=" << StringUtils::URLEncode(m_destinationPrefixListId.c_str()) << "&";
-  }
-
   if(m_dryRunHasBeenSet)
   {
     ss << "DryRun=" << std::boolalpha << m_dryRun << "&";
   }
 
-  if(m_vpcEndpointIdHasBeenSet)
-  {
-    ss << "VpcEndpointId=" << StringUtils::URLEncode(m_vpcEndpointId.c_str()) << "&";
-  }
-
   if(m_egressOnlyInternetGatewayIdHasBeenSet)
   {
     ss << "EgressOnlyInternetGatewayId=" << StringUtils::URLEncode(m_egressOnlyInternetGatewayId.c_str()) << "&";
@@ -76,11 +70,6 @@ Aws::String ReplaceRouteRequest::SerializePayload() const
     ss << "InstanceId=" << StringUtils::URLEncode(m_instanceId.c_str()) << "&";
   }
 
-  if(m_localTargetHasBeenSet)
-  {
-    ss << "LocalTarget=" << std::boolalpha << m_localTarget << "&";
-  }
-
   if(m_natGatewayIdHasBeenSet)
   {
     ss << "NatGatewayId=" << StringUtils::URLEncode(m_natGatewayId.c_str()) << "&";
@@ -91,16 +80,6 @@ Aws::String ReplaceRouteRequest::SerializePayload() const
     ss << "TransitGatewayId=" << StringUtils::URLEncode(m_transitGatewayId.c_str()) << "&";
   }
 
-  if(m_localGatewayIdHasBeenSet)
-  {
-    ss << "LocalGatewayId=" << StringUtils::URLEncode(m_localGatewayId.c_str()) << "&";
-  }
-
-  if(m_carrierGatewayIdHasBeenSet)
-  {
-    ss << "CarrierGatewayId=" << StringUtils::URLEncode(m_carrierGatewayId.c_str()) << "&";
-  }
-
   if(m_networkInterfaceIdHasBeenSet)
   {
     ss << "NetworkInterfaceId=" << StringUtils::URLEncode(m_networkInterfaceId.c_str()) << "&";
