@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/ec2/model/RequestLaunchTemplateData.h>
 #include <aws/core/utils/xml/XmlSerializer.h>
@@ -48,10 +58,8 @@ RequestLaunchTemplateData::RequestLaunchTemplateData() :
     m_creditSpecificationHasBeenSet(false),
     m_cpuOptionsHasBeenSet(false),
     m_capacityReservationSpecificationHasBeenSet(false),
-    m_licenseSpecificationsHasBeenSet(false),
     m_hibernationOptionsHasBeenSet(false),
-    m_metadataOptionsHasBeenSet(false),
-    m_enclaveOptionsHasBeenSet(false)
+    m_licenseSpecificationsHasBeenSet(false)
 {
 }
 
@@ -83,10 +91,8 @@ RequestLaunchTemplateData::RequestLaunchTemplateData(const XmlNode& xmlNode) :
     m_creditSpecificationHasBeenSet(false),
     m_cpuOptionsHasBeenSet(false),
     m_capacityReservationSpecificationHasBeenSet(false),
-    m_licenseSpecificationsHasBeenSet(false),
     m_hibernationOptionsHasBeenSet(false),
-    m_metadataOptionsHasBeenSet(false),
-    m_enclaveOptionsHasBeenSet(false)
+    m_licenseSpecificationsHasBeenSet(false)
 {
   *this = xmlNode;
 }
@@ -100,13 +106,13 @@ RequestLaunchTemplateData& RequestLaunchTemplateData::operator =(const XmlNode&
     XmlNode kernelIdNode = resultNode.FirstChild("KernelId");
     if(!kernelIdNode.IsNull())
     {
-      m_kernelId = Aws::Utils::Xml::DecodeEscapedXmlText(kernelIdNode.GetText());
+      m_kernelId = StringUtils::Trim(kernelIdNode.GetText().c_str());
       m_kernelIdHasBeenSet = true;
     }
     XmlNode ebsOptimizedNode = resultNode.FirstChild("EbsOptimized");
     if(!ebsOptimizedNode.IsNull())
     {
-      m_ebsOptimized = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(ebsOptimizedNode.GetText()).c_str()).c_str());
+      m_ebsOptimized = StringUtils::ConvertToBool(StringUtils::Trim(ebsOptimizedNode.GetText().c_str()).c_str());
       m_ebsOptimizedHasBeenSet = true;
     }
     XmlNode iamInstanceProfileNode = resultNode.FirstChild("IamInstanceProfile");
@@ -142,19 +148,19 @@ RequestLaunchTemplateData& RequestLaunchTemplateData::operator =(const XmlNode&
     XmlNode imageIdNode = resultNode.FirstChild("ImageId");
     if(!imageIdNode.IsNull())
     {
-      m_imageId = Aws::Utils::Xml::DecodeEscapedXmlText(imageIdNode.GetText());
+      m_imageId = StringUtils::Trim(imageIdNode.GetText().c_str());
       m_imageIdHasBeenSet = true;
     }
     XmlNode instanceTypeNode = resultNode.FirstChild("InstanceType");
     if(!instanceTypeNode.IsNull())
     {
-      m_instanceType = InstanceTypeMapper::GetInstanceTypeForName(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(instanceTypeNode.GetText()).c_str()).c_str());
+      m_instanceType = InstanceTypeMapper::GetInstanceTypeForName(StringUtils::Trim(instanceTypeNode.GetText().c_str()).c_str());
       m_instanceTypeHasBeenSet = true;
     }
     XmlNode keyNameNode = resultNode.FirstChild("KeyName");
     if(!keyNameNode.IsNull())
     {
-      m_keyName = Aws::Utils::Xml::DecodeEscapedXmlText(keyNameNode.GetText());
+      m_keyName = StringUtils::Trim(keyNameNode.GetText().c_str());
       m_keyNameHasBeenSet = true;
     }
     XmlNode monitoringNode = resultNode.FirstChild("Monitoring");
@@ -172,25 +178,25 @@ RequestLaunchTemplateData& RequestLaunchTemplateData::operator =(const XmlNode&
     XmlNode ramDiskIdNode = resultNode.FirstChild("RamDiskId");
     if(!ramDiskIdNode.IsNull())
     {
-      m_ramDiskId = Aws::Utils::Xml::DecodeEscapedXmlText(ramDiskIdNode.GetText());
+      m_ramDiskId = StringUtils::Trim(ramDiskIdNode.GetText().c_str());
       m_ramDiskIdHasBeenSet = true;
     }
     XmlNode disableApiTerminationNode = resultNode.FirstChild("DisableApiTermination");
     if(!disableApiTerminationNode.IsNull())
     {
-      m_disableApiTermination = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(disableApiTerminationNode.GetText()).c_str()).c_str());
+      m_disableApiTermination = StringUtils::ConvertToBool(StringUtils::Trim(disableApiTerminationNode.GetText().c_str()).c_str());
       m_disableApiTerminationHasBeenSet = true;
     }
     XmlNode instanceInitiatedShutdownBehaviorNode = resultNode.FirstChild("InstanceInitiatedShutdownBehavior");
     if(!instanceInitiatedShutdownBehaviorNode.IsNull())
     {
-      m_instanceInitiatedShutdownBehavior = ShutdownBehaviorMapper::GetShutdownBehaviorForName(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(instanceInitiatedShutdownBehaviorNode.GetText()).c_str()).c_str());
+      m_instanceInitiatedShutdownBehavior = ShutdownBehaviorMapper::GetShutdownBehaviorForName(StringUtils::Trim(instanceInitiatedShutdownBehaviorNode.GetText().c_str()).c_str());
       m_instanceInitiatedShutdownBehaviorHasBeenSet = true;
     }
     XmlNode userDataNode = resultNode.FirstChild("UserData");
     if(!userDataNode.IsNull())
     {
-      m_userData = Aws::Utils::Xml::DecodeEscapedXmlText(userDataNode.GetText());
+      m_userData = StringUtils::Trim(userDataNode.GetText().c_str());
       m_userDataHasBeenSet = true;
     }
     XmlNode tagSpecificationsNode = resultNode.FirstChild("TagSpecification");
@@ -235,7 +241,7 @@ RequestLaunchTemplateData& RequestLaunchTemplateData::operator =(const XmlNode&
       XmlNode securityGroupIdsMember = securityGroupIdsNode.FirstChild("SecurityGroupId");
       while(!securityGroupIdsMember.IsNull())
       {
-        m_securityGroupIds.push_back(securityGroupIdsMember.GetText());
+        m_securityGroupIds.push_back(StringUtils::Trim(securityGroupIdsMember.GetText().c_str()));
         securityGroupIdsMember = securityGroupIdsMember.NextNode("SecurityGroupId");
       }
 
@@ -247,7 +253,7 @@ RequestLaunchTemplateData& RequestLaunchTemplateData::operator =(const XmlNode&
       XmlNode securityGroupsMember = securityGroupsNode.FirstChild("SecurityGroup");
       while(!securityGroupsMember.IsNull())
       {
-        m_securityGroups.push_back(securityGroupsMember.GetText());
+        m_securityGroups.push_back(StringUtils::Trim(securityGroupsMember.GetText().c_str()));
         securityGroupsMember = securityGroupsMember.NextNode("SecurityGroup");
       }
 
@@ -277,6 +283,12 @@ RequestLaunchTemplateData& RequestLaunchTemplateData::operator =(const XmlNode&
       m_capacityReservationSpecification = capacityReservationSpecificationNode;
       m_capacityReservationSpecificationHasBeenSet = true;
     }
+    XmlNode hibernationOptionsNode = resultNode.FirstChild("HibernationOptions");
+    if(!hibernationOptionsNode.IsNull())
+    {
+      m_hibernationOptions = hibernationOptionsNode;
+      m_hibernationOptionsHasBeenSet = true;
+    }
     XmlNode licenseSpecificationsNode = resultNode.FirstChild("LicenseSpecification");
     if(!licenseSpecificationsNode.IsNull())
     {
@@ -289,24 +301,6 @@ RequestLaunchTemplateData& RequestLaunchTemplateData::operator =(const XmlNode&
 
       m_licenseSpecificationsHasBeenSet = true;
     }
-    XmlNode hibernationOptionsNode = resultNode.FirstChild("HibernationOptions");
-    if(!hibernationOptionsNode.IsNull())
-    {
-      m_hibernationOptions = hibernationOptionsNode;
-      m_hibernationOptionsHasBeenSet = true;
-    }
-    XmlNode metadataOptionsNode = resultNode.FirstChild("MetadataOptions");
-    if(!metadataOptionsNode.IsNull())
-    {
-      m_metadataOptions = metadataOptionsNode;
-      m_metadataOptionsHasBeenSet = true;
-    }
-    XmlNode enclaveOptionsNode = resultNode.FirstChild("EnclaveOptions");
-    if(!enclaveOptionsNode.IsNull())
-    {
-      m_enclaveOptions = enclaveOptionsNode;
-      m_enclaveOptionsHasBeenSet = true;
-    }
   }
 
   return *this;
@@ -481,6 +475,13 @@ void RequestLaunchTemplateData::OutputToStream(Aws::OStream& oStream, const char
       m_capacityReservationSpecification.OutputToStream(oStream, capacityReservationSpecificationLocationAndMemberSs.str().c_str());
   }
 
+  if(m_hibernationOptionsHasBeenSet)
+  {
+      Aws::StringStream hibernationOptionsLocationAndMemberSs;
+      hibernationOptionsLocationAndMemberSs << location << index << locationValue << ".HibernationOptions";
+      m_hibernationOptions.OutputToStream(oStream, hibernationOptionsLocationAndMemberSs.str().c_str());
+  }
+
   if(m_licenseSpecificationsHasBeenSet)
   {
       unsigned licenseSpecificationsIdx = 1;
@@ -492,27 +493,6 @@ void RequestLaunchTemplateData::OutputToStream(Aws::OStream& oStream, const char
       }
   }
 
-  if(m_hibernationOptionsHasBeenSet)
-  {
-      Aws::StringStream hibernationOptionsLocationAndMemberSs;
-      hibernationOptionsLocationAndMemberSs << location << index << locationValue << ".HibernationOptions";
-      m_hibernationOptions.OutputToStream(oStream, hibernationOptionsLocationAndMemberSs.str().c_str());
-  }
-
-  if(m_metadataOptionsHasBeenSet)
-  {
-      Aws::StringStream metadataOptionsLocationAndMemberSs;
-      metadataOptionsLocationAndMemberSs << location << index << locationValue << ".MetadataOptions";
-      m_metadataOptions.OutputToStream(oStream, metadataOptionsLocationAndMemberSs.str().c_str());
-  }
-
-  if(m_enclaveOptionsHasBeenSet)
-  {
-      Aws::StringStream enclaveOptionsLocationAndMemberSs;
-      enclaveOptionsLocationAndMemberSs << location << index << locationValue << ".EnclaveOptions";
-      m_enclaveOptions.OutputToStream(oStream, enclaveOptionsLocationAndMemberSs.str().c_str());
-  }
-
 }
 
 void RequestLaunchTemplateData::OutputToStream(Aws::OStream& oStream, const char* location) const
@@ -661,6 +641,12 @@ void RequestLaunchTemplateData::OutputToStream(Aws::OStream& oStream, const char
       capacityReservationSpecificationLocationAndMember += ".CapacityReservationSpecification";
       m_capacityReservationSpecification.OutputToStream(oStream, capacityReservationSpecificationLocationAndMember.c_str());
   }
+  if(m_hibernationOptionsHasBeenSet)
+  {
+      Aws::String hibernationOptionsLocationAndMember(location);
+      hibernationOptionsLocationAndMember += ".HibernationOptions";
+      m_hibernationOptions.OutputToStream(oStream, hibernationOptionsLocationAndMember.c_str());
+  }
   if(m_licenseSpecificationsHasBeenSet)
   {
       unsigned licenseSpecificationsIdx = 1;
@@ -671,24 +657,6 @@ void RequestLaunchTemplateData::OutputToStream(Aws::OStream& oStream, const char
         item.OutputToStream(oStream, licenseSpecificationsSs.str().c_str());
       }
   }
-  if(m_hibernationOptionsHasBeenSet)
-  {
-      Aws::String hibernationOptionsLocationAndMember(location);
-      hibernationOptionsLocationAndMember += ".HibernationOptions";
-      m_hibernationOptions.OutputToStream(oStream, hibernationOptionsLocationAndMember.c_str());
-  }
-  if(m_metadataOptionsHasBeenSet)
-  {
-      Aws::String metadataOptionsLocationAndMember(location);
-      metadataOptionsLocationAndMember += ".MetadataOptions";
-      m_metadataOptions.OutputToStream(oStream, metadataOptionsLocationAndMember.c_str());
-  }
-  if(m_enclaveOptionsHasBeenSet)
-  {
-      Aws::String enclaveOptionsLocationAndMember(location);
-      enclaveOptionsLocationAndMember += ".EnclaveOptions";
-      m_enclaveOptions.OutputToStream(oStream, enclaveOptionsLocationAndMember.c_str());
-  }
 }
 
 } // namespace Model
