@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/ec2/model/ServiceConfiguration.h>
 #include <aws/core/utils/xml/XmlSerializer.h>
@@ -32,11 +42,8 @@ ServiceConfiguration::ServiceConfiguration() :
     m_managesVpcEndpoints(false),
     m_managesVpcEndpointsHasBeenSet(false),
     m_networkLoadBalancerArnsHasBeenSet(false),
-    m_gatewayLoadBalancerArnsHasBeenSet(false),
     m_baseEndpointDnsNamesHasBeenSet(false),
-    m_privateDnsNameHasBeenSet(false),
-    m_privateDnsNameConfigurationHasBeenSet(false),
-    m_tagsHasBeenSet(false)
+    m_privateDnsNameHasBeenSet(false)
 {
 }
 
@@ -52,11 +59,8 @@ ServiceConfiguration::ServiceConfiguration(const XmlNode& xmlNode) :
     m_managesVpcEndpoints(false),
     m_managesVpcEndpointsHasBeenSet(false),
     m_networkLoadBalancerArnsHasBeenSet(false),
-    m_gatewayLoadBalancerArnsHasBeenSet(false),
     m_baseEndpointDnsNamesHasBeenSet(false),
-    m_privateDnsNameHasBeenSet(false),
-    m_privateDnsNameConfigurationHasBeenSet(false),
-    m_tagsHasBeenSet(false)
+    m_privateDnsNameHasBeenSet(false)
 {
   *this = xmlNode;
 }
@@ -82,19 +86,19 @@ ServiceConfiguration& ServiceConfiguration::operator =(const XmlNode& xmlNode)
     XmlNode serviceIdNode = resultNode.FirstChild("serviceId");
     if(!serviceIdNode.IsNull())
     {
-      m_serviceId = Aws::Utils::Xml::DecodeEscapedXmlText(serviceIdNode.GetText());
+      m_serviceId = StringUtils::Trim(serviceIdNode.GetText().c_str());
       m_serviceIdHasBeenSet = true;
     }
     XmlNode serviceNameNode = resultNode.FirstChild("serviceName");
     if(!serviceNameNode.IsNull())
     {
-      m_serviceName = Aws::Utils::Xml::DecodeEscapedXmlText(serviceNameNode.GetText());
+      m_serviceName = StringUtils::Trim(serviceNameNode.GetText().c_str());
       m_serviceNameHasBeenSet = true;
     }
     XmlNode serviceStateNode = resultNode.FirstChild("serviceState");
     if(!serviceStateNode.IsNull())
     {
-      m_serviceState = ServiceStateMapper::GetServiceStateForName(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(serviceStateNode.GetText()).c_str()).c_str());
+      m_serviceState = ServiceStateMapper::GetServiceStateForName(StringUtils::Trim(serviceStateNode.GetText().c_str()).c_str());
       m_serviceStateHasBeenSet = true;
     }
     XmlNode availabilityZonesNode = resultNode.FirstChild("availabilityZoneSet");
@@ -103,7 +107,7 @@ ServiceConfiguration& ServiceConfiguration::operator =(const XmlNode& xmlNode)
       XmlNode availabilityZonesMember = availabilityZonesNode.FirstChild("item");
       while(!availabilityZonesMember.IsNull())
       {
-        m_availabilityZones.push_back(availabilityZonesMember.GetText());
+        m_availabilityZones.push_back(StringUtils::Trim(availabilityZonesMember.GetText().c_str()));
         availabilityZonesMember = availabilityZonesMember.NextNode("item");
       }
 
@@ -112,13 +116,13 @@ ServiceConfiguration& ServiceConfiguration::operator =(const XmlNode& xmlNode)
     XmlNode acceptanceRequiredNode = resultNode.FirstChild("acceptanceRequired");
     if(!acceptanceRequiredNode.IsNull())
     {
-      m_acceptanceRequired = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(acceptanceRequiredNode.GetText()).c_str()).c_str());
+      m_acceptanceRequired = StringUtils::ConvertToBool(StringUtils::Trim(acceptanceRequiredNode.GetText().c_str()).c_str());
       m_acceptanceRequiredHasBeenSet = true;
     }
     XmlNode managesVpcEndpointsNode = resultNode.FirstChild("managesVpcEndpoints");
     if(!managesVpcEndpointsNode.IsNull())
     {
-      m_managesVpcEndpoints = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(managesVpcEndpointsNode.GetText()).c_str()).c_str());
+      m_managesVpcEndpoints = StringUtils::ConvertToBool(StringUtils::Trim(managesVpcEndpointsNode.GetText().c_str()).c_str());
       m_managesVpcEndpointsHasBeenSet = true;
     }
     XmlNode networkLoadBalancerArnsNode = resultNode.FirstChild("networkLoadBalancerArnSet");
@@ -127,31 +131,19 @@ ServiceConfiguration& ServiceConfiguration::operator =(const XmlNode& xmlNode)
       XmlNode networkLoadBalancerArnsMember = networkLoadBalancerArnsNode.FirstChild("item");
       while(!networkLoadBalancerArnsMember.IsNull())
       {
-        m_networkLoadBalancerArns.push_back(networkLoadBalancerArnsMember.GetText());
+        m_networkLoadBalancerArns.push_back(StringUtils::Trim(networkLoadBalancerArnsMember.GetText().c_str()));
         networkLoadBalancerArnsMember = networkLoadBalancerArnsMember.NextNode("item");
       }
 
       m_networkLoadBalancerArnsHasBeenSet = true;
     }
-    XmlNode gatewayLoadBalancerArnsNode = resultNode.FirstChild("gatewayLoadBalancerArnSet");
-    if(!gatewayLoadBalancerArnsNode.IsNull())
-    {
-      XmlNode gatewayLoadBalancerArnsMember = gatewayLoadBalancerArnsNode.FirstChild("item");
-      while(!gatewayLoadBalancerArnsMember.IsNull())
-      {
-        m_gatewayLoadBalancerArns.push_back(gatewayLoadBalancerArnsMember.GetText());
-        gatewayLoadBalancerArnsMember = gatewayLoadBalancerArnsMember.NextNode("item");
-      }
-
-      m_gatewayLoadBalancerArnsHasBeenSet = true;
-    }
     XmlNode baseEndpointDnsNamesNode = resultNode.FirstChild("baseEndpointDnsNameSet");
     if(!baseEndpointDnsNamesNode.IsNull())
     {
       XmlNode baseEndpointDnsNamesMember = baseEndpointDnsNamesNode.FirstChild("item");
       while(!baseEndpointDnsNamesMember.IsNull())
       {
-        m_baseEndpointDnsNames.push_back(baseEndpointDnsNamesMember.GetText());
+        m_baseEndpointDnsNames.push_back(StringUtils::Trim(baseEndpointDnsNamesMember.GetText().c_str()));
         baseEndpointDnsNamesMember = baseEndpointDnsNamesMember.NextNode("item");
       }
 
@@ -160,27 +152,9 @@ ServiceConfiguration& ServiceConfiguration::operator =(const XmlNode& xmlNode)
     XmlNode privateDnsNameNode = resultNode.FirstChild("privateDnsName");
     if(!privateDnsNameNode.IsNull())
     {
-      m_privateDnsName = Aws::Utils::Xml::DecodeEscapedXmlText(privateDnsNameNode.GetText());
+      m_privateDnsName = StringUtils::Trim(privateDnsNameNode.GetText().c_str());
       m_privateDnsNameHasBeenSet = true;
     }
-    XmlNode privateDnsNameConfigurationNode = resultNode.FirstChild("privateDnsNameConfiguration");
-    if(!privateDnsNameConfigurationNode.IsNull())
-    {
-      m_privateDnsNameConfiguration = privateDnsNameConfigurationNode;
-      m_privateDnsNameConfigurationHasBeenSet = true;
-    }
-    XmlNode tagsNode = resultNode.FirstChild("tagSet");
-    if(!tagsNode.IsNull())
-    {
-      XmlNode tagsMember = tagsNode.FirstChild("item");
-      while(!tagsMember.IsNull())
-      {
-        m_tags.push_back(tagsMember);
-        tagsMember = tagsMember.NextNode("item");
-      }
-
-      m_tagsHasBeenSet = true;
-    }
   }
 
   return *this;
@@ -242,15 +216,6 @@ void ServiceConfiguration::OutputToStream(Aws::OStream& oStream, const char* loc
       }
   }
 
-  if(m_gatewayLoadBalancerArnsHasBeenSet)
-  {
-      unsigned gatewayLoadBalancerArnsIdx = 1;
-      for(auto& item : m_gatewayLoadBalancerArns)
-      {
-        oStream << location << index << locationValue << ".GatewayLoadBalancerArnSet." << gatewayLoadBalancerArnsIdx++ << "=" << StringUtils::URLEncode(item.c_str()) << "&";
-      }
-  }
-
   if(m_baseEndpointDnsNamesHasBeenSet)
   {
       unsigned baseEndpointDnsNamesIdx = 1;
@@ -265,24 +230,6 @@ void ServiceConfiguration::OutputToStream(Aws::OStream& oStream, const char* loc
       oStream << location << index << locationValue << ".PrivateDnsName=" << StringUtils::URLEncode(m_privateDnsName.c_str()) << "&";
   }
 
-  if(m_privateDnsNameConfigurationHasBeenSet)
-  {
-      Aws::StringStream privateDnsNameConfigurationLocationAndMemberSs;
-      privateDnsNameConfigurationLocationAndMemberSs << location << index << locationValue << ".PrivateDnsNameConfiguration";
-      m_privateDnsNameConfiguration.OutputToStream(oStream, privateDnsNameConfigurationLocationAndMemberSs.str().c_str());
-  }
-
-  if(m_tagsHasBeenSet)
-  {
-      unsigned tagsIdx = 1;
-      for(auto& item : m_tags)
-      {
-        Aws::StringStream tagsSs;
-        tagsSs << location << index << locationValue << ".TagSet." << tagsIdx++;
-        item.OutputToStream(oStream, tagsSs.str().c_str());
-      }
-  }
-
 }
 
 void ServiceConfiguration::OutputToStream(Aws::OStream& oStream, const char* location) const
@@ -333,14 +280,6 @@ void ServiceConfiguration::OutputToStream(Aws::OStream& oStream, const char* loc
         oStream << location << ".NetworkLoadBalancerArnSet." << networkLoadBalancerArnsIdx++ << "=" << StringUtils::URLEncode(item.c_str()) << "&";
       }
   }
-  if(m_gatewayLoadBalancerArnsHasBeenSet)
-  {
-      unsigned gatewayLoadBalancerArnsIdx = 1;
-      for(auto& item : m_gatewayLoadBalancerArns)
-      {
-        oStream << location << ".GatewayLoadBalancerArnSet." << gatewayLoadBalancerArnsIdx++ << "=" << StringUtils::URLEncode(item.c_str()) << "&";
-      }
-  }
   if(m_baseEndpointDnsNamesHasBeenSet)
   {
       unsigned baseEndpointDnsNamesIdx = 1;
@@ -353,22 +292,6 @@ void ServiceConfiguration::OutputToStream(Aws::OStream& oStream, const char* loc
   {
       oStream << location << ".PrivateDnsName=" << StringUtils::URLEncode(m_privateDnsName.c_str()) << "&";
   }
-  if(m_privateDnsNameConfigurationHasBeenSet)
-  {
-      Aws::String privateDnsNameConfigurationLocationAndMember(location);
-      privateDnsNameConfigurationLocationAndMember += ".PrivateDnsNameConfiguration";
-      m_privateDnsNameConfiguration.OutputToStream(oStream, privateDnsNameConfigurationLocationAndMember.c_str());
-  }
-  if(m_tagsHasBeenSet)
-  {
-      unsigned tagsIdx = 1;
-      for(auto& item : m_tags)
-      {
-        Aws::StringStream tagsSs;
-        tagsSs << location <<  ".TagSet." << tagsIdx++;
-        item.OutputToStream(oStream, tagsSs.str().c_str());
-      }
-  }
 }
 
 } // namespace Model
