@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/ecr/ECR_EXPORTS.h>
@@ -23,7 +33,7 @@ namespace Model
   {
   public:
     DescribeRepositoriesRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -36,57 +46,57 @@ namespace Model
 
 
     /**
-     * <p>The Amazon Web Services account ID associated with the registry that contains
-     * the repositories to be described. If you do not specify a registry, the default
+     * <p>The AWS account ID associated with the registry that contains the
+     * repositories to be described. If you do not specify a registry, the default
      * registry is assumed.</p>
      */
     inline const Aws::String& GetRegistryId() const{ return m_registryId; }
 
     /**
-     * <p>The Amazon Web Services account ID associated with the registry that contains
-     * the repositories to be described. If you do not specify a registry, the default
+     * <p>The AWS account ID associated with the registry that contains the
+     * repositories to be described. If you do not specify a registry, the default
      * registry is assumed.</p>
      */
     inline bool RegistryIdHasBeenSet() const { return m_registryIdHasBeenSet; }
 
     /**
-     * <p>The Amazon Web Services account ID associated with the registry that contains
-     * the repositories to be described. If you do not specify a registry, the default
+     * <p>The AWS account ID associated with the registry that contains the
+     * repositories to be described. If you do not specify a registry, the default
      * registry is assumed.</p>
      */
     inline void SetRegistryId(const Aws::String& value) { m_registryIdHasBeenSet = true; m_registryId = value; }
 
     /**
-     * <p>The Amazon Web Services account ID associated with the registry that contains
-     * the repositories to be described. If you do not specify a registry, the default
+     * <p>The AWS account ID associated with the registry that contains the
+     * repositories to be described. If you do not specify a registry, the default
      * registry is assumed.</p>
      */
     inline void SetRegistryId(Aws::String&& value) { m_registryIdHasBeenSet = true; m_registryId = std::move(value); }
 
     /**
-     * <p>The Amazon Web Services account ID associated with the registry that contains
-     * the repositories to be described. If you do not specify a registry, the default
+     * <p>The AWS account ID associated with the registry that contains the
+     * repositories to be described. If you do not specify a registry, the default
      * registry is assumed.</p>
      */
     inline void SetRegistryId(const char* value) { m_registryIdHasBeenSet = true; m_registryId.assign(value); }
 
     /**
-     * <p>The Amazon Web Services account ID associated with the registry that contains
-     * the repositories to be described. If you do not specify a registry, the default
+     * <p>The AWS account ID associated with the registry that contains the
+     * repositories to be described. If you do not specify a registry, the default
      * registry is assumed.</p>
      */
     inline DescribeRepositoriesRequest& WithRegistryId(const Aws::String& value) { SetRegistryId(value); return *this;}
 
     /**
-     * <p>The Amazon Web Services account ID associated with the registry that contains
-     * the repositories to be described. If you do not specify a registry, the default
+     * <p>The AWS account ID associated with the registry that contains the
+     * repositories to be described. If you do not specify a registry, the default
      * registry is assumed.</p>
      */
     inline DescribeRepositoriesRequest& WithRegistryId(Aws::String&& value) { SetRegistryId(std::move(value)); return *this;}
 
     /**
-     * <p>The Amazon Web Services account ID associated with the registry that contains
-     * the repositories to be described. If you do not specify a registry, the default
+     * <p>The AWS account ID associated with the registry that contains the
+     * repositories to be described. If you do not specify a registry, the default
      * registry is assumed.</p>
      */
     inline DescribeRepositoriesRequest& WithRegistryId(const char* value) { SetRegistryId(value); return *this;}
@@ -154,9 +164,9 @@ namespace Model
      * the end of the previous results that returned the <code>nextToken</code> value.
      * This value is <code>null</code> when there are no more results to return. This
      * option cannot be used when you specify repositories with
-     * <code>repositoryNames</code>.</p>  <p>This token should be treated as an
+     * <code>repositoryNames</code>.</p> <note> <p>This token should be treated as an
      * opaque identifier that is only used to retrieve the next items in a list and not
-     * for other programmatic purposes.</p> 
+     * for other programmatic purposes.</p> </note>
      */
     inline const Aws::String& GetNextToken() const{ return m_nextToken; }
 
@@ -167,9 +177,9 @@ namespace Model
      * the end of the previous results that returned the <code>nextToken</code> value.
      * This value is <code>null</code> when there are no more results to return. This
      * option cannot be used when you specify repositories with
-     * <code>repositoryNames</code>.</p>  <p>This token should be treated as an
+     * <code>repositoryNames</code>.</p> <note> <p>This token should be treated as an
      * opaque identifier that is only used to retrieve the next items in a list and not
-     * for other programmatic purposes.</p> 
+     * for other programmatic purposes.</p> </note>
      */
     inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }
 
@@ -180,9 +190,9 @@ namespace Model
      * the end of the previous results that returned the <code>nextToken</code> value.
      * This value is <code>null</code> when there are no more results to return. This
      * option cannot be used when you specify repositories with
-     * <code>repositoryNames</code>.</p>  <p>This token should be treated as an
+     * <code>repositoryNames</code>.</p> <note> <p>This token should be treated as an
      * opaque identifier that is only used to retrieve the next items in a list and not
-     * for other programmatic purposes.</p> 
+     * for other programmatic purposes.</p> </note>
      */
     inline void SetNextToken(const Aws::String& value) { m_nextTokenHasBeenSet = true; m_nextToken = value; }
 
@@ -193,9 +203,9 @@ namespace Model
      * the end of the previous results that returned the <code>nextToken</code> value.
      * This value is <code>null</code> when there are no more results to return. This
      * option cannot be used when you specify repositories with
-     * <code>repositoryNames</code>.</p>  <p>This token should be treated as an
+     * <code>repositoryNames</code>.</p> <note> <p>This token should be treated as an
      * opaque identifier that is only used to retrieve the next items in a list and not
-     * for other programmatic purposes.</p> 
+     * for other programmatic purposes.</p> </note>
      */
     inline void SetNextToken(Aws::String&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::move(value); }
 
@@ -206,9 +216,9 @@ namespace Model
      * the end of the previous results that returned the <code>nextToken</code> value.
      * This value is <code>null</code> when there are no more results to return. This
      * option cannot be used when you specify repositories with
-     * <code>repositoryNames</code>.</p>  <p>This token should be treated as an
+     * <code>repositoryNames</code>.</p> <note> <p>This token should be treated as an
      * opaque identifier that is only used to retrieve the next items in a list and not
-     * for other programmatic purposes.</p> 
+     * for other programmatic purposes.</p> </note>
      */
     inline void SetNextToken(const char* value) { m_nextTokenHasBeenSet = true; m_nextToken.assign(value); }
 
@@ -219,9 +229,9 @@ namespace Model
      * the end of the previous results that returned the <code>nextToken</code> value.
      * This value is <code>null</code> when there are no more results to return. This
      * option cannot be used when you specify repositories with
-     * <code>repositoryNames</code>.</p>  <p>This token should be treated as an
+     * <code>repositoryNames</code>.</p> <note> <p>This token should be treated as an
      * opaque identifier that is only used to retrieve the next items in a list and not
-     * for other programmatic purposes.</p> 
+     * for other programmatic purposes.</p> </note>
      */
     inline DescribeRepositoriesRequest& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}
 
@@ -232,9 +242,9 @@ namespace Model
      * the end of the previous results that returned the <code>nextToken</code> value.
      * This value is <code>null</code> when there are no more results to return. This
      * option cannot be used when you specify repositories with
-     * <code>repositoryNames</code>.</p>  <p>This token should be treated as an
+     * <code>repositoryNames</code>.</p> <note> <p>This token should be treated as an
      * opaque identifier that is only used to retrieve the next items in a list and not
-     * for other programmatic purposes.</p> 
+     * for other programmatic purposes.</p> </note>
      */
     inline DescribeRepositoriesRequest& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}
 
@@ -245,9 +255,9 @@ namespace Model
      * the end of the previous results that returned the <code>nextToken</code> value.
      * This value is <code>null</code> when there are no more results to return. This
      * option cannot be used when you specify repositories with
-     * <code>repositoryNames</code>.</p>  <p>This token should be treated as an
+     * <code>repositoryNames</code>.</p> <note> <p>This token should be treated as an
      * opaque identifier that is only used to retrieve the next items in a list and not
-     * for other programmatic purposes.</p> 
+     * for other programmatic purposes.</p> </note>
      */
     inline DescribeRepositoriesRequest& WithNextToken(const char* value) { SetNextToken(value); return *this;}
 
@@ -311,16 +321,16 @@ namespace Model
   private:
 
     Aws::String m_registryId;
-    bool m_registryIdHasBeenSet = false;
+    bool m_registryIdHasBeenSet;
 
     Aws::Vector<Aws::String> m_repositoryNames;
-    bool m_repositoryNamesHasBeenSet = false;
+    bool m_repositoryNamesHasBeenSet;
 
     Aws::String m_nextToken;
-    bool m_nextTokenHasBeenSet = false;
+    bool m_nextTokenHasBeenSet;
 
     int m_maxResults;
-    bool m_maxResultsHasBeenSet = false;
+    bool m_maxResultsHasBeenSet;
   };
 
 } // namespace Model
