@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/ecs/ECS_EXPORTS.h>
@@ -43,55 +53,49 @@ namespace Model
 
     /**
      * <p>The Linux capabilities for the container that are added to or dropped from
-     * the default configuration provided by Docker.</p>  <p>For tasks that use
-     * the Fargate launch type, <code>capabilities</code> is supported for all platform
-     * versions but the <code>add</code> parameter is only supported if using platform
-     * version 1.4.0 or later.</p> 
+     * the default configuration provided by Docker.</p> <note> <p>If you are using
+     * tasks that use the Fargate launch type, <code>capabilities</code> is supported
+     * but the <code>add</code> parameter is not supported.</p> </note>
      */
     inline const KernelCapabilities& GetCapabilities() const{ return m_capabilities; }
 
     /**
      * <p>The Linux capabilities for the container that are added to or dropped from
-     * the default configuration provided by Docker.</p>  <p>For tasks that use
-     * the Fargate launch type, <code>capabilities</code> is supported for all platform
-     * versions but the <code>add</code> parameter is only supported if using platform
-     * version 1.4.0 or later.</p> 
+     * the default configuration provided by Docker.</p> <note> <p>If you are using
+     * tasks that use the Fargate launch type, <code>capabilities</code> is supported
+     * but the <code>add</code> parameter is not supported.</p> </note>
      */
     inline bool CapabilitiesHasBeenSet() const { return m_capabilitiesHasBeenSet; }
 
     /**
      * <p>The Linux capabilities for the container that are added to or dropped from
-     * the default configuration provided by Docker.</p>  <p>For tasks that use
-     * the Fargate launch type, <code>capabilities</code> is supported for all platform
-     * versions but the <code>add</code> parameter is only supported if using platform
-     * version 1.4.0 or later.</p> 
+     * the default configuration provided by Docker.</p> <note> <p>If you are using
+     * tasks that use the Fargate launch type, <code>capabilities</code> is supported
+     * but the <code>add</code> parameter is not supported.</p> </note>
      */
     inline void SetCapabilities(const KernelCapabilities& value) { m_capabilitiesHasBeenSet = true; m_capabilities = value; }
 
     /**
      * <p>The Linux capabilities for the container that are added to or dropped from
-     * the default configuration provided by Docker.</p>  <p>For tasks that use
-     * the Fargate launch type, <code>capabilities</code> is supported for all platform
-     * versions but the <code>add</code> parameter is only supported if using platform
-     * version 1.4.0 or later.</p> 
+     * the default configuration provided by Docker.</p> <note> <p>If you are using
+     * tasks that use the Fargate launch type, <code>capabilities</code> is supported
+     * but the <code>add</code> parameter is not supported.</p> </note>
      */
     inline void SetCapabilities(KernelCapabilities&& value) { m_capabilitiesHasBeenSet = true; m_capabilities = std::move(value); }
 
     /**
      * <p>The Linux capabilities for the container that are added to or dropped from
-     * the default configuration provided by Docker.</p>  <p>For tasks that use
-     * the Fargate launch type, <code>capabilities</code> is supported for all platform
-     * versions but the <code>add</code> parameter is only supported if using platform
-     * version 1.4.0 or later.</p> 
+     * the default configuration provided by Docker.</p> <note> <p>If you are using
+     * tasks that use the Fargate launch type, <code>capabilities</code> is supported
+     * but the <code>add</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& WithCapabilities(const KernelCapabilities& value) { SetCapabilities(value); return *this;}
 
     /**
      * <p>The Linux capabilities for the container that are added to or dropped from
-     * the default configuration provided by Docker.</p>  <p>For tasks that use
-     * the Fargate launch type, <code>capabilities</code> is supported for all platform
-     * versions but the <code>add</code> parameter is only supported if using platform
-     * version 1.4.0 or later.</p> 
+     * the default configuration provided by Docker.</p> <note> <p>If you are using
+     * tasks that use the Fargate launch type, <code>capabilities</code> is supported
+     * but the <code>add</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& WithCapabilities(KernelCapabilities&& value) { SetCapabilities(std::move(value)); return *this;}
 
@@ -103,9 +107,9 @@ namespace Model
      * a container</a> section of the <a
      * href="https://docs.docker.com/engine/api/v1.35/">Docker Remote API</a> and the
      * <code>--device</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>devices</code> parameter is not supported.</p> 
+     * <code>devices</code> parameter is not supported.</p> </note>
      */
     inline const Aws::Vector<Device>& GetDevices() const{ return m_devices; }
 
@@ -116,9 +120,9 @@ namespace Model
      * a container</a> section of the <a
      * href="https://docs.docker.com/engine/api/v1.35/">Docker Remote API</a> and the
      * <code>--device</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>devices</code> parameter is not supported.</p> 
+     * <code>devices</code> parameter is not supported.</p> </note>
      */
     inline bool DevicesHasBeenSet() const { return m_devicesHasBeenSet; }
 
@@ -129,9 +133,9 @@ namespace Model
      * a container</a> section of the <a
      * href="https://docs.docker.com/engine/api/v1.35/">Docker Remote API</a> and the
      * <code>--device</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>devices</code> parameter is not supported.</p> 
+     * <code>devices</code> parameter is not supported.</p> </note>
      */
     inline void SetDevices(const Aws::Vector<Device>& value) { m_devicesHasBeenSet = true; m_devices = value; }
 
@@ -142,9 +146,9 @@ namespace Model
      * a container</a> section of the <a
      * href="https://docs.docker.com/engine/api/v1.35/">Docker Remote API</a> and the
      * <code>--device</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>devices</code> parameter is not supported.</p> 
+     * <code>devices</code> parameter is not supported.</p> </note>
      */
     inline void SetDevices(Aws::Vector<Device>&& value) { m_devicesHasBeenSet = true; m_devices = std::move(value); }
 
@@ -155,9 +159,9 @@ namespace Model
      * a container</a> section of the <a
      * href="https://docs.docker.com/engine/api/v1.35/">Docker Remote API</a> and the
      * <code>--device</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>devices</code> parameter is not supported.</p> 
+     * <code>devices</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& WithDevices(const Aws::Vector<Device>& value) { SetDevices(value); return *this;}
 
@@ -168,9 +172,9 @@ namespace Model
      * a container</a> section of the <a
      * href="https://docs.docker.com/engine/api/v1.35/">Docker Remote API</a> and the
      * <code>--device</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>devices</code> parameter is not supported.</p> 
+     * <code>devices</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& WithDevices(Aws::Vector<Device>&& value) { SetDevices(std::move(value)); return *this;}
 
@@ -181,9 +185,9 @@ namespace Model
      * a container</a> section of the <a
      * href="https://docs.docker.com/engine/api/v1.35/">Docker Remote API</a> and the
      * <code>--device</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>devices</code> parameter is not supported.</p> 
+     * <code>devices</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& AddDevices(const Device& value) { m_devicesHasBeenSet = true; m_devices.push_back(value); return *this; }
 
@@ -194,9 +198,9 @@ namespace Model
      * a container</a> section of the <a
      * href="https://docs.docker.com/engine/api/v1.35/">Docker Remote API</a> and the
      * <code>--device</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>devices</code> parameter is not supported.</p> 
+     * <code>devices</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& AddDevices(Device&& value) { m_devicesHasBeenSet = true; m_devices.push_back(std::move(value)); return *this; }
 
@@ -249,36 +253,36 @@ namespace Model
     /**
      * <p>The value for the size (in MiB) of the <code>/dev/shm</code> volume. This
      * parameter maps to the <code>--shm-size</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>sharedMemorySize</code> parameter is not supported.</p> 
+     * <code>sharedMemorySize</code> parameter is not supported.</p> </note>
      */
     inline int GetSharedMemorySize() const{ return m_sharedMemorySize; }
 
     /**
      * <p>The value for the size (in MiB) of the <code>/dev/shm</code> volume. This
      * parameter maps to the <code>--shm-size</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>sharedMemorySize</code> parameter is not supported.</p> 
+     * <code>sharedMemorySize</code> parameter is not supported.</p> </note>
      */
     inline bool SharedMemorySizeHasBeenSet() const { return m_sharedMemorySizeHasBeenSet; }
 
     /**
      * <p>The value for the size (in MiB) of the <code>/dev/shm</code> volume. This
      * parameter maps to the <code>--shm-size</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>sharedMemorySize</code> parameter is not supported.</p> 
+     * <code>sharedMemorySize</code> parameter is not supported.</p> </note>
      */
     inline void SetSharedMemorySize(int value) { m_sharedMemorySizeHasBeenSet = true; m_sharedMemorySize = value; }
 
     /**
      * <p>The value for the size (in MiB) of the <code>/dev/shm</code> volume. This
      * parameter maps to the <code>--shm-size</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>sharedMemorySize</code> parameter is not supported.</p> 
+     * <code>sharedMemorySize</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& WithSharedMemorySize(int value) { SetSharedMemorySize(value); return *this;}
 
@@ -286,205 +290,75 @@ namespace Model
     /**
      * <p>The container path, mount options, and size (in MiB) of the tmpfs mount. This
      * parameter maps to the <code>--tmpfs</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>tmpfs</code> parameter is not supported.</p> 
+     * <code>tmpfs</code> parameter is not supported.</p> </note>
      */
     inline const Aws::Vector<Tmpfs>& GetTmpfs() const{ return m_tmpfs; }
 
     /**
      * <p>The container path, mount options, and size (in MiB) of the tmpfs mount. This
      * parameter maps to the <code>--tmpfs</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>tmpfs</code> parameter is not supported.</p> 
+     * <code>tmpfs</code> parameter is not supported.</p> </note>
      */
     inline bool TmpfsHasBeenSet() const { return m_tmpfsHasBeenSet; }
 
     /**
      * <p>The container path, mount options, and size (in MiB) of the tmpfs mount. This
      * parameter maps to the <code>--tmpfs</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>tmpfs</code> parameter is not supported.</p> 
+     * <code>tmpfs</code> parameter is not supported.</p> </note>
      */
     inline void SetTmpfs(const Aws::Vector<Tmpfs>& value) { m_tmpfsHasBeenSet = true; m_tmpfs = value; }
 
     /**
      * <p>The container path, mount options, and size (in MiB) of the tmpfs mount. This
      * parameter maps to the <code>--tmpfs</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>tmpfs</code> parameter is not supported.</p> 
+     * <code>tmpfs</code> parameter is not supported.</p> </note>
      */
     inline void SetTmpfs(Aws::Vector<Tmpfs>&& value) { m_tmpfsHasBeenSet = true; m_tmpfs = std::move(value); }
 
     /**
      * <p>The container path, mount options, and size (in MiB) of the tmpfs mount. This
      * parameter maps to the <code>--tmpfs</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>tmpfs</code> parameter is not supported.</p> 
+     * <code>tmpfs</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& WithTmpfs(const Aws::Vector<Tmpfs>& value) { SetTmpfs(value); return *this;}
 
     /**
      * <p>The container path, mount options, and size (in MiB) of the tmpfs mount. This
      * parameter maps to the <code>--tmpfs</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>tmpfs</code> parameter is not supported.</p> 
+     * <code>tmpfs</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& WithTmpfs(Aws::Vector<Tmpfs>&& value) { SetTmpfs(std::move(value)); return *this;}
 
     /**
      * <p>The container path, mount options, and size (in MiB) of the tmpfs mount. This
      * parameter maps to the <code>--tmpfs</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>tmpfs</code> parameter is not supported.</p> 
+     * <code>tmpfs</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& AddTmpfs(const Tmpfs& value) { m_tmpfsHasBeenSet = true; m_tmpfs.push_back(value); return *this; }
 
     /**
      * <p>The container path, mount options, and size (in MiB) of the tmpfs mount. This
      * parameter maps to the <code>--tmpfs</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
+     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> <note>
      * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>tmpfs</code> parameter is not supported.</p> 
+     * <code>tmpfs</code> parameter is not supported.</p> </note>
      */
     inline LinuxParameters& AddTmpfs(Tmpfs&& value) { m_tmpfsHasBeenSet = true; m_tmpfs.push_back(std::move(value)); return *this; }
 
-
-    /**
-     * <p>The total amount of swap memory (in MiB) a container can use. This parameter
-     * will be translated to the <code>--memory-swap</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a> where the
-     * value would be the sum of the container memory plus the <code>maxSwap</code>
-     * value.</p> <p>If a <code>maxSwap</code> value of <code>0</code> is specified,
-     * the container will not use swap. Accepted values are <code>0</code> or any
-     * positive integer. If the <code>maxSwap</code> parameter is omitted, the
-     * container will use the swap configuration for the container instance it is
-     * running on. A <code>maxSwap</code> value must be set for the
-     * <code>swappiness</code> parameter to be used.</p>  <p>If you are using
-     * tasks that use the Fargate launch type, the <code>maxSwap</code> parameter is
-     * not supported.</p> 
-     */
-    inline int GetMaxSwap() const{ return m_maxSwap; }
-
-    /**
-     * <p>The total amount of swap memory (in MiB) a container can use. This parameter
-     * will be translated to the <code>--memory-swap</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a> where the
-     * value would be the sum of the container memory plus the <code>maxSwap</code>
-     * value.</p> <p>If a <code>maxSwap</code> value of <code>0</code> is specified,
-     * the container will not use swap. Accepted values are <code>0</code> or any
-     * positive integer. If the <code>maxSwap</code> parameter is omitted, the
-     * container will use the swap configuration for the container instance it is
-     * running on. A <code>maxSwap</code> value must be set for the
-     * <code>swappiness</code> parameter to be used.</p>  <p>If you are using
-     * tasks that use the Fargate launch type, the <code>maxSwap</code> parameter is
-     * not supported.</p> 
-     */
-    inline bool MaxSwapHasBeenSet() const { return m_maxSwapHasBeenSet; }
-
-    /**
-     * <p>The total amount of swap memory (in MiB) a container can use. This parameter
-     * will be translated to the <code>--memory-swap</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a> where the
-     * value would be the sum of the container memory plus the <code>maxSwap</code>
-     * value.</p> <p>If a <code>maxSwap</code> value of <code>0</code> is specified,
-     * the container will not use swap. Accepted values are <code>0</code> or any
-     * positive integer. If the <code>maxSwap</code> parameter is omitted, the
-     * container will use the swap configuration for the container instance it is
-     * running on. A <code>maxSwap</code> value must be set for the
-     * <code>swappiness</code> parameter to be used.</p>  <p>If you are using
-     * tasks that use the Fargate launch type, the <code>maxSwap</code> parameter is
-     * not supported.</p> 
-     */
-    inline void SetMaxSwap(int value) { m_maxSwapHasBeenSet = true; m_maxSwap = value; }
-
-    /**
-     * <p>The total amount of swap memory (in MiB) a container can use. This parameter
-     * will be translated to the <code>--memory-swap</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a> where the
-     * value would be the sum of the container memory plus the <code>maxSwap</code>
-     * value.</p> <p>If a <code>maxSwap</code> value of <code>0</code> is specified,
-     * the container will not use swap. Accepted values are <code>0</code> or any
-     * positive integer. If the <code>maxSwap</code> parameter is omitted, the
-     * container will use the swap configuration for the container instance it is
-     * running on. A <code>maxSwap</code> value must be set for the
-     * <code>swappiness</code> parameter to be used.</p>  <p>If you are using
-     * tasks that use the Fargate launch type, the <code>maxSwap</code> parameter is
-     * not supported.</p> 
-     */
-    inline LinuxParameters& WithMaxSwap(int value) { SetMaxSwap(value); return *this;}
-
-
-    /**
-     * <p>This allows you to tune a container's memory swappiness behavior. A
-     * <code>swappiness</code> value of <code>0</code> will cause swapping to not
-     * happen unless absolutely necessary. A <code>swappiness</code> value of
-     * <code>100</code> will cause pages to be swapped very aggressively. Accepted
-     * values are whole numbers between <code>0</code> and <code>100</code>. If the
-     * <code>swappiness</code> parameter is not specified, a default value of
-     * <code>60</code> is used. If a value is not specified for <code>maxSwap</code>
-     * then this parameter is ignored. This parameter maps to the
-     * <code>--memory-swappiness</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
-     * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>swappiness</code> parameter is not supported.</p> 
-     */
-    inline int GetSwappiness() const{ return m_swappiness; }
-
-    /**
-     * <p>This allows you to tune a container's memory swappiness behavior. A
-     * <code>swappiness</code> value of <code>0</code> will cause swapping to not
-     * happen unless absolutely necessary. A <code>swappiness</code> value of
-     * <code>100</code> will cause pages to be swapped very aggressively. Accepted
-     * values are whole numbers between <code>0</code> and <code>100</code>. If the
-     * <code>swappiness</code> parameter is not specified, a default value of
-     * <code>60</code> is used. If a value is not specified for <code>maxSwap</code>
-     * then this parameter is ignored. This parameter maps to the
-     * <code>--memory-swappiness</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
-     * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>swappiness</code> parameter is not supported.</p> 
-     */
-    inline bool SwappinessHasBeenSet() const { return m_swappinessHasBeenSet; }
-
-    /**
-     * <p>This allows you to tune a container's memory swappiness behavior. A
-     * <code>swappiness</code> value of <code>0</code> will cause swapping to not
-     * happen unless absolutely necessary. A <code>swappiness</code> value of
-     * <code>100</code> will cause pages to be swapped very aggressively. Accepted
-     * values are whole numbers between <code>0</code> and <code>100</code>. If the
-     * <code>swappiness</code> parameter is not specified, a default value of
-     * <code>60</code> is used. If a value is not specified for <code>maxSwap</code>
-     * then this parameter is ignored. This parameter maps to the
-     * <code>--memory-swappiness</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
-     * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>swappiness</code> parameter is not supported.</p> 
-     */
-    inline void SetSwappiness(int value) { m_swappinessHasBeenSet = true; m_swappiness = value; }
-
-    /**
-     * <p>This allows you to tune a container's memory swappiness behavior. A
-     * <code>swappiness</code> value of <code>0</code> will cause swapping to not
-     * happen unless absolutely necessary. A <code>swappiness</code> value of
-     * <code>100</code> will cause pages to be swapped very aggressively. Accepted
-     * values are whole numbers between <code>0</code> and <code>100</code>. If the
-     * <code>swappiness</code> parameter is not specified, a default value of
-     * <code>60</code> is used. If a value is not specified for <code>maxSwap</code>
-     * then this parameter is ignored. This parameter maps to the
-     * <code>--memory-swappiness</code> option to <a
-     * href="https://docs.docker.com/engine/reference/run/">docker run</a>.</p> 
-     * <p>If you are using tasks that use the Fargate launch type, the
-     * <code>swappiness</code> parameter is not supported.</p> 
-     */
-    inline LinuxParameters& WithSwappiness(int value) { SetSwappiness(value); return *this;}
-
   private:
 
     KernelCapabilities m_capabilities;
@@ -501,12 +375,6 @@ namespace Model
 
     Aws::Vector<Tmpfs> m_tmpfs;
     bool m_tmpfsHasBeenSet;
-
-    int m_maxSwap;
-    bool m_maxSwapHasBeenSet;
-
-    int m_swappiness;
-    bool m_swappinessHasBeenSet;
   };
 
 } // namespace Model
