@@ -1,21 +1,29 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/ecs/ECS_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/DateTime.h>
 #include <aws/ecs/model/LaunchType.h>
-#include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/ecs/model/NetworkConfiguration.h>
+#include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/ecs/model/Scale.h>
 #include <aws/ecs/model/StabilityStatus.h>
-#include <aws/ecs/model/CapacityProviderStrategyItem.h>
 #include <aws/ecs/model/LoadBalancer.h>
 #include <aws/ecs/model/ServiceRegistry.h>
-#include <aws/ecs/model/Tag.h>
 #include <utility>
 
 namespace Aws
@@ -706,47 +714,6 @@ namespace Model
     inline TaskSet& WithLaunchType(LaunchType&& value) { SetLaunchType(std::move(value)); return *this;}
 
 
-    /**
-     * <p>The capacity provider strategy associated with the task set.</p>
-     */
-    inline const Aws::Vector<CapacityProviderStrategyItem>& GetCapacityProviderStrategy() const{ return m_capacityProviderStrategy; }
-
-    /**
-     * <p>The capacity provider strategy associated with the task set.</p>
-     */
-    inline bool CapacityProviderStrategyHasBeenSet() const { return m_capacityProviderStrategyHasBeenSet; }
-
-    /**
-     * <p>The capacity provider strategy associated with the task set.</p>
-     */
-    inline void SetCapacityProviderStrategy(const Aws::Vector<CapacityProviderStrategyItem>& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy = value; }
-
-    /**
-     * <p>The capacity provider strategy associated with the task set.</p>
-     */
-    inline void SetCapacityProviderStrategy(Aws::Vector<CapacityProviderStrategyItem>&& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy = std::move(value); }
-
-    /**
-     * <p>The capacity provider strategy associated with the task set.</p>
-     */
-    inline TaskSet& WithCapacityProviderStrategy(const Aws::Vector<CapacityProviderStrategyItem>& value) { SetCapacityProviderStrategy(value); return *this;}
-
-    /**
-     * <p>The capacity provider strategy associated with the task set.</p>
-     */
-    inline TaskSet& WithCapacityProviderStrategy(Aws::Vector<CapacityProviderStrategyItem>&& value) { SetCapacityProviderStrategy(std::move(value)); return *this;}
-
-    /**
-     * <p>The capacity provider strategy associated with the task set.</p>
-     */
-    inline TaskSet& AddCapacityProviderStrategy(const CapacityProviderStrategyItem& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy.push_back(value); return *this; }
-
-    /**
-     * <p>The capacity provider strategy associated with the task set.</p>
-     */
-    inline TaskSet& AddCapacityProviderStrategy(CapacityProviderStrategyItem&& value) { m_capacityProviderStrategyHasBeenSet = true; m_capacityProviderStrategy.push_back(std::move(value)); return *this; }
-
-
     /**
      * <p>The platform version on which the tasks in the task set are running. A
      * platform version is only specified for tasks using the Fargate launch type. If
@@ -911,7 +878,7 @@ namespace Model
     /**
      * <p>The details of the service discovery registries to assign to this task set.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
+     * href="http://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
      * Discovery</a>.</p>
      */
     inline const Aws::Vector<ServiceRegistry>& GetServiceRegistries() const{ return m_serviceRegistries; }
@@ -919,7 +886,7 @@ namespace Model
     /**
      * <p>The details of the service discovery registries to assign to this task set.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
+     * href="http://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
      * Discovery</a>.</p>
      */
     inline bool ServiceRegistriesHasBeenSet() const { return m_serviceRegistriesHasBeenSet; }
@@ -927,7 +894,7 @@ namespace Model
     /**
      * <p>The details of the service discovery registries to assign to this task set.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
+     * href="http://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
      * Discovery</a>.</p>
      */
     inline void SetServiceRegistries(const Aws::Vector<ServiceRegistry>& value) { m_serviceRegistriesHasBeenSet = true; m_serviceRegistries = value; }
@@ -935,7 +902,7 @@ namespace Model
     /**
      * <p>The details of the service discovery registries to assign to this task set.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
+     * href="http://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
      * Discovery</a>.</p>
      */
     inline void SetServiceRegistries(Aws::Vector<ServiceRegistry>&& value) { m_serviceRegistriesHasBeenSet = true; m_serviceRegistries = std::move(value); }
@@ -943,7 +910,7 @@ namespace Model
     /**
      * <p>The details of the service discovery registries to assign to this task set.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
+     * href="http://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
      * Discovery</a>.</p>
      */
     inline TaskSet& WithServiceRegistries(const Aws::Vector<ServiceRegistry>& value) { SetServiceRegistries(value); return *this;}
@@ -951,7 +918,7 @@ namespace Model
     /**
      * <p>The details of the service discovery registries to assign to this task set.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
+     * href="http://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
      * Discovery</a>.</p>
      */
     inline TaskSet& WithServiceRegistries(Aws::Vector<ServiceRegistry>&& value) { SetServiceRegistries(std::move(value)); return *this;}
@@ -959,7 +926,7 @@ namespace Model
     /**
      * <p>The details of the service discovery registries to assign to this task set.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
+     * href="http://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
      * Discovery</a>.</p>
      */
     inline TaskSet& AddServiceRegistries(const ServiceRegistry& value) { m_serviceRegistriesHasBeenSet = true; m_serviceRegistries.push_back(value); return *this; }
@@ -967,7 +934,7 @@ namespace Model
     /**
      * <p>The details of the service discovery registries to assign to this task set.
      * For more information, see <a
-     * href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
+     * href="http://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html">Service
      * Discovery</a>.</p>
      */
     inline TaskSet& AddServiceRegistries(ServiceRegistry&& value) { m_serviceRegistriesHasBeenSet = true; m_serviceRegistries.push_back(std::move(value)); return *this; }
@@ -1125,167 +1092,6 @@ namespace Model
      */
     inline TaskSet& WithStabilityStatusAt(Aws::Utils::DateTime&& value) { SetStabilityStatusAt(std::move(value)); return *this;}
 
-
-    /**
-     * <p>The metadata that you apply to the task set to help you categorize and
-     * organize them. Each tag consists of a key and an optional value, both of which
-     * you define.</p> <p>The following basic restrictions apply to tags:</p> <ul> <li>
-     * <p>Maximum number of tags per resource - 50</p> </li> <li> <p>For each resource,
-     * each tag key must be unique, and each tag key can have only one value.</p> </li>
-     * <li> <p>Maximum key length - 128 Unicode characters in UTF-8</p> </li> <li>
-     * <p>Maximum value length - 256 Unicode characters in UTF-8</p> </li> <li> <p>If
-     * your tagging schema is used across multiple services and resources, remember
-     * that other services may have restrictions on allowed characters. Generally
-     * allowed characters are: letters, numbers, and spaces representable in UTF-8, and
-     * the following characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values
-     * are case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
-     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
-     * either keys or values as it is reserved for AWS use. You cannot edit or delete
-     * tag keys or values with this prefix. Tags with this prefix do not count against
-     * your tags per resource limit.</p> </li> </ul>
-     */
-    inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
-
-    /**
-     * <p>The metadata that you apply to the task set to help you categorize and
-     * organize them. Each tag consists of a key and an optional value, both of which
-     * you define.</p> <p>The following basic restrictions apply to tags:</p> <ul> <li>
-     * <p>Maximum number of tags per resource - 50</p> </li> <li> <p>For each resource,
-     * each tag key must be unique, and each tag key can have only one value.</p> </li>
-     * <li> <p>Maximum key length - 128 Unicode characters in UTF-8</p> </li> <li>
-     * <p>Maximum value length - 256 Unicode characters in UTF-8</p> </li> <li> <p>If
-     * your tagging schema is used across multiple services and resources, remember
-     * that other services may have restrictions on allowed characters. Generally
-     * allowed characters are: letters, numbers, and spaces representable in UTF-8, and
-     * the following characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values
-     * are case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
-     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
-     * either keys or values as it is reserved for AWS use. You cannot edit or delete
-     * tag keys or values with this prefix. Tags with this prefix do not count against
-     * your tags per resource limit.</p> </li> </ul>
-     */
-    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
-
-    /**
-     * <p>The metadata that you apply to the task set to help you categorize and
-     * organize them. Each tag consists of a key and an optional value, both of which
-     * you define.</p> <p>The following basic restrictions apply to tags:</p> <ul> <li>
-     * <p>Maximum number of tags per resource - 50</p> </li> <li> <p>For each resource,
-     * each tag key must be unique, and each tag key can have only one value.</p> </li>
-     * <li> <p>Maximum key length - 128 Unicode characters in UTF-8</p> </li> <li>
-     * <p>Maximum value length - 256 Unicode characters in UTF-8</p> </li> <li> <p>If
-     * your tagging schema is used across multiple services and resources, remember
-     * that other services may have restrictions on allowed characters. Generally
-     * allowed characters are: letters, numbers, and spaces representable in UTF-8, and
-     * the following characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values
-     * are case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
-     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
-     * either keys or values as it is reserved for AWS use. You cannot edit or delete
-     * tag keys or values with this prefix. Tags with this prefix do not count against
-     * your tags per resource limit.</p> </li> </ul>
-     */
-    inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
-
-    /**
-     * <p>The metadata that you apply to the task set to help you categorize and
-     * organize them. Each tag consists of a key and an optional value, both of which
-     * you define.</p> <p>The following basic restrictions apply to tags:</p> <ul> <li>
-     * <p>Maximum number of tags per resource - 50</p> </li> <li> <p>For each resource,
-     * each tag key must be unique, and each tag key can have only one value.</p> </li>
-     * <li> <p>Maximum key length - 128 Unicode characters in UTF-8</p> </li> <li>
-     * <p>Maximum value length - 256 Unicode characters in UTF-8</p> </li> <li> <p>If
-     * your tagging schema is used across multiple services and resources, remember
-     * that other services may have restrictions on allowed characters. Generally
-     * allowed characters are: letters, numbers, and spaces representable in UTF-8, and
-     * the following characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values
-     * are case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
-     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
-     * either keys or values as it is reserved for AWS use. You cannot edit or delete
-     * tag keys or values with this prefix. Tags with this prefix do not count against
-     * your tags per resource limit.</p> </li> </ul>
-     */
-    inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
-
-    /**
-     * <p>The metadata that you apply to the task set to help you categorize and
-     * organize them. Each tag consists of a key and an optional value, both of which
-     * you define.</p> <p>The following basic restrictions apply to tags:</p> <ul> <li>
-     * <p>Maximum number of tags per resource - 50</p> </li> <li> <p>For each resource,
-     * each tag key must be unique, and each tag key can have only one value.</p> </li>
-     * <li> <p>Maximum key length - 128 Unicode characters in UTF-8</p> </li> <li>
-     * <p>Maximum value length - 256 Unicode characters in UTF-8</p> </li> <li> <p>If
-     * your tagging schema is used across multiple services and resources, remember
-     * that other services may have restrictions on allowed characters. Generally
-     * allowed characters are: letters, numbers, and spaces representable in UTF-8, and
-     * the following characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values
-     * are case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
-     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
-     * either keys or values as it is reserved for AWS use. You cannot edit or delete
-     * tag keys or values with this prefix. Tags with this prefix do not count against
-     * your tags per resource limit.</p> </li> </ul>
-     */
-    inline TaskSet& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
-
-    /**
-     * <p>The metadata that you apply to the task set to help you categorize and
-     * organize them. Each tag consists of a key and an optional value, both of which
-     * you define.</p> <p>The following basic restrictions apply to tags:</p> <ul> <li>
-     * <p>Maximum number of tags per resource - 50</p> </li> <li> <p>For each resource,
-     * each tag key must be unique, and each tag key can have only one value.</p> </li>
-     * <li> <p>Maximum key length - 128 Unicode characters in UTF-8</p> </li> <li>
-     * <p>Maximum value length - 256 Unicode characters in UTF-8</p> </li> <li> <p>If
-     * your tagging schema is used across multiple services and resources, remember
-     * that other services may have restrictions on allowed characters. Generally
-     * allowed characters are: letters, numbers, and spaces representable in UTF-8, and
-     * the following characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values
-     * are case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
-     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
-     * either keys or values as it is reserved for AWS use. You cannot edit or delete
-     * tag keys or values with this prefix. Tags with this prefix do not count against
-     * your tags per resource limit.</p> </li> </ul>
-     */
-    inline TaskSet& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
-
-    /**
-     * <p>The metadata that you apply to the task set to help you categorize and
-     * organize them. Each tag consists of a key and an optional value, both of which
-     * you define.</p> <p>The following basic restrictions apply to tags:</p> <ul> <li>
-     * <p>Maximum number of tags per resource - 50</p> </li> <li> <p>For each resource,
-     * each tag key must be unique, and each tag key can have only one value.</p> </li>
-     * <li> <p>Maximum key length - 128 Unicode characters in UTF-8</p> </li> <li>
-     * <p>Maximum value length - 256 Unicode characters in UTF-8</p> </li> <li> <p>If
-     * your tagging schema is used across multiple services and resources, remember
-     * that other services may have restrictions on allowed characters. Generally
-     * allowed characters are: letters, numbers, and spaces representable in UTF-8, and
-     * the following characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values
-     * are case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
-     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
-     * either keys or values as it is reserved for AWS use. You cannot edit or delete
-     * tag keys or values with this prefix. Tags with this prefix do not count against
-     * your tags per resource limit.</p> </li> </ul>
-     */
-    inline TaskSet& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
-
-    /**
-     * <p>The metadata that you apply to the task set to help you categorize and
-     * organize them. Each tag consists of a key and an optional value, both of which
-     * you define.</p> <p>The following basic restrictions apply to tags:</p> <ul> <li>
-     * <p>Maximum number of tags per resource - 50</p> </li> <li> <p>For each resource,
-     * each tag key must be unique, and each tag key can have only one value.</p> </li>
-     * <li> <p>Maximum key length - 128 Unicode characters in UTF-8</p> </li> <li>
-     * <p>Maximum value length - 256 Unicode characters in UTF-8</p> </li> <li> <p>If
-     * your tagging schema is used across multiple services and resources, remember
-     * that other services may have restrictions on allowed characters. Generally
-     * allowed characters are: letters, numbers, and spaces representable in UTF-8, and
-     * the following characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values
-     * are case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
-     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
-     * either keys or values as it is reserved for AWS use. You cannot edit or delete
-     * tag keys or values with this prefix. Tags with this prefix do not count against
-     * your tags per resource limit.</p> </li> </ul>
-     */
-    inline TaskSet& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
-
   private:
 
     Aws::String m_id;
@@ -1330,9 +1136,6 @@ namespace Model
     LaunchType m_launchType;
     bool m_launchTypeHasBeenSet;
 
-    Aws::Vector<CapacityProviderStrategyItem> m_capacityProviderStrategy;
-    bool m_capacityProviderStrategyHasBeenSet;
-
     Aws::String m_platformVersion;
     bool m_platformVersionHasBeenSet;
 
@@ -1353,9 +1156,6 @@ namespace Model
 
     Aws::Utils::DateTime m_stabilityStatusAt;
     bool m_stabilityStatusAtHasBeenSet;
-
-    Aws::Vector<Tag> m_tags;
-    bool m_tagsHasBeenSet;
   };
 
 } // namespace Model
