@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/ecs/model/ContainerDefinition.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -35,7 +45,6 @@ ContainerDefinition::ContainerDefinition() :
     m_entryPointHasBeenSet(false),
     m_commandHasBeenSet(false),
     m_environmentHasBeenSet(false),
-    m_environmentFilesHasBeenSet(false),
     m_mountPointsHasBeenSet(false),
     m_volumesFromHasBeenSet(false),
     m_linuxParametersHasBeenSet(false),
@@ -67,8 +76,7 @@ ContainerDefinition::ContainerDefinition() :
     m_logConfigurationHasBeenSet(false),
     m_healthCheckHasBeenSet(false),
     m_systemControlsHasBeenSet(false),
-    m_resourceRequirementsHasBeenSet(false),
-    m_firelensConfigurationHasBeenSet(false)
+    m_resourceRequirementsHasBeenSet(false)
 {
 }
 
@@ -89,7 +97,6 @@ ContainerDefinition::ContainerDefinition(JsonView jsonValue) :
     m_entryPointHasBeenSet(false),
     m_commandHasBeenSet(false),
     m_environmentHasBeenSet(false),
-    m_environmentFilesHasBeenSet(false),
     m_mountPointsHasBeenSet(false),
     m_volumesFromHasBeenSet(false),
     m_linuxParametersHasBeenSet(false),
@@ -121,8 +128,7 @@ ContainerDefinition::ContainerDefinition(JsonView jsonValue) :
     m_logConfigurationHasBeenSet(false),
     m_healthCheckHasBeenSet(false),
     m_systemControlsHasBeenSet(false),
-    m_resourceRequirementsHasBeenSet(false),
-    m_firelensConfigurationHasBeenSet(false)
+    m_resourceRequirementsHasBeenSet(false)
 {
   *this = jsonValue;
 }
@@ -228,16 +234,6 @@ ContainerDefinition& ContainerDefinition::operator =(JsonView jsonValue)
     m_environmentHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("environmentFiles"))
-  {
-    Array<JsonView> environmentFilesJsonList = jsonValue.GetArray("environmentFiles");
-    for(unsigned environmentFilesIndex = 0; environmentFilesIndex < environmentFilesJsonList.GetLength(); ++environmentFilesIndex)
-    {
-      m_environmentFiles.push_back(environmentFilesJsonList[environmentFilesIndex].AsObject());
-    }
-    m_environmentFilesHasBeenSet = true;
-  }
-
   if(jsonValue.ValueExists("mountPoints"))
   {
     Array<JsonView> mountPointsJsonList = jsonValue.GetArray("mountPoints");
@@ -449,13 +445,6 @@ ContainerDefinition& ContainerDefinition::operator =(JsonView jsonValue)
     m_resourceRequirementsHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("firelensConfiguration"))
-  {
-    m_firelensConfiguration = jsonValue.GetObject("firelensConfiguration");
-
-    m_firelensConfigurationHasBeenSet = true;
-  }
-
   return *this;
 }
 
@@ -560,17 +549,6 @@ JsonValue ContainerDefinition::Jsonize() const
 
   }
 
-  if(m_environmentFilesHasBeenSet)
-  {
-   Array<JsonValue> environmentFilesJsonList(m_environmentFiles.size());
-   for(unsigned environmentFilesIndex = 0; environmentFilesIndex < environmentFilesJsonList.GetLength(); ++environmentFilesIndex)
-   {
-     environmentFilesJsonList[environmentFilesIndex].AsObject(m_environmentFiles[environmentFilesIndex].Jsonize());
-   }
-   payload.WithArray("environmentFiles", std::move(environmentFilesJsonList));
-
-  }
-
   if(m_mountPointsHasBeenSet)
   {
    Array<JsonValue> mountPointsJsonList(m_mountPoints.size());
@@ -781,12 +759,6 @@ JsonValue ContainerDefinition::Jsonize() const
 
   }
 
-  if(m_firelensConfigurationHasBeenSet)
-  {
-   payload.WithObject("firelensConfiguration", m_firelensConfiguration.Jsonize());
-
-  }
-
   return payload;
 }
 
