@@ -1,21 +1,26 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/eks/EKS_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/DateTime.h>
 #include <aws/eks/model/VpcConfigResponse.h>
-#include <aws/eks/model/KubernetesNetworkConfigResponse.h>
 #include <aws/eks/model/Logging.h>
-#include <aws/eks/model/Identity.h>
 #include <aws/eks/model/ClusterStatus.h>
 #include <aws/eks/model/Certificate.h>
-#include <aws/core/utils/memory/stl/AWSMap.h>
-#include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/eks/model/EncryptionConfig.h>
 #include <utility>
 
 namespace Aws
@@ -366,37 +371,6 @@ namespace Model
     inline Cluster& WithResourcesVpcConfig(VpcConfigResponse&& value) { SetResourcesVpcConfig(std::move(value)); return *this;}
 
 
-    /**
-     * <p>Network configuration settings for your cluster.</p>
-     */
-    inline const KubernetesNetworkConfigResponse& GetKubernetesNetworkConfig() const{ return m_kubernetesNetworkConfig; }
-
-    /**
-     * <p>Network configuration settings for your cluster.</p>
-     */
-    inline bool KubernetesNetworkConfigHasBeenSet() const { return m_kubernetesNetworkConfigHasBeenSet; }
-
-    /**
-     * <p>Network configuration settings for your cluster.</p>
-     */
-    inline void SetKubernetesNetworkConfig(const KubernetesNetworkConfigResponse& value) { m_kubernetesNetworkConfigHasBeenSet = true; m_kubernetesNetworkConfig = value; }
-
-    /**
-     * <p>Network configuration settings for your cluster.</p>
-     */
-    inline void SetKubernetesNetworkConfig(KubernetesNetworkConfigResponse&& value) { m_kubernetesNetworkConfigHasBeenSet = true; m_kubernetesNetworkConfig = std::move(value); }
-
-    /**
-     * <p>Network configuration settings for your cluster.</p>
-     */
-    inline Cluster& WithKubernetesNetworkConfig(const KubernetesNetworkConfigResponse& value) { SetKubernetesNetworkConfig(value); return *this;}
-
-    /**
-     * <p>Network configuration settings for your cluster.</p>
-     */
-    inline Cluster& WithKubernetesNetworkConfig(KubernetesNetworkConfigResponse&& value) { SetKubernetesNetworkConfig(std::move(value)); return *this;}
-
-
     /**
      * <p>The logging configuration for your cluster.</p>
      */
@@ -428,37 +402,6 @@ namespace Model
     inline Cluster& WithLogging(Logging&& value) { SetLogging(std::move(value)); return *this;}
 
 
-    /**
-     * <p>The identity provider information for the cluster.</p>
-     */
-    inline const Identity& GetIdentity() const{ return m_identity; }
-
-    /**
-     * <p>The identity provider information for the cluster.</p>
-     */
-    inline bool IdentityHasBeenSet() const { return m_identityHasBeenSet; }
-
-    /**
-     * <p>The identity provider information for the cluster.</p>
-     */
-    inline void SetIdentity(const Identity& value) { m_identityHasBeenSet = true; m_identity = value; }
-
-    /**
-     * <p>The identity provider information for the cluster.</p>
-     */
-    inline void SetIdentity(Identity&& value) { m_identityHasBeenSet = true; m_identity = std::move(value); }
-
-    /**
-     * <p>The identity provider information for the cluster.</p>
-     */
-    inline Cluster& WithIdentity(const Identity& value) { SetIdentity(value); return *this;}
-
-    /**
-     * <p>The identity provider information for the cluster.</p>
-     */
-    inline Cluster& WithIdentity(Identity&& value) { SetIdentity(std::move(value)); return *this;}
-
-
     /**
      * <p>The current status of the cluster.</p>
      */
@@ -626,152 +569,6 @@ namespace Model
      */
     inline Cluster& WithPlatformVersion(const char* value) { SetPlatformVersion(value); return *this;}
 
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tagsHasBeenSet = true; m_tags = value; }
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline Cluster& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline Cluster& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline Cluster& AddTags(const Aws::String& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline Cluster& AddTags(Aws::String&& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline Cluster& AddTags(const Aws::String& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline Cluster& AddTags(Aws::String&& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), std::move(value)); return *this; }
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline Cluster& AddTags(const char* key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline Cluster& AddTags(Aws::String&& key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
-
-    /**
-     * <p>The metadata that you apply to the cluster to assist with categorization and
-     * organization. Each tag consists of a key and an optional value, both of which
-     * you define. Cluster tags do not propagate to any other resources associated with
-     * the cluster. </p>
-     */
-    inline Cluster& AddTags(const char* key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
-
-
-    /**
-     * <p>The encryption configuration for the cluster.</p>
-     */
-    inline const Aws::Vector<EncryptionConfig>& GetEncryptionConfig() const{ return m_encryptionConfig; }
-
-    /**
-     * <p>The encryption configuration for the cluster.</p>
-     */
-    inline bool EncryptionConfigHasBeenSet() const { return m_encryptionConfigHasBeenSet; }
-
-    /**
-     * <p>The encryption configuration for the cluster.</p>
-     */
-    inline void SetEncryptionConfig(const Aws::Vector<EncryptionConfig>& value) { m_encryptionConfigHasBeenSet = true; m_encryptionConfig = value; }
-
-    /**
-     * <p>The encryption configuration for the cluster.</p>
-     */
-    inline void SetEncryptionConfig(Aws::Vector<EncryptionConfig>&& value) { m_encryptionConfigHasBeenSet = true; m_encryptionConfig = std::move(value); }
-
-    /**
-     * <p>The encryption configuration for the cluster.</p>
-     */
-    inline Cluster& WithEncryptionConfig(const Aws::Vector<EncryptionConfig>& value) { SetEncryptionConfig(value); return *this;}
-
-    /**
-     * <p>The encryption configuration for the cluster.</p>
-     */
-    inline Cluster& WithEncryptionConfig(Aws::Vector<EncryptionConfig>&& value) { SetEncryptionConfig(std::move(value)); return *this;}
-
-    /**
-     * <p>The encryption configuration for the cluster.</p>
-     */
-    inline Cluster& AddEncryptionConfig(const EncryptionConfig& value) { m_encryptionConfigHasBeenSet = true; m_encryptionConfig.push_back(value); return *this; }
-
-    /**
-     * <p>The encryption configuration for the cluster.</p>
-     */
-    inline Cluster& AddEncryptionConfig(EncryptionConfig&& value) { m_encryptionConfigHasBeenSet = true; m_encryptionConfig.push_back(std::move(value)); return *this; }
-
   private:
 
     Aws::String m_name;
@@ -795,15 +592,9 @@ namespace Model
     VpcConfigResponse m_resourcesVpcConfig;
     bool m_resourcesVpcConfigHasBeenSet;
 
-    KubernetesNetworkConfigResponse m_kubernetesNetworkConfig;
-    bool m_kubernetesNetworkConfigHasBeenSet;
-
     Logging m_logging;
     bool m_loggingHasBeenSet;
 
-    Identity m_identity;
-    bool m_identityHasBeenSet;
-
     ClusterStatus m_status;
     bool m_statusHasBeenSet;
 
@@ -815,12 +606,6 @@ namespace Model
 
     Aws::String m_platformVersion;
     bool m_platformVersionHasBeenSet;
-
-    Aws::Map<Aws::String, Aws::String> m_tags;
-    bool m_tagsHasBeenSet;
-
-    Aws::Vector<EncryptionConfig> m_encryptionConfig;
-    bool m_encryptionConfigHasBeenSet;
   };
 
 } // namespace Model
