@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/eks/EKS_EXPORTS.h>
@@ -106,7 +116,7 @@ namespace Model
     /**
      * <p>Specify one or more security groups for the cross-account elastic network
      * interfaces that Amazon EKS creates to use to allow communication between your
-     * worker nodes and the Kubernetes control plane. If you don't specify a security
+     * worker nodes and the Kubernetes control plane. If you do not specify a security
      * group, the default security group for your VPC is used.</p>
      */
     inline const Aws::Vector<Aws::String>& GetSecurityGroupIds() const{ return m_securityGroupIds; }
@@ -114,7 +124,7 @@ namespace Model
     /**
      * <p>Specify one or more security groups for the cross-account elastic network
      * interfaces that Amazon EKS creates to use to allow communication between your
-     * worker nodes and the Kubernetes control plane. If you don't specify a security
+     * worker nodes and the Kubernetes control plane. If you do not specify a security
      * group, the default security group for your VPC is used.</p>
      */
     inline bool SecurityGroupIdsHasBeenSet() const { return m_securityGroupIdsHasBeenSet; }
@@ -122,7 +132,7 @@ namespace Model
     /**
      * <p>Specify one or more security groups for the cross-account elastic network
      * interfaces that Amazon EKS creates to use to allow communication between your
-     * worker nodes and the Kubernetes control plane. If you don't specify a security
+     * worker nodes and the Kubernetes control plane. If you do not specify a security
      * group, the default security group for your VPC is used.</p>
      */
     inline void SetSecurityGroupIds(const Aws::Vector<Aws::String>& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds = value; }
@@ -130,7 +140,7 @@ namespace Model
     /**
      * <p>Specify one or more security groups for the cross-account elastic network
      * interfaces that Amazon EKS creates to use to allow communication between your
-     * worker nodes and the Kubernetes control plane. If you don't specify a security
+     * worker nodes and the Kubernetes control plane. If you do not specify a security
      * group, the default security group for your VPC is used.</p>
      */
     inline void SetSecurityGroupIds(Aws::Vector<Aws::String>&& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds = std::move(value); }
@@ -138,7 +148,7 @@ namespace Model
     /**
      * <p>Specify one or more security groups for the cross-account elastic network
      * interfaces that Amazon EKS creates to use to allow communication between your
-     * worker nodes and the Kubernetes control plane. If you don't specify a security
+     * worker nodes and the Kubernetes control plane. If you do not specify a security
      * group, the default security group for your VPC is used.</p>
      */
     inline VpcConfigRequest& WithSecurityGroupIds(const Aws::Vector<Aws::String>& value) { SetSecurityGroupIds(value); return *this;}
@@ -146,7 +156,7 @@ namespace Model
     /**
      * <p>Specify one or more security groups for the cross-account elastic network
      * interfaces that Amazon EKS creates to use to allow communication between your
-     * worker nodes and the Kubernetes control plane. If you don't specify a security
+     * worker nodes and the Kubernetes control plane. If you do not specify a security
      * group, the default security group for your VPC is used.</p>
      */
     inline VpcConfigRequest& WithSecurityGroupIds(Aws::Vector<Aws::String>&& value) { SetSecurityGroupIds(std::move(value)); return *this;}
@@ -154,7 +164,7 @@ namespace Model
     /**
      * <p>Specify one or more security groups for the cross-account elastic network
      * interfaces that Amazon EKS creates to use to allow communication between your
-     * worker nodes and the Kubernetes control plane. If you don't specify a security
+     * worker nodes and the Kubernetes control plane. If you do not specify a security
      * group, the default security group for your VPC is used.</p>
      */
     inline VpcConfigRequest& AddSecurityGroupIds(const Aws::String& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds.push_back(value); return *this; }
@@ -162,7 +172,7 @@ namespace Model
     /**
      * <p>Specify one or more security groups for the cross-account elastic network
      * interfaces that Amazon EKS creates to use to allow communication between your
-     * worker nodes and the Kubernetes control plane. If you don't specify a security
+     * worker nodes and the Kubernetes control plane. If you do not specify a security
      * group, the default security group for your VPC is used.</p>
      */
     inline VpcConfigRequest& AddSecurityGroupIds(Aws::String&& value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds.push_back(std::move(value)); return *this; }
@@ -170,14 +180,14 @@ namespace Model
     /**
      * <p>Specify one or more security groups for the cross-account elastic network
      * interfaces that Amazon EKS creates to use to allow communication between your
-     * worker nodes and the Kubernetes control plane. If you don't specify a security
+     * worker nodes and the Kubernetes control plane. If you do not specify a security
      * group, the default security group for your VPC is used.</p>
      */
     inline VpcConfigRequest& AddSecurityGroupIds(const char* value) { m_securityGroupIdsHasBeenSet = true; m_securityGroupIds.push_back(value); return *this; }
 
 
     /**
-     * <p>Set this value to <code>false</code> to disable public access to your
+     * <p>Set this value to <code>false</code> to disable public access for your
      * cluster's Kubernetes API server endpoint. If you disable public access, your
      * cluster's Kubernetes API server can only receive requests from within the
      * cluster VPC. The default value for this parameter is <code>true</code>, which
@@ -190,7 +200,7 @@ namespace Model
     inline bool GetEndpointPublicAccess() const{ return m_endpointPublicAccess; }
 
     /**
-     * <p>Set this value to <code>false</code> to disable public access to your
+     * <p>Set this value to <code>false</code> to disable public access for your
      * cluster's Kubernetes API server endpoint. If you disable public access, your
      * cluster's Kubernetes API server can only receive requests from within the
      * cluster VPC. The default value for this parameter is <code>true</code>, which
@@ -203,7 +213,7 @@ namespace Model
     inline bool EndpointPublicAccessHasBeenSet() const { return m_endpointPublicAccessHasBeenSet; }
 
     /**
-     * <p>Set this value to <code>false</code> to disable public access to your
+     * <p>Set this value to <code>false</code> to disable public access for your
      * cluster's Kubernetes API server endpoint. If you disable public access, your
      * cluster's Kubernetes API server can only receive requests from within the
      * cluster VPC. The default value for this parameter is <code>true</code>, which
@@ -216,7 +226,7 @@ namespace Model
     inline void SetEndpointPublicAccess(bool value) { m_endpointPublicAccessHasBeenSet = true; m_endpointPublicAccess = value; }
 
     /**
-     * <p>Set this value to <code>false</code> to disable public access to your
+     * <p>Set this value to <code>false</code> to disable public access for your
      * cluster's Kubernetes API server endpoint. If you disable public access, your
      * cluster's Kubernetes API server can only receive requests from within the
      * cluster VPC. The default value for this parameter is <code>true</code>, which
@@ -232,13 +242,10 @@ namespace Model
     /**
      * <p>Set this value to <code>true</code> to enable private access for your
      * cluster's Kubernetes API server endpoint. If you enable private access,
-     * Kubernetes API requests from within your cluster's VPC use the private VPC
+     * Kubernetes API requests from within your cluster's VPC will use the private VPC
      * endpoint. The default value for this parameter is <code>false</code>, which
-     * disables private access for your Kubernetes API server. If you disable private
-     * access and you have worker nodes or AWS Fargate pods in the cluster, then ensure
-     * that <code>publicAccessCidrs</code> includes the necessary CIDR blocks for
-     * communication with the worker nodes or Fargate pods. For more information, see
-     * <a
+     * disables private access for your Kubernetes API server. For more information,
+     * see <a
      * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
      * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
      * </i>.</p>
@@ -248,13 +255,10 @@ namespace Model
     /**
      * <p>Set this value to <code>true</code> to enable private access for your
      * cluster's Kubernetes API server endpoint. If you enable private access,
-     * Kubernetes API requests from within your cluster's VPC use the private VPC
+     * Kubernetes API requests from within your cluster's VPC will use the private VPC
      * endpoint. The default value for this parameter is <code>false</code>, which
-     * disables private access for your Kubernetes API server. If you disable private
-     * access and you have worker nodes or AWS Fargate pods in the cluster, then ensure
-     * that <code>publicAccessCidrs</code> includes the necessary CIDR blocks for
-     * communication with the worker nodes or Fargate pods. For more information, see
-     * <a
+     * disables private access for your Kubernetes API server. For more information,
+     * see <a
      * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
      * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
      * </i>.</p>
@@ -264,13 +268,10 @@ namespace Model
     /**
      * <p>Set this value to <code>true</code> to enable private access for your
      * cluster's Kubernetes API server endpoint. If you enable private access,
-     * Kubernetes API requests from within your cluster's VPC use the private VPC
+     * Kubernetes API requests from within your cluster's VPC will use the private VPC
      * endpoint. The default value for this parameter is <code>false</code>, which
-     * disables private access for your Kubernetes API server. If you disable private
-     * access and you have worker nodes or AWS Fargate pods in the cluster, then ensure
-     * that <code>publicAccessCidrs</code> includes the necessary CIDR blocks for
-     * communication with the worker nodes or Fargate pods. For more information, see
-     * <a
+     * disables private access for your Kubernetes API server. For more information,
+     * see <a
      * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
      * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
      * </i>.</p>
@@ -280,137 +281,16 @@ namespace Model
     /**
      * <p>Set this value to <code>true</code> to enable private access for your
      * cluster's Kubernetes API server endpoint. If you enable private access,
-     * Kubernetes API requests from within your cluster's VPC use the private VPC
+     * Kubernetes API requests from within your cluster's VPC will use the private VPC
      * endpoint. The default value for this parameter is <code>false</code>, which
-     * disables private access for your Kubernetes API server. If you disable private
-     * access and you have worker nodes or AWS Fargate pods in the cluster, then ensure
-     * that <code>publicAccessCidrs</code> includes the necessary CIDR blocks for
-     * communication with the worker nodes or Fargate pods. For more information, see
-     * <a
+     * disables private access for your Kubernetes API server. For more information,
+     * see <a
      * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
      * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
      * </i>.</p>
      */
     inline VpcConfigRequest& WithEndpointPrivateAccess(bool value) { SetEndpointPrivateAccess(value); return *this;}
 
-
-    /**
-     * <p>The CIDR blocks that are allowed access to your cluster's public Kubernetes
-     * API server endpoint. Communication to the endpoint from addresses outside of the
-     * CIDR blocks that you specify is denied. The default value is
-     * <code>0.0.0.0/0</code>. If you've disabled private endpoint access and you have
-     * worker nodes or AWS Fargate pods in the cluster, then ensure that you specify
-     * the necessary CIDR blocks. For more information, see <a
-     * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
-     * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
-     * </i>.</p>
-     */
-    inline const Aws::Vector<Aws::String>& GetPublicAccessCidrs() const{ return m_publicAccessCidrs; }
-
-    /**
-     * <p>The CIDR blocks that are allowed access to your cluster's public Kubernetes
-     * API server endpoint. Communication to the endpoint from addresses outside of the
-     * CIDR blocks that you specify is denied. The default value is
-     * <code>0.0.0.0/0</code>. If you've disabled private endpoint access and you have
-     * worker nodes or AWS Fargate pods in the cluster, then ensure that you specify
-     * the necessary CIDR blocks. For more information, see <a
-     * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
-     * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
-     * </i>.</p>
-     */
-    inline bool PublicAccessCidrsHasBeenSet() const { return m_publicAccessCidrsHasBeenSet; }
-
-    /**
-     * <p>The CIDR blocks that are allowed access to your cluster's public Kubernetes
-     * API server endpoint. Communication to the endpoint from addresses outside of the
-     * CIDR blocks that you specify is denied. The default value is
-     * <code>0.0.0.0/0</code>. If you've disabled private endpoint access and you have
-     * worker nodes or AWS Fargate pods in the cluster, then ensure that you specify
-     * the necessary CIDR blocks. For more information, see <a
-     * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
-     * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
-     * </i>.</p>
-     */
-    inline void SetPublicAccessCidrs(const Aws::Vector<Aws::String>& value) { m_publicAccessCidrsHasBeenSet = true; m_publicAccessCidrs = value; }
-
-    /**
-     * <p>The CIDR blocks that are allowed access to your cluster's public Kubernetes
-     * API server endpoint. Communication to the endpoint from addresses outside of the
-     * CIDR blocks that you specify is denied. The default value is
-     * <code>0.0.0.0/0</code>. If you've disabled private endpoint access and you have
-     * worker nodes or AWS Fargate pods in the cluster, then ensure that you specify
-     * the necessary CIDR blocks. For more information, see <a
-     * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
-     * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
-     * </i>.</p>
-     */
-    inline void SetPublicAccessCidrs(Aws::Vector<Aws::String>&& value) { m_publicAccessCidrsHasBeenSet = true; m_publicAccessCidrs = std::move(value); }
-
-    /**
-     * <p>The CIDR blocks that are allowed access to your cluster's public Kubernetes
-     * API server endpoint. Communication to the endpoint from addresses outside of the
-     * CIDR blocks that you specify is denied. The default value is
-     * <code>0.0.0.0/0</code>. If you've disabled private endpoint access and you have
-     * worker nodes or AWS Fargate pods in the cluster, then ensure that you specify
-     * the necessary CIDR blocks. For more information, see <a
-     * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
-     * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
-     * </i>.</p>
-     */
-    inline VpcConfigRequest& WithPublicAccessCidrs(const Aws::Vector<Aws::String>& value) { SetPublicAccessCidrs(value); return *this;}
-
-    /**
-     * <p>The CIDR blocks that are allowed access to your cluster's public Kubernetes
-     * API server endpoint. Communication to the endpoint from addresses outside of the
-     * CIDR blocks that you specify is denied. The default value is
-     * <code>0.0.0.0/0</code>. If you've disabled private endpoint access and you have
-     * worker nodes or AWS Fargate pods in the cluster, then ensure that you specify
-     * the necessary CIDR blocks. For more information, see <a
-     * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
-     * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
-     * </i>.</p>
-     */
-    inline VpcConfigRequest& WithPublicAccessCidrs(Aws::Vector<Aws::String>&& value) { SetPublicAccessCidrs(std::move(value)); return *this;}
-
-    /**
-     * <p>The CIDR blocks that are allowed access to your cluster's public Kubernetes
-     * API server endpoint. Communication to the endpoint from addresses outside of the
-     * CIDR blocks that you specify is denied. The default value is
-     * <code>0.0.0.0/0</code>. If you've disabled private endpoint access and you have
-     * worker nodes or AWS Fargate pods in the cluster, then ensure that you specify
-     * the necessary CIDR blocks. For more information, see <a
-     * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
-     * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
-     * </i>.</p>
-     */
-    inline VpcConfigRequest& AddPublicAccessCidrs(const Aws::String& value) { m_publicAccessCidrsHasBeenSet = true; m_publicAccessCidrs.push_back(value); return *this; }
-
-    /**
-     * <p>The CIDR blocks that are allowed access to your cluster's public Kubernetes
-     * API server endpoint. Communication to the endpoint from addresses outside of the
-     * CIDR blocks that you specify is denied. The default value is
-     * <code>0.0.0.0/0</code>. If you've disabled private endpoint access and you have
-     * worker nodes or AWS Fargate pods in the cluster, then ensure that you specify
-     * the necessary CIDR blocks. For more information, see <a
-     * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
-     * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
-     * </i>.</p>
-     */
-    inline VpcConfigRequest& AddPublicAccessCidrs(Aws::String&& value) { m_publicAccessCidrsHasBeenSet = true; m_publicAccessCidrs.push_back(std::move(value)); return *this; }
-
-    /**
-     * <p>The CIDR blocks that are allowed access to your cluster's public Kubernetes
-     * API server endpoint. Communication to the endpoint from addresses outside of the
-     * CIDR blocks that you specify is denied. The default value is
-     * <code>0.0.0.0/0</code>. If you've disabled private endpoint access and you have
-     * worker nodes or AWS Fargate pods in the cluster, then ensure that you specify
-     * the necessary CIDR blocks. For more information, see <a
-     * href="https://docs.aws.amazon.com/eks/latest/userguide/cluster-endpoint.html">Amazon
-     * EKS Cluster Endpoint Access Control</a> in the <i> <i>Amazon EKS User Guide</i>
-     * </i>.</p>
-     */
-    inline VpcConfigRequest& AddPublicAccessCidrs(const char* value) { m_publicAccessCidrsHasBeenSet = true; m_publicAccessCidrs.push_back(value); return *this; }
-
   private:
 
     Aws::Vector<Aws::String> m_subnetIds;
@@ -424,9 +304,6 @@ namespace Model
 
     bool m_endpointPrivateAccess;
     bool m_endpointPrivateAccessHasBeenSet;
-
-    Aws::Vector<Aws::String> m_publicAccessCidrs;
-    bool m_publicAccessCidrsHasBeenSet;
   };
 
 } // namespace Model
