@@ -1,14 +1,23 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/elasticache/ElastiCache_EXPORTS.h>
 #include <aws/elasticache/ElastiCacheRequest.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/elasticache/model/AuthTokenUpdateStrategyType.h>
 #include <utility>
 
 namespace Aws
@@ -28,7 +37,7 @@ namespace Model
   {
   public:
     ModifyReplicationGroupRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -257,65 +266,48 @@ namespace Model
     /**
      * <p>Determines whether a read replica is automatically promoted to read/write
      * primary if the existing primary encounters a failure.</p> <p>Valid values:
-     * <code>true</code> | <code>false</code> </p>
+     * <code>true</code> | <code>false</code> </p> <p>Amazon ElastiCache for Redis does
+     * not support Multi-AZ with automatic failover on:</p> <ul> <li> <p>Redis versions
+     * earlier than 2.8.6.</p> </li> <li> <p>Redis (cluster mode disabled): T1 and T2
+     * cache node types.</p> </li> <li> <p>Redis (cluster mode enabled): T1 node
+     * types.</p> </li> </ul>
      */
     inline bool GetAutomaticFailoverEnabled() const{ return m_automaticFailoverEnabled; }
 
     /**
      * <p>Determines whether a read replica is automatically promoted to read/write
      * primary if the existing primary encounters a failure.</p> <p>Valid values:
-     * <code>true</code> | <code>false</code> </p>
+     * <code>true</code> | <code>false</code> </p> <p>Amazon ElastiCache for Redis does
+     * not support Multi-AZ with automatic failover on:</p> <ul> <li> <p>Redis versions
+     * earlier than 2.8.6.</p> </li> <li> <p>Redis (cluster mode disabled): T1 and T2
+     * cache node types.</p> </li> <li> <p>Redis (cluster mode enabled): T1 node
+     * types.</p> </li> </ul>
      */
     inline bool AutomaticFailoverEnabledHasBeenSet() const { return m_automaticFailoverEnabledHasBeenSet; }
 
     /**
      * <p>Determines whether a read replica is automatically promoted to read/write
      * primary if the existing primary encounters a failure.</p> <p>Valid values:
-     * <code>true</code> | <code>false</code> </p>
+     * <code>true</code> | <code>false</code> </p> <p>Amazon ElastiCache for Redis does
+     * not support Multi-AZ with automatic failover on:</p> <ul> <li> <p>Redis versions
+     * earlier than 2.8.6.</p> </li> <li> <p>Redis (cluster mode disabled): T1 and T2
+     * cache node types.</p> </li> <li> <p>Redis (cluster mode enabled): T1 node
+     * types.</p> </li> </ul>
      */
     inline void SetAutomaticFailoverEnabled(bool value) { m_automaticFailoverEnabledHasBeenSet = true; m_automaticFailoverEnabled = value; }
 
     /**
      * <p>Determines whether a read replica is automatically promoted to read/write
      * primary if the existing primary encounters a failure.</p> <p>Valid values:
-     * <code>true</code> | <code>false</code> </p>
+     * <code>true</code> | <code>false</code> </p> <p>Amazon ElastiCache for Redis does
+     * not support Multi-AZ with automatic failover on:</p> <ul> <li> <p>Redis versions
+     * earlier than 2.8.6.</p> </li> <li> <p>Redis (cluster mode disabled): T1 and T2
+     * cache node types.</p> </li> <li> <p>Redis (cluster mode enabled): T1 node
+     * types.</p> </li> </ul>
      */
     inline ModifyReplicationGroupRequest& WithAutomaticFailoverEnabled(bool value) { SetAutomaticFailoverEnabled(value); return *this;}
 
 
-    /**
-     * <p>A flag indicating if you have Multi-AZ enabled to enhance fault tolerance.
-     * For more information, see <a
-     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/AutoFailover.html">Minimizing
-     * Downtime: Multi-AZ</a>.</p>
-     */
-    inline bool GetMultiAZEnabled() const{ return m_multiAZEnabled; }
-
-    /**
-     * <p>A flag indicating if you have Multi-AZ enabled to enhance fault tolerance.
-     * For more information, see <a
-     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/AutoFailover.html">Minimizing
-     * Downtime: Multi-AZ</a>.</p>
-     */
-    inline bool MultiAZEnabledHasBeenSet() const { return m_multiAZEnabledHasBeenSet; }
-
-    /**
-     * <p>A flag indicating if you have Multi-AZ enabled to enhance fault tolerance.
-     * For more information, see <a
-     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/AutoFailover.html">Minimizing
-     * Downtime: Multi-AZ</a>.</p>
-     */
-    inline void SetMultiAZEnabled(bool value) { m_multiAZEnabledHasBeenSet = true; m_multiAZEnabled = value; }
-
-    /**
-     * <p>A flag indicating if you have Multi-AZ enabled to enhance fault tolerance.
-     * For more information, see <a
-     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/AutoFailover.html">Minimizing
-     * Downtime: Multi-AZ</a>.</p>
-     */
-    inline ModifyReplicationGroupRequest& WithMultiAZEnabled(bool value) { SetMultiAZEnabled(value); return *this;}
-
-
     /**
      * <p>A list of cache security group names to authorize for the clusters in this
      * replication group. This change is asynchronously applied as soon as
@@ -570,57 +562,57 @@ namespace Model
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications
-     * are sent.</p>  <p>The Amazon SNS topic owner must be same as the
-     * replication group owner. </p> 
+     * are sent.</p> <note> <p>The Amazon SNS topic owner must be same as the
+     * replication group owner. </p> </note>
      */
     inline const Aws::String& GetNotificationTopicArn() const{ return m_notificationTopicArn; }
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications
-     * are sent.</p>  <p>The Amazon SNS topic owner must be same as the
-     * replication group owner. </p> 
+     * are sent.</p> <note> <p>The Amazon SNS topic owner must be same as the
+     * replication group owner. </p> </note>
      */
     inline bool NotificationTopicArnHasBeenSet() const { return m_notificationTopicArnHasBeenSet; }
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications
-     * are sent.</p>  <p>The Amazon SNS topic owner must be same as the
-     * replication group owner. </p> 
+     * are sent.</p> <note> <p>The Amazon SNS topic owner must be same as the
+     * replication group owner. </p> </note>
      */
     inline void SetNotificationTopicArn(const Aws::String& value) { m_notificationTopicArnHasBeenSet = true; m_notificationTopicArn = value; }
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications
-     * are sent.</p>  <p>The Amazon SNS topic owner must be same as the
-     * replication group owner. </p> 
+     * are sent.</p> <note> <p>The Amazon SNS topic owner must be same as the
+     * replication group owner. </p> </note>
      */
     inline void SetNotificationTopicArn(Aws::String&& value) { m_notificationTopicArnHasBeenSet = true; m_notificationTopicArn = std::move(value); }
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications
-     * are sent.</p>  <p>The Amazon SNS topic owner must be same as the
-     * replication group owner. </p> 
+     * are sent.</p> <note> <p>The Amazon SNS topic owner must be same as the
+     * replication group owner. </p> </note>
      */
     inline void SetNotificationTopicArn(const char* value) { m_notificationTopicArnHasBeenSet = true; m_notificationTopicArn.assign(value); }
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications
-     * are sent.</p>  <p>The Amazon SNS topic owner must be same as the
-     * replication group owner. </p> 
+     * are sent.</p> <note> <p>The Amazon SNS topic owner must be same as the
+     * replication group owner. </p> </note>
      */
     inline ModifyReplicationGroupRequest& WithNotificationTopicArn(const Aws::String& value) { SetNotificationTopicArn(value); return *this;}
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications
-     * are sent.</p>  <p>The Amazon SNS topic owner must be same as the
-     * replication group owner. </p> 
+     * are sent.</p> <note> <p>The Amazon SNS topic owner must be same as the
+     * replication group owner. </p> </note>
      */
     inline ModifyReplicationGroupRequest& WithNotificationTopicArn(Aws::String&& value) { SetNotificationTopicArn(std::move(value)); return *this;}
 
     /**
      * <p>The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications
-     * are sent.</p>  <p>The Amazon SNS topic owner must be same as the
-     * replication group owner. </p> 
+     * are sent.</p> <note> <p>The Amazon SNS topic owner must be same as the
+     * replication group owner. </p> </note>
      */
     inline ModifyReplicationGroupRequest& WithNotificationTopicArn(const char* value) { SetNotificationTopicArn(value); return *this;}
 
@@ -796,7 +788,7 @@ namespace Model
      * <p>The upgraded version of the cache engine to be run on the clusters in the
      * replication group.</p> <p> <b>Important:</b> You can upgrade to a newer engine
      * version (see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
+     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
      * a Cache Engine and Version</a>), but you cannot downgrade to an earlier engine
      * version. If you want to use an earlier engine version, you must delete the
      * existing replication group and create it anew with the earlier engine version.
@@ -808,7 +800,7 @@ namespace Model
      * <p>The upgraded version of the cache engine to be run on the clusters in the
      * replication group.</p> <p> <b>Important:</b> You can upgrade to a newer engine
      * version (see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
+     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
      * a Cache Engine and Version</a>), but you cannot downgrade to an earlier engine
      * version. If you want to use an earlier engine version, you must delete the
      * existing replication group and create it anew with the earlier engine version.
@@ -820,7 +812,7 @@ namespace Model
      * <p>The upgraded version of the cache engine to be run on the clusters in the
      * replication group.</p> <p> <b>Important:</b> You can upgrade to a newer engine
      * version (see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
+     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
      * a Cache Engine and Version</a>), but you cannot downgrade to an earlier engine
      * version. If you want to use an earlier engine version, you must delete the
      * existing replication group and create it anew with the earlier engine version.
@@ -832,7 +824,7 @@ namespace Model
      * <p>The upgraded version of the cache engine to be run on the clusters in the
      * replication group.</p> <p> <b>Important:</b> You can upgrade to a newer engine
      * version (see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
+     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
      * a Cache Engine and Version</a>), but you cannot downgrade to an earlier engine
      * version. If you want to use an earlier engine version, you must delete the
      * existing replication group and create it anew with the earlier engine version.
@@ -844,7 +836,7 @@ namespace Model
      * <p>The upgraded version of the cache engine to be run on the clusters in the
      * replication group.</p> <p> <b>Important:</b> You can upgrade to a newer engine
      * version (see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
+     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
      * a Cache Engine and Version</a>), but you cannot downgrade to an earlier engine
      * version. If you want to use an earlier engine version, you must delete the
      * existing replication group and create it anew with the earlier engine version.
@@ -856,7 +848,7 @@ namespace Model
      * <p>The upgraded version of the cache engine to be run on the clusters in the
      * replication group.</p> <p> <b>Important:</b> You can upgrade to a newer engine
      * version (see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
+     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
      * a Cache Engine and Version</a>), but you cannot downgrade to an earlier engine
      * version. If you want to use an earlier engine version, you must delete the
      * existing replication group and create it anew with the earlier engine version.
@@ -868,7 +860,7 @@ namespace Model
      * <p>The upgraded version of the cache engine to be run on the clusters in the
      * replication group.</p> <p> <b>Important:</b> You can upgrade to a newer engine
      * version (see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
+     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
      * a Cache Engine and Version</a>), but you cannot downgrade to an earlier engine
      * version. If you want to use an earlier engine version, you must delete the
      * existing replication group and create it anew with the earlier engine version.
@@ -880,7 +872,7 @@ namespace Model
      * <p>The upgraded version of the cache engine to be run on the clusters in the
      * replication group.</p> <p> <b>Important:</b> You can upgrade to a newer engine
      * version (see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
+     * href="http://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement">Selecting
      * a Cache Engine and Version</a>), but you cannot downgrade to an earlier engine
      * version. If you want to use an earlier engine version, you must delete the
      * existing replication group and create it anew with the earlier engine version.
@@ -1060,164 +1052,6 @@ namespace Model
      */
     inline ModifyReplicationGroupRequest& WithCacheNodeType(const char* value) { SetCacheNodeType(value); return *this;}
 
-
-    /**
-     * <p>Reserved parameter. The password used to access a password protected server.
-     * This parameter must be specified with the <code>auth-token-update-strategy
-     * </code> parameter. Password constraints:</p> <ul> <li> <p>Must be only printable
-     * ASCII characters</p> </li> <li> <p>Must be at least 16 characters and no more
-     * than 128 characters in length</p> </li> <li> <p>Cannot contain any of the
-     * following characters: '/', '"', or '@', '%'</p> </li> </ul> <p> For more
-     * information, see AUTH password at <a
-     * href="http://redis.io/commands/AUTH">AUTH</a>.</p>
-     */
-    inline const Aws::String& GetAuthToken() const{ return m_authToken; }
-
-    /**
-     * <p>Reserved parameter. The password used to access a password protected server.
-     * This parameter must be specified with the <code>auth-token-update-strategy
-     * </code> parameter. Password constraints:</p> <ul> <li> <p>Must be only printable
-     * ASCII characters</p> </li> <li> <p>Must be at least 16 characters and no more
-     * than 128 characters in length</p> </li> <li> <p>Cannot contain any of the
-     * following characters: '/', '"', or '@', '%'</p> </li> </ul> <p> For more
-     * information, see AUTH password at <a
-     * href="http://redis.io/commands/AUTH">AUTH</a>.</p>
-     */
-    inline bool AuthTokenHasBeenSet() const { return m_authTokenHasBeenSet; }
-
-    /**
-     * <p>Reserved parameter. The password used to access a password protected server.
-     * This parameter must be specified with the <code>auth-token-update-strategy
-     * </code> parameter. Password constraints:</p> <ul> <li> <p>Must be only printable
-     * ASCII characters</p> </li> <li> <p>Must be at least 16 characters and no more
-     * than 128 characters in length</p> </li> <li> <p>Cannot contain any of the
-     * following characters: '/', '"', or '@', '%'</p> </li> </ul> <p> For more
-     * information, see AUTH password at <a
-     * href="http://redis.io/commands/AUTH">AUTH</a>.</p>
-     */
-    inline void SetAuthToken(const Aws::String& value) { m_authTokenHasBeenSet = true; m_authToken = value; }
-
-    /**
-     * <p>Reserved parameter. The password used to access a password protected server.
-     * This parameter must be specified with the <code>auth-token-update-strategy
-     * </code> parameter. Password constraints:</p> <ul> <li> <p>Must be only printable
-     * ASCII characters</p> </li> <li> <p>Must be at least 16 characters and no more
-     * than 128 characters in length</p> </li> <li> <p>Cannot contain any of the
-     * following characters: '/', '"', or '@', '%'</p> </li> </ul> <p> For more
-     * information, see AUTH password at <a
-     * href="http://redis.io/commands/AUTH">AUTH</a>.</p>
-     */
-    inline void SetAuthToken(Aws::String&& value) { m_authTokenHasBeenSet = true; m_authToken = std::move(value); }
-
-    /**
-     * <p>Reserved parameter. The password used to access a password protected server.
-     * This parameter must be specified with the <code>auth-token-update-strategy
-     * </code> parameter. Password constraints:</p> <ul> <li> <p>Must be only printable
-     * ASCII characters</p> </li> <li> <p>Must be at least 16 characters and no more
-     * than 128 characters in length</p> </li> <li> <p>Cannot contain any of the
-     * following characters: '/', '"', or '@', '%'</p> </li> </ul> <p> For more
-     * information, see AUTH password at <a
-     * href="http://redis.io/commands/AUTH">AUTH</a>.</p>
-     */
-    inline void SetAuthToken(const char* value) { m_authTokenHasBeenSet = true; m_authToken.assign(value); }
-
-    /**
-     * <p>Reserved parameter. The password used to access a password protected server.
-     * This parameter must be specified with the <code>auth-token-update-strategy
-     * </code> parameter. Password constraints:</p> <ul> <li> <p>Must be only printable
-     * ASCII characters</p> </li> <li> <p>Must be at least 16 characters and no more
-     * than 128 characters in length</p> </li> <li> <p>Cannot contain any of the
-     * following characters: '/', '"', or '@', '%'</p> </li> </ul> <p> For more
-     * information, see AUTH password at <a
-     * href="http://redis.io/commands/AUTH">AUTH</a>.</p>
-     */
-    inline ModifyReplicationGroupRequest& WithAuthToken(const Aws::String& value) { SetAuthToken(value); return *this;}
-
-    /**
-     * <p>Reserved parameter. The password used to access a password protected server.
-     * This parameter must be specified with the <code>auth-token-update-strategy
-     * </code> parameter. Password constraints:</p> <ul> <li> <p>Must be only printable
-     * ASCII characters</p> </li> <li> <p>Must be at least 16 characters and no more
-     * than 128 characters in length</p> </li> <li> <p>Cannot contain any of the
-     * following characters: '/', '"', or '@', '%'</p> </li> </ul> <p> For more
-     * information, see AUTH password at <a
-     * href="http://redis.io/commands/AUTH">AUTH</a>.</p>
-     */
-    inline ModifyReplicationGroupRequest& WithAuthToken(Aws::String&& value) { SetAuthToken(std::move(value)); return *this;}
-
-    /**
-     * <p>Reserved parameter. The password used to access a password protected server.
-     * This parameter must be specified with the <code>auth-token-update-strategy
-     * </code> parameter. Password constraints:</p> <ul> <li> <p>Must be only printable
-     * ASCII characters</p> </li> <li> <p>Must be at least 16 characters and no more
-     * than 128 characters in length</p> </li> <li> <p>Cannot contain any of the
-     * following characters: '/', '"', or '@', '%'</p> </li> </ul> <p> For more
-     * information, see AUTH password at <a
-     * href="http://redis.io/commands/AUTH">AUTH</a>.</p>
-     */
-    inline ModifyReplicationGroupRequest& WithAuthToken(const char* value) { SetAuthToken(value); return *this;}
-
-
-    /**
-     * <p>Specifies the strategy to use to update the AUTH token. This parameter must
-     * be specified with the <code>auth-token</code> parameter. Possible values:</p>
-     * <ul> <li> <p>Rotate</p> </li> <li> <p>Set</p> </li> </ul> <p> For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/auth.html">Authenticating
-     * Users with Redis AUTH</a> </p>
-     */
-    inline const AuthTokenUpdateStrategyType& GetAuthTokenUpdateStrategy() const{ return m_authTokenUpdateStrategy; }
-
-    /**
-     * <p>Specifies the strategy to use to update the AUTH token. This parameter must
-     * be specified with the <code>auth-token</code> parameter. Possible values:</p>
-     * <ul> <li> <p>Rotate</p> </li> <li> <p>Set</p> </li> </ul> <p> For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/auth.html">Authenticating
-     * Users with Redis AUTH</a> </p>
-     */
-    inline bool AuthTokenUpdateStrategyHasBeenSet() const { return m_authTokenUpdateStrategyHasBeenSet; }
-
-    /**
-     * <p>Specifies the strategy to use to update the AUTH token. This parameter must
-     * be specified with the <code>auth-token</code> parameter. Possible values:</p>
-     * <ul> <li> <p>Rotate</p> </li> <li> <p>Set</p> </li> </ul> <p> For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/auth.html">Authenticating
-     * Users with Redis AUTH</a> </p>
-     */
-    inline void SetAuthTokenUpdateStrategy(const AuthTokenUpdateStrategyType& value) { m_authTokenUpdateStrategyHasBeenSet = true; m_authTokenUpdateStrategy = value; }
-
-    /**
-     * <p>Specifies the strategy to use to update the AUTH token. This parameter must
-     * be specified with the <code>auth-token</code> parameter. Possible values:</p>
-     * <ul> <li> <p>Rotate</p> </li> <li> <p>Set</p> </li> </ul> <p> For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/auth.html">Authenticating
-     * Users with Redis AUTH</a> </p>
-     */
-    inline void SetAuthTokenUpdateStrategy(AuthTokenUpdateStrategyType&& value) { m_authTokenUpdateStrategyHasBeenSet = true; m_authTokenUpdateStrategy = std::move(value); }
-
-    /**
-     * <p>Specifies the strategy to use to update the AUTH token. This parameter must
-     * be specified with the <code>auth-token</code> parameter. Possible values:</p>
-     * <ul> <li> <p>Rotate</p> </li> <li> <p>Set</p> </li> </ul> <p> For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/auth.html">Authenticating
-     * Users with Redis AUTH</a> </p>
-     */
-    inline ModifyReplicationGroupRequest& WithAuthTokenUpdateStrategy(const AuthTokenUpdateStrategyType& value) { SetAuthTokenUpdateStrategy(value); return *this;}
-
-    /**
-     * <p>Specifies the strategy to use to update the AUTH token. This parameter must
-     * be specified with the <code>auth-token</code> parameter. Possible values:</p>
-     * <ul> <li> <p>Rotate</p> </li> <li> <p>Set</p> </li> </ul> <p> For more
-     * information, see <a
-     * href="https://docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/auth.html">Authenticating
-     * Users with Redis AUTH</a> </p>
-     */
-    inline ModifyReplicationGroupRequest& WithAuthTokenUpdateStrategy(AuthTokenUpdateStrategyType&& value) { SetAuthTokenUpdateStrategy(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_replicationGroupId;
@@ -1235,9 +1069,6 @@ namespace Model
     bool m_automaticFailoverEnabled;
     bool m_automaticFailoverEnabledHasBeenSet;
 
-    bool m_multiAZEnabled;
-    bool m_multiAZEnabledHasBeenSet;
-
     Aws::Vector<Aws::String> m_cacheSecurityGroupNames;
     bool m_cacheSecurityGroupNamesHasBeenSet;
 
@@ -1273,12 +1104,6 @@ namespace Model
 
     Aws::String m_cacheNodeType;
     bool m_cacheNodeTypeHasBeenSet;
-
-    Aws::String m_authToken;
-    bool m_authTokenHasBeenSet;
-
-    AuthTokenUpdateStrategyType m_authTokenUpdateStrategy;
-    bool m_authTokenUpdateStrategyHasBeenSet;
   };
 
 } // namespace Model
