@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/elasticfilesystem/EFS_EXPORTS.h>
@@ -175,79 +185,6 @@ namespace Model
     inline FileSystemDescription& WithFileSystemId(const char* value) { SetFileSystemId(value); return *this;}
 
 
-    /**
-     * <p>The Amazon Resource Name (ARN) for the EFS file system, in the format
-     * <code>arn:aws:elasticfilesystem:<i>region</i>:<i>account-id</i>:file-system/<i>file-system-id</i>
-     * </code>. Example with sample data:
-     * <code>arn:aws:elasticfilesystem:us-west-2:1111333322228888:file-system/fs-01234567</code>
-     * </p>
-     */
-    inline const Aws::String& GetFileSystemArn() const{ return m_fileSystemArn; }
-
-    /**
-     * <p>The Amazon Resource Name (ARN) for the EFS file system, in the format
-     * <code>arn:aws:elasticfilesystem:<i>region</i>:<i>account-id</i>:file-system/<i>file-system-id</i>
-     * </code>. Example with sample data:
-     * <code>arn:aws:elasticfilesystem:us-west-2:1111333322228888:file-system/fs-01234567</code>
-     * </p>
-     */
-    inline bool FileSystemArnHasBeenSet() const { return m_fileSystemArnHasBeenSet; }
-
-    /**
-     * <p>The Amazon Resource Name (ARN) for the EFS file system, in the format
-     * <code>arn:aws:elasticfilesystem:<i>region</i>:<i>account-id</i>:file-system/<i>file-system-id</i>
-     * </code>. Example with sample data:
-     * <code>arn:aws:elasticfilesystem:us-west-2:1111333322228888:file-system/fs-01234567</code>
-     * </p>
-     */
-    inline void SetFileSystemArn(const Aws::String& value) { m_fileSystemArnHasBeenSet = true; m_fileSystemArn = value; }
-
-    /**
-     * <p>The Amazon Resource Name (ARN) for the EFS file system, in the format
-     * <code>arn:aws:elasticfilesystem:<i>region</i>:<i>account-id</i>:file-system/<i>file-system-id</i>
-     * </code>. Example with sample data:
-     * <code>arn:aws:elasticfilesystem:us-west-2:1111333322228888:file-system/fs-01234567</code>
-     * </p>
-     */
-    inline void SetFileSystemArn(Aws::String&& value) { m_fileSystemArnHasBeenSet = true; m_fileSystemArn = std::move(value); }
-
-    /**
-     * <p>The Amazon Resource Name (ARN) for the EFS file system, in the format
-     * <code>arn:aws:elasticfilesystem:<i>region</i>:<i>account-id</i>:file-system/<i>file-system-id</i>
-     * </code>. Example with sample data:
-     * <code>arn:aws:elasticfilesystem:us-west-2:1111333322228888:file-system/fs-01234567</code>
-     * </p>
-     */
-    inline void SetFileSystemArn(const char* value) { m_fileSystemArnHasBeenSet = true; m_fileSystemArn.assign(value); }
-
-    /**
-     * <p>The Amazon Resource Name (ARN) for the EFS file system, in the format
-     * <code>arn:aws:elasticfilesystem:<i>region</i>:<i>account-id</i>:file-system/<i>file-system-id</i>
-     * </code>. Example with sample data:
-     * <code>arn:aws:elasticfilesystem:us-west-2:1111333322228888:file-system/fs-01234567</code>
-     * </p>
-     */
-    inline FileSystemDescription& WithFileSystemArn(const Aws::String& value) { SetFileSystemArn(value); return *this;}
-
-    /**
-     * <p>The Amazon Resource Name (ARN) for the EFS file system, in the format
-     * <code>arn:aws:elasticfilesystem:<i>region</i>:<i>account-id</i>:file-system/<i>file-system-id</i>
-     * </code>. Example with sample data:
-     * <code>arn:aws:elasticfilesystem:us-west-2:1111333322228888:file-system/fs-01234567</code>
-     * </p>
-     */
-    inline FileSystemDescription& WithFileSystemArn(Aws::String&& value) { SetFileSystemArn(std::move(value)); return *this;}
-
-    /**
-     * <p>The Amazon Resource Name (ARN) for the EFS file system, in the format
-     * <code>arn:aws:elasticfilesystem:<i>region</i>:<i>account-id</i>:file-system/<i>file-system-id</i>
-     * </code>. Example with sample data:
-     * <code>arn:aws:elasticfilesystem:us-west-2:1111333322228888:file-system/fs-01234567</code>
-     * </p>
-     */
-    inline FileSystemDescription& WithFileSystemArn(const char* value) { SetFileSystemArn(value); return *this;}
-
-
     /**
      * <p>The time that the file system was created, in seconds (since
      * 1970-01-01T00:00:00Z).</p>
@@ -590,82 +527,63 @@ namespace Model
 
     /**
      * <p>The throughput mode for a file system. There are two throughput modes to
-     * choose from for your file system: <code>bursting</code> and
-     * <code>provisioned</code>. If you set <code>ThroughputMode</code> to
-     * <code>provisioned</code>, you must also set a value for
-     * <code>ProvisionedThroughPutInMibps</code>. You can decrease your file system's
-     * throughput in Provisioned Throughput mode or change between the throughput modes
-     * as long as it’s been more than 24 hours since the last decrease or throughput
-     * mode change. </p>
+     * choose from for your file system: bursting and provisioned. You can decrease
+     * your file system's throughput in Provisioned Throughput mode or change between
+     * the throughput modes as long as it’s been more than 24 hours since the last
+     * decrease or throughput mode change.</p>
      */
     inline const ThroughputMode& GetThroughputMode() const{ return m_throughputMode; }
 
     /**
      * <p>The throughput mode for a file system. There are two throughput modes to
-     * choose from for your file system: <code>bursting</code> and
-     * <code>provisioned</code>. If you set <code>ThroughputMode</code> to
-     * <code>provisioned</code>, you must also set a value for
-     * <code>ProvisionedThroughPutInMibps</code>. You can decrease your file system's
-     * throughput in Provisioned Throughput mode or change between the throughput modes
-     * as long as it’s been more than 24 hours since the last decrease or throughput
-     * mode change. </p>
+     * choose from for your file system: bursting and provisioned. You can decrease
+     * your file system's throughput in Provisioned Throughput mode or change between
+     * the throughput modes as long as it’s been more than 24 hours since the last
+     * decrease or throughput mode change.</p>
      */
     inline bool ThroughputModeHasBeenSet() const { return m_throughputModeHasBeenSet; }
 
     /**
      * <p>The throughput mode for a file system. There are two throughput modes to
-     * choose from for your file system: <code>bursting</code> and
-     * <code>provisioned</code>. If you set <code>ThroughputMode</code> to
-     * <code>provisioned</code>, you must also set a value for
-     * <code>ProvisionedThroughPutInMibps</code>. You can decrease your file system's
-     * throughput in Provisioned Throughput mode or change between the throughput modes
-     * as long as it’s been more than 24 hours since the last decrease or throughput
-     * mode change. </p>
+     * choose from for your file system: bursting and provisioned. You can decrease
+     * your file system's throughput in Provisioned Throughput mode or change between
+     * the throughput modes as long as it’s been more than 24 hours since the last
+     * decrease or throughput mode change.</p>
      */
     inline void SetThroughputMode(const ThroughputMode& value) { m_throughputModeHasBeenSet = true; m_throughputMode = value; }
 
     /**
      * <p>The throughput mode for a file system. There are two throughput modes to
-     * choose from for your file system: <code>bursting</code> and
-     * <code>provisioned</code>. If you set <code>ThroughputMode</code> to
-     * <code>provisioned</code>, you must also set a value for
-     * <code>ProvisionedThroughPutInMibps</code>. You can decrease your file system's
-     * throughput in Provisioned Throughput mode or change between the throughput modes
-     * as long as it’s been more than 24 hours since the last decrease or throughput
-     * mode change. </p>
+     * choose from for your file system: bursting and provisioned. You can decrease
+     * your file system's throughput in Provisioned Throughput mode or change between
+     * the throughput modes as long as it’s been more than 24 hours since the last
+     * decrease or throughput mode change.</p>
      */
     inline void SetThroughputMode(ThroughputMode&& value) { m_throughputModeHasBeenSet = true; m_throughputMode = std::move(value); }
 
     /**
      * <p>The throughput mode for a file system. There are two throughput modes to
-     * choose from for your file system: <code>bursting</code> and
-     * <code>provisioned</code>. If you set <code>ThroughputMode</code> to
-     * <code>provisioned</code>, you must also set a value for
-     * <code>ProvisionedThroughPutInMibps</code>. You can decrease your file system's
-     * throughput in Provisioned Throughput mode or change between the throughput modes
-     * as long as it’s been more than 24 hours since the last decrease or throughput
-     * mode change. </p>
+     * choose from for your file system: bursting and provisioned. You can decrease
+     * your file system's throughput in Provisioned Throughput mode or change between
+     * the throughput modes as long as it’s been more than 24 hours since the last
+     * decrease or throughput mode change.</p>
      */
     inline FileSystemDescription& WithThroughputMode(const ThroughputMode& value) { SetThroughputMode(value); return *this;}
 
     /**
      * <p>The throughput mode for a file system. There are two throughput modes to
-     * choose from for your file system: <code>bursting</code> and
-     * <code>provisioned</code>. If you set <code>ThroughputMode</code> to
-     * <code>provisioned</code>, you must also set a value for
-     * <code>ProvisionedThroughPutInMibps</code>. You can decrease your file system's
-     * throughput in Provisioned Throughput mode or change between the throughput modes
-     * as long as it’s been more than 24 hours since the last decrease or throughput
-     * mode change. </p>
+     * choose from for your file system: bursting and provisioned. You can decrease
+     * your file system's throughput in Provisioned Throughput mode or change between
+     * the throughput modes as long as it’s been more than 24 hours since the last
+     * decrease or throughput mode change.</p>
      */
     inline FileSystemDescription& WithThroughputMode(ThroughputMode&& value) { SetThroughputMode(std::move(value)); return *this;}
 
 
     /**
      * <p>The throughput, measured in MiB/s, that you want to provision for a file
-     * system. Valid values are 1-1024. Required if <code>ThroughputMode</code> is set
-     * to <code>provisioned</code>. The limit on throughput is 1024 MiB/s. You can get
-     * these limits increased by contacting AWS Support. For more information, see <a
+     * system. The limit on throughput is 1024 MiB/s. You can get these limits
+     * increased by contacting AWS Support. For more information, see <a
      * href="https://docs.aws.amazon.com/efs/latest/ug/limits.html#soft-limits">Amazon
      * EFS Limits That You Can Increase</a> in the <i>Amazon EFS User Guide.</i> </p>
      */
@@ -673,9 +591,8 @@ namespace Model
 
     /**
      * <p>The throughput, measured in MiB/s, that you want to provision for a file
-     * system. Valid values are 1-1024. Required if <code>ThroughputMode</code> is set
-     * to <code>provisioned</code>. The limit on throughput is 1024 MiB/s. You can get
-     * these limits increased by contacting AWS Support. For more information, see <a
+     * system. The limit on throughput is 1024 MiB/s. You can get these limits
+     * increased by contacting AWS Support. For more information, see <a
      * href="https://docs.aws.amazon.com/efs/latest/ug/limits.html#soft-limits">Amazon
      * EFS Limits That You Can Increase</a> in the <i>Amazon EFS User Guide.</i> </p>
      */
@@ -683,9 +600,8 @@ namespace Model
 
     /**
      * <p>The throughput, measured in MiB/s, that you want to provision for a file
-     * system. Valid values are 1-1024. Required if <code>ThroughputMode</code> is set
-     * to <code>provisioned</code>. The limit on throughput is 1024 MiB/s. You can get
-     * these limits increased by contacting AWS Support. For more information, see <a
+     * system. The limit on throughput is 1024 MiB/s. You can get these limits
+     * increased by contacting AWS Support. For more information, see <a
      * href="https://docs.aws.amazon.com/efs/latest/ug/limits.html#soft-limits">Amazon
      * EFS Limits That You Can Increase</a> in the <i>Amazon EFS User Guide.</i> </p>
      */
@@ -693,9 +609,8 @@ namespace Model
 
     /**
      * <p>The throughput, measured in MiB/s, that you want to provision for a file
-     * system. Valid values are 1-1024. Required if <code>ThroughputMode</code> is set
-     * to <code>provisioned</code>. The limit on throughput is 1024 MiB/s. You can get
-     * these limits increased by contacting AWS Support. For more information, see <a
+     * system. The limit on throughput is 1024 MiB/s. You can get these limits
+     * increased by contacting AWS Support. For more information, see <a
      * href="https://docs.aws.amazon.com/efs/latest/ug/limits.html#soft-limits">Amazon
      * EFS Limits That You Can Increase</a> in the <i>Amazon EFS User Guide.</i> </p>
      */
@@ -761,9 +676,6 @@ namespace Model
     Aws::String m_fileSystemId;
     bool m_fileSystemIdHasBeenSet;
 
-    Aws::String m_fileSystemArn;
-    bool m_fileSystemArnHasBeenSet;
-
     Aws::Utils::DateTime m_creationTime;
     bool m_creationTimeHasBeenSet;
 
