@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/elasticloadbalancingv2/ElasticLoadBalancingv2_EXPORTS.h>
@@ -28,7 +38,7 @@ namespace Model
   {
   public:
     CreateLoadBalancerRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -111,10 +121,8 @@ namespace Model
      * <p>The IDs of the public subnets. You can specify only one subnet per
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
-     * Availability Zones.</p> <p>[Application Load Balancers on Outposts] You must
-     * specify one Outpost subnet.</p> <p>[Application Load Balancers on Local Zones]
-     * You can specify subnets from one or more Local Zones.</p> <p>[Network Load
-     * Balancers] You can specify subnets from one or more Availability Zones.</p>
+     * Availability Zones.</p> <p>[Network Load Balancers] You can specify subnets from
+     * one or more Availability Zones.</p>
      */
     inline const Aws::Vector<Aws::String>& GetSubnets() const{ return m_subnets; }
 
@@ -122,10 +130,8 @@ namespace Model
      * <p>The IDs of the public subnets. You can specify only one subnet per
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
-     * Availability Zones.</p> <p>[Application Load Balancers on Outposts] You must
-     * specify one Outpost subnet.</p> <p>[Application Load Balancers on Local Zones]
-     * You can specify subnets from one or more Local Zones.</p> <p>[Network Load
-     * Balancers] You can specify subnets from one or more Availability Zones.</p>
+     * Availability Zones.</p> <p>[Network Load Balancers] You can specify subnets from
+     * one or more Availability Zones.</p>
      */
     inline bool SubnetsHasBeenSet() const { return m_subnetsHasBeenSet; }
 
@@ -133,10 +139,8 @@ namespace Model
      * <p>The IDs of the public subnets. You can specify only one subnet per
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
-     * Availability Zones.</p> <p>[Application Load Balancers on Outposts] You must
-     * specify one Outpost subnet.</p> <p>[Application Load Balancers on Local Zones]
-     * You can specify subnets from one or more Local Zones.</p> <p>[Network Load
-     * Balancers] You can specify subnets from one or more Availability Zones.</p>
+     * Availability Zones.</p> <p>[Network Load Balancers] You can specify subnets from
+     * one or more Availability Zones.</p>
      */
     inline void SetSubnets(const Aws::Vector<Aws::String>& value) { m_subnetsHasBeenSet = true; m_subnets = value; }
 
@@ -144,10 +148,8 @@ namespace Model
      * <p>The IDs of the public subnets. You can specify only one subnet per
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
-     * Availability Zones.</p> <p>[Application Load Balancers on Outposts] You must
-     * specify one Outpost subnet.</p> <p>[Application Load Balancers on Local Zones]
-     * You can specify subnets from one or more Local Zones.</p> <p>[Network Load
-     * Balancers] You can specify subnets from one or more Availability Zones.</p>
+     * Availability Zones.</p> <p>[Network Load Balancers] You can specify subnets from
+     * one or more Availability Zones.</p>
      */
     inline void SetSubnets(Aws::Vector<Aws::String>&& value) { m_subnetsHasBeenSet = true; m_subnets = std::move(value); }
 
@@ -155,10 +157,8 @@ namespace Model
      * <p>The IDs of the public subnets. You can specify only one subnet per
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
-     * Availability Zones.</p> <p>[Application Load Balancers on Outposts] You must
-     * specify one Outpost subnet.</p> <p>[Application Load Balancers on Local Zones]
-     * You can specify subnets from one or more Local Zones.</p> <p>[Network Load
-     * Balancers] You can specify subnets from one or more Availability Zones.</p>
+     * Availability Zones.</p> <p>[Network Load Balancers] You can specify subnets from
+     * one or more Availability Zones.</p>
      */
     inline CreateLoadBalancerRequest& WithSubnets(const Aws::Vector<Aws::String>& value) { SetSubnets(value); return *this;}
 
@@ -166,10 +166,8 @@ namespace Model
      * <p>The IDs of the public subnets. You can specify only one subnet per
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
-     * Availability Zones.</p> <p>[Application Load Balancers on Outposts] You must
-     * specify one Outpost subnet.</p> <p>[Application Load Balancers on Local Zones]
-     * You can specify subnets from one or more Local Zones.</p> <p>[Network Load
-     * Balancers] You can specify subnets from one or more Availability Zones.</p>
+     * Availability Zones.</p> <p>[Network Load Balancers] You can specify subnets from
+     * one or more Availability Zones.</p>
      */
     inline CreateLoadBalancerRequest& WithSubnets(Aws::Vector<Aws::String>&& value) { SetSubnets(std::move(value)); return *this;}
 
@@ -177,10 +175,8 @@ namespace Model
      * <p>The IDs of the public subnets. You can specify only one subnet per
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
-     * Availability Zones.</p> <p>[Application Load Balancers on Outposts] You must
-     * specify one Outpost subnet.</p> <p>[Application Load Balancers on Local Zones]
-     * You can specify subnets from one or more Local Zones.</p> <p>[Network Load
-     * Balancers] You can specify subnets from one or more Availability Zones.</p>
+     * Availability Zones.</p> <p>[Network Load Balancers] You can specify subnets from
+     * one or more Availability Zones.</p>
      */
     inline CreateLoadBalancerRequest& AddSubnets(const Aws::String& value) { m_subnetsHasBeenSet = true; m_subnets.push_back(value); return *this; }
 
@@ -188,10 +184,8 @@ namespace Model
      * <p>The IDs of the public subnets. You can specify only one subnet per
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
-     * Availability Zones.</p> <p>[Application Load Balancers on Outposts] You must
-     * specify one Outpost subnet.</p> <p>[Application Load Balancers on Local Zones]
-     * You can specify subnets from one or more Local Zones.</p> <p>[Network Load
-     * Balancers] You can specify subnets from one or more Availability Zones.</p>
+     * Availability Zones.</p> <p>[Network Load Balancers] You can specify subnets from
+     * one or more Availability Zones.</p>
      */
     inline CreateLoadBalancerRequest& AddSubnets(Aws::String&& value) { m_subnetsHasBeenSet = true; m_subnets.push_back(std::move(value)); return *this; }
 
@@ -199,10 +193,8 @@ namespace Model
      * <p>The IDs of the public subnets. You can specify only one subnet per
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
-     * Availability Zones.</p> <p>[Application Load Balancers on Outposts] You must
-     * specify one Outpost subnet.</p> <p>[Application Load Balancers on Local Zones]
-     * You can specify subnets from one or more Local Zones.</p> <p>[Network Load
-     * Balancers] You can specify subnets from one or more Availability Zones.</p>
+     * Availability Zones.</p> <p>[Network Load Balancers] You can specify subnets from
+     * one or more Availability Zones.</p>
      */
     inline CreateLoadBalancerRequest& AddSubnets(const char* value) { m_subnetsHasBeenSet = true; m_subnets.push_back(value); return *this; }
 
@@ -212,13 +204,8 @@ namespace Model
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
      * Availability Zones. You cannot specify Elastic IP addresses for your
-     * subnets.</p> <p>[Application Load Balancers on Outposts] You must specify one
-     * Outpost subnet.</p> <p>[Application Load Balancers on Local Zones] You can
-     * specify subnets from one or more Local Zones.</p> <p>[Network Load Balancers]
-     * You can specify subnets from one or more Availability Zones. You can specify one
-     * Elastic IP address per subnet if you need static IP addresses for your
-     * internet-facing load balancer. For internal load balancers, you can specify one
-     * private IP address per subnet from the IPv4 range of the subnet.</p>
+     * subnets.</p> <p>[Network Load Balancers] You can specify subnets from one or
+     * more Availability Zones. You can specify one Elastic IP address per subnet.</p>
      */
     inline const Aws::Vector<SubnetMapping>& GetSubnetMappings() const{ return m_subnetMappings; }
 
@@ -227,13 +214,8 @@ namespace Model
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
      * Availability Zones. You cannot specify Elastic IP addresses for your
-     * subnets.</p> <p>[Application Load Balancers on Outposts] You must specify one
-     * Outpost subnet.</p> <p>[Application Load Balancers on Local Zones] You can
-     * specify subnets from one or more Local Zones.</p> <p>[Network Load Balancers]
-     * You can specify subnets from one or more Availability Zones. You can specify one
-     * Elastic IP address per subnet if you need static IP addresses for your
-     * internet-facing load balancer. For internal load balancers, you can specify one
-     * private IP address per subnet from the IPv4 range of the subnet.</p>
+     * subnets.</p> <p>[Network Load Balancers] You can specify subnets from one or
+     * more Availability Zones. You can specify one Elastic IP address per subnet.</p>
      */
     inline bool SubnetMappingsHasBeenSet() const { return m_subnetMappingsHasBeenSet; }
 
@@ -242,13 +224,8 @@ namespace Model
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
      * Availability Zones. You cannot specify Elastic IP addresses for your
-     * subnets.</p> <p>[Application Load Balancers on Outposts] You must specify one
-     * Outpost subnet.</p> <p>[Application Load Balancers on Local Zones] You can
-     * specify subnets from one or more Local Zones.</p> <p>[Network Load Balancers]
-     * You can specify subnets from one or more Availability Zones. You can specify one
-     * Elastic IP address per subnet if you need static IP addresses for your
-     * internet-facing load balancer. For internal load balancers, you can specify one
-     * private IP address per subnet from the IPv4 range of the subnet.</p>
+     * subnets.</p> <p>[Network Load Balancers] You can specify subnets from one or
+     * more Availability Zones. You can specify one Elastic IP address per subnet.</p>
      */
     inline void SetSubnetMappings(const Aws::Vector<SubnetMapping>& value) { m_subnetMappingsHasBeenSet = true; m_subnetMappings = value; }
 
@@ -257,13 +234,8 @@ namespace Model
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
      * Availability Zones. You cannot specify Elastic IP addresses for your
-     * subnets.</p> <p>[Application Load Balancers on Outposts] You must specify one
-     * Outpost subnet.</p> <p>[Application Load Balancers on Local Zones] You can
-     * specify subnets from one or more Local Zones.</p> <p>[Network Load Balancers]
-     * You can specify subnets from one or more Availability Zones. You can specify one
-     * Elastic IP address per subnet if you need static IP addresses for your
-     * internet-facing load balancer. For internal load balancers, you can specify one
-     * private IP address per subnet from the IPv4 range of the subnet.</p>
+     * subnets.</p> <p>[Network Load Balancers] You can specify subnets from one or
+     * more Availability Zones. You can specify one Elastic IP address per subnet.</p>
      */
     inline void SetSubnetMappings(Aws::Vector<SubnetMapping>&& value) { m_subnetMappingsHasBeenSet = true; m_subnetMappings = std::move(value); }
 
@@ -272,13 +244,8 @@ namespace Model
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
      * Availability Zones. You cannot specify Elastic IP addresses for your
-     * subnets.</p> <p>[Application Load Balancers on Outposts] You must specify one
-     * Outpost subnet.</p> <p>[Application Load Balancers on Local Zones] You can
-     * specify subnets from one or more Local Zones.</p> <p>[Network Load Balancers]
-     * You can specify subnets from one or more Availability Zones. You can specify one
-     * Elastic IP address per subnet if you need static IP addresses for your
-     * internet-facing load balancer. For internal load balancers, you can specify one
-     * private IP address per subnet from the IPv4 range of the subnet.</p>
+     * subnets.</p> <p>[Network Load Balancers] You can specify subnets from one or
+     * more Availability Zones. You can specify one Elastic IP address per subnet.</p>
      */
     inline CreateLoadBalancerRequest& WithSubnetMappings(const Aws::Vector<SubnetMapping>& value) { SetSubnetMappings(value); return *this;}
 
@@ -287,13 +254,8 @@ namespace Model
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
      * Availability Zones. You cannot specify Elastic IP addresses for your
-     * subnets.</p> <p>[Application Load Balancers on Outposts] You must specify one
-     * Outpost subnet.</p> <p>[Application Load Balancers on Local Zones] You can
-     * specify subnets from one or more Local Zones.</p> <p>[Network Load Balancers]
-     * You can specify subnets from one or more Availability Zones. You can specify one
-     * Elastic IP address per subnet if you need static IP addresses for your
-     * internet-facing load balancer. For internal load balancers, you can specify one
-     * private IP address per subnet from the IPv4 range of the subnet.</p>
+     * subnets.</p> <p>[Network Load Balancers] You can specify subnets from one or
+     * more Availability Zones. You can specify one Elastic IP address per subnet.</p>
      */
     inline CreateLoadBalancerRequest& WithSubnetMappings(Aws::Vector<SubnetMapping>&& value) { SetSubnetMappings(std::move(value)); return *this;}
 
@@ -302,13 +264,8 @@ namespace Model
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
      * Availability Zones. You cannot specify Elastic IP addresses for your
-     * subnets.</p> <p>[Application Load Balancers on Outposts] You must specify one
-     * Outpost subnet.</p> <p>[Application Load Balancers on Local Zones] You can
-     * specify subnets from one or more Local Zones.</p> <p>[Network Load Balancers]
-     * You can specify subnets from one or more Availability Zones. You can specify one
-     * Elastic IP address per subnet if you need static IP addresses for your
-     * internet-facing load balancer. For internal load balancers, you can specify one
-     * private IP address per subnet from the IPv4 range of the subnet.</p>
+     * subnets.</p> <p>[Network Load Balancers] You can specify subnets from one or
+     * more Availability Zones. You can specify one Elastic IP address per subnet.</p>
      */
     inline CreateLoadBalancerRequest& AddSubnetMappings(const SubnetMapping& value) { m_subnetMappingsHasBeenSet = true; m_subnetMappings.push_back(value); return *this; }
 
@@ -317,13 +274,8 @@ namespace Model
      * Availability Zone. You must specify either subnets or subnet mappings.</p>
      * <p>[Application Load Balancers] You must specify subnets from at least two
      * Availability Zones. You cannot specify Elastic IP addresses for your
-     * subnets.</p> <p>[Application Load Balancers on Outposts] You must specify one
-     * Outpost subnet.</p> <p>[Application Load Balancers on Local Zones] You can
-     * specify subnets from one or more Local Zones.</p> <p>[Network Load Balancers]
-     * You can specify subnets from one or more Availability Zones. You can specify one
-     * Elastic IP address per subnet if you need static IP addresses for your
-     * internet-facing load balancer. For internal load balancers, you can specify one
-     * private IP address per subnet from the IPv4 range of the subnet.</p>
+     * subnets.</p> <p>[Network Load Balancers] You can specify subnets from one or
+     * more Availability Zones. You can specify one Elastic IP address per subnet.</p>
      */
     inline CreateLoadBalancerRequest& AddSubnetMappings(SubnetMapping&& value) { m_subnetMappingsHasBeenSet = true; m_subnetMappings.push_back(std::move(value)); return *this; }
 
@@ -390,7 +342,7 @@ namespace Model
      * route requests from clients over the internet.</p> <p>The nodes of an internal
      * load balancer have only private IP addresses. The DNS name of an internal load
      * balancer is publicly resolvable to the private IP addresses of the nodes.
-     * Therefore, internal load balancers can route requests only from clients with
+     * Therefore, internal load balancers can only route requests from clients with
      * access to the VPC for the load balancer.</p> <p>The default is an
      * Internet-facing load balancer.</p>
      */
@@ -403,7 +355,7 @@ namespace Model
      * route requests from clients over the internet.</p> <p>The nodes of an internal
      * load balancer have only private IP addresses. The DNS name of an internal load
      * balancer is publicly resolvable to the private IP addresses of the nodes.
-     * Therefore, internal load balancers can route requests only from clients with
+     * Therefore, internal load balancers can only route requests from clients with
      * access to the VPC for the load balancer.</p> <p>The default is an
      * Internet-facing load balancer.</p>
      */
@@ -416,7 +368,7 @@ namespace Model
      * route requests from clients over the internet.</p> <p>The nodes of an internal
      * load balancer have only private IP addresses. The DNS name of an internal load
      * balancer is publicly resolvable to the private IP addresses of the nodes.
-     * Therefore, internal load balancers can route requests only from clients with
+     * Therefore, internal load balancers can only route requests from clients with
      * access to the VPC for the load balancer.</p> <p>The default is an
      * Internet-facing load balancer.</p>
      */
@@ -429,7 +381,7 @@ namespace Model
      * route requests from clients over the internet.</p> <p>The nodes of an internal
      * load balancer have only private IP addresses. The DNS name of an internal load
      * balancer is publicly resolvable to the private IP addresses of the nodes.
-     * Therefore, internal load balancers can route requests only from clients with
+     * Therefore, internal load balancers can only route requests from clients with
      * access to the VPC for the load balancer.</p> <p>The default is an
      * Internet-facing load balancer.</p>
      */
@@ -442,7 +394,7 @@ namespace Model
      * route requests from clients over the internet.</p> <p>The nodes of an internal
      * load balancer have only private IP addresses. The DNS name of an internal load
      * balancer is publicly resolvable to the private IP addresses of the nodes.
-     * Therefore, internal load balancers can route requests only from clients with
+     * Therefore, internal load balancers can only route requests from clients with
      * access to the VPC for the load balancer.</p> <p>The default is an
      * Internet-facing load balancer.</p>
      */
@@ -455,7 +407,7 @@ namespace Model
      * route requests from clients over the internet.</p> <p>The nodes of an internal
      * load balancer have only private IP addresses. The DNS name of an internal load
      * balancer is publicly resolvable to the private IP addresses of the nodes.
-     * Therefore, internal load balancers can route requests only from clients with
+     * Therefore, internal load balancers can only route requests from clients with
      * access to the VPC for the load balancer.</p> <p>The default is an
      * Internet-facing load balancer.</p>
      */
@@ -582,55 +534,6 @@ namespace Model
      */
     inline CreateLoadBalancerRequest& WithIpAddressType(IpAddressType&& value) { SetIpAddressType(std::move(value)); return *this;}
 
-
-    /**
-     * <p>[Application Load Balancers on Outposts] The ID of the customer-owned address
-     * pool (CoIP pool).</p>
-     */
-    inline const Aws::String& GetCustomerOwnedIpv4Pool() const{ return m_customerOwnedIpv4Pool; }
-
-    /**
-     * <p>[Application Load Balancers on Outposts] The ID of the customer-owned address
-     * pool (CoIP pool).</p>
-     */
-    inline bool CustomerOwnedIpv4PoolHasBeenSet() const { return m_customerOwnedIpv4PoolHasBeenSet; }
-
-    /**
-     * <p>[Application Load Balancers on Outposts] The ID of the customer-owned address
-     * pool (CoIP pool).</p>
-     */
-    inline void SetCustomerOwnedIpv4Pool(const Aws::String& value) { m_customerOwnedIpv4PoolHasBeenSet = true; m_customerOwnedIpv4Pool = value; }
-
-    /**
-     * <p>[Application Load Balancers on Outposts] The ID of the customer-owned address
-     * pool (CoIP pool).</p>
-     */
-    inline void SetCustomerOwnedIpv4Pool(Aws::String&& value) { m_customerOwnedIpv4PoolHasBeenSet = true; m_customerOwnedIpv4Pool = std::move(value); }
-
-    /**
-     * <p>[Application Load Balancers on Outposts] The ID of the customer-owned address
-     * pool (CoIP pool).</p>
-     */
-    inline void SetCustomerOwnedIpv4Pool(const char* value) { m_customerOwnedIpv4PoolHasBeenSet = true; m_customerOwnedIpv4Pool.assign(value); }
-
-    /**
-     * <p>[Application Load Balancers on Outposts] The ID of the customer-owned address
-     * pool (CoIP pool).</p>
-     */
-    inline CreateLoadBalancerRequest& WithCustomerOwnedIpv4Pool(const Aws::String& value) { SetCustomerOwnedIpv4Pool(value); return *this;}
-
-    /**
-     * <p>[Application Load Balancers on Outposts] The ID of the customer-owned address
-     * pool (CoIP pool).</p>
-     */
-    inline CreateLoadBalancerRequest& WithCustomerOwnedIpv4Pool(Aws::String&& value) { SetCustomerOwnedIpv4Pool(std::move(value)); return *this;}
-
-    /**
-     * <p>[Application Load Balancers on Outposts] The ID of the customer-owned address
-     * pool (CoIP pool).</p>
-     */
-    inline CreateLoadBalancerRequest& WithCustomerOwnedIpv4Pool(const char* value) { SetCustomerOwnedIpv4Pool(value); return *this;}
-
   private:
 
     Aws::String m_name;
@@ -656,9 +559,6 @@ namespace Model
 
     IpAddressType m_ipAddressType;
     bool m_ipAddressTypeHasBeenSet;
-
-    Aws::String m_customerOwnedIpv4Pool;
-    bool m_customerOwnedIpv4PoolHasBeenSet;
   };
 
 } // namespace Model
