@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/gamelift/GameLift_EXPORTS.h>
@@ -47,42 +57,42 @@ namespace Model
 
 
     /**
-     * <p>A unique identifier for a matchmaking ticket.</p>
+     * <p>Unique identifier for a matchmaking ticket.</p>
      */
     inline const Aws::String& GetTicketId() const{ return m_ticketId; }
 
     /**
-     * <p>A unique identifier for a matchmaking ticket.</p>
+     * <p>Unique identifier for a matchmaking ticket.</p>
      */
     inline bool TicketIdHasBeenSet() const { return m_ticketIdHasBeenSet; }
 
     /**
-     * <p>A unique identifier for a matchmaking ticket.</p>
+     * <p>Unique identifier for a matchmaking ticket.</p>
      */
     inline void SetTicketId(const Aws::String& value) { m_ticketIdHasBeenSet = true; m_ticketId = value; }
 
     /**
-     * <p>A unique identifier for a matchmaking ticket.</p>
+     * <p>Unique identifier for a matchmaking ticket.</p>
      */
     inline void SetTicketId(Aws::String&& value) { m_ticketIdHasBeenSet = true; m_ticketId = std::move(value); }
 
     /**
-     * <p>A unique identifier for a matchmaking ticket.</p>
+     * <p>Unique identifier for a matchmaking ticket.</p>
      */
     inline void SetTicketId(const char* value) { m_ticketIdHasBeenSet = true; m_ticketId.assign(value); }
 
     /**
-     * <p>A unique identifier for a matchmaking ticket.</p>
+     * <p>Unique identifier for a matchmaking ticket.</p>
      */
     inline MatchmakingTicket& WithTicketId(const Aws::String& value) { SetTicketId(value); return *this;}
 
     /**
-     * <p>A unique identifier for a matchmaking ticket.</p>
+     * <p>Unique identifier for a matchmaking ticket.</p>
      */
     inline MatchmakingTicket& WithTicketId(Aws::String&& value) { SetTicketId(std::move(value)); return *this;}
 
     /**
-     * <p>A unique identifier for a matchmaking ticket.</p>
+     * <p>Unique identifier for a matchmaking ticket.</p>
      */
     inline MatchmakingTicket& WithTicketId(const char* value) { SetTicketId(value); return *this;}
 
@@ -144,71 +154,6 @@ namespace Model
     inline MatchmakingTicket& WithConfigurationName(const char* value) { SetConfigurationName(value); return *this;}
 
 
-    /**
-     * <p>The Amazon Resource Name (<a
-     * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">ARN</a>)
-     * associated with the GameLift matchmaking configuration resource that is used
-     * with this ticket.</p>
-     */
-    inline const Aws::String& GetConfigurationArn() const{ return m_configurationArn; }
-
-    /**
-     * <p>The Amazon Resource Name (<a
-     * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">ARN</a>)
-     * associated with the GameLift matchmaking configuration resource that is used
-     * with this ticket.</p>
-     */
-    inline bool ConfigurationArnHasBeenSet() const { return m_configurationArnHasBeenSet; }
-
-    /**
-     * <p>The Amazon Resource Name (<a
-     * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">ARN</a>)
-     * associated with the GameLift matchmaking configuration resource that is used
-     * with this ticket.</p>
-     */
-    inline void SetConfigurationArn(const Aws::String& value) { m_configurationArnHasBeenSet = true; m_configurationArn = value; }
-
-    /**
-     * <p>The Amazon Resource Name (<a
-     * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">ARN</a>)
-     * associated with the GameLift matchmaking configuration resource that is used
-     * with this ticket.</p>
-     */
-    inline void SetConfigurationArn(Aws::String&& value) { m_configurationArnHasBeenSet = true; m_configurationArn = std::move(value); }
-
-    /**
-     * <p>The Amazon Resource Name (<a
-     * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">ARN</a>)
-     * associated with the GameLift matchmaking configuration resource that is used
-     * with this ticket.</p>
-     */
-    inline void SetConfigurationArn(const char* value) { m_configurationArnHasBeenSet = true; m_configurationArn.assign(value); }
-
-    /**
-     * <p>The Amazon Resource Name (<a
-     * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">ARN</a>)
-     * associated with the GameLift matchmaking configuration resource that is used
-     * with this ticket.</p>
-     */
-    inline MatchmakingTicket& WithConfigurationArn(const Aws::String& value) { SetConfigurationArn(value); return *this;}
-
-    /**
-     * <p>The Amazon Resource Name (<a
-     * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">ARN</a>)
-     * associated with the GameLift matchmaking configuration resource that is used
-     * with this ticket.</p>
-     */
-    inline MatchmakingTicket& WithConfigurationArn(Aws::String&& value) { SetConfigurationArn(std::move(value)); return *this;}
-
-    /**
-     * <p>The Amazon Resource Name (<a
-     * href="https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html">ARN</a>)
-     * associated with the GameLift matchmaking configuration resource that is used
-     * with this ticket.</p>
-     */
-    inline MatchmakingTicket& WithConfigurationArn(const char* value) { SetConfigurationArn(value); return *this;}
-
-
     /**
      * <p>Current status of the matchmaking request.</p> <ul> <li> <p> <b>QUEUED</b> --
      * The matchmaking request has been received and is currently waiting to be
@@ -222,14 +167,14 @@ namespace Model
      * <b>COMPLETED</b> -- Players have been matched and a game session is ready to
      * host the players. A ticket in this state contains the necessary connection
      * information for players.</p> </li> <li> <p> <b>FAILED</b> -- The matchmaking
-     * request was not completed.</p> </li> <li> <p> <b>CANCELLED</b> -- The
-     * matchmaking request was canceled. This may be the result of a call to
-     * <a>StopMatchmaking</a> or a proposed match that one or more players failed to
-     * accept.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking request was not
-     * successful within the duration specified in the matchmaking configuration. </p>
-     * </li> </ul>  <p>Matchmaking requests that fail to successfully complete
-     * (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted as new requests with
-     * new ticket IDs.</p> 
+     * request was not completed. Tickets with players who fail to accept a proposed
+     * match are placed in <code>FAILED</code> status.</p> </li> <li> <p>
+     * <b>CANCELLED</b> -- The matchmaking request was canceled with a call to
+     * <a>StopMatchmaking</a>.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking
+     * request was not successful within the duration specified in the matchmaking
+     * configuration. </p> </li> </ul> <note> <p>Matchmaking requests that fail to
+     * successfully complete (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted
+     * as new requests with new ticket IDs.</p> </note>
      */
     inline const MatchmakingConfigurationStatus& GetStatus() const{ return m_status; }
 
@@ -246,14 +191,14 @@ namespace Model
      * <b>COMPLETED</b> -- Players have been matched and a game session is ready to
      * host the players. A ticket in this state contains the necessary connection
      * information for players.</p> </li> <li> <p> <b>FAILED</b> -- The matchmaking
-     * request was not completed.</p> </li> <li> <p> <b>CANCELLED</b> -- The
-     * matchmaking request was canceled. This may be the result of a call to
-     * <a>StopMatchmaking</a> or a proposed match that one or more players failed to
-     * accept.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking request was not
-     * successful within the duration specified in the matchmaking configuration. </p>
-     * </li> </ul>  <p>Matchmaking requests that fail to successfully complete
-     * (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted as new requests with
-     * new ticket IDs.</p> 
+     * request was not completed. Tickets with players who fail to accept a proposed
+     * match are placed in <code>FAILED</code> status.</p> </li> <li> <p>
+     * <b>CANCELLED</b> -- The matchmaking request was canceled with a call to
+     * <a>StopMatchmaking</a>.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking
+     * request was not successful within the duration specified in the matchmaking
+     * configuration. </p> </li> </ul> <note> <p>Matchmaking requests that fail to
+     * successfully complete (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted
+     * as new requests with new ticket IDs.</p> </note>
      */
     inline bool StatusHasBeenSet() const { return m_statusHasBeenSet; }
 
@@ -270,14 +215,14 @@ namespace Model
      * <b>COMPLETED</b> -- Players have been matched and a game session is ready to
      * host the players. A ticket in this state contains the necessary connection
      * information for players.</p> </li> <li> <p> <b>FAILED</b> -- The matchmaking
-     * request was not completed.</p> </li> <li> <p> <b>CANCELLED</b> -- The
-     * matchmaking request was canceled. This may be the result of a call to
-     * <a>StopMatchmaking</a> or a proposed match that one or more players failed to
-     * accept.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking request was not
-     * successful within the duration specified in the matchmaking configuration. </p>
-     * </li> </ul>  <p>Matchmaking requests that fail to successfully complete
-     * (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted as new requests with
-     * new ticket IDs.</p> 
+     * request was not completed. Tickets with players who fail to accept a proposed
+     * match are placed in <code>FAILED</code> status.</p> </li> <li> <p>
+     * <b>CANCELLED</b> -- The matchmaking request was canceled with a call to
+     * <a>StopMatchmaking</a>.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking
+     * request was not successful within the duration specified in the matchmaking
+     * configuration. </p> </li> </ul> <note> <p>Matchmaking requests that fail to
+     * successfully complete (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted
+     * as new requests with new ticket IDs.</p> </note>
      */
     inline void SetStatus(const MatchmakingConfigurationStatus& value) { m_statusHasBeenSet = true; m_status = value; }
 
@@ -294,14 +239,14 @@ namespace Model
      * <b>COMPLETED</b> -- Players have been matched and a game session is ready to
      * host the players. A ticket in this state contains the necessary connection
      * information for players.</p> </li> <li> <p> <b>FAILED</b> -- The matchmaking
-     * request was not completed.</p> </li> <li> <p> <b>CANCELLED</b> -- The
-     * matchmaking request was canceled. This may be the result of a call to
-     * <a>StopMatchmaking</a> or a proposed match that one or more players failed to
-     * accept.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking request was not
-     * successful within the duration specified in the matchmaking configuration. </p>
-     * </li> </ul>  <p>Matchmaking requests that fail to successfully complete
-     * (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted as new requests with
-     * new ticket IDs.</p> 
+     * request was not completed. Tickets with players who fail to accept a proposed
+     * match are placed in <code>FAILED</code> status.</p> </li> <li> <p>
+     * <b>CANCELLED</b> -- The matchmaking request was canceled with a call to
+     * <a>StopMatchmaking</a>.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking
+     * request was not successful within the duration specified in the matchmaking
+     * configuration. </p> </li> </ul> <note> <p>Matchmaking requests that fail to
+     * successfully complete (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted
+     * as new requests with new ticket IDs.</p> </note>
      */
     inline void SetStatus(MatchmakingConfigurationStatus&& value) { m_statusHasBeenSet = true; m_status = std::move(value); }
 
@@ -318,14 +263,14 @@ namespace Model
      * <b>COMPLETED</b> -- Players have been matched and a game session is ready to
      * host the players. A ticket in this state contains the necessary connection
      * information for players.</p> </li> <li> <p> <b>FAILED</b> -- The matchmaking
-     * request was not completed.</p> </li> <li> <p> <b>CANCELLED</b> -- The
-     * matchmaking request was canceled. This may be the result of a call to
-     * <a>StopMatchmaking</a> or a proposed match that one or more players failed to
-     * accept.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking request was not
-     * successful within the duration specified in the matchmaking configuration. </p>
-     * </li> </ul>  <p>Matchmaking requests that fail to successfully complete
-     * (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted as new requests with
-     * new ticket IDs.</p> 
+     * request was not completed. Tickets with players who fail to accept a proposed
+     * match are placed in <code>FAILED</code> status.</p> </li> <li> <p>
+     * <b>CANCELLED</b> -- The matchmaking request was canceled with a call to
+     * <a>StopMatchmaking</a>.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking
+     * request was not successful within the duration specified in the matchmaking
+     * configuration. </p> </li> </ul> <note> <p>Matchmaking requests that fail to
+     * successfully complete (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted
+     * as new requests with new ticket IDs.</p> </note>
      */
     inline MatchmakingTicket& WithStatus(const MatchmakingConfigurationStatus& value) { SetStatus(value); return *this;}
 
@@ -342,14 +287,14 @@ namespace Model
      * <b>COMPLETED</b> -- Players have been matched and a game session is ready to
      * host the players. A ticket in this state contains the necessary connection
      * information for players.</p> </li> <li> <p> <b>FAILED</b> -- The matchmaking
-     * request was not completed.</p> </li> <li> <p> <b>CANCELLED</b> -- The
-     * matchmaking request was canceled. This may be the result of a call to
-     * <a>StopMatchmaking</a> or a proposed match that one or more players failed to
-     * accept.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking request was not
-     * successful within the duration specified in the matchmaking configuration. </p>
-     * </li> </ul>  <p>Matchmaking requests that fail to successfully complete
-     * (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted as new requests with
-     * new ticket IDs.</p> 
+     * request was not completed. Tickets with players who fail to accept a proposed
+     * match are placed in <code>FAILED</code> status.</p> </li> <li> <p>
+     * <b>CANCELLED</b> -- The matchmaking request was canceled with a call to
+     * <a>StopMatchmaking</a>.</p> </li> <li> <p> <b>TIMED_OUT</b> -- The matchmaking
+     * request was not successful within the duration specified in the matchmaking
+     * configuration. </p> </li> </ul> <note> <p>Matchmaking requests that fail to
+     * successfully complete (statuses FAILED, CANCELLED, TIMED_OUT) can be resubmitted
+     * as new requests with new ticket IDs.</p> </note>
      */
     inline MatchmakingTicket& WithStatus(MatchmakingConfigurationStatus&& value) { SetStatus(std::move(value)); return *this;}
 
@@ -686,9 +631,6 @@ namespace Model
     Aws::String m_configurationName;
     bool m_configurationNameHasBeenSet;
 
-    Aws::String m_configurationArn;
-    bool m_configurationArnHasBeenSet;
-
     MatchmakingConfigurationStatus m_status;
     bool m_statusHasBeenSet;
 
