@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/guardduty/model/UpdateFilterRequest.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -13,14 +23,14 @@ using namespace Aws::Utils::Json;
 using namespace Aws::Utils;
 
 UpdateFilterRequest::UpdateFilterRequest() : 
-    m_detectorIdHasBeenSet(false),
-    m_filterNameHasBeenSet(false),
-    m_descriptionHasBeenSet(false),
     m_action(FilterAction::NOT_SET),
     m_actionHasBeenSet(false),
+    m_descriptionHasBeenSet(false),
+    m_detectorIdHasBeenSet(false),
+    m_filterNameHasBeenSet(false),
+    m_findingCriteriaHasBeenSet(false),
     m_rank(0),
-    m_rankHasBeenSet(false),
-    m_findingCriteriaHasBeenSet(false)
+    m_rankHasBeenSet(false)
 {
 }
 
@@ -28,20 +38,14 @@ Aws::String UpdateFilterRequest::SerializePayload() const
 {
   JsonValue payload;
 
-  if(m_descriptionHasBeenSet)
-  {
-   payload.WithString("description", m_description);
-
-  }
-
   if(m_actionHasBeenSet)
   {
    payload.WithString("action", FilterActionMapper::GetNameForFilterAction(m_action));
   }
 
-  if(m_rankHasBeenSet)
+  if(m_descriptionHasBeenSet)
   {
-   payload.WithInteger("rank", m_rank);
+   payload.WithString("description", m_description);
 
   }
 
@@ -51,6 +55,12 @@ Aws::String UpdateFilterRequest::SerializePayload() const
 
   }
 
+  if(m_rankHasBeenSet)
+  {
+   payload.WithInteger("rank", m_rank);
+
+  }
+
   return payload.View().WriteReadable();
 }
 
