@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/iam/IAM_EXPORTS.h>
@@ -24,7 +34,7 @@ namespace Model
   {
   public:
     CreateUserRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -41,177 +51,193 @@ namespace Model
     /**
      * <p> The path for the user name. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
+     * Identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
      * If it is not included, it defaults to a slash (/).</p> <p>This parameter allows
      * (through its <a href="http://wikipedia.org/wiki/regex">regex pattern</a>) a
      * string of characters consisting of either a forward slash (/) by itself or a
      * string that must begin and end with forward slashes. In addition, it can contain
-     * any ASCII character from the ! (<code>\u0021</code>) through the DEL character
-     * (<code>\u007F</code>), including most punctuation characters, digits, and upper
-     * and lowercased letters.</p>
+     * any ASCII character from the ! (\u0021) through the DEL character (\u007F),
+     * including most punctuation characters, digits, and upper and lowercased
+     * letters.</p>
      */
     inline const Aws::String& GetPath() const{ return m_path; }
 
     /**
      * <p> The path for the user name. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
+     * Identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
      * If it is not included, it defaults to a slash (/).</p> <p>This parameter allows
      * (through its <a href="http://wikipedia.org/wiki/regex">regex pattern</a>) a
      * string of characters consisting of either a forward slash (/) by itself or a
      * string that must begin and end with forward slashes. In addition, it can contain
-     * any ASCII character from the ! (<code>\u0021</code>) through the DEL character
-     * (<code>\u007F</code>), including most punctuation characters, digits, and upper
-     * and lowercased letters.</p>
+     * any ASCII character from the ! (\u0021) through the DEL character (\u007F),
+     * including most punctuation characters, digits, and upper and lowercased
+     * letters.</p>
      */
     inline bool PathHasBeenSet() const { return m_pathHasBeenSet; }
 
     /**
      * <p> The path for the user name. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
+     * Identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
      * If it is not included, it defaults to a slash (/).</p> <p>This parameter allows
      * (through its <a href="http://wikipedia.org/wiki/regex">regex pattern</a>) a
      * string of characters consisting of either a forward slash (/) by itself or a
      * string that must begin and end with forward slashes. In addition, it can contain
-     * any ASCII character from the ! (<code>\u0021</code>) through the DEL character
-     * (<code>\u007F</code>), including most punctuation characters, digits, and upper
-     * and lowercased letters.</p>
+     * any ASCII character from the ! (\u0021) through the DEL character (\u007F),
+     * including most punctuation characters, digits, and upper and lowercased
+     * letters.</p>
      */
     inline void SetPath(const Aws::String& value) { m_pathHasBeenSet = true; m_path = value; }
 
     /**
      * <p> The path for the user name. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
+     * Identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
      * If it is not included, it defaults to a slash (/).</p> <p>This parameter allows
      * (through its <a href="http://wikipedia.org/wiki/regex">regex pattern</a>) a
      * string of characters consisting of either a forward slash (/) by itself or a
      * string that must begin and end with forward slashes. In addition, it can contain
-     * any ASCII character from the ! (<code>\u0021</code>) through the DEL character
-     * (<code>\u007F</code>), including most punctuation characters, digits, and upper
-     * and lowercased letters.</p>
+     * any ASCII character from the ! (\u0021) through the DEL character (\u007F),
+     * including most punctuation characters, digits, and upper and lowercased
+     * letters.</p>
      */
     inline void SetPath(Aws::String&& value) { m_pathHasBeenSet = true; m_path = std::move(value); }
 
     /**
      * <p> The path for the user name. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
+     * Identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
      * If it is not included, it defaults to a slash (/).</p> <p>This parameter allows
      * (through its <a href="http://wikipedia.org/wiki/regex">regex pattern</a>) a
      * string of characters consisting of either a forward slash (/) by itself or a
      * string that must begin and end with forward slashes. In addition, it can contain
-     * any ASCII character from the ! (<code>\u0021</code>) through the DEL character
-     * (<code>\u007F</code>), including most punctuation characters, digits, and upper
-     * and lowercased letters.</p>
+     * any ASCII character from the ! (\u0021) through the DEL character (\u007F),
+     * including most punctuation characters, digits, and upper and lowercased
+     * letters.</p>
      */
     inline void SetPath(const char* value) { m_pathHasBeenSet = true; m_path.assign(value); }
 
     /**
      * <p> The path for the user name. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
+     * Identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
      * If it is not included, it defaults to a slash (/).</p> <p>This parameter allows
      * (through its <a href="http://wikipedia.org/wiki/regex">regex pattern</a>) a
      * string of characters consisting of either a forward slash (/) by itself or a
      * string that must begin and end with forward slashes. In addition, it can contain
-     * any ASCII character from the ! (<code>\u0021</code>) through the DEL character
-     * (<code>\u007F</code>), including most punctuation characters, digits, and upper
-     * and lowercased letters.</p>
+     * any ASCII character from the ! (\u0021) through the DEL character (\u007F),
+     * including most punctuation characters, digits, and upper and lowercased
+     * letters.</p>
      */
     inline CreateUserRequest& WithPath(const Aws::String& value) { SetPath(value); return *this;}
 
     /**
      * <p> The path for the user name. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
+     * Identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
      * If it is not included, it defaults to a slash (/).</p> <p>This parameter allows
      * (through its <a href="http://wikipedia.org/wiki/regex">regex pattern</a>) a
      * string of characters consisting of either a forward slash (/) by itself or a
      * string that must begin and end with forward slashes. In addition, it can contain
-     * any ASCII character from the ! (<code>\u0021</code>) through the DEL character
-     * (<code>\u007F</code>), including most punctuation characters, digits, and upper
-     * and lowercased letters.</p>
+     * any ASCII character from the ! (\u0021) through the DEL character (\u007F),
+     * including most punctuation characters, digits, and upper and lowercased
+     * letters.</p>
      */
     inline CreateUserRequest& WithPath(Aws::String&& value) { SetPath(std::move(value)); return *this;}
 
     /**
      * <p> The path for the user name. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
+     * Identifiers</a> in the <i>IAM User Guide</i>.</p> <p>This parameter is optional.
      * If it is not included, it defaults to a slash (/).</p> <p>This parameter allows
      * (through its <a href="http://wikipedia.org/wiki/regex">regex pattern</a>) a
      * string of characters consisting of either a forward slash (/) by itself or a
      * string that must begin and end with forward slashes. In addition, it can contain
-     * any ASCII character from the ! (<code>\u0021</code>) through the DEL character
-     * (<code>\u007F</code>), including most punctuation characters, digits, and upper
-     * and lowercased letters.</p>
+     * any ASCII character from the ! (\u0021) through the DEL character (\u007F),
+     * including most punctuation characters, digits, and upper and lowercased
+     * letters.</p>
      */
     inline CreateUserRequest& WithPath(const char* value) { SetPath(value); return *this;}
 
 
     /**
-     * <p>The name of the user to create.</p> <p>IAM user, group, role, and policy
-     * names must be unique within the account. Names are not distinguished by case.
-     * For example, you cannot create resources named both "MyResource" and
-     * "myresource".</p>
+     * <p>The name of the user to create.</p> <p>This parameter allows (through its <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a>) a string of characters
+     * consisting of upper and lowercase alphanumeric characters with no spaces. You
+     * can also include any of the following characters: _+=,.@-. User names are not
+     * distinguished by case. For example, you cannot create users named both
+     * "TESTUSER" and "testuser".</p>
      */
     inline const Aws::String& GetUserName() const{ return m_userName; }
 
     /**
-     * <p>The name of the user to create.</p> <p>IAM user, group, role, and policy
-     * names must be unique within the account. Names are not distinguished by case.
-     * For example, you cannot create resources named both "MyResource" and
-     * "myresource".</p>
+     * <p>The name of the user to create.</p> <p>This parameter allows (through its <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a>) a string of characters
+     * consisting of upper and lowercase alphanumeric characters with no spaces. You
+     * can also include any of the following characters: _+=,.@-. User names are not
+     * distinguished by case. For example, you cannot create users named both
+     * "TESTUSER" and "testuser".</p>
      */
     inline bool UserNameHasBeenSet() const { return m_userNameHasBeenSet; }
 
     /**
-     * <p>The name of the user to create.</p> <p>IAM user, group, role, and policy
-     * names must be unique within the account. Names are not distinguished by case.
-     * For example, you cannot create resources named both "MyResource" and
-     * "myresource".</p>
+     * <p>The name of the user to create.</p> <p>This parameter allows (through its <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a>) a string of characters
+     * consisting of upper and lowercase alphanumeric characters with no spaces. You
+     * can also include any of the following characters: _+=,.@-. User names are not
+     * distinguished by case. For example, you cannot create users named both
+     * "TESTUSER" and "testuser".</p>
      */
     inline void SetUserName(const Aws::String& value) { m_userNameHasBeenSet = true; m_userName = value; }
 
     /**
-     * <p>The name of the user to create.</p> <p>IAM user, group, role, and policy
-     * names must be unique within the account. Names are not distinguished by case.
-     * For example, you cannot create resources named both "MyResource" and
-     * "myresource".</p>
+     * <p>The name of the user to create.</p> <p>This parameter allows (through its <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a>) a string of characters
+     * consisting of upper and lowercase alphanumeric characters with no spaces. You
+     * can also include any of the following characters: _+=,.@-. User names are not
+     * distinguished by case. For example, you cannot create users named both
+     * "TESTUSER" and "testuser".</p>
      */
     inline void SetUserName(Aws::String&& value) { m_userNameHasBeenSet = true; m_userName = std::move(value); }
 
     /**
-     * <p>The name of the user to create.</p> <p>IAM user, group, role, and policy
-     * names must be unique within the account. Names are not distinguished by case.
-     * For example, you cannot create resources named both "MyResource" and
-     * "myresource".</p>
+     * <p>The name of the user to create.</p> <p>This parameter allows (through its <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a>) a string of characters
+     * consisting of upper and lowercase alphanumeric characters with no spaces. You
+     * can also include any of the following characters: _+=,.@-. User names are not
+     * distinguished by case. For example, you cannot create users named both
+     * "TESTUSER" and "testuser".</p>
      */
     inline void SetUserName(const char* value) { m_userNameHasBeenSet = true; m_userName.assign(value); }
 
     /**
-     * <p>The name of the user to create.</p> <p>IAM user, group, role, and policy
-     * names must be unique within the account. Names are not distinguished by case.
-     * For example, you cannot create resources named both "MyResource" and
-     * "myresource".</p>
+     * <p>The name of the user to create.</p> <p>This parameter allows (through its <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a>) a string of characters
+     * consisting of upper and lowercase alphanumeric characters with no spaces. You
+     * can also include any of the following characters: _+=,.@-. User names are not
+     * distinguished by case. For example, you cannot create users named both
+     * "TESTUSER" and "testuser".</p>
      */
     inline CreateUserRequest& WithUserName(const Aws::String& value) { SetUserName(value); return *this;}
 
     /**
-     * <p>The name of the user to create.</p> <p>IAM user, group, role, and policy
-     * names must be unique within the account. Names are not distinguished by case.
-     * For example, you cannot create resources named both "MyResource" and
-     * "myresource".</p>
+     * <p>The name of the user to create.</p> <p>This parameter allows (through its <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a>) a string of characters
+     * consisting of upper and lowercase alphanumeric characters with no spaces. You
+     * can also include any of the following characters: _+=,.@-. User names are not
+     * distinguished by case. For example, you cannot create users named both
+     * "TESTUSER" and "testuser".</p>
      */
     inline CreateUserRequest& WithUserName(Aws::String&& value) { SetUserName(std::move(value)); return *this;}
 
     /**
-     * <p>The name of the user to create.</p> <p>IAM user, group, role, and policy
-     * names must be unique within the account. Names are not distinguished by case.
-     * For example, you cannot create resources named both "MyResource" and
-     * "myresource".</p>
+     * <p>The name of the user to create.</p> <p>This parameter allows (through its <a
+     * href="http://wikipedia.org/wiki/regex">regex pattern</a>) a string of characters
+     * consisting of upper and lowercase alphanumeric characters with no spaces. You
+     * can also include any of the following characters: _+=,.@-. User names are not
+     * distinguished by case. For example, you cannot create users named both
+     * "TESTUSER" and "testuser".</p>
      */
     inline CreateUserRequest& WithUserName(const char* value) { SetUserName(value); return *this;}
 
@@ -266,98 +292,106 @@ namespace Model
 
 
     /**
-     * <p>A list of tags that you want to attach to the new user. Each tag consists of
-     * a key name and an associated value. For more information about tagging, see <a
+     * <p>A list of tags that you want to attach to the newly created user. Each tag
+     * consists of a key name and an associated value. For more information about
+     * tagging, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html">Tagging IAM
-     * resources</a> in the <i>IAM User Guide</i>.</p>  <p>If any one of the tags
-     * is invalid or if you exceed the allowed maximum number of tags, then the entire
-     * request fails and the resource is not created.</p> 
+     * Identities</a> in the <i>IAM User Guide</i>.</p> <note> <p>If any one of the
+     * tags is invalid or if you exceed the allowed number of tags per user, then the
+     * entire request fails and the user is not created.</p> </note>
      */
     inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
 
     /**
-     * <p>A list of tags that you want to attach to the new user. Each tag consists of
-     * a key name and an associated value. For more information about tagging, see <a
+     * <p>A list of tags that you want to attach to the newly created user. Each tag
+     * consists of a key name and an associated value. For more information about
+     * tagging, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html">Tagging IAM
-     * resources</a> in the <i>IAM User Guide</i>.</p>  <p>If any one of the tags
-     * is invalid or if you exceed the allowed maximum number of tags, then the entire
-     * request fails and the resource is not created.</p> 
+     * Identities</a> in the <i>IAM User Guide</i>.</p> <note> <p>If any one of the
+     * tags is invalid or if you exceed the allowed number of tags per user, then the
+     * entire request fails and the user is not created.</p> </note>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
-     * <p>A list of tags that you want to attach to the new user. Each tag consists of
-     * a key name and an associated value. For more information about tagging, see <a
+     * <p>A list of tags that you want to attach to the newly created user. Each tag
+     * consists of a key name and an associated value. For more information about
+     * tagging, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html">Tagging IAM
-     * resources</a> in the <i>IAM User Guide</i>.</p>  <p>If any one of the tags
-     * is invalid or if you exceed the allowed maximum number of tags, then the entire
-     * request fails and the resource is not created.</p> 
+     * Identities</a> in the <i>IAM User Guide</i>.</p> <note> <p>If any one of the
+     * tags is invalid or if you exceed the allowed number of tags per user, then the
+     * entire request fails and the user is not created.</p> </note>
      */
     inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
-     * <p>A list of tags that you want to attach to the new user. Each tag consists of
-     * a key name and an associated value. For more information about tagging, see <a
+     * <p>A list of tags that you want to attach to the newly created user. Each tag
+     * consists of a key name and an associated value. For more information about
+     * tagging, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html">Tagging IAM
-     * resources</a> in the <i>IAM User Guide</i>.</p>  <p>If any one of the tags
-     * is invalid or if you exceed the allowed maximum number of tags, then the entire
-     * request fails and the resource is not created.</p> 
+     * Identities</a> in the <i>IAM User Guide</i>.</p> <note> <p>If any one of the
+     * tags is invalid or if you exceed the allowed number of tags per user, then the
+     * entire request fails and the user is not created.</p> </note>
      */
     inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
-     * <p>A list of tags that you want to attach to the new user. Each tag consists of
-     * a key name and an associated value. For more information about tagging, see <a
+     * <p>A list of tags that you want to attach to the newly created user. Each tag
+     * consists of a key name and an associated value. For more information about
+     * tagging, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html">Tagging IAM
-     * resources</a> in the <i>IAM User Guide</i>.</p>  <p>If any one of the tags
-     * is invalid or if you exceed the allowed maximum number of tags, then the entire
-     * request fails and the resource is not created.</p> 
+     * Identities</a> in the <i>IAM User Guide</i>.</p> <note> <p>If any one of the
+     * tags is invalid or if you exceed the allowed number of tags per user, then the
+     * entire request fails and the user is not created.</p> </note>
      */
     inline CreateUserRequest& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
 
     /**
-     * <p>A list of tags that you want to attach to the new user. Each tag consists of
-     * a key name and an associated value. For more information about tagging, see <a
+     * <p>A list of tags that you want to attach to the newly created user. Each tag
+     * consists of a key name and an associated value. For more information about
+     * tagging, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html">Tagging IAM
-     * resources</a> in the <i>IAM User Guide</i>.</p>  <p>If any one of the tags
-     * is invalid or if you exceed the allowed maximum number of tags, then the entire
-     * request fails and the resource is not created.</p> 
+     * Identities</a> in the <i>IAM User Guide</i>.</p> <note> <p>If any one of the
+     * tags is invalid or if you exceed the allowed number of tags per user, then the
+     * entire request fails and the user is not created.</p> </note>
      */
     inline CreateUserRequest& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
-     * <p>A list of tags that you want to attach to the new user. Each tag consists of
-     * a key name and an associated value. For more information about tagging, see <a
+     * <p>A list of tags that you want to attach to the newly created user. Each tag
+     * consists of a key name and an associated value. For more information about
+     * tagging, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html">Tagging IAM
-     * resources</a> in the <i>IAM User Guide</i>.</p>  <p>If any one of the tags
-     * is invalid or if you exceed the allowed maximum number of tags, then the entire
-     * request fails and the resource is not created.</p> 
+     * Identities</a> in the <i>IAM User Guide</i>.</p> <note> <p>If any one of the
+     * tags is invalid or if you exceed the allowed number of tags per user, then the
+     * entire request fails and the user is not created.</p> </note>
      */
     inline CreateUserRequest& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
 
     /**
-     * <p>A list of tags that you want to attach to the new user. Each tag consists of
-     * a key name and an associated value. For more information about tagging, see <a
+     * <p>A list of tags that you want to attach to the newly created user. Each tag
+     * consists of a key name and an associated value. For more information about
+     * tagging, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html">Tagging IAM
-     * resources</a> in the <i>IAM User Guide</i>.</p>  <p>If any one of the tags
-     * is invalid or if you exceed the allowed maximum number of tags, then the entire
-     * request fails and the resource is not created.</p> 
+     * Identities</a> in the <i>IAM User Guide</i>.</p> <note> <p>If any one of the
+     * tags is invalid or if you exceed the allowed number of tags per user, then the
+     * entire request fails and the user is not created.</p> </note>
      */
     inline CreateUserRequest& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
   private:
 
     Aws::String m_path;
-    bool m_pathHasBeenSet = false;
+    bool m_pathHasBeenSet;
 
     Aws::String m_userName;
-    bool m_userNameHasBeenSet = false;
+    bool m_userNameHasBeenSet;
 
     Aws::String m_permissionsBoundary;
-    bool m_permissionsBoundaryHasBeenSet = false;
+    bool m_permissionsBoundaryHasBeenSet;
 
     Aws::Vector<Tag> m_tags;
-    bool m_tagsHasBeenSet = false;
+    bool m_tagsHasBeenSet;
   };
 
 } // namespace Model
