@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/iam/IAM_EXPORTS.h>
@@ -10,7 +20,6 @@
 #include <aws/core/utils/DateTime.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/iam/model/AttachedPermissionsBoundary.h>
-#include <aws/iam/model/RoleLastUsed.h>
 #include <aws/iam/model/InstanceProfile.h>
 #include <aws/iam/model/PolicyDetail.h>
 #include <aws/iam/model/AttachedPolicy.h>
@@ -52,56 +61,56 @@ namespace Model
     /**
      * <p>The path to the role. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline const Aws::String& GetPath() const{ return m_path; }
 
     /**
      * <p>The path to the role. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline bool PathHasBeenSet() const { return m_pathHasBeenSet; }
 
     /**
      * <p>The path to the role. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline void SetPath(const Aws::String& value) { m_pathHasBeenSet = true; m_path = value; }
 
     /**
      * <p>The path to the role. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline void SetPath(Aws::String&& value) { m_pathHasBeenSet = true; m_path = std::move(value); }
 
     /**
      * <p>The path to the role. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline void SetPath(const char* value) { m_pathHasBeenSet = true; m_path.assign(value); }
 
     /**
      * <p>The path to the role. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline RoleDetail& WithPath(const Aws::String& value) { SetPath(value); return *this;}
 
     /**
      * <p>The path to the role. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline RoleDetail& WithPath(Aws::String&& value) { SetPath(std::move(value)); return *this;}
 
     /**
      * <p>The path to the role. For more information about paths, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline RoleDetail& WithPath(const char* value) { SetPath(value); return *this;}
 
@@ -151,7 +160,7 @@ namespace Model
      * <p>The stable and unique string identifying the role. For more information about
      * IDs, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline const Aws::String& GetRoleId() const{ return m_roleId; }
 
@@ -159,7 +168,7 @@ namespace Model
      * <p>The stable and unique string identifying the role. For more information about
      * IDs, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline bool RoleIdHasBeenSet() const { return m_roleIdHasBeenSet; }
 
@@ -167,7 +176,7 @@ namespace Model
      * <p>The stable and unique string identifying the role. For more information about
      * IDs, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline void SetRoleId(const Aws::String& value) { m_roleIdHasBeenSet = true; m_roleId = value; }
 
@@ -175,7 +184,7 @@ namespace Model
      * <p>The stable and unique string identifying the role. For more information about
      * IDs, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline void SetRoleId(Aws::String&& value) { m_roleIdHasBeenSet = true; m_roleId = std::move(value); }
 
@@ -183,7 +192,7 @@ namespace Model
      * <p>The stable and unique string identifying the role. For more information about
      * IDs, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline void SetRoleId(const char* value) { m_roleIdHasBeenSet = true; m_roleId.assign(value); }
 
@@ -191,7 +200,7 @@ namespace Model
      * <p>The stable and unique string identifying the role. For more information about
      * IDs, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline RoleDetail& WithRoleId(const Aws::String& value) { SetRoleId(value); return *this;}
 
@@ -199,7 +208,7 @@ namespace Model
      * <p>The stable and unique string identifying the role. For more information about
      * IDs, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline RoleDetail& WithRoleId(Aws::String&& value) { SetRoleId(std::move(value)); return *this;}
 
@@ -207,7 +216,7 @@ namespace Model
      * <p>The stable and unique string identifying the role. For more information about
      * IDs, see <a
      * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html">IAM
-     * Identifiers</a> in the <i>IAM User Guide</i>.</p>
+     * Identifiers</a> in the <i>Using IAM</i> guide.</p>
      */
     inline RoleDetail& WithRoleId(const char* value) { SetRoleId(value); return *this;}
 
@@ -457,7 +466,7 @@ namespace Model
     /**
      * <p>The ARN of the policy used to set the permissions boundary for the role.</p>
      * <p>For more information about permissions boundaries, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
+     * href="IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
      * Boundaries for IAM Identities </a> in the <i>IAM User Guide</i>.</p>
      */
     inline const AttachedPermissionsBoundary& GetPermissionsBoundary() const{ return m_permissionsBoundary; }
@@ -465,7 +474,7 @@ namespace Model
     /**
      * <p>The ARN of the policy used to set the permissions boundary for the role.</p>
      * <p>For more information about permissions boundaries, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
+     * href="IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
      * Boundaries for IAM Identities </a> in the <i>IAM User Guide</i>.</p>
      */
     inline bool PermissionsBoundaryHasBeenSet() const { return m_permissionsBoundaryHasBeenSet; }
@@ -473,7 +482,7 @@ namespace Model
     /**
      * <p>The ARN of the policy used to set the permissions boundary for the role.</p>
      * <p>For more information about permissions boundaries, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
+     * href="IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
      * Boundaries for IAM Identities </a> in the <i>IAM User Guide</i>.</p>
      */
     inline void SetPermissionsBoundary(const AttachedPermissionsBoundary& value) { m_permissionsBoundaryHasBeenSet = true; m_permissionsBoundary = value; }
@@ -481,7 +490,7 @@ namespace Model
     /**
      * <p>The ARN of the policy used to set the permissions boundary for the role.</p>
      * <p>For more information about permissions boundaries, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
+     * href="IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
      * Boundaries for IAM Identities </a> in the <i>IAM User Guide</i>.</p>
      */
     inline void SetPermissionsBoundary(AttachedPermissionsBoundary&& value) { m_permissionsBoundaryHasBeenSet = true; m_permissionsBoundary = std::move(value); }
@@ -489,7 +498,7 @@ namespace Model
     /**
      * <p>The ARN of the policy used to set the permissions boundary for the role.</p>
      * <p>For more information about permissions boundaries, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
+     * href="IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
      * Boundaries for IAM Identities </a> in the <i>IAM User Guide</i>.</p>
      */
     inline RoleDetail& WithPermissionsBoundary(const AttachedPermissionsBoundary& value) { SetPermissionsBoundary(value); return *this;}
@@ -497,7 +506,7 @@ namespace Model
     /**
      * <p>The ARN of the policy used to set the permissions boundary for the role.</p>
      * <p>For more information about permissions boundaries, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
+     * href="IAM/latest/UserGuide/access_policies_boundaries.html">Permissions
      * Boundaries for IAM Identities </a> in the <i>IAM User Guide</i>.</p>
      */
     inline RoleDetail& WithPermissionsBoundary(AttachedPermissionsBoundary&& value) { SetPermissionsBoundary(std::move(value)); return *this;}
@@ -567,73 +576,6 @@ namespace Model
      */
     inline RoleDetail& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
-
-    /**
-     * <p>Contains information about the last time that an IAM role was used. This
-     * includes the date and time and the Region in which the role was last used.
-     * Activity is only reported for the trailing 400 days. This period can be shorter
-     * if your Region began supporting these features within the last year. The role
-     * might have been used more than 400 days ago. For more information, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html#access-advisor_tracking-period">Regions
-     * Where Data Is Tracked</a> in the <i>IAM User Guide</i>.</p>
-     */
-    inline const RoleLastUsed& GetRoleLastUsed() const{ return m_roleLastUsed; }
-
-    /**
-     * <p>Contains information about the last time that an IAM role was used. This
-     * includes the date and time and the Region in which the role was last used.
-     * Activity is only reported for the trailing 400 days. This period can be shorter
-     * if your Region began supporting these features within the last year. The role
-     * might have been used more than 400 days ago. For more information, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html#access-advisor_tracking-period">Regions
-     * Where Data Is Tracked</a> in the <i>IAM User Guide</i>.</p>
-     */
-    inline bool RoleLastUsedHasBeenSet() const { return m_roleLastUsedHasBeenSet; }
-
-    /**
-     * <p>Contains information about the last time that an IAM role was used. This
-     * includes the date and time and the Region in which the role was last used.
-     * Activity is only reported for the trailing 400 days. This period can be shorter
-     * if your Region began supporting these features within the last year. The role
-     * might have been used more than 400 days ago. For more information, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html#access-advisor_tracking-period">Regions
-     * Where Data Is Tracked</a> in the <i>IAM User Guide</i>.</p>
-     */
-    inline void SetRoleLastUsed(const RoleLastUsed& value) { m_roleLastUsedHasBeenSet = true; m_roleLastUsed = value; }
-
-    /**
-     * <p>Contains information about the last time that an IAM role was used. This
-     * includes the date and time and the Region in which the role was last used.
-     * Activity is only reported for the trailing 400 days. This period can be shorter
-     * if your Region began supporting these features within the last year. The role
-     * might have been used more than 400 days ago. For more information, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html#access-advisor_tracking-period">Regions
-     * Where Data Is Tracked</a> in the <i>IAM User Guide</i>.</p>
-     */
-    inline void SetRoleLastUsed(RoleLastUsed&& value) { m_roleLastUsedHasBeenSet = true; m_roleLastUsed = std::move(value); }
-
-    /**
-     * <p>Contains information about the last time that an IAM role was used. This
-     * includes the date and time and the Region in which the role was last used.
-     * Activity is only reported for the trailing 400 days. This period can be shorter
-     * if your Region began supporting these features within the last year. The role
-     * might have been used more than 400 days ago. For more information, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html#access-advisor_tracking-period">Regions
-     * Where Data Is Tracked</a> in the <i>IAM User Guide</i>.</p>
-     */
-    inline RoleDetail& WithRoleLastUsed(const RoleLastUsed& value) { SetRoleLastUsed(value); return *this;}
-
-    /**
-     * <p>Contains information about the last time that an IAM role was used. This
-     * includes the date and time and the Region in which the role was last used.
-     * Activity is only reported for the trailing 400 days. This period can be shorter
-     * if your Region began supporting these features within the last year. The role
-     * might have been used more than 400 days ago. For more information, see <a
-     * href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor.html#access-advisor_tracking-period">Regions
-     * Where Data Is Tracked</a> in the <i>IAM User Guide</i>.</p>
-     */
-    inline RoleDetail& WithRoleLastUsed(RoleLastUsed&& value) { SetRoleLastUsed(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_path;
@@ -668,9 +610,6 @@ namespace Model
 
     Aws::Vector<Tag> m_tags;
     bool m_tagsHasBeenSet;
-
-    RoleLastUsed m_roleLastUsed;
-    bool m_roleLastUsedHasBeenSet;
   };
 
 } // namespace Model
