@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/importexport/ImportExport_EXPORTS.h>
@@ -70,12 +80,12 @@ namespace Model
         class ListJobsRequest;
         class UpdateJobRequest;
 
-        typedef Aws::Utils::Outcome<CancelJobResult, ImportExportError> CancelJobOutcome;
-        typedef Aws::Utils::Outcome<CreateJobResult, ImportExportError> CreateJobOutcome;
-        typedef Aws::Utils::Outcome<GetShippingLabelResult, ImportExportError> GetShippingLabelOutcome;
-        typedef Aws::Utils::Outcome<GetStatusResult, ImportExportError> GetStatusOutcome;
-        typedef Aws::Utils::Outcome<ListJobsResult, ImportExportError> ListJobsOutcome;
-        typedef Aws::Utils::Outcome<UpdateJobResult, ImportExportError> UpdateJobOutcome;
+        typedef Aws::Utils::Outcome<CancelJobResult, Aws::Client::AWSError<ImportExportErrors>> CancelJobOutcome;
+        typedef Aws::Utils::Outcome<CreateJobResult, Aws::Client::AWSError<ImportExportErrors>> CreateJobOutcome;
+        typedef Aws::Utils::Outcome<GetShippingLabelResult, Aws::Client::AWSError<ImportExportErrors>> GetShippingLabelOutcome;
+        typedef Aws::Utils::Outcome<GetStatusResult, Aws::Client::AWSError<ImportExportErrors>> GetStatusOutcome;
+        typedef Aws::Utils::Outcome<ListJobsResult, Aws::Client::AWSError<ImportExportErrors>> ListJobsOutcome;
+        typedef Aws::Utils::Outcome<UpdateJobResult, Aws::Client::AWSError<ImportExportErrors>> UpdateJobOutcome;
 
         typedef std::future<CancelJobOutcome> CancelJobOutcomeCallable;
         typedef std::future<CreateJobOutcome> CreateJobOutcomeCallable;
@@ -128,6 +138,8 @@ namespace Model
 
         virtual ~ImportExportClient();
 
+        inline virtual const char* GetServiceClientName() const override { return "importexport"; }
+
 
        /**
         * Converts any request object to a presigned URL with the GET method, using region for the signer and a timeout of 15 minutes.
@@ -339,10 +351,11 @@ namespace Model
          */
         virtual void UpdateJobAsync(const Model::UpdateJobRequest& request, const UpdateJobResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
 
-
+      
         void OverrideEndpoint(const Aws::String& endpoint);
   private:
         void init(const Aws::Client::ClientConfiguration& clientConfiguration);
+        /**Async helpers**/
         void CancelJobAsyncHelper(const Model::CancelJobRequest& request, const CancelJobResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void CreateJobAsyncHelper(const Model::CreateJobRequest& request, const CreateJobResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
         void GetShippingLabelAsyncHelper(const Model::GetShippingLabelRequest& request, const GetShippingLabelResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const;
