@@ -1,7 +1,17 @@
-/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+/*
+  * Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+  * 
+  * Licensed under the Apache License, Version 2.0 (the "License").
+  * You may not use this file except in compliance with the License.
+  * A copy of the License is located at
+  * 
+  *  http://aws.amazon.com/apache2.0
+  * 
+  * or in the "license" file accompanying this file. This file is distributed
+  * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+  * express or implied. See the License for the specific language governing
+  * permissions and limitations under the License.
+  */
 #include <fstream>
 
 #include <aws/external/gtest.h>
@@ -30,7 +40,6 @@
 #include <aws/lambda/model/GetEventSourceMappingRequest.h>
 #include <aws/lambda/model/UpdateEventSourceMappingRequest.h>
 #include <aws/lambda/model/DeleteEventSourceMappingRequest.h>
-#include <aws/lambda/model/ResourceNotFoundException.h>
 
 #include <aws/kinesis/KinesisClient.h>
 #include <aws/kinesis/model/CreateStreamRequest.h>
@@ -43,7 +52,6 @@
 #include <aws/access-management/AccessManagementClient.h>
 #include <aws/cognito-identity/CognitoIdentityClient.h>
 #include <aws/testing/TestingEnvironment.h>
-#include <aws/core/utils/UUID.h>
 
 using namespace Aws::Auth;
 using namespace Aws::Http;
@@ -56,15 +64,29 @@ using namespace Aws::IAM;
 using namespace Aws::IAM::Model;
 using namespace Aws::CognitoIdentity;
 
+
+#define TEST_FUNCTION_PREFIX  "IntegrationTest_"
+static const char* BASE_KINESIS_STREAM_NAME = "AWSNativeSDKIntegrationTest";
+
+//fill these in before running the test.
+static const char* BASE_SIMPLE_FUNCTION = TEST_FUNCTION_PREFIX "Simple";
+static const char* BASE_HANDLED_ERROR_FUNCTION = TEST_FUNCTION_PREFIX "HandledError";
+
+static const char* SIMPLE_FUNCTION_CODE = RESOURCES_DIR "/succeed.zip";
+static const char* HANDLED_ERROR_FUNCTION_CODE = RESOURCES_DIR "/handled.zip";
+
+static const char* ALLOCATION_TAG = "FunctionTest";
+
+static const char* BASE_IAM_ROLE_NAME = "AWSNativeSDKLambdaIntegrationTestRole";
+
+
 namespace {
 
-static const char BASE_KINESIS_STREAM_NAME[] = "AWSNativeSDKIntegrationTest";
-static const char BASE_SIMPLE_FUNCTION[] = "TestSimple";
-static const char BASE_UNHANDLED_ERROR_FUNCTION[] = "TestUnhandledError";
-static const char SIMPLE_FUNCTION_CODE[] = RESOURCES_DIR "/succeed.zip";
-static const char UNHANDLED_ERROR_FUNCTION_CODE[] = RESOURCES_DIR "/unhandled.zip";
-static const char ALLOCATION_TAG[] = "FunctionTest";
-static const char BASE_IAM_ROLE_NAME[] = "AWSNativeSDKLambdaIntegrationTestRole";
+// role + functions only; policy can be shared since it's permanent and read only
+Aws::String BuildResourceName(const char* baseName)
+{
+    return Aws::Testing::GetAwsResourcePrefix() + baseName;
+}
 
 class FunctionTest : public ::testing::Test {
 
@@ -76,13 +98,8 @@ public:
     static std::shared_ptr<Aws::IAM::IAMClient> m_iamClient;
     static std::shared_ptr<Aws::AccessManagement::AccessManagementClient> m_accessManagementClient;
     static std::map<Aws::String, Aws::String> functionArnMapping;
-    Aws::String m_UUID;
 
 protected:
-    Aws::String BuildResourceName(const char* baseName)
-    {
-        return Aws::Testing::GetAwsResourcePrefix() + baseName + m_UUID;
-    }
 
     static Aws::String MakeFilePath(const Aws::String& localFile)
     {
@@ -93,24 +110,12 @@ protected:
         #endif
     }
 
-    void SetUp()
-    {
-        m_UUID = Aws::Utils::UUID::RandomUUID();
-        CreateFunction(BuildResourceName(BASE_SIMPLE_FUNCTION), SIMPLE_FUNCTION_CODE);
-    }
-
-    void TearDown()
-    {
-        DeleteFunction(BuildResourceName(BASE_SIMPLE_FUNCTION));
-    }
-
     static void SetUpTestCase()
     {
         m_limiter = Aws::MakeShared<Aws::Utils::RateLimits::DefaultRateLimiter<>>(ALLOCATION_TAG, 200000);
 
         // Create a client
         ClientConfiguration config;
-        config.region = Aws::Region::US_EAST_1;
         config.scheme = Scheme::HTTPS;
         config.connectTimeoutMs = 30000;
         config.requestTimeoutMs = 30000;
@@ -124,15 +129,19 @@ protected:
         //Create our IAM Role, so that the Lambda tests have the right policies.
         m_role = Aws::MakeShared<Aws::IAM::Model::Role>(ALLOCATION_TAG);
         ClientConfiguration clientConfig;
-        clientConfig.region = Aws::Region::US_EAST_1;
         m_iamClient = Aws::MakeShared<Aws::IAM::IAMClient>(ALLOCATION_TAG, clientConfig);
         auto cognitoClient = Aws::MakeShared<CognitoIdentityClient>(ALLOCATION_TAG);
         m_accessManagementClient = Aws::MakeShared<Aws::AccessManagement::AccessManagementClient>(ALLOCATION_TAG, m_iamClient, cognitoClient);
         m_accessManagementClient->GetRole(BASE_IAM_ROLE_NAME, *m_role);
+
+        // delete all functions, just in case
+        DeleteAllFunctions();
+        CreateAllFunctions();
     }
 
     static void TearDownTestCase()
     {
+        DeleteAllFunctions();
         // Return the memory claimed for static variables to memory manager before shutting down memory manager.
         // Otherwise there will be double free crash.
         functionArnMapping.clear();
@@ -144,6 +153,18 @@ protected:
         m_accessManagementClient = nullptr;
     }
 
+    static void CreateAllFunctions()
+    {
+        CreateFunction(BuildResourceName(BASE_SIMPLE_FUNCTION), SIMPLE_FUNCTION_CODE);
+        CreateFunction(BuildResourceName(BASE_HANDLED_ERROR_FUNCTION), HANDLED_ERROR_FUNCTION_CODE);
+    }
+
+    static void DeleteAllFunctions()
+    {
+        DeleteFunction(BuildResourceName(BASE_SIMPLE_FUNCTION));
+        DeleteFunction(BuildResourceName(BASE_HANDLED_ERROR_FUNCTION));
+    }
+
     enum class ResourceStatusType
     {
         READY,
@@ -162,8 +183,8 @@ protected:
 
             auto functions = listFunctionsOutcome.GetResult().GetFunctions();
 
-            auto iter = std::find_if(functions.cbegin(),
-                                     functions.cend(),
+            auto iter = std::find_if(functions.cbegin(), 
+                                     functions.cend(), 
                                      [=](const FunctionConfiguration& function){ return function.GetFunctionName() == functionName; });
 
             switch(status)
@@ -183,7 +204,7 @@ protected:
                 break;
             }
 
-            std::this_thread::sleep_for(std::chrono::seconds(1));
+            std::this_thread::sleep_for(std::chrono::seconds(1));	    
         }
     }
 
@@ -191,6 +212,7 @@ protected:
     {
         DeleteFunctionRequest deleteFunctionRequest;
         deleteFunctionRequest.SetFunctionName(functionName);
+
         bool done = false;
         while(!done)
         {
@@ -206,20 +228,22 @@ protected:
                 auto errCode = deleteFunctionOutcome.GetError().GetErrorType();
                 switch (errCode)
                 {
-                    case LambdaErrors::RESOURCE_NOT_FOUND:
-                        //The function was already deleted or not present.
-                        done = true;
-                        break;
-                    case LambdaErrors::TOO_MANY_REQUESTS:
-                        //This is OK; Keep spinning.
-                        break;
-                    default:
-                        //Something bad happened, and we can't commit to this being successful.
-                        FAIL();
-                        break;
+                case LambdaErrors::RESOURCE_NOT_FOUND:
+                    //The function was already deleted or not present.
+                    done = true;
+                    break;
+                case LambdaErrors::TOO_MANY_REQUESTS:
+                    //This is OK; Keep spinning.
+                    break;
+                default:
+                    //Something bad happened, and we can't commit to this being successful.
+                    FAIL();
+                    break;
                 }
             }
         }
+
+        WaitForFunctionStatus(functionName, ResourceStatusType::NOT_FOUND);
     }
 
     static void CreateFunction(Aws::String functionName,Aws::String zipLocation)
@@ -241,14 +265,14 @@ protected:
 
         functionCode.SetZipFile(Aws::Utils::ByteBuffer((unsigned char*)buffer.str().c_str(), buffer.str().length()));
         createFunctionRequest.SetCode(functionCode);
-        createFunctionRequest.SetRuntime(Aws::Lambda::Model::Runtime::nodejs12_x);
+        createFunctionRequest.SetRuntime(Aws::Lambda::Model::Runtime::nodejs8_10);
 
         CreateFunctionOutcome createFunctionOutcome = m_client->CreateFunction(createFunctionRequest);
         ASSERT_TRUE(createFunctionOutcome.IsSuccess());
         ASSERT_EQ(functionName,createFunctionOutcome.GetResult().GetFunctionName());
         ASSERT_EQ("test.handler",createFunctionOutcome.GetResult().GetHandler());
         ASSERT_EQ(roleARN,createFunctionOutcome.GetResult().GetRole());
-        ASSERT_EQ(Aws::Lambda::Model::Runtime::nodejs12_x, createFunctionOutcome.GetResult().GetRuntime());
+        ASSERT_EQ(Aws::Lambda::Model::Runtime::nodejs8_10, createFunctionOutcome.GetResult().GetRuntime());
         functionArnMapping[functionName] = createFunctionOutcome.GetResult().GetFunctionArn();
 
         WaitForFunctionStatus(functionName, ResourceStatusType::READY);
@@ -263,6 +287,7 @@ std::shared_ptr<Aws::IAM::IAMClient> FunctionTest::m_iamClient(nullptr);
 std::shared_ptr< Aws::AccessManagement::AccessManagementClient > FunctionTest::m_accessManagementClient(nullptr);
 std::map<Aws::String, Aws::String> FunctionTest::functionArnMapping;
 
+
 TEST_F(FunctionTest, TestListFunction)
 {
     ListFunctionsRequest listFunctionsRequest;
@@ -291,7 +316,7 @@ TEST_F(FunctionTest, TestGetFunction)
     EXPECT_TRUE(getFunctionOutcome.IsSuccess());
 
     GetFunctionResult getFunctionResult = getFunctionOutcome.GetResult();
-    EXPECT_EQ(Runtime::nodejs12_x, getFunctionResult.GetConfiguration().GetRuntime());
+    EXPECT_EQ(Runtime::nodejs8_10, getFunctionResult.GetConfiguration().GetRuntime());
     EXPECT_EQ("test.handler",getFunctionResult.GetConfiguration().GetHandler());
     EXPECT_EQ(simpleFunctionName,getFunctionResult.GetConfiguration().GetFunctionName());
     //Just see that is looks like an aws url
@@ -305,11 +330,11 @@ TEST_F(FunctionTest, TestGetFunctionConfiguration)
 
     GetFunctionConfigurationRequest getFunctionConfigurationRequest;
     getFunctionConfigurationRequest.SetFunctionName(simpleFunctionName);
-    GetFunctionConfigurationOutcome getFunctionConfigurationOutcome = m_client->GetFunctionConfiguration(getFunctionConfigurationRequest);
+    GetFunctionConfigurationOutcome getFunctionConfigurationOutcome = m_client->GetFunctionConfiguration(getFunctionConfigurationRequest); 
     EXPECT_TRUE(getFunctionConfigurationOutcome.IsSuccess());
 
     GetFunctionConfigurationResult getFunctionConfigurationResult = getFunctionConfigurationOutcome.GetResult();
-    EXPECT_EQ(Runtime::nodejs12_x, getFunctionConfigurationResult.GetRuntime());
+    EXPECT_EQ(Runtime::nodejs8_10, getFunctionConfigurationResult.GetRuntime());
     EXPECT_EQ("test.handler",getFunctionConfigurationResult.GetHandler());
     EXPECT_EQ(simpleFunctionName,getFunctionConfigurationResult.GetFunctionName());
 }
@@ -393,12 +418,10 @@ TEST_F(FunctionTest, TestInvokeSync)
 }
 
 
-TEST_F(FunctionTest, TestInvokeSyncUnhandledFunctionError)
+TEST_F(FunctionTest, TestInvokeSyncHandledFunctionError)
 {
-    CreateFunction(BuildResourceName(BASE_UNHANDLED_ERROR_FUNCTION), UNHANDLED_ERROR_FUNCTION_CODE);
-
     InvokeRequest invokeRequest;
-    invokeRequest.SetFunctionName(BuildResourceName(BASE_UNHANDLED_ERROR_FUNCTION));
+    invokeRequest.SetFunctionName(BuildResourceName(BASE_HANDLED_ERROR_FUNCTION));
     invokeRequest.SetInvocationType(InvocationType::RequestResponse);
     invokeRequest.SetContentType("application/javascript");
     invokeRequest.SetLogType(LogType::Tail);
@@ -415,9 +438,8 @@ TEST_F(FunctionTest, TestInvokeSyncUnhandledFunctionError)
     EXPECT_EQ(200,result.GetStatusCode());
 
     //This is the same as the last test, but we should have a FunctionError
-    EXPECT_EQ("Unhandled", result.GetFunctionError());
+    EXPECT_EQ("Handled", result.GetFunctionError());
 
-    DeleteFunction(BuildResourceName(BASE_UNHANDLED_ERROR_FUNCTION));
 }
 
 TEST_F(FunctionTest, TestPermissions)
@@ -457,14 +479,13 @@ TEST_F(FunctionTest, TestPermissions)
     auto removePermissionOutcome = m_client->RemovePermission(removePermissionRequest);
     EXPECT_TRUE(removePermissionOutcome.IsSuccess());
 
-
+    
     auto getRemovedPolicyOutcome = m_client->GetPolicy(getPolicyRequest);
     //lambda used to return an empty string here, now it doesn't but we aren't entirely sure if this is the expected behavior
     //or a regression. For now just handle both gracefully.
     if (!getRemovedPolicyOutcome.IsSuccess())
     {
        EXPECT_EQ(LambdaErrors::RESOURCE_NOT_FOUND, getRemovedPolicyOutcome.GetError().GetErrorType());
-       EXPECT_STREQ("User", getRemovedPolicyOutcome.GetError<ResourceNotFoundException>().GetType().c_str());
     }
     //Now we should get an empty policy a GetPolicy because we just removed it
     else
@@ -475,7 +496,7 @@ TEST_F(FunctionTest, TestPermissions)
     }
 }
 
-TEST_F(FunctionTest, TestEventSources)
+TEST_F(FunctionTest, TestEventSources) 
 {
     Aws::String simpleFunctionName = BuildResourceName(BASE_SIMPLE_FUNCTION);
 
@@ -497,10 +518,6 @@ TEST_F(FunctionTest, TestEventSources)
         }
         else
         {
-#if ENABLE_CURL_CLIENT
-            ASSERT_FALSE(describeStreamOutcome.GetError().GetRemoteHostIpAddress().empty());
-#endif
-            ASSERT_FALSE(describeStreamOutcome.GetError().GetRequestId().empty());
             auto errCode = describeStreamOutcome.GetError().GetErrorType();
             ASSERT_TRUE(KinesisErrors::LIMIT_EXCEEDED == errCode);
             //If the limit was exceeded, wait and try again.
@@ -531,10 +548,6 @@ TEST_F(FunctionTest, TestEventSources)
     {
         //This means the mapping still exists from a previous failed test. We'll skip the CreatedResult test, but continue with the existing mapping.
         //This should only happen during dev after test failures
-#if ENABLE_CURL_CLIENT
-        ASSERT_FALSE(createOutcome.GetError().GetRemoteHostIpAddress().empty());
-#endif
-        ASSERT_FALSE(createOutcome.GetError().GetRequestId().empty());
         auto message = createOutcome.GetError().GetMessage();
         createdMappingUUID = message.substr(message.length()-36);
     }
