@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/lambda/Lambda_EXPORTS.h>
@@ -13,7 +23,6 @@
 #include <aws/lambda/model/DeadLetterConfig.h>
 #include <aws/lambda/model/TracingConfig.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/lambda/model/FileSystemConfig.h>
 #include <utility>
 
 namespace Aws
@@ -29,7 +38,7 @@ namespace Model
   {
   public:
     UpdateFunctionConfigurationRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -350,7 +359,7 @@ namespace Model
      * security groups and subnets in the VPC. When you connect a function to a VPC, it
      * can only access resources and the internet through that VPC. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html">VPC
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/vpc.html">VPC
      * Settings</a>.</p>
      */
     inline const VpcConfig& GetVpcConfig() const{ return m_vpcConfig; }
@@ -360,7 +369,7 @@ namespace Model
      * security groups and subnets in the VPC. When you connect a function to a VPC, it
      * can only access resources and the internet through that VPC. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html">VPC
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/vpc.html">VPC
      * Settings</a>.</p>
      */
     inline bool VpcConfigHasBeenSet() const { return m_vpcConfigHasBeenSet; }
@@ -370,7 +379,7 @@ namespace Model
      * security groups and subnets in the VPC. When you connect a function to a VPC, it
      * can only access resources and the internet through that VPC. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html">VPC
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/vpc.html">VPC
      * Settings</a>.</p>
      */
     inline void SetVpcConfig(const VpcConfig& value) { m_vpcConfigHasBeenSet = true; m_vpcConfig = value; }
@@ -380,7 +389,7 @@ namespace Model
      * security groups and subnets in the VPC. When you connect a function to a VPC, it
      * can only access resources and the internet through that VPC. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html">VPC
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/vpc.html">VPC
      * Settings</a>.</p>
      */
     inline void SetVpcConfig(VpcConfig&& value) { m_vpcConfigHasBeenSet = true; m_vpcConfig = std::move(value); }
@@ -390,7 +399,7 @@ namespace Model
      * security groups and subnets in the VPC. When you connect a function to a VPC, it
      * can only access resources and the internet through that VPC. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html">VPC
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/vpc.html">VPC
      * Settings</a>.</p>
      */
     inline UpdateFunctionConfigurationRequest& WithVpcConfig(const VpcConfig& value) { SetVpcConfig(value); return *this;}
@@ -400,7 +409,7 @@ namespace Model
      * security groups and subnets in the VPC. When you connect a function to a VPC, it
      * can only access resources and the internet through that VPC. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html">VPC
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/vpc.html">VPC
      * Settings</a>.</p>
      */
     inline UpdateFunctionConfigurationRequest& WithVpcConfig(VpcConfig&& value) { SetVpcConfig(std::move(value)); return *this;}
@@ -484,8 +493,8 @@ namespace Model
      * <p>A dead letter queue configuration that specifies the queue or topic where
      * Lambda sends asynchronous events when they fail processing. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#dlq">Dead
-     * Letter Queues</a>.</p>
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/dlq.html">Dead Letter
+     * Queues</a>.</p>
      */
     inline const DeadLetterConfig& GetDeadLetterConfig() const{ return m_deadLetterConfig; }
 
@@ -493,8 +502,8 @@ namespace Model
      * <p>A dead letter queue configuration that specifies the queue or topic where
      * Lambda sends asynchronous events when they fail processing. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#dlq">Dead
-     * Letter Queues</a>.</p>
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/dlq.html">Dead Letter
+     * Queues</a>.</p>
      */
     inline bool DeadLetterConfigHasBeenSet() const { return m_deadLetterConfigHasBeenSet; }
 
@@ -502,8 +511,8 @@ namespace Model
      * <p>A dead letter queue configuration that specifies the queue or topic where
      * Lambda sends asynchronous events when they fail processing. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#dlq">Dead
-     * Letter Queues</a>.</p>
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/dlq.html">Dead Letter
+     * Queues</a>.</p>
      */
     inline void SetDeadLetterConfig(const DeadLetterConfig& value) { m_deadLetterConfigHasBeenSet = true; m_deadLetterConfig = value; }
 
@@ -511,8 +520,8 @@ namespace Model
      * <p>A dead letter queue configuration that specifies the queue or topic where
      * Lambda sends asynchronous events when they fail processing. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#dlq">Dead
-     * Letter Queues</a>.</p>
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/dlq.html">Dead Letter
+     * Queues</a>.</p>
      */
     inline void SetDeadLetterConfig(DeadLetterConfig&& value) { m_deadLetterConfigHasBeenSet = true; m_deadLetterConfig = std::move(value); }
 
@@ -520,8 +529,8 @@ namespace Model
      * <p>A dead letter queue configuration that specifies the queue or topic where
      * Lambda sends asynchronous events when they fail processing. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#dlq">Dead
-     * Letter Queues</a>.</p>
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/dlq.html">Dead Letter
+     * Queues</a>.</p>
      */
     inline UpdateFunctionConfigurationRequest& WithDeadLetterConfig(const DeadLetterConfig& value) { SetDeadLetterConfig(value); return *this;}
 
@@ -529,8 +538,8 @@ namespace Model
      * <p>A dead letter queue configuration that specifies the queue or topic where
      * Lambda sends asynchronous events when they fail processing. For more
      * information, see <a
-     * href="https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#dlq">Dead
-     * Letter Queues</a>.</p>
+     * href="https://docs.aws.amazon.com/lambda/latest/dg/dlq.html">Dead Letter
+     * Queues</a>.</p>
      */
     inline UpdateFunctionConfigurationRequest& WithDeadLetterConfig(DeadLetterConfig&& value) { SetDeadLetterConfig(std::move(value)); return *this;}
 
@@ -758,47 +767,6 @@ namespace Model
      */
     inline UpdateFunctionConfigurationRequest& AddLayers(const char* value) { m_layersHasBeenSet = true; m_layers.push_back(value); return *this; }
 
-
-    /**
-     * <p>Connection settings for an Amazon EFS file system.</p>
-     */
-    inline const Aws::Vector<FileSystemConfig>& GetFileSystemConfigs() const{ return m_fileSystemConfigs; }
-
-    /**
-     * <p>Connection settings for an Amazon EFS file system.</p>
-     */
-    inline bool FileSystemConfigsHasBeenSet() const { return m_fileSystemConfigsHasBeenSet; }
-
-    /**
-     * <p>Connection settings for an Amazon EFS file system.</p>
-     */
-    inline void SetFileSystemConfigs(const Aws::Vector<FileSystemConfig>& value) { m_fileSystemConfigsHasBeenSet = true; m_fileSystemConfigs = value; }
-
-    /**
-     * <p>Connection settings for an Amazon EFS file system.</p>
-     */
-    inline void SetFileSystemConfigs(Aws::Vector<FileSystemConfig>&& value) { m_fileSystemConfigsHasBeenSet = true; m_fileSystemConfigs = std::move(value); }
-
-    /**
-     * <p>Connection settings for an Amazon EFS file system.</p>
-     */
-    inline UpdateFunctionConfigurationRequest& WithFileSystemConfigs(const Aws::Vector<FileSystemConfig>& value) { SetFileSystemConfigs(value); return *this;}
-
-    /**
-     * <p>Connection settings for an Amazon EFS file system.</p>
-     */
-    inline UpdateFunctionConfigurationRequest& WithFileSystemConfigs(Aws::Vector<FileSystemConfig>&& value) { SetFileSystemConfigs(std::move(value)); return *this;}
-
-    /**
-     * <p>Connection settings for an Amazon EFS file system.</p>
-     */
-    inline UpdateFunctionConfigurationRequest& AddFileSystemConfigs(const FileSystemConfig& value) { m_fileSystemConfigsHasBeenSet = true; m_fileSystemConfigs.push_back(value); return *this; }
-
-    /**
-     * <p>Connection settings for an Amazon EFS file system.</p>
-     */
-    inline UpdateFunctionConfigurationRequest& AddFileSystemConfigs(FileSystemConfig&& value) { m_fileSystemConfigsHasBeenSet = true; m_fileSystemConfigs.push_back(std::move(value)); return *this; }
-
   private:
 
     Aws::String m_functionName;
@@ -842,9 +810,6 @@ namespace Model
 
     Aws::Vector<Aws::String> m_layers;
     bool m_layersHasBeenSet;
-
-    Aws::Vector<FileSystemConfig> m_fileSystemConfigs;
-    bool m_fileSystemConfigsHasBeenSet;
   };
 
 } // namespace Model
