@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/lex-models/LexModelBuildingService_EXPORTS.h>
@@ -13,7 +23,6 @@
 #include <aws/lex-models/model/FollowUpPrompt.h>
 #include <aws/lex-models/model/CodeHook.h>
 #include <aws/lex-models/model/FulfillmentActivity.h>
-#include <aws/lex-models/model/KendraConfiguration.h>
 #include <aws/lex-models/model/Slot.h>
 #include <utility>
 
@@ -30,7 +39,7 @@ namespace Model
   {
   public:
     PutIntentRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -298,9 +307,9 @@ namespace Model
      * <code>OrderPizza</code> intent, you might want to confirm that the order is
      * correct before placing it. For other intents, such as intents that simply
      * respond to user questions, you might not need to ask the user for confirmation
-     * before providing the information. </p>  <p>You you must provide both the
+     * before providing the information. </p> <note> <p>You you must provide both the
      * <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline const Prompt& GetConfirmationPrompt() const{ return m_confirmationPrompt; }
 
@@ -311,9 +320,9 @@ namespace Model
      * <code>OrderPizza</code> intent, you might want to confirm that the order is
      * correct before placing it. For other intents, such as intents that simply
      * respond to user questions, you might not need to ask the user for confirmation
-     * before providing the information. </p>  <p>You you must provide both the
+     * before providing the information. </p> <note> <p>You you must provide both the
      * <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline bool ConfirmationPromptHasBeenSet() const { return m_confirmationPromptHasBeenSet; }
 
@@ -324,9 +333,9 @@ namespace Model
      * <code>OrderPizza</code> intent, you might want to confirm that the order is
      * correct before placing it. For other intents, such as intents that simply
      * respond to user questions, you might not need to ask the user for confirmation
-     * before providing the information. </p>  <p>You you must provide both the
+     * before providing the information. </p> <note> <p>You you must provide both the
      * <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline void SetConfirmationPrompt(const Prompt& value) { m_confirmationPromptHasBeenSet = true; m_confirmationPrompt = value; }
 
@@ -337,9 +346,9 @@ namespace Model
      * <code>OrderPizza</code> intent, you might want to confirm that the order is
      * correct before placing it. For other intents, such as intents that simply
      * respond to user questions, you might not need to ask the user for confirmation
-     * before providing the information. </p>  <p>You you must provide both the
+     * before providing the information. </p> <note> <p>You you must provide both the
      * <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline void SetConfirmationPrompt(Prompt&& value) { m_confirmationPromptHasBeenSet = true; m_confirmationPrompt = std::move(value); }
 
@@ -350,9 +359,9 @@ namespace Model
      * <code>OrderPizza</code> intent, you might want to confirm that the order is
      * correct before placing it. For other intents, such as intents that simply
      * respond to user questions, you might not need to ask the user for confirmation
-     * before providing the information. </p>  <p>You you must provide both the
+     * before providing the information. </p> <note> <p>You you must provide both the
      * <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline PutIntentRequest& WithConfirmationPrompt(const Prompt& value) { SetConfirmationPrompt(value); return *this;}
 
@@ -363,9 +372,9 @@ namespace Model
      * <code>OrderPizza</code> intent, you might want to confirm that the order is
      * correct before placing it. For other intents, such as intents that simply
      * respond to user questions, you might not need to ask the user for confirmation
-     * before providing the information. </p>  <p>You you must provide both the
+     * before providing the information. </p> <note> <p>You you must provide both the
      * <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline PutIntentRequest& WithConfirmationPrompt(Prompt&& value) { SetConfirmationPrompt(std::move(value)); return *this;}
 
@@ -373,54 +382,54 @@ namespace Model
     /**
      * <p>When the user answers "no" to the question defined in
      * <code>confirmationPrompt</code>, Amazon Lex responds with this statement to
-     * acknowledge that the intent was canceled. </p>  <p>You must provide both
+     * acknowledge that the intent was canceled. </p> <note> <p>You must provide both
      * the <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline const Statement& GetRejectionStatement() const{ return m_rejectionStatement; }
 
     /**
      * <p>When the user answers "no" to the question defined in
      * <code>confirmationPrompt</code>, Amazon Lex responds with this statement to
-     * acknowledge that the intent was canceled. </p>  <p>You must provide both
+     * acknowledge that the intent was canceled. </p> <note> <p>You must provide both
      * the <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline bool RejectionStatementHasBeenSet() const { return m_rejectionStatementHasBeenSet; }
 
     /**
      * <p>When the user answers "no" to the question defined in
      * <code>confirmationPrompt</code>, Amazon Lex responds with this statement to
-     * acknowledge that the intent was canceled. </p>  <p>You must provide both
+     * acknowledge that the intent was canceled. </p> <note> <p>You must provide both
      * the <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline void SetRejectionStatement(const Statement& value) { m_rejectionStatementHasBeenSet = true; m_rejectionStatement = value; }
 
     /**
      * <p>When the user answers "no" to the question defined in
      * <code>confirmationPrompt</code>, Amazon Lex responds with this statement to
-     * acknowledge that the intent was canceled. </p>  <p>You must provide both
+     * acknowledge that the intent was canceled. </p> <note> <p>You must provide both
      * the <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline void SetRejectionStatement(Statement&& value) { m_rejectionStatementHasBeenSet = true; m_rejectionStatement = std::move(value); }
 
     /**
      * <p>When the user answers "no" to the question defined in
      * <code>confirmationPrompt</code>, Amazon Lex responds with this statement to
-     * acknowledge that the intent was canceled. </p>  <p>You must provide both
+     * acknowledge that the intent was canceled. </p> <note> <p>You must provide both
      * the <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline PutIntentRequest& WithRejectionStatement(const Statement& value) { SetRejectionStatement(value); return *this;}
 
     /**
      * <p>When the user answers "no" to the question defined in
      * <code>confirmationPrompt</code>, Amazon Lex responds with this statement to
-     * acknowledge that the intent was canceled. </p>  <p>You must provide both
+     * acknowledge that the intent was canceled. </p> <note> <p>You must provide both
      * the <code>rejectionStatement</code> and the <code>confirmationPrompt</code>, or
-     * neither.</p> 
+     * neither.</p> </note>
      */
     inline PutIntentRequest& WithRejectionStatement(Statement&& value) { SetRejectionStatement(std::move(value)); return *this;}
 
@@ -527,9 +536,9 @@ namespace Model
      * intent is successfully fulfilled by the Lambda function. </p> <p>This element is
      * relevant only if you provide a Lambda function in the
      * <code>fulfillmentActivity</code>. If you return the intent to the client
-     * application, you can't specify this element.</p>  <p>The
+     * application, you can't specify this element.</p> <note> <p>The
      * <code>followUpPrompt</code> and <code>conclusionStatement</code> are mutually
-     * exclusive. You can specify only one.</p> 
+     * exclusive. You can specify only one.</p> </note>
      */
     inline const Statement& GetConclusionStatement() const{ return m_conclusionStatement; }
 
@@ -538,9 +547,9 @@ namespace Model
      * intent is successfully fulfilled by the Lambda function. </p> <p>This element is
      * relevant only if you provide a Lambda function in the
      * <code>fulfillmentActivity</code>. If you return the intent to the client
-     * application, you can't specify this element.</p>  <p>The
+     * application, you can't specify this element.</p> <note> <p>The
      * <code>followUpPrompt</code> and <code>conclusionStatement</code> are mutually
-     * exclusive. You can specify only one.</p> 
+     * exclusive. You can specify only one.</p> </note>
      */
     inline bool ConclusionStatementHasBeenSet() const { return m_conclusionStatementHasBeenSet; }
 
@@ -549,9 +558,9 @@ namespace Model
      * intent is successfully fulfilled by the Lambda function. </p> <p>This element is
      * relevant only if you provide a Lambda function in the
      * <code>fulfillmentActivity</code>. If you return the intent to the client
-     * application, you can't specify this element.</p>  <p>The
+     * application, you can't specify this element.</p> <note> <p>The
      * <code>followUpPrompt</code> and <code>conclusionStatement</code> are mutually
-     * exclusive. You can specify only one.</p> 
+     * exclusive. You can specify only one.</p> </note>
      */
     inline void SetConclusionStatement(const Statement& value) { m_conclusionStatementHasBeenSet = true; m_conclusionStatement = value; }
 
@@ -560,9 +569,9 @@ namespace Model
      * intent is successfully fulfilled by the Lambda function. </p> <p>This element is
      * relevant only if you provide a Lambda function in the
      * <code>fulfillmentActivity</code>. If you return the intent to the client
-     * application, you can't specify this element.</p>  <p>The
+     * application, you can't specify this element.</p> <note> <p>The
      * <code>followUpPrompt</code> and <code>conclusionStatement</code> are mutually
-     * exclusive. You can specify only one.</p> 
+     * exclusive. You can specify only one.</p> </note>
      */
     inline void SetConclusionStatement(Statement&& value) { m_conclusionStatementHasBeenSet = true; m_conclusionStatement = std::move(value); }
 
@@ -571,9 +580,9 @@ namespace Model
      * intent is successfully fulfilled by the Lambda function. </p> <p>This element is
      * relevant only if you provide a Lambda function in the
      * <code>fulfillmentActivity</code>. If you return the intent to the client
-     * application, you can't specify this element.</p>  <p>The
+     * application, you can't specify this element.</p> <note> <p>The
      * <code>followUpPrompt</code> and <code>conclusionStatement</code> are mutually
-     * exclusive. You can specify only one.</p> 
+     * exclusive. You can specify only one.</p> </note>
      */
     inline PutIntentRequest& WithConclusionStatement(const Statement& value) { SetConclusionStatement(value); return *this;}
 
@@ -582,9 +591,9 @@ namespace Model
      * intent is successfully fulfilled by the Lambda function. </p> <p>This element is
      * relevant only if you provide a Lambda function in the
      * <code>fulfillmentActivity</code>. If you return the intent to the client
-     * application, you can't specify this element.</p>  <p>The
+     * application, you can't specify this element.</p> <note> <p>The
      * <code>followUpPrompt</code> and <code>conclusionStatement</code> are mutually
-     * exclusive. You can specify only one.</p> 
+     * exclusive. You can specify only one.</p> </note>
      */
     inline PutIntentRequest& WithConclusionStatement(Statement&& value) { SetConclusionStatement(std::move(value)); return *this;}
 
@@ -885,93 +894,18 @@ namespace Model
     inline PutIntentRequest& WithChecksum(const char* value) { SetChecksum(value); return *this;}
 
 
-    /**
-     * <p>When set to <code>true</code> a new numbered version of the intent is
-     * created. This is the same as calling the <code>CreateIntentVersion</code>
-     * operation. If you do not specify <code>createVersion</code>, the default is
-     * <code>false</code>.</p>
-     */
+    
     inline bool GetCreateVersion() const{ return m_createVersion; }
 
-    /**
-     * <p>When set to <code>true</code> a new numbered version of the intent is
-     * created. This is the same as calling the <code>CreateIntentVersion</code>
-     * operation. If you do not specify <code>createVersion</code>, the default is
-     * <code>false</code>.</p>
-     */
+    
     inline bool CreateVersionHasBeenSet() const { return m_createVersionHasBeenSet; }
 
-    /**
-     * <p>When set to <code>true</code> a new numbered version of the intent is
-     * created. This is the same as calling the <code>CreateIntentVersion</code>
-     * operation. If you do not specify <code>createVersion</code>, the default is
-     * <code>false</code>.</p>
-     */
+    
     inline void SetCreateVersion(bool value) { m_createVersionHasBeenSet = true; m_createVersion = value; }
 
-    /**
-     * <p>When set to <code>true</code> a new numbered version of the intent is
-     * created. This is the same as calling the <code>CreateIntentVersion</code>
-     * operation. If you do not specify <code>createVersion</code>, the default is
-     * <code>false</code>.</p>
-     */
+    
     inline PutIntentRequest& WithCreateVersion(bool value) { SetCreateVersion(value); return *this;}
 
-
-    /**
-     * <p>Configuration information required to use the
-     * <code>AMAZON.KendraSearchIntent</code> intent to connect to an Amazon Kendra
-     * index. For more information, see <a
-     * href="http://docs.aws.amazon.com/lex/latest/dg/built-in-intent-kendra-search.html">
-     * AMAZON.KendraSearchIntent</a>.</p>
-     */
-    inline const KendraConfiguration& GetKendraConfiguration() const{ return m_kendraConfiguration; }
-
-    /**
-     * <p>Configuration information required to use the
-     * <code>AMAZON.KendraSearchIntent</code> intent to connect to an Amazon Kendra
-     * index. For more information, see <a
-     * href="http://docs.aws.amazon.com/lex/latest/dg/built-in-intent-kendra-search.html">
-     * AMAZON.KendraSearchIntent</a>.</p>
-     */
-    inline bool KendraConfigurationHasBeenSet() const { return m_kendraConfigurationHasBeenSet; }
-
-    /**
-     * <p>Configuration information required to use the
-     * <code>AMAZON.KendraSearchIntent</code> intent to connect to an Amazon Kendra
-     * index. For more information, see <a
-     * href="http://docs.aws.amazon.com/lex/latest/dg/built-in-intent-kendra-search.html">
-     * AMAZON.KendraSearchIntent</a>.</p>
-     */
-    inline void SetKendraConfiguration(const KendraConfiguration& value) { m_kendraConfigurationHasBeenSet = true; m_kendraConfiguration = value; }
-
-    /**
-     * <p>Configuration information required to use the
-     * <code>AMAZON.KendraSearchIntent</code> intent to connect to an Amazon Kendra
-     * index. For more information, see <a
-     * href="http://docs.aws.amazon.com/lex/latest/dg/built-in-intent-kendra-search.html">
-     * AMAZON.KendraSearchIntent</a>.</p>
-     */
-    inline void SetKendraConfiguration(KendraConfiguration&& value) { m_kendraConfigurationHasBeenSet = true; m_kendraConfiguration = std::move(value); }
-
-    /**
-     * <p>Configuration information required to use the
-     * <code>AMAZON.KendraSearchIntent</code> intent to connect to an Amazon Kendra
-     * index. For more information, see <a
-     * href="http://docs.aws.amazon.com/lex/latest/dg/built-in-intent-kendra-search.html">
-     * AMAZON.KendraSearchIntent</a>.</p>
-     */
-    inline PutIntentRequest& WithKendraConfiguration(const KendraConfiguration& value) { SetKendraConfiguration(value); return *this;}
-
-    /**
-     * <p>Configuration information required to use the
-     * <code>AMAZON.KendraSearchIntent</code> intent to connect to an Amazon Kendra
-     * index. For more information, see <a
-     * href="http://docs.aws.amazon.com/lex/latest/dg/built-in-intent-kendra-search.html">
-     * AMAZON.KendraSearchIntent</a>.</p>
-     */
-    inline PutIntentRequest& WithKendraConfiguration(KendraConfiguration&& value) { SetKendraConfiguration(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_name;
@@ -1012,9 +946,6 @@ namespace Model
 
     bool m_createVersion;
     bool m_createVersionHasBeenSet;
-
-    KendraConfiguration m_kendraConfiguration;
-    bool m_kendraConfigurationHasBeenSet;
   };
 
 } // namespace Model
