@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/logs/CloudWatchLogs_EXPORTS.h>
@@ -23,7 +33,7 @@ namespace Model
   {
   public:
     DescribeQueriesRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -167,16 +177,16 @@ namespace Model
   private:
 
     Aws::String m_logGroupName;
-    bool m_logGroupNameHasBeenSet = false;
+    bool m_logGroupNameHasBeenSet;
 
     QueryStatus m_status;
-    bool m_statusHasBeenSet = false;
+    bool m_statusHasBeenSet;
 
     int m_maxResults;
-    bool m_maxResultsHasBeenSet = false;
+    bool m_maxResultsHasBeenSet;
 
     Aws::String m_nextToken;
-    bool m_nextTokenHasBeenSet = false;
+    bool m_nextTokenHasBeenSet;
   };
 
 } // namespace Model
