@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/logs/CloudWatchLogs_EXPORTS.h>
@@ -23,7 +33,7 @@ namespace Model
   {
   public:
     FilterLogEventsRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -414,31 +424,71 @@ namespace Model
      */
     inline FilterLogEventsRequest& WithLimit(int value) { SetLimit(value); return *this;}
 
+
+    /**
+     * <p>If the value is true, the operation makes a best effort to provide responses
+     * that contain events from multiple log streams within the log group, interleaved
+     * in a single response. If the value is false, all the matched log events in the
+     * first log stream are searched first, then those in the next log stream, and so
+     * on. The default is false.</p>
+     */
+    inline bool GetInterleaved() const{ return m_interleaved; }
+
+    /**
+     * <p>If the value is true, the operation makes a best effort to provide responses
+     * that contain events from multiple log streams within the log group, interleaved
+     * in a single response. If the value is false, all the matched log events in the
+     * first log stream are searched first, then those in the next log stream, and so
+     * on. The default is false.</p>
+     */
+    inline bool InterleavedHasBeenSet() const { return m_interleavedHasBeenSet; }
+
+    /**
+     * <p>If the value is true, the operation makes a best effort to provide responses
+     * that contain events from multiple log streams within the log group, interleaved
+     * in a single response. If the value is false, all the matched log events in the
+     * first log stream are searched first, then those in the next log stream, and so
+     * on. The default is false.</p>
+     */
+    inline void SetInterleaved(bool value) { m_interleavedHasBeenSet = true; m_interleaved = value; }
+
+    /**
+     * <p>If the value is true, the operation makes a best effort to provide responses
+     * that contain events from multiple log streams within the log group, interleaved
+     * in a single response. If the value is false, all the matched log events in the
+     * first log stream are searched first, then those in the next log stream, and so
+     * on. The default is false.</p>
+     */
+    inline FilterLogEventsRequest& WithInterleaved(bool value) { SetInterleaved(value); return *this;}
+
   private:
 
     Aws::String m_logGroupName;
-    bool m_logGroupNameHasBeenSet = false;
+    bool m_logGroupNameHasBeenSet;
 
     Aws::Vector<Aws::String> m_logStreamNames;
-    bool m_logStreamNamesHasBeenSet = false;
+    bool m_logStreamNamesHasBeenSet;
 
     Aws::String m_logStreamNamePrefix;
-    bool m_logStreamNamePrefixHasBeenSet = false;
+    bool m_logStreamNamePrefixHasBeenSet;
 
     long long m_startTime;
-    bool m_startTimeHasBeenSet = false;
+    bool m_startTimeHasBeenSet;
 
     long long m_endTime;
-    bool m_endTimeHasBeenSet = false;
+    bool m_endTimeHasBeenSet;
 
     Aws::String m_filterPattern;
-    bool m_filterPatternHasBeenSet = false;
+    bool m_filterPatternHasBeenSet;
 
     Aws::String m_nextToken;
-    bool m_nextTokenHasBeenSet = false;
+    bool m_nextTokenHasBeenSet;
 
     int m_limit;
-    bool m_limitHasBeenSet = false;
+    bool m_limitHasBeenSet;
+
+    bool m_interleaved;
+    bool m_interleavedHasBeenSet;
   };
 
 } // namespace Model
