@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediaconnect/MediaConnect_EXPORTS.h>
@@ -27,7 +37,7 @@ namespace Model
   {
   public:
     UpdateFlowSourceRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -237,47 +247,43 @@ namespace Model
 
 
     /**
-     * The smoothing max bitrate for RIST, RTP, and RTP-FEC streams.
+     * The smoothing max bitrate for RTP and RTP-FEC streams.
      */
     inline int GetMaxBitrate() const{ return m_maxBitrate; }
 
     /**
-     * The smoothing max bitrate for RIST, RTP, and RTP-FEC streams.
+     * The smoothing max bitrate for RTP and RTP-FEC streams.
      */
     inline bool MaxBitrateHasBeenSet() const { return m_maxBitrateHasBeenSet; }
 
     /**
-     * The smoothing max bitrate for RIST, RTP, and RTP-FEC streams.
+     * The smoothing max bitrate for RTP and RTP-FEC streams.
      */
     inline void SetMaxBitrate(int value) { m_maxBitrateHasBeenSet = true; m_maxBitrate = value; }
 
     /**
-     * The smoothing max bitrate for RIST, RTP, and RTP-FEC streams.
+     * The smoothing max bitrate for RTP and RTP-FEC streams.
      */
     inline UpdateFlowSourceRequest& WithMaxBitrate(int value) { SetMaxBitrate(value); return *this;}
 
 
     /**
-     * The maximum latency in milliseconds. This parameter applies only to RIST-based
-     * and Zixi-based streams.
+     * The maximum latency in milliseconds for Zixi-based streams.
      */
     inline int GetMaxLatency() const{ return m_maxLatency; }
 
     /**
-     * The maximum latency in milliseconds. This parameter applies only to RIST-based
-     * and Zixi-based streams.
+     * The maximum latency in milliseconds for Zixi-based streams.
      */
     inline bool MaxLatencyHasBeenSet() const { return m_maxLatencyHasBeenSet; }
 
     /**
-     * The maximum latency in milliseconds. This parameter applies only to RIST-based
-     * and Zixi-based streams.
+     * The maximum latency in milliseconds for Zixi-based streams.
      */
     inline void SetMaxLatency(int value) { m_maxLatencyHasBeenSet = true; m_maxLatency = value; }
 
     /**
-     * The maximum latency in milliseconds. This parameter applies only to RIST-based
-     * and Zixi-based streams.
+     * The maximum latency in milliseconds for Zixi-based streams.
      */
     inline UpdateFlowSourceRequest& WithMaxLatency(int value) { SetMaxLatency(value); return *this;}
 
@@ -403,99 +409,58 @@ namespace Model
     inline UpdateFlowSourceRequest& WithStreamId(const char* value) { SetStreamId(value); return *this;}
 
 
-    /**
-     * The name of the VPC Interface to configure this Source with.
-     */
-    inline const Aws::String& GetVpcInterfaceName() const{ return m_vpcInterfaceName; }
-
-    /**
-     * The name of the VPC Interface to configure this Source with.
-     */
-    inline bool VpcInterfaceNameHasBeenSet() const { return m_vpcInterfaceNameHasBeenSet; }
-
-    /**
-     * The name of the VPC Interface to configure this Source with.
-     */
-    inline void SetVpcInterfaceName(const Aws::String& value) { m_vpcInterfaceNameHasBeenSet = true; m_vpcInterfaceName = value; }
-
-    /**
-     * The name of the VPC Interface to configure this Source with.
-     */
-    inline void SetVpcInterfaceName(Aws::String&& value) { m_vpcInterfaceNameHasBeenSet = true; m_vpcInterfaceName = std::move(value); }
-
-    /**
-     * The name of the VPC Interface to configure this Source with.
-     */
-    inline void SetVpcInterfaceName(const char* value) { m_vpcInterfaceNameHasBeenSet = true; m_vpcInterfaceName.assign(value); }
-
-    /**
-     * The name of the VPC Interface to configure this Source with.
-     */
-    inline UpdateFlowSourceRequest& WithVpcInterfaceName(const Aws::String& value) { SetVpcInterfaceName(value); return *this;}
-
-    /**
-     * The name of the VPC Interface to configure this Source with.
-     */
-    inline UpdateFlowSourceRequest& WithVpcInterfaceName(Aws::String&& value) { SetVpcInterfaceName(std::move(value)); return *this;}
-
-    /**
-     * The name of the VPC Interface to configure this Source with.
-     */
-    inline UpdateFlowSourceRequest& WithVpcInterfaceName(const char* value) { SetVpcInterfaceName(value); return *this;}
-
-
     /**
      * The range of IP addresses that should be allowed to contribute content to your
-     * source. These IP addresses should be in the form of a Classless Inter-Domain
+     * source. These IP addresses should in the form of a Classless Inter-Domain
      * Routing (CIDR) block; for example, 10.0.0.0/16.
      */
     inline const Aws::String& GetWhitelistCidr() const{ return m_whitelistCidr; }
 
     /**
      * The range of IP addresses that should be allowed to contribute content to your
-     * source. These IP addresses should be in the form of a Classless Inter-Domain
+     * source. These IP addresses should in the form of a Classless Inter-Domain
      * Routing (CIDR) block; for example, 10.0.0.0/16.
      */
     inline bool WhitelistCidrHasBeenSet() const { return m_whitelistCidrHasBeenSet; }
 
     /**
      * The range of IP addresses that should be allowed to contribute content to your
-     * source. These IP addresses should be in the form of a Classless Inter-Domain
+     * source. These IP addresses should in the form of a Classless Inter-Domain
      * Routing (CIDR) block; for example, 10.0.0.0/16.
      */
     inline void SetWhitelistCidr(const Aws::String& value) { m_whitelistCidrHasBeenSet = true; m_whitelistCidr = value; }
 
     /**
      * The range of IP addresses that should be allowed to contribute content to your
-     * source. These IP addresses should be in the form of a Classless Inter-Domain
+     * source. These IP addresses should in the form of a Classless Inter-Domain
      * Routing (CIDR) block; for example, 10.0.0.0/16.
      */
     inline void SetWhitelistCidr(Aws::String&& value) { m_whitelistCidrHasBeenSet = true; m_whitelistCidr = std::move(value); }
 
     /**
      * The range of IP addresses that should be allowed to contribute content to your
-     * source. These IP addresses should be in the form of a Classless Inter-Domain
+     * source. These IP addresses should in the form of a Classless Inter-Domain
      * Routing (CIDR) block; for example, 10.0.0.0/16.
      */
     inline void SetWhitelistCidr(const char* value) { m_whitelistCidrHasBeenSet = true; m_whitelistCidr.assign(value); }
 
     /**
      * The range of IP addresses that should be allowed to contribute content to your
-     * source. These IP addresses should be in the form of a Classless Inter-Domain
+     * source. These IP addresses should in the form of a Classless Inter-Domain
      * Routing (CIDR) block; for example, 10.0.0.0/16.
      */
     inline UpdateFlowSourceRequest& WithWhitelistCidr(const Aws::String& value) { SetWhitelistCidr(value); return *this;}
 
     /**
      * The range of IP addresses that should be allowed to contribute content to your
-     * source. These IP addresses should be in the form of a Classless Inter-Domain
+     * source. These IP addresses should in the form of a Classless Inter-Domain
      * Routing (CIDR) block; for example, 10.0.0.0/16.
      */
     inline UpdateFlowSourceRequest& WithWhitelistCidr(Aws::String&& value) { SetWhitelistCidr(std::move(value)); return *this;}
 
     /**
      * The range of IP addresses that should be allowed to contribute content to your
-     * source. These IP addresses should be in the form of a Classless Inter-Domain
+     * source. These IP addresses should in the form of a Classless Inter-Domain
      * Routing (CIDR) block; for example, 10.0.0.0/16.
      */
     inline UpdateFlowSourceRequest& WithWhitelistCidr(const char* value) { SetWhitelistCidr(value); return *this;}
@@ -532,9 +497,6 @@ namespace Model
     Aws::String m_streamId;
     bool m_streamIdHasBeenSet;
 
-    Aws::String m_vpcInterfaceName;
-    bool m_vpcInterfaceNameHasBeenSet;
-
     Aws::String m_whitelistCidr;
     bool m_whitelistCidrHasBeenSet;
   };
