@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediaconvert/MediaConvert_EXPORTS.h>
@@ -9,12 +19,8 @@
 #include <aws/mediaconvert/model/Ac3Settings.h>
 #include <aws/mediaconvert/model/AiffSettings.h>
 #include <aws/mediaconvert/model/AudioCodec.h>
-#include <aws/mediaconvert/model/Eac3AtmosSettings.h>
 #include <aws/mediaconvert/model/Eac3Settings.h>
 #include <aws/mediaconvert/model/Mp2Settings.h>
-#include <aws/mediaconvert/model/Mp3Settings.h>
-#include <aws/mediaconvert/model/OpusSettings.h>
-#include <aws/mediaconvert/model/VorbisSettings.h>
 #include <aws/mediaconvert/model/WavSettings.h>
 #include <utility>
 
@@ -36,12 +42,11 @@ namespace Model
   /**
    * Audio codec settings (CodecSettings) under (AudioDescriptions) contains the
    * group of settings related to audio encoding. The settings in this group vary
-   * depending on the value that you choose for Audio codec (Codec). For each codec
-   * enum that you choose, define the corresponding settings object. The following
-   * lists the codec enum, settings object pairs. * AAC, AacSettings * MP2,
-   * Mp2Settings * MP3, Mp3Settings * WAV, WavSettings * AIFF, AiffSettings * AC3,
-   * Ac3Settings * EAC3, Eac3Settings * EAC3_ATMOS, Eac3AtmosSettings * VORBIS,
-   * VorbisSettings * OPUS, OpusSettings<p><h3>See Also:</h3>   <a
+   * depending on the value you choose for Audio codec (Codec). For each codec enum
+   * you choose, define the corresponding settings object. The following lists the
+   * codec enum, settings object pairs. * AAC, AacSettings * MP2, Mp2Settings * WAV,
+   * WavSettings * AIFF, AiffSettings * AC3, Ac3Settings * EAC3,
+   * Eac3Settings<p><h3>See Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/mediaconvert-2017-08-29/AudioCodecSettings">AWS
    * API Reference</a></p>
    */
@@ -226,43 +231,6 @@ namespace Model
     inline AudioCodecSettings& WithCodec(AudioCodec&& value) { SetCodec(std::move(value)); return *this;}
 
 
-    /**
-     * Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the
-     * value EAC3_ATMOS.
-     */
-    inline const Eac3AtmosSettings& GetEac3AtmosSettings() const{ return m_eac3AtmosSettings; }
-
-    /**
-     * Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the
-     * value EAC3_ATMOS.
-     */
-    inline bool Eac3AtmosSettingsHasBeenSet() const { return m_eac3AtmosSettingsHasBeenSet; }
-
-    /**
-     * Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the
-     * value EAC3_ATMOS.
-     */
-    inline void SetEac3AtmosSettings(const Eac3AtmosSettings& value) { m_eac3AtmosSettingsHasBeenSet = true; m_eac3AtmosSettings = value; }
-
-    /**
-     * Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the
-     * value EAC3_ATMOS.
-     */
-    inline void SetEac3AtmosSettings(Eac3AtmosSettings&& value) { m_eac3AtmosSettingsHasBeenSet = true; m_eac3AtmosSettings = std::move(value); }
-
-    /**
-     * Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the
-     * value EAC3_ATMOS.
-     */
-    inline AudioCodecSettings& WithEac3AtmosSettings(const Eac3AtmosSettings& value) { SetEac3AtmosSettings(value); return *this;}
-
-    /**
-     * Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the
-     * value EAC3_ATMOS.
-     */
-    inline AudioCodecSettings& WithEac3AtmosSettings(Eac3AtmosSettings&& value) { SetEac3AtmosSettings(std::move(value)); return *this;}
-
-
     /**
      * Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the
      * value EAC3.
@@ -337,117 +305,6 @@ namespace Model
     inline AudioCodecSettings& WithMp2Settings(Mp2Settings&& value) { SetMp2Settings(std::move(value)); return *this;}
 
 
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * MP3.
-     */
-    inline const Mp3Settings& GetMp3Settings() const{ return m_mp3Settings; }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * MP3.
-     */
-    inline bool Mp3SettingsHasBeenSet() const { return m_mp3SettingsHasBeenSet; }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * MP3.
-     */
-    inline void SetMp3Settings(const Mp3Settings& value) { m_mp3SettingsHasBeenSet = true; m_mp3Settings = value; }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * MP3.
-     */
-    inline void SetMp3Settings(Mp3Settings&& value) { m_mp3SettingsHasBeenSet = true; m_mp3Settings = std::move(value); }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * MP3.
-     */
-    inline AudioCodecSettings& WithMp3Settings(const Mp3Settings& value) { SetMp3Settings(value); return *this;}
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * MP3.
-     */
-    inline AudioCodecSettings& WithMp3Settings(Mp3Settings&& value) { SetMp3Settings(std::move(value)); return *this;}
-
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * OPUS.
-     */
-    inline const OpusSettings& GetOpusSettings() const{ return m_opusSettings; }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * OPUS.
-     */
-    inline bool OpusSettingsHasBeenSet() const { return m_opusSettingsHasBeenSet; }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * OPUS.
-     */
-    inline void SetOpusSettings(const OpusSettings& value) { m_opusSettingsHasBeenSet = true; m_opusSettings = value; }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * OPUS.
-     */
-    inline void SetOpusSettings(OpusSettings&& value) { m_opusSettingsHasBeenSet = true; m_opusSettings = std::move(value); }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * OPUS.
-     */
-    inline AudioCodecSettings& WithOpusSettings(const OpusSettings& value) { SetOpusSettings(value); return *this;}
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * OPUS.
-     */
-    inline AudioCodecSettings& WithOpusSettings(OpusSettings&& value) { SetOpusSettings(std::move(value)); return *this;}
-
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * Vorbis.
-     */
-    inline const VorbisSettings& GetVorbisSettings() const{ return m_vorbisSettings; }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * Vorbis.
-     */
-    inline bool VorbisSettingsHasBeenSet() const { return m_vorbisSettingsHasBeenSet; }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * Vorbis.
-     */
-    inline void SetVorbisSettings(const VorbisSettings& value) { m_vorbisSettingsHasBeenSet = true; m_vorbisSettings = value; }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * Vorbis.
-     */
-    inline void SetVorbisSettings(VorbisSettings&& value) { m_vorbisSettingsHasBeenSet = true; m_vorbisSettings = std::move(value); }
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * Vorbis.
-     */
-    inline AudioCodecSettings& WithVorbisSettings(const VorbisSettings& value) { SetVorbisSettings(value); return *this;}
-
-    /**
-     * Required when you set Codec, under AudioDescriptions>CodecSettings, to the value
-     * Vorbis.
-     */
-    inline AudioCodecSettings& WithVorbisSettings(VorbisSettings&& value) { SetVorbisSettings(std::move(value)); return *this;}
-
-
     /**
      * Required when you set (Codec) under (AudioDescriptions)>(CodecSettings) to the
      * value WAV.
@@ -498,24 +355,12 @@ namespace Model
     AudioCodec m_codec;
     bool m_codecHasBeenSet;
 
-    Eac3AtmosSettings m_eac3AtmosSettings;
-    bool m_eac3AtmosSettingsHasBeenSet;
-
     Eac3Settings m_eac3Settings;
     bool m_eac3SettingsHasBeenSet;
 
     Mp2Settings m_mp2Settings;
     bool m_mp2SettingsHasBeenSet;
 
-    Mp3Settings m_mp3Settings;
-    bool m_mp3SettingsHasBeenSet;
-
-    OpusSettings m_opusSettings;
-    bool m_opusSettingsHasBeenSet;
-
-    VorbisSettings m_vorbisSettings;
-    bool m_vorbisSettingsHasBeenSet;
-
     WavSettings m_wavSettings;
     bool m_wavSettingsHasBeenSet;
   };
