@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediaconvert/MediaConvert_EXPORTS.h>
@@ -27,8 +37,7 @@ namespace Model
 {
 
   /**
-   * Advanced audio normalization settings. Ignore these settings unless you need to
-   * comply with a loudness standard.<p><h3>See Also:</h3>   <a
+   * Advanced audio normalization settings.<p><h3>See Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/mediaconvert-2017-08-29/AudioNormalizationSettings">AWS
    * API Reference</a></p>
    */
@@ -42,86 +51,38 @@ namespace Model
 
 
     /**
-     * Choose one of the following audio normalization algorithms: ITU-R BS.1770-1:
-     * Ungated loudness. A measurement of ungated average loudness for an entire piece
-     * of content, suitable for measurement of short-form content under ATSC
-     * recommendation A/85. Supports up to 5.1 audio channels. ITU-R BS.1770-2: Gated
-     * loudness. A measurement of gated average loudness compliant with the
-     * requirements of EBU-R128. Supports up to 5.1 audio channels. ITU-R BS.1770-3:
-     * Modified peak. The same loudness measurement algorithm as 1770-2, with an
-     * updated true peak measurement. ITU-R BS.1770-4: Higher channel count. Allows for
-     * more audio channels than the other algorithms, including configurations such as
-     * 7.1.
+     * Audio normalization algorithm to use. 1770-1 conforms to the CALM Act
+     * specification, 1770-2 conforms to the EBU R-128 specification.
      */
     inline const AudioNormalizationAlgorithm& GetAlgorithm() const{ return m_algorithm; }
 
     /**
-     * Choose one of the following audio normalization algorithms: ITU-R BS.1770-1:
-     * Ungated loudness. A measurement of ungated average loudness for an entire piece
-     * of content, suitable for measurement of short-form content under ATSC
-     * recommendation A/85. Supports up to 5.1 audio channels. ITU-R BS.1770-2: Gated
-     * loudness. A measurement of gated average loudness compliant with the
-     * requirements of EBU-R128. Supports up to 5.1 audio channels. ITU-R BS.1770-3:
-     * Modified peak. The same loudness measurement algorithm as 1770-2, with an
-     * updated true peak measurement. ITU-R BS.1770-4: Higher channel count. Allows for
-     * more audio channels than the other algorithms, including configurations such as
-     * 7.1.
+     * Audio normalization algorithm to use. 1770-1 conforms to the CALM Act
+     * specification, 1770-2 conforms to the EBU R-128 specification.
      */
     inline bool AlgorithmHasBeenSet() const { return m_algorithmHasBeenSet; }
 
     /**
-     * Choose one of the following audio normalization algorithms: ITU-R BS.1770-1:
-     * Ungated loudness. A measurement of ungated average loudness for an entire piece
-     * of content, suitable for measurement of short-form content under ATSC
-     * recommendation A/85. Supports up to 5.1 audio channels. ITU-R BS.1770-2: Gated
-     * loudness. A measurement of gated average loudness compliant with the
-     * requirements of EBU-R128. Supports up to 5.1 audio channels. ITU-R BS.1770-3:
-     * Modified peak. The same loudness measurement algorithm as 1770-2, with an
-     * updated true peak measurement. ITU-R BS.1770-4: Higher channel count. Allows for
-     * more audio channels than the other algorithms, including configurations such as
-     * 7.1.
+     * Audio normalization algorithm to use. 1770-1 conforms to the CALM Act
+     * specification, 1770-2 conforms to the EBU R-128 specification.
      */
     inline void SetAlgorithm(const AudioNormalizationAlgorithm& value) { m_algorithmHasBeenSet = true; m_algorithm = value; }
 
     /**
-     * Choose one of the following audio normalization algorithms: ITU-R BS.1770-1:
-     * Ungated loudness. A measurement of ungated average loudness for an entire piece
-     * of content, suitable for measurement of short-form content under ATSC
-     * recommendation A/85. Supports up to 5.1 audio channels. ITU-R BS.1770-2: Gated
-     * loudness. A measurement of gated average loudness compliant with the
-     * requirements of EBU-R128. Supports up to 5.1 audio channels. ITU-R BS.1770-3:
-     * Modified peak. The same loudness measurement algorithm as 1770-2, with an
-     * updated true peak measurement. ITU-R BS.1770-4: Higher channel count. Allows for
-     * more audio channels than the other algorithms, including configurations such as
-     * 7.1.
+     * Audio normalization algorithm to use. 1770-1 conforms to the CALM Act
+     * specification, 1770-2 conforms to the EBU R-128 specification.
      */
     inline void SetAlgorithm(AudioNormalizationAlgorithm&& value) { m_algorithmHasBeenSet = true; m_algorithm = std::move(value); }
 
     /**
-     * Choose one of the following audio normalization algorithms: ITU-R BS.1770-1:
-     * Ungated loudness. A measurement of ungated average loudness for an entire piece
-     * of content, suitable for measurement of short-form content under ATSC
-     * recommendation A/85. Supports up to 5.1 audio channels. ITU-R BS.1770-2: Gated
-     * loudness. A measurement of gated average loudness compliant with the
-     * requirements of EBU-R128. Supports up to 5.1 audio channels. ITU-R BS.1770-3:
-     * Modified peak. The same loudness measurement algorithm as 1770-2, with an
-     * updated true peak measurement. ITU-R BS.1770-4: Higher channel count. Allows for
-     * more audio channels than the other algorithms, including configurations such as
-     * 7.1.
+     * Audio normalization algorithm to use. 1770-1 conforms to the CALM Act
+     * specification, 1770-2 conforms to the EBU R-128 specification.
      */
     inline AudioNormalizationSettings& WithAlgorithm(const AudioNormalizationAlgorithm& value) { SetAlgorithm(value); return *this;}
 
     /**
-     * Choose one of the following audio normalization algorithms: ITU-R BS.1770-1:
-     * Ungated loudness. A measurement of ungated average loudness for an entire piece
-     * of content, suitable for measurement of short-form content under ATSC
-     * recommendation A/85. Supports up to 5.1 audio channels. ITU-R BS.1770-2: Gated
-     * loudness. A measurement of gated average loudness compliant with the
-     * requirements of EBU-R128. Supports up to 5.1 audio channels. ITU-R BS.1770-3:
-     * Modified peak. The same loudness measurement algorithm as 1770-2, with an
-     * updated true peak measurement. ITU-R BS.1770-4: Higher channel count. Allows for
-     * more audio channels than the other algorithms, including configurations such as
-     * 7.1.
+     * Audio normalization algorithm to use. 1770-1 conforms to the CALM Act
+     * specification, 1770-2 conforms to the EBU R-128 specification.
      */
     inline AudioNormalizationSettings& WithAlgorithm(AudioNormalizationAlgorithm&& value) { SetAlgorithm(std::move(value)); return *this;}
 
@@ -165,25 +126,29 @@ namespace Model
 
     /**
      * Content measuring above this level will be corrected to the target level.
-     * Content measuring below this level will not be corrected.
+     * Content measuring below this level will not be corrected. Gating only applies
+     * when not using real_time_correction.
      */
     inline int GetCorrectionGateLevel() const{ return m_correctionGateLevel; }
 
     /**
      * Content measuring above this level will be corrected to the target level.
-     * Content measuring below this level will not be corrected.
+     * Content measuring below this level will not be corrected. Gating only applies
+     * when not using real_time_correction.
      */
     inline bool CorrectionGateLevelHasBeenSet() const { return m_correctionGateLevelHasBeenSet; }
 
     /**
      * Content measuring above this level will be corrected to the target level.
-     * Content measuring below this level will not be corrected.
+     * Content measuring below this level will not be corrected. Gating only applies
+     * when not using real_time_correction.
      */
     inline void SetCorrectionGateLevel(int value) { m_correctionGateLevelHasBeenSet = true; m_correctionGateLevel = value; }
 
     /**
      * Content measuring above this level will be corrected to the target level.
-     * Content measuring below this level will not be corrected.
+     * Content measuring below this level will not be corrected. Gating only applies
+     * when not using real_time_correction.
      */
     inline AudioNormalizationSettings& WithCorrectionGateLevel(int value) { SetCorrectionGateLevel(value); return *this;}
 
@@ -257,60 +222,56 @@ namespace Model
 
 
     /**
-     * When you use Audio normalization (AudioNormalizationSettings), optionally use
-     * this setting to specify a target loudness. If you don't specify a value here,
-     * the encoder chooses a value for you, based on the algorithm that you choose for
-     * Algorithm (algorithm). If you choose algorithm 1770-1, the encoder will choose
-     * -24 LKFS; otherwise, the encoder will choose -23 LKFS.
+     * Target LKFS(loudness) to adjust volume to. If no value is entered, a default
+     * value will be used according to the chosen algorithm. The CALM Act (1770-1)
+     * recommends a target of -24 LKFS. The EBU R-128 specification (1770-2) recommends
+     * a target of -23 LKFS.
      */
     inline double GetTargetLkfs() const{ return m_targetLkfs; }
 
     /**
-     * When you use Audio normalization (AudioNormalizationSettings), optionally use
-     * this setting to specify a target loudness. If you don't specify a value here,
-     * the encoder chooses a value for you, based on the algorithm that you choose for
-     * Algorithm (algorithm). If you choose algorithm 1770-1, the encoder will choose
-     * -24 LKFS; otherwise, the encoder will choose -23 LKFS.
+     * Target LKFS(loudness) to adjust volume to. If no value is entered, a default
+     * value will be used according to the chosen algorithm. The CALM Act (1770-1)
+     * recommends a target of -24 LKFS. The EBU R-128 specification (1770-2) recommends
+     * a target of -23 LKFS.
      */
     inline bool TargetLkfsHasBeenSet() const { return m_targetLkfsHasBeenSet; }
 
     /**
-     * When you use Audio normalization (AudioNormalizationSettings), optionally use
-     * this setting to specify a target loudness. If you don't specify a value here,
-     * the encoder chooses a value for you, based on the algorithm that you choose for
-     * Algorithm (algorithm). If you choose algorithm 1770-1, the encoder will choose
-     * -24 LKFS; otherwise, the encoder will choose -23 LKFS.
+     * Target LKFS(loudness) to adjust volume to. If no value is entered, a default
+     * value will be used according to the chosen algorithm. The CALM Act (1770-1)
+     * recommends a target of -24 LKFS. The EBU R-128 specification (1770-2) recommends
+     * a target of -23 LKFS.
      */
     inline void SetTargetLkfs(double value) { m_targetLkfsHasBeenSet = true; m_targetLkfs = value; }
 
     /**
-     * When you use Audio normalization (AudioNormalizationSettings), optionally use
-     * this setting to specify a target loudness. If you don't specify a value here,
-     * the encoder chooses a value for you, based on the algorithm that you choose for
-     * Algorithm (algorithm). If you choose algorithm 1770-1, the encoder will choose
-     * -24 LKFS; otherwise, the encoder will choose -23 LKFS.
+     * Target LKFS(loudness) to adjust volume to. If no value is entered, a default
+     * value will be used according to the chosen algorithm. The CALM Act (1770-1)
+     * recommends a target of -24 LKFS. The EBU R-128 specification (1770-2) recommends
+     * a target of -23 LKFS.
      */
     inline AudioNormalizationSettings& WithTargetLkfs(double value) { SetTargetLkfs(value); return *this;}
 
   private:
 
     AudioNormalizationAlgorithm m_algorithm;
-    bool m_algorithmHasBeenSet = false;
+    bool m_algorithmHasBeenSet;
 
     AudioNormalizationAlgorithmControl m_algorithmControl;
-    bool m_algorithmControlHasBeenSet = false;
+    bool m_algorithmControlHasBeenSet;
 
     int m_correctionGateLevel;
-    bool m_correctionGateLevelHasBeenSet = false;
+    bool m_correctionGateLevelHasBeenSet;
 
     AudioNormalizationLoudnessLogging m_loudnessLogging;
-    bool m_loudnessLoggingHasBeenSet = false;
+    bool m_loudnessLoggingHasBeenSet;
 
     AudioNormalizationPeakCalculation m_peakCalculation;
-    bool m_peakCalculationHasBeenSet = false;
+    bool m_peakCalculationHasBeenSet;
 
     double m_targetLkfs;
-    bool m_targetLkfsHasBeenSet = false;
+    bool m_targetLkfsHasBeenSet;
   };
 
 } // namespace Model
