@@ -1,18 +1,26 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediaconvert/MediaConvert_EXPORTS.h>
 #include <aws/mediaconvert/MediaConvertRequest.h>
 #include <aws/mediaconvert/model/AccelerationSettings.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
-#include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/mediaconvert/model/JobTemplateSettings.h>
 #include <aws/mediaconvert/model/StatusUpdateInterval.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
-#include <aws/mediaconvert/model/HopDestination.h>
 #include <utility>
 
 namespace Aws
@@ -28,7 +36,7 @@ namespace Model
   {
   public:
     CreateJobTemplateRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -39,50 +47,38 @@ namespace Model
 
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content. Outputs that use this feature incur pro-tier pricing. For
-     * information about feature limitations, see the AWS Elemental MediaConvert User
-     * Guide.
+     * This is a beta feature. If you are interested in using this feature please
+     * contact AWS customer support.
      */
     inline const AccelerationSettings& GetAccelerationSettings() const{ return m_accelerationSettings; }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content. Outputs that use this feature incur pro-tier pricing. For
-     * information about feature limitations, see the AWS Elemental MediaConvert User
-     * Guide.
+     * This is a beta feature. If you are interested in using this feature please
+     * contact AWS customer support.
      */
     inline bool AccelerationSettingsHasBeenSet() const { return m_accelerationSettingsHasBeenSet; }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content. Outputs that use this feature incur pro-tier pricing. For
-     * information about feature limitations, see the AWS Elemental MediaConvert User
-     * Guide.
+     * This is a beta feature. If you are interested in using this feature please
+     * contact AWS customer support.
      */
     inline void SetAccelerationSettings(const AccelerationSettings& value) { m_accelerationSettingsHasBeenSet = true; m_accelerationSettings = value; }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content. Outputs that use this feature incur pro-tier pricing. For
-     * information about feature limitations, see the AWS Elemental MediaConvert User
-     * Guide.
+     * This is a beta feature. If you are interested in using this feature please
+     * contact AWS customer support.
      */
     inline void SetAccelerationSettings(AccelerationSettings&& value) { m_accelerationSettingsHasBeenSet = true; m_accelerationSettings = std::move(value); }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content. Outputs that use this feature incur pro-tier pricing. For
-     * information about feature limitations, see the AWS Elemental MediaConvert User
-     * Guide.
+     * This is a beta feature. If you are interested in using this feature please
+     * contact AWS customer support.
      */
     inline CreateJobTemplateRequest& WithAccelerationSettings(const AccelerationSettings& value) { SetAccelerationSettings(value); return *this;}
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content. Outputs that use this feature incur pro-tier pricing. For
-     * information about feature limitations, see the AWS Elemental MediaConvert User
-     * Guide.
+     * This is a beta feature. If you are interested in using this feature please
+     * contact AWS customer support.
      */
     inline CreateJobTemplateRequest& WithAccelerationSettings(AccelerationSettings&& value) { SetAccelerationSettings(std::move(value)); return *this;}
 
@@ -169,71 +165,6 @@ namespace Model
     inline CreateJobTemplateRequest& WithDescription(const char* value) { SetDescription(value); return *this;}
 
 
-    /**
-     * Optional. Use queue hopping to avoid overly long waits in the backlog of the
-     * queue that you submit your job to. Specify an alternate queue and the maximum
-     * time that your job will wait in the initial queue before hopping. For more
-     * information about this feature, see the AWS Elemental MediaConvert User Guide.
-     */
-    inline const Aws::Vector<HopDestination>& GetHopDestinations() const{ return m_hopDestinations; }
-
-    /**
-     * Optional. Use queue hopping to avoid overly long waits in the backlog of the
-     * queue that you submit your job to. Specify an alternate queue and the maximum
-     * time that your job will wait in the initial queue before hopping. For more
-     * information about this feature, see the AWS Elemental MediaConvert User Guide.
-     */
-    inline bool HopDestinationsHasBeenSet() const { return m_hopDestinationsHasBeenSet; }
-
-    /**
-     * Optional. Use queue hopping to avoid overly long waits in the backlog of the
-     * queue that you submit your job to. Specify an alternate queue and the maximum
-     * time that your job will wait in the initial queue before hopping. For more
-     * information about this feature, see the AWS Elemental MediaConvert User Guide.
-     */
-    inline void SetHopDestinations(const Aws::Vector<HopDestination>& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations = value; }
-
-    /**
-     * Optional. Use queue hopping to avoid overly long waits in the backlog of the
-     * queue that you submit your job to. Specify an alternate queue and the maximum
-     * time that your job will wait in the initial queue before hopping. For more
-     * information about this feature, see the AWS Elemental MediaConvert User Guide.
-     */
-    inline void SetHopDestinations(Aws::Vector<HopDestination>&& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations = std::move(value); }
-
-    /**
-     * Optional. Use queue hopping to avoid overly long waits in the backlog of the
-     * queue that you submit your job to. Specify an alternate queue and the maximum
-     * time that your job will wait in the initial queue before hopping. For more
-     * information about this feature, see the AWS Elemental MediaConvert User Guide.
-     */
-    inline CreateJobTemplateRequest& WithHopDestinations(const Aws::Vector<HopDestination>& value) { SetHopDestinations(value); return *this;}
-
-    /**
-     * Optional. Use queue hopping to avoid overly long waits in the backlog of the
-     * queue that you submit your job to. Specify an alternate queue and the maximum
-     * time that your job will wait in the initial queue before hopping. For more
-     * information about this feature, see the AWS Elemental MediaConvert User Guide.
-     */
-    inline CreateJobTemplateRequest& WithHopDestinations(Aws::Vector<HopDestination>&& value) { SetHopDestinations(std::move(value)); return *this;}
-
-    /**
-     * Optional. Use queue hopping to avoid overly long waits in the backlog of the
-     * queue that you submit your job to. Specify an alternate queue and the maximum
-     * time that your job will wait in the initial queue before hopping. For more
-     * information about this feature, see the AWS Elemental MediaConvert User Guide.
-     */
-    inline CreateJobTemplateRequest& AddHopDestinations(const HopDestination& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations.push_back(value); return *this; }
-
-    /**
-     * Optional. Use queue hopping to avoid overly long waits in the backlog of the
-     * queue that you submit your job to. Specify an alternate queue and the maximum
-     * time that your job will wait in the initial queue before hopping. For more
-     * information about this feature, see the AWS Elemental MediaConvert User Guide.
-     */
-    inline CreateJobTemplateRequest& AddHopDestinations(HopDestination&& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations.push_back(std::move(value)); return *this; }
-
-
     /**
      * The name of the job template you are creating.
      */
@@ -275,39 +206,6 @@ namespace Model
     inline CreateJobTemplateRequest& WithName(const char* value) { SetName(value); return *this;}
 
 
-    /**
-     * Specify the relative priority for this job. In any given queue, the service
-     * begins processing the job with the highest value first. When more than one job
-     * has the same priority, the service begins processing the job that you submitted
-     * first. If you don't specify a priority, the service uses the default value 0.
-     */
-    inline int GetPriority() const{ return m_priority; }
-
-    /**
-     * Specify the relative priority for this job. In any given queue, the service
-     * begins processing the job with the highest value first. When more than one job
-     * has the same priority, the service begins processing the job that you submitted
-     * first. If you don't specify a priority, the service uses the default value 0.
-     */
-    inline bool PriorityHasBeenSet() const { return m_priorityHasBeenSet; }
-
-    /**
-     * Specify the relative priority for this job. In any given queue, the service
-     * begins processing the job with the highest value first. When more than one job
-     * has the same priority, the service begins processing the job that you submitted
-     * first. If you don't specify a priority, the service uses the default value 0.
-     */
-    inline void SetPriority(int value) { m_priorityHasBeenSet = true; m_priority = value; }
-
-    /**
-     * Specify the relative priority for this job. In any given queue, the service
-     * begins processing the job with the highest value first. When more than one job
-     * has the same priority, the service begins processing the job that you submitted
-     * first. If you don't specify a priority, the service uses the default value 0.
-     */
-    inline CreateJobTemplateRequest& WithPriority(int value) { SetPriority(value); return *this;}
-
-
     /**
      * Optional. The queue that jobs created from this template are assigned to. If you
      * don't specify this, jobs will go to the default queue.
@@ -524,34 +422,28 @@ namespace Model
   private:
 
     AccelerationSettings m_accelerationSettings;
-    bool m_accelerationSettingsHasBeenSet = false;
+    bool m_accelerationSettingsHasBeenSet;
 
     Aws::String m_category;
-    bool m_categoryHasBeenSet = false;
+    bool m_categoryHasBeenSet;
 
     Aws::String m_description;
-    bool m_descriptionHasBeenSet = false;
-
-    Aws::Vector<HopDestination> m_hopDestinations;
-    bool m_hopDestinationsHasBeenSet = false;
+    bool m_descriptionHasBeenSet;
 
     Aws::String m_name;
-    bool m_nameHasBeenSet = false;
-
-    int m_priority;
-    bool m_priorityHasBeenSet = false;
+    bool m_nameHasBeenSet;
 
     Aws::String m_queue;
-    bool m_queueHasBeenSet = false;
+    bool m_queueHasBeenSet;
 
     JobTemplateSettings m_settings;
-    bool m_settingsHasBeenSet = false;
+    bool m_settingsHasBeenSet;
 
     StatusUpdateInterval m_statusUpdateInterval;
-    bool m_statusUpdateIntervalHasBeenSet = false;
+    bool m_statusUpdateIntervalHasBeenSet;
 
     Aws::Map<Aws::String, Aws::String> m_tags;
-    bool m_tagsHasBeenSet = false;
+    bool m_tagsHasBeenSet;
   };
 
 } // namespace Model
