@@ -1,12 +1,21 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediaconvert/MediaConvert_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/mediaconvert/model/HlsAudioOnlyHeader.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/mediaconvert/model/HlsCaptionLanguageSetting.h>
 #include <aws/mediaconvert/model/HlsClientCache.h>
@@ -22,7 +31,6 @@
 #include <aws/mediaconvert/model/HlsStreamInfResolution.h>
 #include <aws/mediaconvert/model/HlsTimedMetadataId3Frame.h>
 #include <aws/mediaconvert/model/HlsAdMarkers.h>
-#include <aws/mediaconvert/model/HlsAdditionalManifest.h>
 #include <aws/mediaconvert/model/HlsCaptionLanguageMapping.h>
 #include <utility>
 
@@ -57,176 +65,54 @@ namespace Model
 
 
     /**
-     * Choose one or more ad marker types to decorate your Apple HLS manifest. This
-     * setting does not determine whether SCTE-35 markers appear in the outputs
-     * themselves.
+     * Choose one or more ad marker types to pass SCTE35 signals through to this group
+     * of Apple HLS outputs.
      */
     inline const Aws::Vector<HlsAdMarkers>& GetAdMarkers() const{ return m_adMarkers; }
 
     /**
-     * Choose one or more ad marker types to decorate your Apple HLS manifest. This
-     * setting does not determine whether SCTE-35 markers appear in the outputs
-     * themselves.
+     * Choose one or more ad marker types to pass SCTE35 signals through to this group
+     * of Apple HLS outputs.
      */
     inline bool AdMarkersHasBeenSet() const { return m_adMarkersHasBeenSet; }
 
     /**
-     * Choose one or more ad marker types to decorate your Apple HLS manifest. This
-     * setting does not determine whether SCTE-35 markers appear in the outputs
-     * themselves.
+     * Choose one or more ad marker types to pass SCTE35 signals through to this group
+     * of Apple HLS outputs.
      */
     inline void SetAdMarkers(const Aws::Vector<HlsAdMarkers>& value) { m_adMarkersHasBeenSet = true; m_adMarkers = value; }
 
     /**
-     * Choose one or more ad marker types to decorate your Apple HLS manifest. This
-     * setting does not determine whether SCTE-35 markers appear in the outputs
-     * themselves.
+     * Choose one or more ad marker types to pass SCTE35 signals through to this group
+     * of Apple HLS outputs.
      */
     inline void SetAdMarkers(Aws::Vector<HlsAdMarkers>&& value) { m_adMarkersHasBeenSet = true; m_adMarkers = std::move(value); }
 
     /**
-     * Choose one or more ad marker types to decorate your Apple HLS manifest. This
-     * setting does not determine whether SCTE-35 markers appear in the outputs
-     * themselves.
+     * Choose one or more ad marker types to pass SCTE35 signals through to this group
+     * of Apple HLS outputs.
      */
     inline HlsGroupSettings& WithAdMarkers(const Aws::Vector<HlsAdMarkers>& value) { SetAdMarkers(value); return *this;}
 
     /**
-     * Choose one or more ad marker types to decorate your Apple HLS manifest. This
-     * setting does not determine whether SCTE-35 markers appear in the outputs
-     * themselves.
+     * Choose one or more ad marker types to pass SCTE35 signals through to this group
+     * of Apple HLS outputs.
      */
     inline HlsGroupSettings& WithAdMarkers(Aws::Vector<HlsAdMarkers>&& value) { SetAdMarkers(std::move(value)); return *this;}
 
     /**
-     * Choose one or more ad marker types to decorate your Apple HLS manifest. This
-     * setting does not determine whether SCTE-35 markers appear in the outputs
-     * themselves.
+     * Choose one or more ad marker types to pass SCTE35 signals through to this group
+     * of Apple HLS outputs.
      */
     inline HlsGroupSettings& AddAdMarkers(const HlsAdMarkers& value) { m_adMarkersHasBeenSet = true; m_adMarkers.push_back(value); return *this; }
 
     /**
-     * Choose one or more ad marker types to decorate your Apple HLS manifest. This
-     * setting does not determine whether SCTE-35 markers appear in the outputs
-     * themselves.
+     * Choose one or more ad marker types to pass SCTE35 signals through to this group
+     * of Apple HLS outputs.
      */
     inline HlsGroupSettings& AddAdMarkers(HlsAdMarkers&& value) { m_adMarkersHasBeenSet = true; m_adMarkers.push_back(std::move(value)); return *this; }
 
 
-    /**
-     * By default, the service creates one top-level .m3u8 HLS manifest for each HLS
-     * output group in your job. This default manifest references every output in the
-     * output group. To create additional top-level manifests that reference a subset
-     * of the outputs in the output group, specify a list of them here.
-     */
-    inline const Aws::Vector<HlsAdditionalManifest>& GetAdditionalManifests() const{ return m_additionalManifests; }
-
-    /**
-     * By default, the service creates one top-level .m3u8 HLS manifest for each HLS
-     * output group in your job. This default manifest references every output in the
-     * output group. To create additional top-level manifests that reference a subset
-     * of the outputs in the output group, specify a list of them here.
-     */
-    inline bool AdditionalManifestsHasBeenSet() const { return m_additionalManifestsHasBeenSet; }
-
-    /**
-     * By default, the service creates one top-level .m3u8 HLS manifest for each HLS
-     * output group in your job. This default manifest references every output in the
-     * output group. To create additional top-level manifests that reference a subset
-     * of the outputs in the output group, specify a list of them here.
-     */
-    inline void SetAdditionalManifests(const Aws::Vector<HlsAdditionalManifest>& value) { m_additionalManifestsHasBeenSet = true; m_additionalManifests = value; }
-
-    /**
-     * By default, the service creates one top-level .m3u8 HLS manifest for each HLS
-     * output group in your job. This default manifest references every output in the
-     * output group. To create additional top-level manifests that reference a subset
-     * of the outputs in the output group, specify a list of them here.
-     */
-    inline void SetAdditionalManifests(Aws::Vector<HlsAdditionalManifest>&& value) { m_additionalManifestsHasBeenSet = true; m_additionalManifests = std::move(value); }
-
-    /**
-     * By default, the service creates one top-level .m3u8 HLS manifest for each HLS
-     * output group in your job. This default manifest references every output in the
-     * output group. To create additional top-level manifests that reference a subset
-     * of the outputs in the output group, specify a list of them here.
-     */
-    inline HlsGroupSettings& WithAdditionalManifests(const Aws::Vector<HlsAdditionalManifest>& value) { SetAdditionalManifests(value); return *this;}
-
-    /**
-     * By default, the service creates one top-level .m3u8 HLS manifest for each HLS
-     * output group in your job. This default manifest references every output in the
-     * output group. To create additional top-level manifests that reference a subset
-     * of the outputs in the output group, specify a list of them here.
-     */
-    inline HlsGroupSettings& WithAdditionalManifests(Aws::Vector<HlsAdditionalManifest>&& value) { SetAdditionalManifests(std::move(value)); return *this;}
-
-    /**
-     * By default, the service creates one top-level .m3u8 HLS manifest for each HLS
-     * output group in your job. This default manifest references every output in the
-     * output group. To create additional top-level manifests that reference a subset
-     * of the outputs in the output group, specify a list of them here.
-     */
-    inline HlsGroupSettings& AddAdditionalManifests(const HlsAdditionalManifest& value) { m_additionalManifestsHasBeenSet = true; m_additionalManifests.push_back(value); return *this; }
-
-    /**
-     * By default, the service creates one top-level .m3u8 HLS manifest for each HLS
-     * output group in your job. This default manifest references every output in the
-     * output group. To create additional top-level manifests that reference a subset
-     * of the outputs in the output group, specify a list of them here.
-     */
-    inline HlsGroupSettings& AddAdditionalManifests(HlsAdditionalManifest&& value) { m_additionalManifestsHasBeenSet = true; m_additionalManifests.push_back(std::move(value)); return *this; }
-
-
-    /**
-     * Ignore this setting unless you are using FairPlay DRM with Verimatrix and you
-     * encounter playback issues. Keep the default value, Include (INCLUDE), to output
-     * audio-only headers. Choose Exclude (EXCLUDE) to remove the audio-only headers
-     * from your audio segments.
-     */
-    inline const HlsAudioOnlyHeader& GetAudioOnlyHeader() const{ return m_audioOnlyHeader; }
-
-    /**
-     * Ignore this setting unless you are using FairPlay DRM with Verimatrix and you
-     * encounter playback issues. Keep the default value, Include (INCLUDE), to output
-     * audio-only headers. Choose Exclude (EXCLUDE) to remove the audio-only headers
-     * from your audio segments.
-     */
-    inline bool AudioOnlyHeaderHasBeenSet() const { return m_audioOnlyHeaderHasBeenSet; }
-
-    /**
-     * Ignore this setting unless you are using FairPlay DRM with Verimatrix and you
-     * encounter playback issues. Keep the default value, Include (INCLUDE), to output
-     * audio-only headers. Choose Exclude (EXCLUDE) to remove the audio-only headers
-     * from your audio segments.
-     */
-    inline void SetAudioOnlyHeader(const HlsAudioOnlyHeader& value) { m_audioOnlyHeaderHasBeenSet = true; m_audioOnlyHeader = value; }
-
-    /**
-     * Ignore this setting unless you are using FairPlay DRM with Verimatrix and you
-     * encounter playback issues. Keep the default value, Include (INCLUDE), to output
-     * audio-only headers. Choose Exclude (EXCLUDE) to remove the audio-only headers
-     * from your audio segments.
-     */
-    inline void SetAudioOnlyHeader(HlsAudioOnlyHeader&& value) { m_audioOnlyHeaderHasBeenSet = true; m_audioOnlyHeader = std::move(value); }
-
-    /**
-     * Ignore this setting unless you are using FairPlay DRM with Verimatrix and you
-     * encounter playback issues. Keep the default value, Include (INCLUDE), to output
-     * audio-only headers. Choose Exclude (EXCLUDE) to remove the audio-only headers
-     * from your audio segments.
-     */
-    inline HlsGroupSettings& WithAudioOnlyHeader(const HlsAudioOnlyHeader& value) { SetAudioOnlyHeader(value); return *this;}
-
-    /**
-     * Ignore this setting unless you are using FairPlay DRM with Verimatrix and you
-     * encounter playback issues. Keep the default value, Include (INCLUDE), to output
-     * audio-only headers. Choose Exclude (EXCLUDE) to remove the audio-only headers
-     * from your audio segments.
-     */
-    inline HlsGroupSettings& WithAudioOnlyHeader(HlsAudioOnlyHeader&& value) { SetAudioOnlyHeader(std::move(value)); return *this;}
-
-
     /**
      * A partial URI prefix that will be prepended to each output in the media .m3u8
      * file. Can be used if base manifest is delivered from a different URL than the
@@ -1116,12 +1002,6 @@ namespace Model
     Aws::Vector<HlsAdMarkers> m_adMarkers;
     bool m_adMarkersHasBeenSet;
 
-    Aws::Vector<HlsAdditionalManifest> m_additionalManifests;
-    bool m_additionalManifestsHasBeenSet;
-
-    HlsAudioOnlyHeader m_audioOnlyHeader;
-    bool m_audioOnlyHeaderHasBeenSet;
-
     Aws::String m_baseUrl;
     bool m_baseUrlHasBeenSet;
 
