@@ -1,12 +1,21 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediaconvert/MediaConvert_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
-#include <aws/mediaconvert/model/HlsAudioOnlyContainer.h>
 #include <aws/mediaconvert/model/HlsAudioTrackType.h>
 #include <aws/mediaconvert/model/HlsIFrameOnlyManifest.h>
 #include <utility>
@@ -81,61 +90,6 @@ namespace Model
     inline HlsSettings& WithAudioGroupId(const char* value) { SetAudioGroupId(value); return *this;}
 
 
-    /**
-     * Use this setting only in audio-only outputs. Choose MPEG-2 Transport Stream
-     * (M2TS) to create a file in an MPEG2-TS container. Keep the default value
-     * Automatic (AUTOMATIC) to create an audio-only file in a raw container.
-     * Regardless of the value that you specify here, if this output has video, the
-     * service will place the output into an MPEG2-TS container.
-     */
-    inline const HlsAudioOnlyContainer& GetAudioOnlyContainer() const{ return m_audioOnlyContainer; }
-
-    /**
-     * Use this setting only in audio-only outputs. Choose MPEG-2 Transport Stream
-     * (M2TS) to create a file in an MPEG2-TS container. Keep the default value
-     * Automatic (AUTOMATIC) to create an audio-only file in a raw container.
-     * Regardless of the value that you specify here, if this output has video, the
-     * service will place the output into an MPEG2-TS container.
-     */
-    inline bool AudioOnlyContainerHasBeenSet() const { return m_audioOnlyContainerHasBeenSet; }
-
-    /**
-     * Use this setting only in audio-only outputs. Choose MPEG-2 Transport Stream
-     * (M2TS) to create a file in an MPEG2-TS container. Keep the default value
-     * Automatic (AUTOMATIC) to create an audio-only file in a raw container.
-     * Regardless of the value that you specify here, if this output has video, the
-     * service will place the output into an MPEG2-TS container.
-     */
-    inline void SetAudioOnlyContainer(const HlsAudioOnlyContainer& value) { m_audioOnlyContainerHasBeenSet = true; m_audioOnlyContainer = value; }
-
-    /**
-     * Use this setting only in audio-only outputs. Choose MPEG-2 Transport Stream
-     * (M2TS) to create a file in an MPEG2-TS container. Keep the default value
-     * Automatic (AUTOMATIC) to create an audio-only file in a raw container.
-     * Regardless of the value that you specify here, if this output has video, the
-     * service will place the output into an MPEG2-TS container.
-     */
-    inline void SetAudioOnlyContainer(HlsAudioOnlyContainer&& value) { m_audioOnlyContainerHasBeenSet = true; m_audioOnlyContainer = std::move(value); }
-
-    /**
-     * Use this setting only in audio-only outputs. Choose MPEG-2 Transport Stream
-     * (M2TS) to create a file in an MPEG2-TS container. Keep the default value
-     * Automatic (AUTOMATIC) to create an audio-only file in a raw container.
-     * Regardless of the value that you specify here, if this output has video, the
-     * service will place the output into an MPEG2-TS container.
-     */
-    inline HlsSettings& WithAudioOnlyContainer(const HlsAudioOnlyContainer& value) { SetAudioOnlyContainer(value); return *this;}
-
-    /**
-     * Use this setting only in audio-only outputs. Choose MPEG-2 Transport Stream
-     * (M2TS) to create a file in an MPEG2-TS container. Keep the default value
-     * Automatic (AUTOMATIC) to create an audio-only file in a raw container.
-     * Regardless of the value that you specify here, if this output has video, the
-     * service will place the output into an MPEG2-TS container.
-     */
-    inline HlsSettings& WithAudioOnlyContainer(HlsAudioOnlyContainer&& value) { SetAudioOnlyContainer(std::move(value)); return *this;}
-
-
     /**
      * List all the audio groups that are used with the video output stream. Input all
      * the audio GROUP-IDs that are associated to the video, separate by ','.
@@ -314,66 +268,50 @@ namespace Model
 
 
     /**
-     * Use this setting to add an identifying string to the filename of each segment.
-     * The service adds this string between the name modifier and segment index number.
-     * You can use format identifiers in the string. For more information, see
-     * https://docs.aws.amazon.com/mediaconvert/latest/ug/using-variables-in-your-job-settings.html
+     * String concatenated to end of segment filenames. Accepts "Format
+     * Identifiers":#format_identifier_parameters.
      */
     inline const Aws::String& GetSegmentModifier() const{ return m_segmentModifier; }
 
     /**
-     * Use this setting to add an identifying string to the filename of each segment.
-     * The service adds this string between the name modifier and segment index number.
-     * You can use format identifiers in the string. For more information, see
-     * https://docs.aws.amazon.com/mediaconvert/latest/ug/using-variables-in-your-job-settings.html
+     * String concatenated to end of segment filenames. Accepts "Format
+     * Identifiers":#format_identifier_parameters.
      */
     inline bool SegmentModifierHasBeenSet() const { return m_segmentModifierHasBeenSet; }
 
     /**
-     * Use this setting to add an identifying string to the filename of each segment.
-     * The service adds this string between the name modifier and segment index number.
-     * You can use format identifiers in the string. For more information, see
-     * https://docs.aws.amazon.com/mediaconvert/latest/ug/using-variables-in-your-job-settings.html
+     * String concatenated to end of segment filenames. Accepts "Format
+     * Identifiers":#format_identifier_parameters.
      */
     inline void SetSegmentModifier(const Aws::String& value) { m_segmentModifierHasBeenSet = true; m_segmentModifier = value; }
 
     /**
-     * Use this setting to add an identifying string to the filename of each segment.
-     * The service adds this string between the name modifier and segment index number.
-     * You can use format identifiers in the string. For more information, see
-     * https://docs.aws.amazon.com/mediaconvert/latest/ug/using-variables-in-your-job-settings.html
+     * String concatenated to end of segment filenames. Accepts "Format
+     * Identifiers":#format_identifier_parameters.
      */
     inline void SetSegmentModifier(Aws::String&& value) { m_segmentModifierHasBeenSet = true; m_segmentModifier = std::move(value); }
 
     /**
-     * Use this setting to add an identifying string to the filename of each segment.
-     * The service adds this string between the name modifier and segment index number.
-     * You can use format identifiers in the string. For more information, see
-     * https://docs.aws.amazon.com/mediaconvert/latest/ug/using-variables-in-your-job-settings.html
+     * String concatenated to end of segment filenames. Accepts "Format
+     * Identifiers":#format_identifier_parameters.
      */
     inline void SetSegmentModifier(const char* value) { m_segmentModifierHasBeenSet = true; m_segmentModifier.assign(value); }
 
     /**
-     * Use this setting to add an identifying string to the filename of each segment.
-     * The service adds this string between the name modifier and segment index number.
-     * You can use format identifiers in the string. For more information, see
-     * https://docs.aws.amazon.com/mediaconvert/latest/ug/using-variables-in-your-job-settings.html
+     * String concatenated to end of segment filenames. Accepts "Format
+     * Identifiers":#format_identifier_parameters.
      */
     inline HlsSettings& WithSegmentModifier(const Aws::String& value) { SetSegmentModifier(value); return *this;}
 
     /**
-     * Use this setting to add an identifying string to the filename of each segment.
-     * The service adds this string between the name modifier and segment index number.
-     * You can use format identifiers in the string. For more information, see
-     * https://docs.aws.amazon.com/mediaconvert/latest/ug/using-variables-in-your-job-settings.html
+     * String concatenated to end of segment filenames. Accepts "Format
+     * Identifiers":#format_identifier_parameters.
      */
     inline HlsSettings& WithSegmentModifier(Aws::String&& value) { SetSegmentModifier(std::move(value)); return *this;}
 
     /**
-     * Use this setting to add an identifying string to the filename of each segment.
-     * The service adds this string between the name modifier and segment index number.
-     * You can use format identifiers in the string. For more information, see
-     * https://docs.aws.amazon.com/mediaconvert/latest/ug/using-variables-in-your-job-settings.html
+     * String concatenated to end of segment filenames. Accepts "Format
+     * Identifiers":#format_identifier_parameters.
      */
     inline HlsSettings& WithSegmentModifier(const char* value) { SetSegmentModifier(value); return *this;}
 
@@ -382,9 +320,6 @@ namespace Model
     Aws::String m_audioGroupId;
     bool m_audioGroupIdHasBeenSet;
 
-    HlsAudioOnlyContainer m_audioOnlyContainer;
-    bool m_audioOnlyContainerHasBeenSet;
-
     Aws::String m_audioRenditionSets;
     bool m_audioRenditionSetsHasBeenSet;
 
