@@ -1,12 +1,21 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediaconvert/MediaConvert_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
-#include <aws/mediaconvert/model/Rectangle.h>
 #include <aws/mediaconvert/model/InputDeblockFilter.h>
 #include <aws/mediaconvert/model/InputDenoiseFilter.h>
 #include <aws/mediaconvert/model/InputFilterEnable.h>
@@ -14,8 +23,8 @@
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/mediaconvert/model/InputPsiControl.h>
 #include <aws/mediaconvert/model/InputTimecodeSource.h>
-#include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/mediaconvert/model/VideoSelector.h>
+#include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/mediaconvert/model/AudioSelectorGroup.h>
 #include <aws/mediaconvert/model/AudioSelector.h>
 #include <aws/mediaconvert/model/CaptionSelector.h>
@@ -138,243 +147,212 @@ namespace Model
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline const Aws::Map<Aws::String, AudioSelector>& GetAudioSelectors() const{ return m_audioSelectors; }
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline bool AudioSelectorsHasBeenSet() const { return m_audioSelectorsHasBeenSet; }
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline void SetAudioSelectors(const Aws::Map<Aws::String, AudioSelector>& value) { m_audioSelectorsHasBeenSet = true; m_audioSelectors = value; }
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline void SetAudioSelectors(Aws::Map<Aws::String, AudioSelector>&& value) { m_audioSelectorsHasBeenSet = true; m_audioSelectors = std::move(value); }
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline InputTemplate& WithAudioSelectors(const Aws::Map<Aws::String, AudioSelector>& value) { SetAudioSelectors(value); return *this;}
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline InputTemplate& WithAudioSelectors(Aws::Map<Aws::String, AudioSelector>&& value) { SetAudioSelectors(std::move(value)); return *this;}
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline InputTemplate& AddAudioSelectors(const Aws::String& key, const AudioSelector& value) { m_audioSelectorsHasBeenSet = true; m_audioSelectors.emplace(key, value); return *this; }
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline InputTemplate& AddAudioSelectors(Aws::String&& key, const AudioSelector& value) { m_audioSelectorsHasBeenSet = true; m_audioSelectors.emplace(std::move(key), value); return *this; }
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline InputTemplate& AddAudioSelectors(const Aws::String& key, AudioSelector&& value) { m_audioSelectorsHasBeenSet = true; m_audioSelectors.emplace(key, std::move(value)); return *this; }
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline InputTemplate& AddAudioSelectors(Aws::String&& key, AudioSelector&& value) { m_audioSelectorsHasBeenSet = true; m_audioSelectors.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline InputTemplate& AddAudioSelectors(const char* key, AudioSelector&& value) { m_audioSelectorsHasBeenSet = true; m_audioSelectors.emplace(key, std::move(value)); return *this; }
 
     /**
      * Use Audio selectors (AudioSelectors) to specify a track or set of tracks from
-     * the input that you will use in your outputs. You can use multiple Audio
-     * selectors per input.
+     * the input that you will use in your outputs. You can use mutiple Audio selectors
+     * per input.
      */
     inline InputTemplate& AddAudioSelectors(const char* key, const AudioSelector& value) { m_audioSelectorsHasBeenSet = true; m_audioSelectors.emplace(key, value); return *this; }
 
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline const Aws::Map<Aws::String, CaptionSelector>& GetCaptionSelectors() const{ return m_captionSelectors; }
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline bool CaptionSelectorsHasBeenSet() const { return m_captionSelectorsHasBeenSet; }
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline void SetCaptionSelectors(const Aws::Map<Aws::String, CaptionSelector>& value) { m_captionSelectorsHasBeenSet = true; m_captionSelectors = value; }
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline void SetCaptionSelectors(Aws::Map<Aws::String, CaptionSelector>&& value) { m_captionSelectorsHasBeenSet = true; m_captionSelectors = std::move(value); }
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline InputTemplate& WithCaptionSelectors(const Aws::Map<Aws::String, CaptionSelector>& value) { SetCaptionSelectors(value); return *this;}
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline InputTemplate& WithCaptionSelectors(Aws::Map<Aws::String, CaptionSelector>&& value) { SetCaptionSelectors(std::move(value)); return *this;}
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline InputTemplate& AddCaptionSelectors(const Aws::String& key, const CaptionSelector& value) { m_captionSelectorsHasBeenSet = true; m_captionSelectors.emplace(key, value); return *this; }
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline InputTemplate& AddCaptionSelectors(Aws::String&& key, const CaptionSelector& value) { m_captionSelectorsHasBeenSet = true; m_captionSelectors.emplace(std::move(key), value); return *this; }
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline InputTemplate& AddCaptionSelectors(const Aws::String& key, CaptionSelector&& value) { m_captionSelectorsHasBeenSet = true; m_captionSelectors.emplace(key, std::move(value)); return *this; }
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline InputTemplate& AddCaptionSelectors(Aws::String&& key, CaptionSelector&& value) { m_captionSelectorsHasBeenSet = true; m_captionSelectors.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline InputTemplate& AddCaptionSelectors(const char* key, CaptionSelector&& value) { m_captionSelectorsHasBeenSet = true; m_captionSelectors.emplace(key, std::move(value)); return *this; }
 
     /**
-     * Use captions selectors to specify the captions data from your input that you use
-     * in your outputs. You can use up to 20 captions selectors per input.
+     * Use Captions selectors (CaptionSelectors) to specify the captions data from the
+     * input that you will use in your outputs. You can use mutiple captions selectors
+     * per input.
      */
     inline InputTemplate& AddCaptionSelectors(const char* key, const CaptionSelector& value) { m_captionSelectorsHasBeenSet = true; m_captionSelectors.emplace(key, value); return *this; }
 
 
-    /**
-     * Use Cropping selection (crop) to specify the video area that the service will
-     * include in the output video frame. If you specify a value here, it will override
-     * any value that you specify in the output setting Cropping selection (crop).
-     */
-    inline const Rectangle& GetCrop() const{ return m_crop; }
-
-    /**
-     * Use Cropping selection (crop) to specify the video area that the service will
-     * include in the output video frame. If you specify a value here, it will override
-     * any value that you specify in the output setting Cropping selection (crop).
-     */
-    inline bool CropHasBeenSet() const { return m_cropHasBeenSet; }
-
-    /**
-     * Use Cropping selection (crop) to specify the video area that the service will
-     * include in the output video frame. If you specify a value here, it will override
-     * any value that you specify in the output setting Cropping selection (crop).
-     */
-    inline void SetCrop(const Rectangle& value) { m_cropHasBeenSet = true; m_crop = value; }
-
-    /**
-     * Use Cropping selection (crop) to specify the video area that the service will
-     * include in the output video frame. If you specify a value here, it will override
-     * any value that you specify in the output setting Cropping selection (crop).
-     */
-    inline void SetCrop(Rectangle&& value) { m_cropHasBeenSet = true; m_crop = std::move(value); }
-
-    /**
-     * Use Cropping selection (crop) to specify the video area that the service will
-     * include in the output video frame. If you specify a value here, it will override
-     * any value that you specify in the output setting Cropping selection (crop).
-     */
-    inline InputTemplate& WithCrop(const Rectangle& value) { SetCrop(value); return *this;}
-
-    /**
-     * Use Cropping selection (crop) to specify the video area that the service will
-     * include in the output video frame. If you specify a value here, it will override
-     * any value that you specify in the output setting Cropping selection (crop).
-     */
-    inline InputTemplate& WithCrop(Rectangle&& value) { SetCrop(std::move(value)); return *this;}
-
-
     /**
      * Enable Deblock (InputDeblockFilter) to produce smoother motion in the output.
-     * Default is disabled. Only manually controllable for MPEG2 and uncompressed video
+     * Default is disabled. Only manaully controllable for MPEG2 and uncompressed video
      * inputs.
      */
     inline const InputDeblockFilter& GetDeblockFilter() const{ return m_deblockFilter; }
 
     /**
      * Enable Deblock (InputDeblockFilter) to produce smoother motion in the output.
-     * Default is disabled. Only manually controllable for MPEG2 and uncompressed video
+     * Default is disabled. Only manaully controllable for MPEG2 and uncompressed video
      * inputs.
      */
     inline bool DeblockFilterHasBeenSet() const { return m_deblockFilterHasBeenSet; }
 
     /**
      * Enable Deblock (InputDeblockFilter) to produce smoother motion in the output.
-     * Default is disabled. Only manually controllable for MPEG2 and uncompressed video
+     * Default is disabled. Only manaully controllable for MPEG2 and uncompressed video
      * inputs.
      */
     inline void SetDeblockFilter(const InputDeblockFilter& value) { m_deblockFilterHasBeenSet = true; m_deblockFilter = value; }
 
     /**
      * Enable Deblock (InputDeblockFilter) to produce smoother motion in the output.
-     * Default is disabled. Only manually controllable for MPEG2 and uncompressed video
+     * Default is disabled. Only manaully controllable for MPEG2 and uncompressed video
      * inputs.
      */
     inline void SetDeblockFilter(InputDeblockFilter&& value) { m_deblockFilterHasBeenSet = true; m_deblockFilter = std::move(value); }
 
     /**
      * Enable Deblock (InputDeblockFilter) to produce smoother motion in the output.
-     * Default is disabled. Only manually controllable for MPEG2 and uncompressed video
+     * Default is disabled. Only manaully controllable for MPEG2 and uncompressed video
      * inputs.
      */
     inline InputTemplate& WithDeblockFilter(const InputDeblockFilter& value) { SetDeblockFilter(value); return *this;}
 
     /**
      * Enable Deblock (InputDeblockFilter) to produce smoother motion in the output.
-     * Default is disabled. Only manually controllable for MPEG2 and uncompressed video
+     * Default is disabled. Only manaully controllable for MPEG2 and uncompressed video
      * inputs.
      */
     inline InputTemplate& WithDeblockFilter(InputDeblockFilter&& value) { SetDeblockFilter(std::move(value)); return *this;}
@@ -633,79 +611,6 @@ namespace Model
     inline InputTemplate& AddInputClippings(InputClipping&& value) { m_inputClippingsHasBeenSet = true; m_inputClippings.push_back(std::move(value)); return *this; }
 
 
-    /**
-     * Use Selection placement (position) to define the video area in your output
-     * frame. The area outside of the rectangle that you specify here is black. If you
-     * specify a value here, it will override any value that you specify in the output
-     * setting Selection placement (position). If you specify a value here, this will
-     * override any AFD values in your input, even if you set Respond to AFD
-     * (RespondToAfd) to Respond (RESPOND). If you specify a value here, this will
-     * ignore anything that you specify for the setting Scaling Behavior
-     * (scalingBehavior).
-     */
-    inline const Rectangle& GetPosition() const{ return m_position; }
-
-    /**
-     * Use Selection placement (position) to define the video area in your output
-     * frame. The area outside of the rectangle that you specify here is black. If you
-     * specify a value here, it will override any value that you specify in the output
-     * setting Selection placement (position). If you specify a value here, this will
-     * override any AFD values in your input, even if you set Respond to AFD
-     * (RespondToAfd) to Respond (RESPOND). If you specify a value here, this will
-     * ignore anything that you specify for the setting Scaling Behavior
-     * (scalingBehavior).
-     */
-    inline bool PositionHasBeenSet() const { return m_positionHasBeenSet; }
-
-    /**
-     * Use Selection placement (position) to define the video area in your output
-     * frame. The area outside of the rectangle that you specify here is black. If you
-     * specify a value here, it will override any value that you specify in the output
-     * setting Selection placement (position). If you specify a value here, this will
-     * override any AFD values in your input, even if you set Respond to AFD
-     * (RespondToAfd) to Respond (RESPOND). If you specify a value here, this will
-     * ignore anything that you specify for the setting Scaling Behavior
-     * (scalingBehavior).
-     */
-    inline void SetPosition(const Rectangle& value) { m_positionHasBeenSet = true; m_position = value; }
-
-    /**
-     * Use Selection placement (position) to define the video area in your output
-     * frame. The area outside of the rectangle that you specify here is black. If you
-     * specify a value here, it will override any value that you specify in the output
-     * setting Selection placement (position). If you specify a value here, this will
-     * override any AFD values in your input, even if you set Respond to AFD
-     * (RespondToAfd) to Respond (RESPOND). If you specify a value here, this will
-     * ignore anything that you specify for the setting Scaling Behavior
-     * (scalingBehavior).
-     */
-    inline void SetPosition(Rectangle&& value) { m_positionHasBeenSet = true; m_position = std::move(value); }
-
-    /**
-     * Use Selection placement (position) to define the video area in your output
-     * frame. The area outside of the rectangle that you specify here is black. If you
-     * specify a value here, it will override any value that you specify in the output
-     * setting Selection placement (position). If you specify a value here, this will
-     * override any AFD values in your input, even if you set Respond to AFD
-     * (RespondToAfd) to Respond (RESPOND). If you specify a value here, this will
-     * ignore anything that you specify for the setting Scaling Behavior
-     * (scalingBehavior).
-     */
-    inline InputTemplate& WithPosition(const Rectangle& value) { SetPosition(value); return *this;}
-
-    /**
-     * Use Selection placement (position) to define the video area in your output
-     * frame. The area outside of the rectangle that you specify here is black. If you
-     * specify a value here, it will override any value that you specify in the output
-     * setting Selection placement (position). If you specify a value here, this will
-     * override any AFD values in your input, even if you set Respond to AFD
-     * (RespondToAfd) to Respond (RESPOND). If you specify a value here, this will
-     * ignore anything that you specify for the setting Scaling Behavior
-     * (scalingBehavior).
-     */
-    inline InputTemplate& WithPosition(Rectangle&& value) { SetPosition(std::move(value)); return *this;}
-
-
     /**
      * Use Program (programNumber) to select a specific program from within a
      * multi-program transport stream. Note that Quad 4K is not currently supported.
@@ -783,169 +688,72 @@ namespace Model
 
 
     /**
-     * Use this Timecode source setting, located under the input settings
-     * (InputTimecodeSource), to specify how the service counts input video frames.
-     * This input frame count affects only the behavior of features that apply to a
-     * single input at a time, such as input clipping and synchronizing some captions
-     * formats. Choose Embedded (EMBEDDED) to use the timecodes in your input video.
-     * Choose Start at zero (ZEROBASED) to start the first frame at zero. Choose
-     * Specified start (SPECIFIEDSTART) to start the first frame at the timecode that
-     * you specify in the setting Start timecode (timecodeStart). If you don't specify
-     * a value for Timecode source, the service will use Embedded by default. For more
-     * information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
+     * Timecode source under input settings (InputTimecodeSource) only affects the
+     * behavior of features that apply to a single input at a time, such as input
+     * clipping and synchronizing some captions formats. Use this setting to specify
+     * whether the service counts frames by timecodes embedded in the video (EMBEDDED)
+     * or by starting the first frame at zero (ZEROBASED). In both cases, the timecode
+     * format is HH:MM:SS:FF or HH:MM:SS;FF, where FF is the frame number. Only set
+     * this to EMBEDDED if your source video has embedded timecodes.
      */
     inline const InputTimecodeSource& GetTimecodeSource() const{ return m_timecodeSource; }
 
     /**
-     * Use this Timecode source setting, located under the input settings
-     * (InputTimecodeSource), to specify how the service counts input video frames.
-     * This input frame count affects only the behavior of features that apply to a
-     * single input at a time, such as input clipping and synchronizing some captions
-     * formats. Choose Embedded (EMBEDDED) to use the timecodes in your input video.
-     * Choose Start at zero (ZEROBASED) to start the first frame at zero. Choose
-     * Specified start (SPECIFIEDSTART) to start the first frame at the timecode that
-     * you specify in the setting Start timecode (timecodeStart). If you don't specify
-     * a value for Timecode source, the service will use Embedded by default. For more
-     * information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
+     * Timecode source under input settings (InputTimecodeSource) only affects the
+     * behavior of features that apply to a single input at a time, such as input
+     * clipping and synchronizing some captions formats. Use this setting to specify
+     * whether the service counts frames by timecodes embedded in the video (EMBEDDED)
+     * or by starting the first frame at zero (ZEROBASED). In both cases, the timecode
+     * format is HH:MM:SS:FF or HH:MM:SS;FF, where FF is the frame number. Only set
+     * this to EMBEDDED if your source video has embedded timecodes.
      */
     inline bool TimecodeSourceHasBeenSet() const { return m_timecodeSourceHasBeenSet; }
 
     /**
-     * Use this Timecode source setting, located under the input settings
-     * (InputTimecodeSource), to specify how the service counts input video frames.
-     * This input frame count affects only the behavior of features that apply to a
-     * single input at a time, such as input clipping and synchronizing some captions
-     * formats. Choose Embedded (EMBEDDED) to use the timecodes in your input video.
-     * Choose Start at zero (ZEROBASED) to start the first frame at zero. Choose
-     * Specified start (SPECIFIEDSTART) to start the first frame at the timecode that
-     * you specify in the setting Start timecode (timecodeStart). If you don't specify
-     * a value for Timecode source, the service will use Embedded by default. For more
-     * information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
+     * Timecode source under input settings (InputTimecodeSource) only affects the
+     * behavior of features that apply to a single input at a time, such as input
+     * clipping and synchronizing some captions formats. Use this setting to specify
+     * whether the service counts frames by timecodes embedded in the video (EMBEDDED)
+     * or by starting the first frame at zero (ZEROBASED). In both cases, the timecode
+     * format is HH:MM:SS:FF or HH:MM:SS;FF, where FF is the frame number. Only set
+     * this to EMBEDDED if your source video has embedded timecodes.
      */
     inline void SetTimecodeSource(const InputTimecodeSource& value) { m_timecodeSourceHasBeenSet = true; m_timecodeSource = value; }
 
     /**
-     * Use this Timecode source setting, located under the input settings
-     * (InputTimecodeSource), to specify how the service counts input video frames.
-     * This input frame count affects only the behavior of features that apply to a
-     * single input at a time, such as input clipping and synchronizing some captions
-     * formats. Choose Embedded (EMBEDDED) to use the timecodes in your input video.
-     * Choose Start at zero (ZEROBASED) to start the first frame at zero. Choose
-     * Specified start (SPECIFIEDSTART) to start the first frame at the timecode that
-     * you specify in the setting Start timecode (timecodeStart). If you don't specify
-     * a value for Timecode source, the service will use Embedded by default. For more
-     * information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
+     * Timecode source under input settings (InputTimecodeSource) only affects the
+     * behavior of features that apply to a single input at a time, such as input
+     * clipping and synchronizing some captions formats. Use this setting to specify
+     * whether the service counts frames by timecodes embedded in the video (EMBEDDED)
+     * or by starting the first frame at zero (ZEROBASED). In both cases, the timecode
+     * format is HH:MM:SS:FF or HH:MM:SS;FF, where FF is the frame number. Only set
+     * this to EMBEDDED if your source video has embedded timecodes.
      */
     inline void SetTimecodeSource(InputTimecodeSource&& value) { m_timecodeSourceHasBeenSet = true; m_timecodeSource = std::move(value); }
 
     /**
-     * Use this Timecode source setting, located under the input settings
-     * (InputTimecodeSource), to specify how the service counts input video frames.
-     * This input frame count affects only the behavior of features that apply to a
-     * single input at a time, such as input clipping and synchronizing some captions
-     * formats. Choose Embedded (EMBEDDED) to use the timecodes in your input video.
-     * Choose Start at zero (ZEROBASED) to start the first frame at zero. Choose
-     * Specified start (SPECIFIEDSTART) to start the first frame at the timecode that
-     * you specify in the setting Start timecode (timecodeStart). If you don't specify
-     * a value for Timecode source, the service will use Embedded by default. For more
-     * information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
+     * Timecode source under input settings (InputTimecodeSource) only affects the
+     * behavior of features that apply to a single input at a time, such as input
+     * clipping and synchronizing some captions formats. Use this setting to specify
+     * whether the service counts frames by timecodes embedded in the video (EMBEDDED)
+     * or by starting the first frame at zero (ZEROBASED). In both cases, the timecode
+     * format is HH:MM:SS:FF or HH:MM:SS;FF, where FF is the frame number. Only set
+     * this to EMBEDDED if your source video has embedded timecodes.
      */
     inline InputTemplate& WithTimecodeSource(const InputTimecodeSource& value) { SetTimecodeSource(value); return *this;}
 
     /**
-     * Use this Timecode source setting, located under the input settings
-     * (InputTimecodeSource), to specify how the service counts input video frames.
-     * This input frame count affects only the behavior of features that apply to a
-     * single input at a time, such as input clipping and synchronizing some captions
-     * formats. Choose Embedded (EMBEDDED) to use the timecodes in your input video.
-     * Choose Start at zero (ZEROBASED) to start the first frame at zero. Choose
-     * Specified start (SPECIFIEDSTART) to start the first frame at the timecode that
-     * you specify in the setting Start timecode (timecodeStart). If you don't specify
-     * a value for Timecode source, the service will use Embedded by default. For more
-     * information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
+     * Timecode source under input settings (InputTimecodeSource) only affects the
+     * behavior of features that apply to a single input at a time, such as input
+     * clipping and synchronizing some captions formats. Use this setting to specify
+     * whether the service counts frames by timecodes embedded in the video (EMBEDDED)
+     * or by starting the first frame at zero (ZEROBASED). In both cases, the timecode
+     * format is HH:MM:SS:FF or HH:MM:SS;FF, where FF is the frame number. Only set
+     * this to EMBEDDED if your source video has embedded timecodes.
      */
     inline InputTemplate& WithTimecodeSource(InputTimecodeSource&& value) { SetTimecodeSource(std::move(value)); return *this;}
 
 
-    /**
-     * Specify the timecode that you want the service to use for this input's initial
-     * frame. To use this setting, you must set the Timecode source setting, located
-     * under the input settings (InputTimecodeSource), to Specified start
-     * (SPECIFIEDSTART). For more information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
-     */
-    inline const Aws::String& GetTimecodeStart() const{ return m_timecodeStart; }
-
-    /**
-     * Specify the timecode that you want the service to use for this input's initial
-     * frame. To use this setting, you must set the Timecode source setting, located
-     * under the input settings (InputTimecodeSource), to Specified start
-     * (SPECIFIEDSTART). For more information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
-     */
-    inline bool TimecodeStartHasBeenSet() const { return m_timecodeStartHasBeenSet; }
-
-    /**
-     * Specify the timecode that you want the service to use for this input's initial
-     * frame. To use this setting, you must set the Timecode source setting, located
-     * under the input settings (InputTimecodeSource), to Specified start
-     * (SPECIFIEDSTART). For more information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
-     */
-    inline void SetTimecodeStart(const Aws::String& value) { m_timecodeStartHasBeenSet = true; m_timecodeStart = value; }
-
-    /**
-     * Specify the timecode that you want the service to use for this input's initial
-     * frame. To use this setting, you must set the Timecode source setting, located
-     * under the input settings (InputTimecodeSource), to Specified start
-     * (SPECIFIEDSTART). For more information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
-     */
-    inline void SetTimecodeStart(Aws::String&& value) { m_timecodeStartHasBeenSet = true; m_timecodeStart = std::move(value); }
-
-    /**
-     * Specify the timecode that you want the service to use for this input's initial
-     * frame. To use this setting, you must set the Timecode source setting, located
-     * under the input settings (InputTimecodeSource), to Specified start
-     * (SPECIFIEDSTART). For more information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
-     */
-    inline void SetTimecodeStart(const char* value) { m_timecodeStartHasBeenSet = true; m_timecodeStart.assign(value); }
-
-    /**
-     * Specify the timecode that you want the service to use for this input's initial
-     * frame. To use this setting, you must set the Timecode source setting, located
-     * under the input settings (InputTimecodeSource), to Specified start
-     * (SPECIFIEDSTART). For more information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
-     */
-    inline InputTemplate& WithTimecodeStart(const Aws::String& value) { SetTimecodeStart(value); return *this;}
-
-    /**
-     * Specify the timecode that you want the service to use for this input's initial
-     * frame. To use this setting, you must set the Timecode source setting, located
-     * under the input settings (InputTimecodeSource), to Specified start
-     * (SPECIFIEDSTART). For more information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
-     */
-    inline InputTemplate& WithTimecodeStart(Aws::String&& value) { SetTimecodeStart(std::move(value)); return *this;}
-
-    /**
-     * Specify the timecode that you want the service to use for this input's initial
-     * frame. To use this setting, you must set the Timecode source setting, located
-     * under the input settings (InputTimecodeSource), to Specified start
-     * (SPECIFIEDSTART). For more information about timecodes, see
-     * https://docs.aws.amazon.com/console/mediaconvert/timecode.
-     */
-    inline InputTemplate& WithTimecodeStart(const char* value) { SetTimecodeStart(value); return *this;}
-
-
     /**
      * Selector for video.
      */
@@ -987,9 +795,6 @@ namespace Model
     Aws::Map<Aws::String, CaptionSelector> m_captionSelectors;
     bool m_captionSelectorsHasBeenSet;
 
-    Rectangle m_crop;
-    bool m_cropHasBeenSet;
-
     InputDeblockFilter m_deblockFilter;
     bool m_deblockFilterHasBeenSet;
 
@@ -1008,9 +813,6 @@ namespace Model
     Aws::Vector<InputClipping> m_inputClippings;
     bool m_inputClippingsHasBeenSet;
 
-    Rectangle m_position;
-    bool m_positionHasBeenSet;
-
     int m_programNumber;
     bool m_programNumberHasBeenSet;
 
@@ -1020,9 +822,6 @@ namespace Model
     InputTimecodeSource m_timecodeSource;
     bool m_timecodeSourceHasBeenSet;
 
-    Aws::String m_timecodeStart;
-    bool m_timecodeStartHasBeenSet;
-
     VideoSelector m_videoSelector;
     bool m_videoSelectorHasBeenSet;
   };
