@@ -1,27 +1,32 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediaconvert/MediaConvert_EXPORTS.h>
 #include <aws/mediaconvert/model/AccelerationSettings.h>
-#include <aws/mediaconvert/model/AccelerationStatus.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/mediaconvert/model/BillingTagsSource.h>
 #include <aws/core/utils/DateTime.h>
 #include <aws/mediaconvert/model/JobPhase.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/mediaconvert/model/JobMessages.h>
 #include <aws/mediaconvert/model/JobSettings.h>
-#include <aws/mediaconvert/model/SimulateReservedQueue.h>
 #include <aws/mediaconvert/model/JobStatus.h>
 #include <aws/mediaconvert/model/StatusUpdateInterval.h>
 #include <aws/mediaconvert/model/Timing.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
-#include <aws/mediaconvert/model/HopDestination.h>
 #include <aws/mediaconvert/model/OutputGroupDetail.h>
-#include <aws/mediaconvert/model/QueueTransition.h>
 #include <utility>
 
 namespace Aws
@@ -57,133 +62,42 @@ namespace Model
 
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline const AccelerationSettings& GetAccelerationSettings() const{ return m_accelerationSettings; }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline bool AccelerationSettingsHasBeenSet() const { return m_accelerationSettingsHasBeenSet; }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline void SetAccelerationSettings(const AccelerationSettings& value) { m_accelerationSettingsHasBeenSet = true; m_accelerationSettings = value; }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline void SetAccelerationSettings(AccelerationSettings&& value) { m_accelerationSettingsHasBeenSet = true; m_accelerationSettings = std::move(value); }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline Job& WithAccelerationSettings(const AccelerationSettings& value) { SetAccelerationSettings(value); return *this;}
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline Job& WithAccelerationSettings(AccelerationSettings&& value) { SetAccelerationSettings(std::move(value)); return *this;}
 
 
-    /**
-     * Describes whether the current job is running with accelerated transcoding. For
-     * jobs that have Acceleration (AccelerationMode) set to DISABLED,
-     * AccelerationStatus is always NOT_APPLICABLE. For jobs that have Acceleration
-     * (AccelerationMode) set to ENABLED or PREFERRED, AccelerationStatus is one of the
-     * other states. AccelerationStatus is IN_PROGRESS initially, while the service
-     * determines whether the input files and job settings are compatible with
-     * accelerated transcoding. If they are, AcclerationStatus is ACCELERATED. If your
-     * input files and job settings aren't compatible with accelerated transcoding, the
-     * service either fails your job or runs it without accelerated transcoding,
-     * depending on how you set Acceleration (AccelerationMode). When the service runs
-     * your job without accelerated transcoding, AccelerationStatus is NOT_ACCELERATED.
-     */
-    inline const AccelerationStatus& GetAccelerationStatus() const{ return m_accelerationStatus; }
-
-    /**
-     * Describes whether the current job is running with accelerated transcoding. For
-     * jobs that have Acceleration (AccelerationMode) set to DISABLED,
-     * AccelerationStatus is always NOT_APPLICABLE. For jobs that have Acceleration
-     * (AccelerationMode) set to ENABLED or PREFERRED, AccelerationStatus is one of the
-     * other states. AccelerationStatus is IN_PROGRESS initially, while the service
-     * determines whether the input files and job settings are compatible with
-     * accelerated transcoding. If they are, AcclerationStatus is ACCELERATED. If your
-     * input files and job settings aren't compatible with accelerated transcoding, the
-     * service either fails your job or runs it without accelerated transcoding,
-     * depending on how you set Acceleration (AccelerationMode). When the service runs
-     * your job without accelerated transcoding, AccelerationStatus is NOT_ACCELERATED.
-     */
-    inline bool AccelerationStatusHasBeenSet() const { return m_accelerationStatusHasBeenSet; }
-
-    /**
-     * Describes whether the current job is running with accelerated transcoding. For
-     * jobs that have Acceleration (AccelerationMode) set to DISABLED,
-     * AccelerationStatus is always NOT_APPLICABLE. For jobs that have Acceleration
-     * (AccelerationMode) set to ENABLED or PREFERRED, AccelerationStatus is one of the
-     * other states. AccelerationStatus is IN_PROGRESS initially, while the service
-     * determines whether the input files and job settings are compatible with
-     * accelerated transcoding. If they are, AcclerationStatus is ACCELERATED. If your
-     * input files and job settings aren't compatible with accelerated transcoding, the
-     * service either fails your job or runs it without accelerated transcoding,
-     * depending on how you set Acceleration (AccelerationMode). When the service runs
-     * your job without accelerated transcoding, AccelerationStatus is NOT_ACCELERATED.
-     */
-    inline void SetAccelerationStatus(const AccelerationStatus& value) { m_accelerationStatusHasBeenSet = true; m_accelerationStatus = value; }
-
-    /**
-     * Describes whether the current job is running with accelerated transcoding. For
-     * jobs that have Acceleration (AccelerationMode) set to DISABLED,
-     * AccelerationStatus is always NOT_APPLICABLE. For jobs that have Acceleration
-     * (AccelerationMode) set to ENABLED or PREFERRED, AccelerationStatus is one of the
-     * other states. AccelerationStatus is IN_PROGRESS initially, while the service
-     * determines whether the input files and job settings are compatible with
-     * accelerated transcoding. If they are, AcclerationStatus is ACCELERATED. If your
-     * input files and job settings aren't compatible with accelerated transcoding, the
-     * service either fails your job or runs it without accelerated transcoding,
-     * depending on how you set Acceleration (AccelerationMode). When the service runs
-     * your job without accelerated transcoding, AccelerationStatus is NOT_ACCELERATED.
-     */
-    inline void SetAccelerationStatus(AccelerationStatus&& value) { m_accelerationStatusHasBeenSet = true; m_accelerationStatus = std::move(value); }
-
-    /**
-     * Describes whether the current job is running with accelerated transcoding. For
-     * jobs that have Acceleration (AccelerationMode) set to DISABLED,
-     * AccelerationStatus is always NOT_APPLICABLE. For jobs that have Acceleration
-     * (AccelerationMode) set to ENABLED or PREFERRED, AccelerationStatus is one of the
-     * other states. AccelerationStatus is IN_PROGRESS initially, while the service
-     * determines whether the input files and job settings are compatible with
-     * accelerated transcoding. If they are, AcclerationStatus is ACCELERATED. If your
-     * input files and job settings aren't compatible with accelerated transcoding, the
-     * service either fails your job or runs it without accelerated transcoding,
-     * depending on how you set Acceleration (AccelerationMode). When the service runs
-     * your job without accelerated transcoding, AccelerationStatus is NOT_ACCELERATED.
-     */
-    inline Job& WithAccelerationStatus(const AccelerationStatus& value) { SetAccelerationStatus(value); return *this;}
-
-    /**
-     * Describes whether the current job is running with accelerated transcoding. For
-     * jobs that have Acceleration (AccelerationMode) set to DISABLED,
-     * AccelerationStatus is always NOT_APPLICABLE. For jobs that have Acceleration
-     * (AccelerationMode) set to ENABLED or PREFERRED, AccelerationStatus is one of the
-     * other states. AccelerationStatus is IN_PROGRESS initially, while the service
-     * determines whether the input files and job settings are compatible with
-     * accelerated transcoding. If they are, AcclerationStatus is ACCELERATED. If your
-     * input files and job settings aren't compatible with accelerated transcoding, the
-     * service either fails your job or runs it without accelerated transcoding,
-     * depending on how you set Acceleration (AccelerationMode). When the service runs
-     * your job without accelerated transcoding, AccelerationStatus is NOT_ACCELERATED.
-     */
-    inline Job& WithAccelerationStatus(AccelerationStatus&& value) { SetAccelerationStatus(std::move(value)); return *this;}
-
-
     /**
      * An identifier for this resource that is unique within all of AWS.
      */
@@ -226,38 +140,56 @@ namespace Model
 
 
     /**
-     * The tag type that AWS Billing and Cost Management will use to sort your AWS
-     * Elemental MediaConvert costs on any billing report that you set up.
+     * Optional. Choose a tag type that AWS Billing and Cost Management will use to
+     * sort your AWS Elemental MediaConvert costs on any billing report that you set
+     * up. Any transcoding outputs that don't have an associated tag will appear in
+     * your billing report unsorted. If you don't choose a valid value for this field,
+     * your job outputs will appear on the billing report unsorted.
      */
     inline const BillingTagsSource& GetBillingTagsSource() const{ return m_billingTagsSource; }
 
     /**
-     * The tag type that AWS Billing and Cost Management will use to sort your AWS
-     * Elemental MediaConvert costs on any billing report that you set up.
+     * Optional. Choose a tag type that AWS Billing and Cost Management will use to
+     * sort your AWS Elemental MediaConvert costs on any billing report that you set
+     * up. Any transcoding outputs that don't have an associated tag will appear in
+     * your billing report unsorted. If you don't choose a valid value for this field,
+     * your job outputs will appear on the billing report unsorted.
      */
     inline bool BillingTagsSourceHasBeenSet() const { return m_billingTagsSourceHasBeenSet; }
 
     /**
-     * The tag type that AWS Billing and Cost Management will use to sort your AWS
-     * Elemental MediaConvert costs on any billing report that you set up.
+     * Optional. Choose a tag type that AWS Billing and Cost Management will use to
+     * sort your AWS Elemental MediaConvert costs on any billing report that you set
+     * up. Any transcoding outputs that don't have an associated tag will appear in
+     * your billing report unsorted. If you don't choose a valid value for this field,
+     * your job outputs will appear on the billing report unsorted.
      */
     inline void SetBillingTagsSource(const BillingTagsSource& value) { m_billingTagsSourceHasBeenSet = true; m_billingTagsSource = value; }
 
     /**
-     * The tag type that AWS Billing and Cost Management will use to sort your AWS
-     * Elemental MediaConvert costs on any billing report that you set up.
+     * Optional. Choose a tag type that AWS Billing and Cost Management will use to
+     * sort your AWS Elemental MediaConvert costs on any billing report that you set
+     * up. Any transcoding outputs that don't have an associated tag will appear in
+     * your billing report unsorted. If you don't choose a valid value for this field,
+     * your job outputs will appear on the billing report unsorted.
      */
     inline void SetBillingTagsSource(BillingTagsSource&& value) { m_billingTagsSourceHasBeenSet = true; m_billingTagsSource = std::move(value); }
 
     /**
-     * The tag type that AWS Billing and Cost Management will use to sort your AWS
-     * Elemental MediaConvert costs on any billing report that you set up.
+     * Optional. Choose a tag type that AWS Billing and Cost Management will use to
+     * sort your AWS Elemental MediaConvert costs on any billing report that you set
+     * up. Any transcoding outputs that don't have an associated tag will appear in
+     * your billing report unsorted. If you don't choose a valid value for this field,
+     * your job outputs will appear on the billing report unsorted.
      */
     inline Job& WithBillingTagsSource(const BillingTagsSource& value) { SetBillingTagsSource(value); return *this;}
 
     /**
-     * The tag type that AWS Billing and Cost Management will use to sort your AWS
-     * Elemental MediaConvert costs on any billing report that you set up.
+     * Optional. Choose a tag type that AWS Billing and Cost Management will use to
+     * sort your AWS Elemental MediaConvert costs on any billing report that you set
+     * up. Any transcoding outputs that don't have an associated tag will appear in
+     * your billing report unsorted. If you don't choose a valid value for this field,
+     * your job outputs will appear on the billing report unsorted.
      */
     inline Job& WithBillingTagsSource(BillingTagsSource&& value) { SetBillingTagsSource(std::move(value)); return *this;}
 
@@ -386,47 +318,6 @@ namespace Model
     inline Job& WithErrorMessage(const char* value) { SetErrorMessage(value); return *this;}
 
 
-    /**
-     * Optional list of hop destinations.
-     */
-    inline const Aws::Vector<HopDestination>& GetHopDestinations() const{ return m_hopDestinations; }
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline bool HopDestinationsHasBeenSet() const { return m_hopDestinationsHasBeenSet; }
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline void SetHopDestinations(const Aws::Vector<HopDestination>& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations = value; }
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline void SetHopDestinations(Aws::Vector<HopDestination>&& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations = std::move(value); }
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline Job& WithHopDestinations(const Aws::Vector<HopDestination>& value) { SetHopDestinations(value); return *this;}
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline Job& WithHopDestinations(Aws::Vector<HopDestination>&& value) { SetHopDestinations(std::move(value)); return *this;}
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline Job& AddHopDestinations(const HopDestination& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations.push_back(value); return *this; }
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline Job& AddHopDestinations(HopDestination&& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations.push_back(std::move(value)); return *this; }
-
-
     /**
      * A portion of the job's ARN, unique within your AWS Elemental MediaConvert
      * resources
@@ -483,8 +374,9 @@ namespace Model
      * provides jobPercentComplete in CloudWatch STATUS_UPDATE events and in the
      * response to GetJob and ListJobs requests. The jobPercentComplete estimate is
      * reliable for the following input containers: Quicktime, Transport Stream, MP4,
-     * and MXF. For some jobs, the service can't provide information about job
-     * progress. In those cases, jobPercentComplete returns a null value.
+     * and MXF. For some jobs, including audio-only jobs and jobs that use input
+     * clipping, the service can't provide information about job progress. In those
+     * cases, jobPercentComplete returns a null value.
      */
     inline int GetJobPercentComplete() const{ return m_jobPercentComplete; }
 
@@ -495,8 +387,9 @@ namespace Model
      * provides jobPercentComplete in CloudWatch STATUS_UPDATE events and in the
      * response to GetJob and ListJobs requests. The jobPercentComplete estimate is
      * reliable for the following input containers: Quicktime, Transport Stream, MP4,
-     * and MXF. For some jobs, the service can't provide information about job
-     * progress. In those cases, jobPercentComplete returns a null value.
+     * and MXF. For some jobs, including audio-only jobs and jobs that use input
+     * clipping, the service can't provide information about job progress. In those
+     * cases, jobPercentComplete returns a null value.
      */
     inline bool JobPercentCompleteHasBeenSet() const { return m_jobPercentCompleteHasBeenSet; }
 
@@ -507,8 +400,9 @@ namespace Model
      * provides jobPercentComplete in CloudWatch STATUS_UPDATE events and in the
      * response to GetJob and ListJobs requests. The jobPercentComplete estimate is
      * reliable for the following input containers: Quicktime, Transport Stream, MP4,
-     * and MXF. For some jobs, the service can't provide information about job
-     * progress. In those cases, jobPercentComplete returns a null value.
+     * and MXF. For some jobs, including audio-only jobs and jobs that use input
+     * clipping, the service can't provide information about job progress. In those
+     * cases, jobPercentComplete returns a null value.
      */
     inline void SetJobPercentComplete(int value) { m_jobPercentCompleteHasBeenSet = true; m_jobPercentComplete = value; }
 
@@ -519,8 +413,9 @@ namespace Model
      * provides jobPercentComplete in CloudWatch STATUS_UPDATE events and in the
      * response to GetJob and ListJobs requests. The jobPercentComplete estimate is
      * reliable for the following input containers: Quicktime, Transport Stream, MP4,
-     * and MXF. For some jobs, the service can't provide information about job
-     * progress. In those cases, jobPercentComplete returns a null value.
+     * and MXF. For some jobs, including audio-only jobs and jobs that use input
+     * clipping, the service can't provide information about job progress. In those
+     * cases, jobPercentComplete returns a null value.
      */
     inline Job& WithJobPercentComplete(int value) { SetJobPercentComplete(value); return *this;}
 
@@ -574,43 +469,6 @@ namespace Model
     inline Job& WithJobTemplate(const char* value) { SetJobTemplate(value); return *this;}
 
 
-    /**
-     * Provides messages from the service about jobs that you have already successfully
-     * submitted.
-     */
-    inline const JobMessages& GetMessages() const{ return m_messages; }
-
-    /**
-     * Provides messages from the service about jobs that you have already successfully
-     * submitted.
-     */
-    inline bool MessagesHasBeenSet() const { return m_messagesHasBeenSet; }
-
-    /**
-     * Provides messages from the service about jobs that you have already successfully
-     * submitted.
-     */
-    inline void SetMessages(const JobMessages& value) { m_messagesHasBeenSet = true; m_messages = value; }
-
-    /**
-     * Provides messages from the service about jobs that you have already successfully
-     * submitted.
-     */
-    inline void SetMessages(JobMessages&& value) { m_messagesHasBeenSet = true; m_messages = std::move(value); }
-
-    /**
-     * Provides messages from the service about jobs that you have already successfully
-     * submitted.
-     */
-    inline Job& WithMessages(const JobMessages& value) { SetMessages(value); return *this;}
-
-    /**
-     * Provides messages from the service about jobs that you have already successfully
-     * submitted.
-     */
-    inline Job& WithMessages(JobMessages&& value) { SetMessages(std::move(value)); return *this;}
-
-
     /**
      * List of output group details
      */
@@ -653,132 +511,70 @@ namespace Model
 
 
     /**
-     * Relative priority on the job.
-     */
-    inline int GetPriority() const{ return m_priority; }
-
-    /**
-     * Relative priority on the job.
-     */
-    inline bool PriorityHasBeenSet() const { return m_priorityHasBeenSet; }
-
-    /**
-     * Relative priority on the job.
-     */
-    inline void SetPriority(int value) { m_priorityHasBeenSet = true; m_priority = value; }
-
-    /**
-     * Relative priority on the job.
-     */
-    inline Job& WithPriority(int value) { SetPriority(value); return *this;}
-
-
-    /**
-     * When you create a job, you can specify a queue to send it to. If you don't
-     * specify, the job will go to the default queue. For more about queues, see the
-     * User Guide topic at
+     * Optional. When you create a job, you can specify a queue to send it to. If you
+     * don't specify, the job will go to the default queue. For more about queues, see
+     * the User Guide topic at
      * http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
      */
     inline const Aws::String& GetQueue() const{ return m_queue; }
 
     /**
-     * When you create a job, you can specify a queue to send it to. If you don't
-     * specify, the job will go to the default queue. For more about queues, see the
-     * User Guide topic at
+     * Optional. When you create a job, you can specify a queue to send it to. If you
+     * don't specify, the job will go to the default queue. For more about queues, see
+     * the User Guide topic at
      * http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
      */
     inline bool QueueHasBeenSet() const { return m_queueHasBeenSet; }
 
     /**
-     * When you create a job, you can specify a queue to send it to. If you don't
-     * specify, the job will go to the default queue. For more about queues, see the
-     * User Guide topic at
+     * Optional. When you create a job, you can specify a queue to send it to. If you
+     * don't specify, the job will go to the default queue. For more about queues, see
+     * the User Guide topic at
      * http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
      */
     inline void SetQueue(const Aws::String& value) { m_queueHasBeenSet = true; m_queue = value; }
 
     /**
-     * When you create a job, you can specify a queue to send it to. If you don't
-     * specify, the job will go to the default queue. For more about queues, see the
-     * User Guide topic at
+     * Optional. When you create a job, you can specify a queue to send it to. If you
+     * don't specify, the job will go to the default queue. For more about queues, see
+     * the User Guide topic at
      * http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
      */
     inline void SetQueue(Aws::String&& value) { m_queueHasBeenSet = true; m_queue = std::move(value); }
 
     /**
-     * When you create a job, you can specify a queue to send it to. If you don't
-     * specify, the job will go to the default queue. For more about queues, see the
-     * User Guide topic at
+     * Optional. When you create a job, you can specify a queue to send it to. If you
+     * don't specify, the job will go to the default queue. For more about queues, see
+     * the User Guide topic at
      * http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
      */
     inline void SetQueue(const char* value) { m_queueHasBeenSet = true; m_queue.assign(value); }
 
     /**
-     * When you create a job, you can specify a queue to send it to. If you don't
-     * specify, the job will go to the default queue. For more about queues, see the
-     * User Guide topic at
+     * Optional. When you create a job, you can specify a queue to send it to. If you
+     * don't specify, the job will go to the default queue. For more about queues, see
+     * the User Guide topic at
      * http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
      */
     inline Job& WithQueue(const Aws::String& value) { SetQueue(value); return *this;}
 
     /**
-     * When you create a job, you can specify a queue to send it to. If you don't
-     * specify, the job will go to the default queue. For more about queues, see the
-     * User Guide topic at
+     * Optional. When you create a job, you can specify a queue to send it to. If you
+     * don't specify, the job will go to the default queue. For more about queues, see
+     * the User Guide topic at
      * http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
      */
     inline Job& WithQueue(Aws::String&& value) { SetQueue(std::move(value)); return *this;}
 
     /**
-     * When you create a job, you can specify a queue to send it to. If you don't
-     * specify, the job will go to the default queue. For more about queues, see the
-     * User Guide topic at
+     * Optional. When you create a job, you can specify a queue to send it to. If you
+     * don't specify, the job will go to the default queue. For more about queues, see
+     * the User Guide topic at
      * http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html
      */
     inline Job& WithQueue(const char* value) { SetQueue(value); return *this;}
 
 
-    /**
-     * The job's queue hopping history.
-     */
-    inline const Aws::Vector<QueueTransition>& GetQueueTransitions() const{ return m_queueTransitions; }
-
-    /**
-     * The job's queue hopping history.
-     */
-    inline bool QueueTransitionsHasBeenSet() const { return m_queueTransitionsHasBeenSet; }
-
-    /**
-     * The job's queue hopping history.
-     */
-    inline void SetQueueTransitions(const Aws::Vector<QueueTransition>& value) { m_queueTransitionsHasBeenSet = true; m_queueTransitions = value; }
-
-    /**
-     * The job's queue hopping history.
-     */
-    inline void SetQueueTransitions(Aws::Vector<QueueTransition>&& value) { m_queueTransitionsHasBeenSet = true; m_queueTransitions = std::move(value); }
-
-    /**
-     * The job's queue hopping history.
-     */
-    inline Job& WithQueueTransitions(const Aws::Vector<QueueTransition>& value) { SetQueueTransitions(value); return *this;}
-
-    /**
-     * The job's queue hopping history.
-     */
-    inline Job& WithQueueTransitions(Aws::Vector<QueueTransition>&& value) { SetQueueTransitions(std::move(value)); return *this;}
-
-    /**
-     * The job's queue hopping history.
-     */
-    inline Job& AddQueueTransitions(const QueueTransition& value) { m_queueTransitionsHasBeenSet = true; m_queueTransitions.push_back(value); return *this; }
-
-    /**
-     * The job's queue hopping history.
-     */
-    inline Job& AddQueueTransitions(QueueTransition&& value) { m_queueTransitionsHasBeenSet = true; m_queueTransitions.push_back(std::move(value)); return *this; }
-
-
     /**
      * The number of times that the service automatically attempted to process your job
      * after encountering an error.
@@ -892,55 +688,6 @@ namespace Model
     inline Job& WithSettings(JobSettings&& value) { SetSettings(std::move(value)); return *this;}
 
 
-    /**
-     * Enable this setting when you run a test job to estimate how many reserved
-     * transcoding slots (RTS) you need. When this is enabled, MediaConvert runs your
-     * job from an on-demand queue with similar performance to what you will see with
-     * one RTS in a reserved queue. This setting is disabled by default.
-     */
-    inline const SimulateReservedQueue& GetSimulateReservedQueue() const{ return m_simulateReservedQueue; }
-
-    /**
-     * Enable this setting when you run a test job to estimate how many reserved
-     * transcoding slots (RTS) you need. When this is enabled, MediaConvert runs your
-     * job from an on-demand queue with similar performance to what you will see with
-     * one RTS in a reserved queue. This setting is disabled by default.
-     */
-    inline bool SimulateReservedQueueHasBeenSet() const { return m_simulateReservedQueueHasBeenSet; }
-
-    /**
-     * Enable this setting when you run a test job to estimate how many reserved
-     * transcoding slots (RTS) you need. When this is enabled, MediaConvert runs your
-     * job from an on-demand queue with similar performance to what you will see with
-     * one RTS in a reserved queue. This setting is disabled by default.
-     */
-    inline void SetSimulateReservedQueue(const SimulateReservedQueue& value) { m_simulateReservedQueueHasBeenSet = true; m_simulateReservedQueue = value; }
-
-    /**
-     * Enable this setting when you run a test job to estimate how many reserved
-     * transcoding slots (RTS) you need. When this is enabled, MediaConvert runs your
-     * job from an on-demand queue with similar performance to what you will see with
-     * one RTS in a reserved queue. This setting is disabled by default.
-     */
-    inline void SetSimulateReservedQueue(SimulateReservedQueue&& value) { m_simulateReservedQueueHasBeenSet = true; m_simulateReservedQueue = std::move(value); }
-
-    /**
-     * Enable this setting when you run a test job to estimate how many reserved
-     * transcoding slots (RTS) you need. When this is enabled, MediaConvert runs your
-     * job from an on-demand queue with similar performance to what you will see with
-     * one RTS in a reserved queue. This setting is disabled by default.
-     */
-    inline Job& WithSimulateReservedQueue(const SimulateReservedQueue& value) { SetSimulateReservedQueue(value); return *this;}
-
-    /**
-     * Enable this setting when you run a test job to estimate how many reserved
-     * transcoding slots (RTS) you need. When this is enabled, MediaConvert runs your
-     * job from an on-demand queue with similar performance to what you will see with
-     * one RTS in a reserved queue. This setting is disabled by default.
-     */
-    inline Job& WithSimulateReservedQueue(SimulateReservedQueue&& value) { SetSimulateReservedQueue(std::move(value)); return *this;}
-
-
     /**
      * A job's status can be SUBMITTED, PROGRESSING, COMPLETE, CANCELED, or ERROR.
      */
@@ -1141,9 +888,6 @@ namespace Model
     AccelerationSettings m_accelerationSettings;
     bool m_accelerationSettingsHasBeenSet;
 
-    AccelerationStatus m_accelerationStatus;
-    bool m_accelerationStatusHasBeenSet;
-
     Aws::String m_arn;
     bool m_arnHasBeenSet;
 
@@ -1162,9 +906,6 @@ namespace Model
     Aws::String m_errorMessage;
     bool m_errorMessageHasBeenSet;
 
-    Aws::Vector<HopDestination> m_hopDestinations;
-    bool m_hopDestinationsHasBeenSet;
-
     Aws::String m_id;
     bool m_idHasBeenSet;
 
@@ -1174,21 +915,12 @@ namespace Model
     Aws::String m_jobTemplate;
     bool m_jobTemplateHasBeenSet;
 
-    JobMessages m_messages;
-    bool m_messagesHasBeenSet;
-
     Aws::Vector<OutputGroupDetail> m_outputGroupDetails;
     bool m_outputGroupDetailsHasBeenSet;
 
-    int m_priority;
-    bool m_priorityHasBeenSet;
-
     Aws::String m_queue;
     bool m_queueHasBeenSet;
 
-    Aws::Vector<QueueTransition> m_queueTransitions;
-    bool m_queueTransitionsHasBeenSet;
-
     int m_retryCount;
     bool m_retryCountHasBeenSet;
 
@@ -1198,9 +930,6 @@ namespace Model
     JobSettings m_settings;
     bool m_settingsHasBeenSet;
 
-    SimulateReservedQueue m_simulateReservedQueue;
-    bool m_simulateReservedQueueHasBeenSet;
-
     JobStatus m_status;
     bool m_statusHasBeenSet;
 
