@@ -1,18 +1,26 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediaconvert/MediaConvert_EXPORTS.h>
 #include <aws/mediaconvert/model/AccelerationSettings.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/DateTime.h>
-#include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/mediaconvert/model/JobTemplateSettings.h>
 #include <aws/mediaconvert/model/StatusUpdateInterval.h>
 #include <aws/mediaconvert/model/Type.h>
-#include <aws/mediaconvert/model/HopDestination.h>
 #include <utility>
 
 namespace Aws
@@ -46,38 +54,38 @@ namespace Model
 
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline const AccelerationSettings& GetAccelerationSettings() const{ return m_accelerationSettings; }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline bool AccelerationSettingsHasBeenSet() const { return m_accelerationSettingsHasBeenSet; }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline void SetAccelerationSettings(const AccelerationSettings& value) { m_accelerationSettingsHasBeenSet = true; m_accelerationSettings = value; }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline void SetAccelerationSettings(AccelerationSettings&& value) { m_accelerationSettingsHasBeenSet = true; m_accelerationSettings = std::move(value); }
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline JobTemplate& WithAccelerationSettings(const AccelerationSettings& value) { SetAccelerationSettings(value); return *this;}
 
     /**
-     * Accelerated transcoding can significantly speed up jobs with long, visually
-     * complex content.
+     * Accelerated transcoding is currently in private preview. Contact AWS for more
+     * information.
      */
     inline JobTemplate& WithAccelerationSettings(AccelerationSettings&& value) { SetAccelerationSettings(std::move(value)); return *this;}
 
@@ -236,47 +244,6 @@ namespace Model
     inline JobTemplate& WithDescription(const char* value) { SetDescription(value); return *this;}
 
 
-    /**
-     * Optional list of hop destinations.
-     */
-    inline const Aws::Vector<HopDestination>& GetHopDestinations() const{ return m_hopDestinations; }
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline bool HopDestinationsHasBeenSet() const { return m_hopDestinationsHasBeenSet; }
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline void SetHopDestinations(const Aws::Vector<HopDestination>& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations = value; }
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline void SetHopDestinations(Aws::Vector<HopDestination>&& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations = std::move(value); }
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline JobTemplate& WithHopDestinations(const Aws::Vector<HopDestination>& value) { SetHopDestinations(value); return *this;}
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline JobTemplate& WithHopDestinations(Aws::Vector<HopDestination>&& value) { SetHopDestinations(std::move(value)); return *this;}
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline JobTemplate& AddHopDestinations(const HopDestination& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations.push_back(value); return *this; }
-
-    /**
-     * Optional list of hop destinations.
-     */
-    inline JobTemplate& AddHopDestinations(HopDestination&& value) { m_hopDestinationsHasBeenSet = true; m_hopDestinations.push_back(std::move(value)); return *this; }
-
-
     /**
      * The timestamp in epoch seconds when the Job template was last updated.
      */
@@ -357,27 +324,6 @@ namespace Model
     inline JobTemplate& WithName(const char* value) { SetName(value); return *this;}
 
 
-    /**
-     * Relative priority on the job.
-     */
-    inline int GetPriority() const{ return m_priority; }
-
-    /**
-     * Relative priority on the job.
-     */
-    inline bool PriorityHasBeenSet() const { return m_priorityHasBeenSet; }
-
-    /**
-     * Relative priority on the job.
-     */
-    inline void SetPriority(int value) { m_priorityHasBeenSet = true; m_priority = value; }
-
-    /**
-     * Relative priority on the job.
-     */
-    inline JobTemplate& WithPriority(int value) { SetPriority(value); return *this;}
-
-
     /**
      * Optional. The queue that jobs created from this template are assigned to. If you
      * don't specify this, jobs will go to the default queue.
@@ -552,43 +498,37 @@ namespace Model
   private:
 
     AccelerationSettings m_accelerationSettings;
-    bool m_accelerationSettingsHasBeenSet = false;
+    bool m_accelerationSettingsHasBeenSet;
 
     Aws::String m_arn;
-    bool m_arnHasBeenSet = false;
+    bool m_arnHasBeenSet;
 
     Aws::String m_category;
-    bool m_categoryHasBeenSet = false;
+    bool m_categoryHasBeenSet;
 
     Aws::Utils::DateTime m_createdAt;
-    bool m_createdAtHasBeenSet = false;
+    bool m_createdAtHasBeenSet;
 
     Aws::String m_description;
-    bool m_descriptionHasBeenSet = false;
-
-    Aws::Vector<HopDestination> m_hopDestinations;
-    bool m_hopDestinationsHasBeenSet = false;
+    bool m_descriptionHasBeenSet;
 
     Aws::Utils::DateTime m_lastUpdated;
-    bool m_lastUpdatedHasBeenSet = false;
+    bool m_lastUpdatedHasBeenSet;
 
     Aws::String m_name;
-    bool m_nameHasBeenSet = false;
-
-    int m_priority;
-    bool m_priorityHasBeenSet = false;
+    bool m_nameHasBeenSet;
 
     Aws::String m_queue;
-    bool m_queueHasBeenSet = false;
+    bool m_queueHasBeenSet;
 
     JobTemplateSettings m_settings;
-    bool m_settingsHasBeenSet = false;
+    bool m_settingsHasBeenSet;
 
     StatusUpdateInterval m_statusUpdateInterval;
-    bool m_statusUpdateIntervalHasBeenSet = false;
+    bool m_statusUpdateIntervalHasBeenSet;
 
     Type m_type;
-    bool m_typeHasBeenSet = false;
+    bool m_typeHasBeenSet;
   };
 
 } // namespace Model
