@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/mediaconvert/model/InputTemplate.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -22,28 +32,22 @@ InputTemplate::InputTemplate() :
     m_audioSelectorGroupsHasBeenSet(false),
     m_audioSelectorsHasBeenSet(false),
     m_captionSelectorsHasBeenSet(false),
-    m_cropHasBeenSet(false),
     m_deblockFilter(InputDeblockFilter::NOT_SET),
     m_deblockFilterHasBeenSet(false),
     m_denoiseFilter(InputDenoiseFilter::NOT_SET),
     m_denoiseFilterHasBeenSet(false),
-    m_dolbyVisionMetadataXmlHasBeenSet(false),
     m_filterEnable(InputFilterEnable::NOT_SET),
     m_filterEnableHasBeenSet(false),
     m_filterStrength(0),
     m_filterStrengthHasBeenSet(false),
     m_imageInserterHasBeenSet(false),
     m_inputClippingsHasBeenSet(false),
-    m_inputScanType(InputScanType::NOT_SET),
-    m_inputScanTypeHasBeenSet(false),
-    m_positionHasBeenSet(false),
     m_programNumber(0),
     m_programNumberHasBeenSet(false),
     m_psiControl(InputPsiControl::NOT_SET),
     m_psiControlHasBeenSet(false),
     m_timecodeSource(InputTimecodeSource::NOT_SET),
     m_timecodeSourceHasBeenSet(false),
-    m_timecodeStartHasBeenSet(false),
     m_videoSelectorHasBeenSet(false)
 {
 }
@@ -52,28 +56,22 @@ InputTemplate::InputTemplate(JsonView jsonValue) :
     m_audioSelectorGroupsHasBeenSet(false),
     m_audioSelectorsHasBeenSet(false),
     m_captionSelectorsHasBeenSet(false),
-    m_cropHasBeenSet(false),
     m_deblockFilter(InputDeblockFilter::NOT_SET),
     m_deblockFilterHasBeenSet(false),
     m_denoiseFilter(InputDenoiseFilter::NOT_SET),
     m_denoiseFilterHasBeenSet(false),
-    m_dolbyVisionMetadataXmlHasBeenSet(false),
     m_filterEnable(InputFilterEnable::NOT_SET),
     m_filterEnableHasBeenSet(false),
     m_filterStrength(0),
     m_filterStrengthHasBeenSet(false),
     m_imageInserterHasBeenSet(false),
     m_inputClippingsHasBeenSet(false),
-    m_inputScanType(InputScanType::NOT_SET),
-    m_inputScanTypeHasBeenSet(false),
-    m_positionHasBeenSet(false),
     m_programNumber(0),
     m_programNumberHasBeenSet(false),
     m_psiControl(InputPsiControl::NOT_SET),
     m_psiControlHasBeenSet(false),
     m_timecodeSource(InputTimecodeSource::NOT_SET),
     m_timecodeSourceHasBeenSet(false),
-    m_timecodeStartHasBeenSet(false),
     m_videoSelectorHasBeenSet(false)
 {
   *this = jsonValue;
@@ -111,13 +109,6 @@ InputTemplate& InputTemplate::operator =(JsonView jsonValue)
     m_captionSelectorsHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("crop"))
-  {
-    m_crop = jsonValue.GetObject("crop");
-
-    m_cropHasBeenSet = true;
-  }
-
   if(jsonValue.ValueExists("deblockFilter"))
   {
     m_deblockFilter = InputDeblockFilterMapper::GetInputDeblockFilterForName(jsonValue.GetString("deblockFilter"));
@@ -132,13 +123,6 @@ InputTemplate& InputTemplate::operator =(JsonView jsonValue)
     m_denoiseFilterHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("dolbyVisionMetadataXml"))
-  {
-    m_dolbyVisionMetadataXml = jsonValue.GetString("dolbyVisionMetadataXml");
-
-    m_dolbyVisionMetadataXmlHasBeenSet = true;
-  }
-
   if(jsonValue.ValueExists("filterEnable"))
   {
     m_filterEnable = InputFilterEnableMapper::GetInputFilterEnableForName(jsonValue.GetString("filterEnable"));
@@ -170,20 +154,6 @@ InputTemplate& InputTemplate::operator =(JsonView jsonValue)
     m_inputClippingsHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("inputScanType"))
-  {
-    m_inputScanType = InputScanTypeMapper::GetInputScanTypeForName(jsonValue.GetString("inputScanType"));
-
-    m_inputScanTypeHasBeenSet = true;
-  }
-
-  if(jsonValue.ValueExists("position"))
-  {
-    m_position = jsonValue.GetObject("position");
-
-    m_positionHasBeenSet = true;
-  }
-
   if(jsonValue.ValueExists("programNumber"))
   {
     m_programNumber = jsonValue.GetInteger("programNumber");
@@ -205,13 +175,6 @@ InputTemplate& InputTemplate::operator =(JsonView jsonValue)
     m_timecodeSourceHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("timecodeStart"))
-  {
-    m_timecodeStart = jsonValue.GetString("timecodeStart");
-
-    m_timecodeStartHasBeenSet = true;
-  }
-
   if(jsonValue.ValueExists("videoSelector"))
   {
     m_videoSelector = jsonValue.GetObject("videoSelector");
@@ -259,12 +222,6 @@ JsonValue InputTemplate::Jsonize() const
 
   }
 
-  if(m_cropHasBeenSet)
-  {
-   payload.WithObject("crop", m_crop.Jsonize());
-
-  }
-
   if(m_deblockFilterHasBeenSet)
   {
    payload.WithString("deblockFilter", InputDeblockFilterMapper::GetNameForInputDeblockFilter(m_deblockFilter));
@@ -275,12 +232,6 @@ JsonValue InputTemplate::Jsonize() const
    payload.WithString("denoiseFilter", InputDenoiseFilterMapper::GetNameForInputDenoiseFilter(m_denoiseFilter));
   }
 
-  if(m_dolbyVisionMetadataXmlHasBeenSet)
-  {
-   payload.WithString("dolbyVisionMetadataXml", m_dolbyVisionMetadataXml);
-
-  }
-
   if(m_filterEnableHasBeenSet)
   {
    payload.WithString("filterEnable", InputFilterEnableMapper::GetNameForInputFilterEnable(m_filterEnable));
@@ -309,17 +260,6 @@ JsonValue InputTemplate::Jsonize() const
 
   }
 
-  if(m_inputScanTypeHasBeenSet)
-  {
-   payload.WithString("inputScanType", InputScanTypeMapper::GetNameForInputScanType(m_inputScanType));
-  }
-
-  if(m_positionHasBeenSet)
-  {
-   payload.WithObject("position", m_position.Jsonize());
-
-  }
-
   if(m_programNumberHasBeenSet)
   {
    payload.WithInteger("programNumber", m_programNumber);
@@ -336,12 +276,6 @@ JsonValue InputTemplate::Jsonize() const
    payload.WithString("timecodeSource", InputTimecodeSourceMapper::GetNameForInputTimecodeSource(m_timecodeSource));
   }
 
-  if(m_timecodeStartHasBeenSet)
-  {
-   payload.WithString("timecodeStart", m_timecodeStart);
-
-  }
-
   if(m_videoSelectorHasBeenSet)
   {
    payload.WithObject("videoSelector", m_videoSelector.Jsonize());
