@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/medialive/MediaLive_EXPORTS.h>
@@ -16,7 +26,6 @@
 #include <aws/medialive/model/OutputDestination.h>
 #include <aws/medialive/model/ChannelEgressEndpoint.h>
 #include <aws/medialive/model/InputAttachment.h>
-#include <aws/medialive/model/PipelineDetail.h>
 #include <utility>
 
 namespace Aws
@@ -440,47 +449,6 @@ one destination per
     inline Channel& WithName(const char* value) { SetName(value); return *this;}
 
 
-    /**
-     * Runtime details for the pipelines of a running channel.
-     */
-    inline const Aws::Vector<PipelineDetail>& GetPipelineDetails() const{ return m_pipelineDetails; }
-
-    /**
-     * Runtime details for the pipelines of a running channel.
-     */
-    inline bool PipelineDetailsHasBeenSet() const { return m_pipelineDetailsHasBeenSet; }
-
-    /**
-     * Runtime details for the pipelines of a running channel.
-     */
-    inline void SetPipelineDetails(const Aws::Vector<PipelineDetail>& value) { m_pipelineDetailsHasBeenSet = true; m_pipelineDetails = value; }
-
-    /**
-     * Runtime details for the pipelines of a running channel.
-     */
-    inline void SetPipelineDetails(Aws::Vector<PipelineDetail>&& value) { m_pipelineDetailsHasBeenSet = true; m_pipelineDetails = std::move(value); }
-
-    /**
-     * Runtime details for the pipelines of a running channel.
-     */
-    inline Channel& WithPipelineDetails(const Aws::Vector<PipelineDetail>& value) { SetPipelineDetails(value); return *this;}
-
-    /**
-     * Runtime details for the pipelines of a running channel.
-     */
-    inline Channel& WithPipelineDetails(Aws::Vector<PipelineDetail>&& value) { SetPipelineDetails(std::move(value)); return *this;}
-
-    /**
-     * Runtime details for the pipelines of a running channel.
-     */
-    inline Channel& AddPipelineDetails(const PipelineDetail& value) { m_pipelineDetailsHasBeenSet = true; m_pipelineDetails.push_back(value); return *this; }
-
-    /**
-     * Runtime details for the pipelines of a running channel.
-     */
-    inline Channel& AddPipelineDetails(PipelineDetail&& value) { m_pipelineDetailsHasBeenSet = true; m_pipelineDetails.push_back(std::move(value)); return *this; }
-
-
     /**
      * The number of currently healthy pipelines.
      */
@@ -659,9 +627,6 @@ one destination per
     Aws::String m_name;
     bool m_nameHasBeenSet;
 
-    Aws::Vector<PipelineDetail> m_pipelineDetails;
-    bool m_pipelineDetailsHasBeenSet;
-
     int m_pipelinesRunningCount;
     bool m_pipelinesRunningCountHasBeenSet;
 
