@@ -1,19 +1,27 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/medialive/MediaLive_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/medialive/model/InputClass.h>
-#include <aws/medialive/model/InputSourceType.h>
 #include <aws/medialive/model/InputState.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/medialive/model/InputType.h>
 #include <aws/medialive/model/InputDestination.h>
-#include <aws/medialive/model/InputDeviceSettings.h>
 #include <aws/medialive/model/MediaConnectFlow.h>
 #include <aws/medialive/model/InputSource.h>
 #include <utility>
@@ -270,88 +278,6 @@ SINGLE_PIPELINE - You can
     inline DescribeInputResult& WithInputClass(InputClass&& value) { SetInputClass(std::move(value)); return *this;}
 
 
-    /**
-     * Settings for the input devices.
-     */
-    inline const Aws::Vector<InputDeviceSettings>& GetInputDevices() const{ return m_inputDevices; }
-
-    /**
-     * Settings for the input devices.
-     */
-    inline void SetInputDevices(const Aws::Vector<InputDeviceSettings>& value) { m_inputDevices = value; }
-
-    /**
-     * Settings for the input devices.
-     */
-    inline void SetInputDevices(Aws::Vector<InputDeviceSettings>&& value) { m_inputDevices = std::move(value); }
-
-    /**
-     * Settings for the input devices.
-     */
-    inline DescribeInputResult& WithInputDevices(const Aws::Vector<InputDeviceSettings>& value) { SetInputDevices(value); return *this;}
-
-    /**
-     * Settings for the input devices.
-     */
-    inline DescribeInputResult& WithInputDevices(Aws::Vector<InputDeviceSettings>&& value) { SetInputDevices(std::move(value)); return *this;}
-
-    /**
-     * Settings for the input devices.
-     */
-    inline DescribeInputResult& AddInputDevices(const InputDeviceSettings& value) { m_inputDevices.push_back(value); return *this; }
-
-    /**
-     * Settings for the input devices.
-     */
-    inline DescribeInputResult& AddInputDevices(InputDeviceSettings&& value) { m_inputDevices.push_back(std::move(value)); return *this; }
-
-
-    /**
-     * Certain pull input sources can be dynamic, meaning that they can have their
-     * URL's dynamically changes
-during input switch actions. Presently, this
-     * functionality only works with MP4_FILE inputs.
-
-     */
-    inline const InputSourceType& GetInputSourceType() const{ return m_inputSourceType; }
-
-    /**
-     * Certain pull input sources can be dynamic, meaning that they can have their
-     * URL's dynamically changes
-during input switch actions. Presently, this
-     * functionality only works with MP4_FILE inputs.
-
-     */
-    inline void SetInputSourceType(const InputSourceType& value) { m_inputSourceType = value; }
-
-    /**
-     * Certain pull input sources can be dynamic, meaning that they can have their
-     * URL's dynamically changes
-during input switch actions. Presently, this
-     * functionality only works with MP4_FILE inputs.
-
-     */
-    inline void SetInputSourceType(InputSourceType&& value) { m_inputSourceType = std::move(value); }
-
-    /**
-     * Certain pull input sources can be dynamic, meaning that they can have their
-     * URL's dynamically changes
-during input switch actions. Presently, this
-     * functionality only works with MP4_FILE inputs.
-
-     */
-    inline DescribeInputResult& WithInputSourceType(const InputSourceType& value) { SetInputSourceType(value); return *this;}
-
-    /**
-     * Certain pull input sources can be dynamic, meaning that they can have their
-     * URL's dynamically changes
-during input switch actions. Presently, this
-     * functionality only works with MP4_FILE inputs.
-
-     */
-    inline DescribeInputResult& WithInputSourceType(InputSourceType&& value) { SetInputSourceType(std::move(value)); return *this;}
-
-
     /**
      * A list of MediaConnect Flows for this input.
      */
@@ -648,10 +574,6 @@ during input switch actions. Presently, this
 
     InputClass m_inputClass;
 
-    Aws::Vector<InputDeviceSettings> m_inputDevices;
-
-    InputSourceType m_inputSourceType;
-
     Aws::Vector<MediaConnectFlow> m_mediaConnectFlows;
 
     Aws::String m_name;
