@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/medialive/model/M2tsSettings.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -62,8 +72,6 @@ M2tsSettings::M2tsSettings() :
     m_klv(M2tsKlv::NOT_SET),
     m_klvHasBeenSet(false),
     m_klvDataPidsHasBeenSet(false),
-    m_nielsenId3Behavior(M2tsNielsenId3Behavior::NOT_SET),
-    m_nielsenId3BehaviorHasBeenSet(false),
     m_nullPacketBitrate(0.0),
     m_nullPacketBitrateHasBeenSet(false),
     m_patInterval(0),
@@ -143,8 +151,6 @@ M2tsSettings::M2tsSettings(JsonView jsonValue) :
     m_klv(M2tsKlv::NOT_SET),
     m_klvHasBeenSet(false),
     m_klvDataPidsHasBeenSet(false),
-    m_nielsenId3Behavior(M2tsNielsenId3Behavior::NOT_SET),
-    m_nielsenId3BehaviorHasBeenSet(false),
     m_nullPacketBitrate(0.0),
     m_nullPacketBitrateHasBeenSet(false),
     m_patInterval(0),
@@ -372,13 +378,6 @@ M2tsSettings& M2tsSettings::operator =(JsonView jsonValue)
     m_klvDataPidsHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("nielsenId3Behavior"))
-  {
-    m_nielsenId3Behavior = M2tsNielsenId3BehaviorMapper::GetM2tsNielsenId3BehaviorForName(jsonValue.GetString("nielsenId3Behavior"));
-
-    m_nielsenId3BehaviorHasBeenSet = true;
-  }
-
   if(jsonValue.ValueExists("nullPacketBitrate"))
   {
     m_nullPacketBitrate = jsonValue.GetDouble("nullPacketBitrate");
@@ -669,11 +668,6 @@ JsonValue M2tsSettings::Jsonize() const
 
   }
 
-  if(m_nielsenId3BehaviorHasBeenSet)
-  {
-   payload.WithString("nielsenId3Behavior", M2tsNielsenId3BehaviorMapper::GetNameForM2tsNielsenId3Behavior(m_nielsenId3Behavior));
-  }
-
   if(m_nullPacketBitrateHasBeenSet)
   {
    payload.WithDouble("nullPacketBitrate", m_nullPacketBitrate);
