@@ -1,16 +1,23 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediapackage/MediaPackage_EXPORTS.h>
 #include <aws/mediapackage/model/AdMarkers.h>
-#include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/mediapackage/model/AdsOnDeliveryRestrictions.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/mediapackage/model/PlaylistType.h>
-#include <aws/mediapackage/model/__AdTriggersElement.h>
 #include <utility>
 
 namespace Aws
@@ -54,12 +61,6 @@ markers (comments) taken directly from the input HTTP Live Streaming (HLS)
 "SCTE35_ENHANCED" generates ad markers and blackout tags based on
      * SCTE-35
 messages in the input source.
-"DATERANGE" inserts EXT-X-DATERANGE tags
-     * to signal ad and program transition events 
-in HLS and CMAF manifests. For this
-     * option, you must set a programDateTimeIntervalSeconds value 
-that is greater
-     * than 0.
 
      */
     inline const AdMarkers& GetAdMarkers() const{ return m_adMarkers; }
@@ -76,12 +77,6 @@ markers (comments) taken directly from the input HTTP Live Streaming (HLS)
 "SCTE35_ENHANCED" generates ad markers and blackout tags based on
      * SCTE-35
 messages in the input source.
-"DATERANGE" inserts EXT-X-DATERANGE tags
-     * to signal ad and program transition events 
-in HLS and CMAF manifests. For this
-     * option, you must set a programDateTimeIntervalSeconds value 
-that is greater
-     * than 0.
 
      */
     inline bool AdMarkersHasBeenSet() const { return m_adMarkersHasBeenSet; }
@@ -98,12 +93,6 @@ markers (comments) taken directly from the input HTTP Live Streaming (HLS)
 "SCTE35_ENHANCED" generates ad markers and blackout tags based on
      * SCTE-35
 messages in the input source.
-"DATERANGE" inserts EXT-X-DATERANGE tags
-     * to signal ad and program transition events 
-in HLS and CMAF manifests. For this
-     * option, you must set a programDateTimeIntervalSeconds value 
-that is greater
-     * than 0.
 
      */
     inline void SetAdMarkers(const AdMarkers& value) { m_adMarkersHasBeenSet = true; m_adMarkers = value; }
@@ -120,12 +109,6 @@ markers (comments) taken directly from the input HTTP Live Streaming (HLS)
 "SCTE35_ENHANCED" generates ad markers and blackout tags based on
      * SCTE-35
 messages in the input source.
-"DATERANGE" inserts EXT-X-DATERANGE tags
-     * to signal ad and program transition events 
-in HLS and CMAF manifests. For this
-     * option, you must set a programDateTimeIntervalSeconds value 
-that is greater
-     * than 0.
 
      */
     inline void SetAdMarkers(AdMarkers&& value) { m_adMarkersHasBeenSet = true; m_adMarkers = std::move(value); }
@@ -142,12 +125,6 @@ markers (comments) taken directly from the input HTTP Live Streaming (HLS)
 "SCTE35_ENHANCED" generates ad markers and blackout tags based on
      * SCTE-35
 messages in the input source.
-"DATERANGE" inserts EXT-X-DATERANGE tags
-     * to signal ad and program transition events 
-in HLS and CMAF manifests. For this
-     * option, you must set a programDateTimeIntervalSeconds value 
-that is greater
-     * than 0.
 
      */
     inline HlsManifestCreateOrUpdateParameters& WithAdMarkers(const AdMarkers& value) { SetAdMarkers(value); return *this;}
@@ -164,61 +141,11 @@ markers (comments) taken directly from the input HTTP Live Streaming (HLS)
 "SCTE35_ENHANCED" generates ad markers and blackout tags based on
      * SCTE-35
 messages in the input source.
-"DATERANGE" inserts EXT-X-DATERANGE tags
-     * to signal ad and program transition events 
-in HLS and CMAF manifests. For this
-     * option, you must set a programDateTimeIntervalSeconds value 
-that is greater
-     * than 0.
 
      */
     inline HlsManifestCreateOrUpdateParameters& WithAdMarkers(AdMarkers&& value) { SetAdMarkers(std::move(value)); return *this;}
 
 
-    
-    inline const Aws::Vector<__AdTriggersElement>& GetAdTriggers() const{ return m_adTriggers; }
-
-    
-    inline bool AdTriggersHasBeenSet() const { return m_adTriggersHasBeenSet; }
-
-    
-    inline void SetAdTriggers(const Aws::Vector<__AdTriggersElement>& value) { m_adTriggersHasBeenSet = true; m_adTriggers = value; }
-
-    
-    inline void SetAdTriggers(Aws::Vector<__AdTriggersElement>&& value) { m_adTriggersHasBeenSet = true; m_adTriggers = std::move(value); }
-
-    
-    inline HlsManifestCreateOrUpdateParameters& WithAdTriggers(const Aws::Vector<__AdTriggersElement>& value) { SetAdTriggers(value); return *this;}
-
-    
-    inline HlsManifestCreateOrUpdateParameters& WithAdTriggers(Aws::Vector<__AdTriggersElement>&& value) { SetAdTriggers(std::move(value)); return *this;}
-
-    
-    inline HlsManifestCreateOrUpdateParameters& AddAdTriggers(const __AdTriggersElement& value) { m_adTriggersHasBeenSet = true; m_adTriggers.push_back(value); return *this; }
-
-    
-    inline HlsManifestCreateOrUpdateParameters& AddAdTriggers(__AdTriggersElement&& value) { m_adTriggersHasBeenSet = true; m_adTriggers.push_back(std::move(value)); return *this; }
-
-
-    
-    inline const AdsOnDeliveryRestrictions& GetAdsOnDeliveryRestrictions() const{ return m_adsOnDeliveryRestrictions; }
-
-    
-    inline bool AdsOnDeliveryRestrictionsHasBeenSet() const { return m_adsOnDeliveryRestrictionsHasBeenSet; }
-
-    
-    inline void SetAdsOnDeliveryRestrictions(const AdsOnDeliveryRestrictions& value) { m_adsOnDeliveryRestrictionsHasBeenSet = true; m_adsOnDeliveryRestrictions = value; }
-
-    
-    inline void SetAdsOnDeliveryRestrictions(AdsOnDeliveryRestrictions&& value) { m_adsOnDeliveryRestrictionsHasBeenSet = true; m_adsOnDeliveryRestrictions = std::move(value); }
-
-    
-    inline HlsManifestCreateOrUpdateParameters& WithAdsOnDeliveryRestrictions(const AdsOnDeliveryRestrictions& value) { SetAdsOnDeliveryRestrictions(value); return *this;}
-
-    
-    inline HlsManifestCreateOrUpdateParameters& WithAdsOnDeliveryRestrictions(AdsOnDeliveryRestrictions&& value) { SetAdsOnDeliveryRestrictions(std::move(value)); return *this;}
-
-
     /**
      * The ID of the manifest. The ID must be unique within the OriginEndpoint and it
      * cannot be changed after it is created.
@@ -509,12 +436,6 @@ it will
     AdMarkers m_adMarkers;
     bool m_adMarkersHasBeenSet;
 
-    Aws::Vector<__AdTriggersElement> m_adTriggers;
-    bool m_adTriggersHasBeenSet;
-
-    AdsOnDeliveryRestrictions m_adsOnDeliveryRestrictions;
-    bool m_adsOnDeliveryRestrictionsHasBeenSet;
-
     Aws::String m_id;
     bool m_idHasBeenSet;
 
