@@ -1,17 +1,25 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediapackage/MediaPackage_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
-#include <aws/mediapackage/model/Authorization.h>
 #include <aws/mediapackage/model/CmafPackage.h>
 #include <aws/mediapackage/model/DashPackage.h>
 #include <aws/mediapackage/model/HlsPackage.h>
 #include <aws/mediapackage/model/MssPackage.h>
-#include <aws/mediapackage/model/Origination.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <utility>
@@ -76,22 +84,6 @@ namespace Model
     inline UpdateOriginEndpointResult& WithArn(const char* value) { SetArn(value); return *this;}
 
 
-    
-    inline const Authorization& GetAuthorization() const{ return m_authorization; }
-
-    
-    inline void SetAuthorization(const Authorization& value) { m_authorization = value; }
-
-    
-    inline void SetAuthorization(Authorization&& value) { m_authorization = std::move(value); }
-
-    
-    inline UpdateOriginEndpointResult& WithAuthorization(const Authorization& value) { SetAuthorization(value); return *this;}
-
-    
-    inline UpdateOriginEndpointResult& WithAuthorization(Authorization&& value) { SetAuthorization(std::move(value)); return *this;}
-
-
     /**
      * The ID of the Channel the OriginEndpoint is associated with.
      */
@@ -300,67 +292,6 @@ namespace Model
     inline UpdateOriginEndpointResult& WithMssPackage(MssPackage&& value) { SetMssPackage(std::move(value)); return *this;}
 
 
-    /**
-     * Control whether origination of video is allowed for this OriginEndpoint. If set
-     * to ALLOW, the OriginEndpoint
-may by requested, pursuant to any other form of
-     * access control. If set to DENY, the OriginEndpoint may not be
-requested. This
-     * can be helpful for Live to VOD harvesting, or for temporarily disabling
-     * origination
-
-     */
-    inline const Origination& GetOrigination() const{ return m_origination; }
-
-    /**
-     * Control whether origination of video is allowed for this OriginEndpoint. If set
-     * to ALLOW, the OriginEndpoint
-may by requested, pursuant to any other form of
-     * access control. If set to DENY, the OriginEndpoint may not be
-requested. This
-     * can be helpful for Live to VOD harvesting, or for temporarily disabling
-     * origination
-
-     */
-    inline void SetOrigination(const Origination& value) { m_origination = value; }
-
-    /**
-     * Control whether origination of video is allowed for this OriginEndpoint. If set
-     * to ALLOW, the OriginEndpoint
-may by requested, pursuant to any other form of
-     * access control. If set to DENY, the OriginEndpoint may not be
-requested. This
-     * can be helpful for Live to VOD harvesting, or for temporarily disabling
-     * origination
-
-     */
-    inline void SetOrigination(Origination&& value) { m_origination = std::move(value); }
-
-    /**
-     * Control whether origination of video is allowed for this OriginEndpoint. If set
-     * to ALLOW, the OriginEndpoint
-may by requested, pursuant to any other form of
-     * access control. If set to DENY, the OriginEndpoint may not be
-requested. This
-     * can be helpful for Live to VOD harvesting, or for temporarily disabling
-     * origination
-
-     */
-    inline UpdateOriginEndpointResult& WithOrigination(const Origination& value) { SetOrigination(value); return *this;}
-
-    /**
-     * Control whether origination of video is allowed for this OriginEndpoint. If set
-     * to ALLOW, the OriginEndpoint
-may by requested, pursuant to any other form of
-     * access control. If set to DENY, the OriginEndpoint may not be
-requested. This
-     * can be helpful for Live to VOD harvesting, or for temporarily disabling
-     * origination
-
-     */
-    inline UpdateOriginEndpointResult& WithOrigination(Origination&& value) { SetOrigination(std::move(value)); return *this;}
-
-
     /**
      * Maximum duration (seconds) of content to retain for startover playback.
 If not
@@ -536,8 +467,6 @@ If not
 
     Aws::String m_arn;
 
-    Authorization m_authorization;
-
     Aws::String m_channelId;
 
     CmafPackage m_cmafPackage;
@@ -554,8 +483,6 @@ If not
 
     MssPackage m_mssPackage;
 
-    Origination m_origination;
-
     int m_startoverWindowSeconds;
 
     Aws::Map<Aws::String, Aws::String> m_tags;
