@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mediastore-data/MediaStoreData_EXPORTS.h>
@@ -9,7 +19,6 @@
 #include <aws/core/utils/Array.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/mediastore-data/model/StorageClass.h>
-#include <aws/mediastore-data/model/UploadAvailability.h>
 #include <utility>
 
 namespace Aws
@@ -25,7 +34,7 @@ namespace Model
   {
   public:
     PutObjectRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -36,8 +45,6 @@ namespace Model
 
     bool SignBody() const override { return false; }
 
-    bool IsChunked() const override { return true; }
-
 
     /**
      * <p>The path (including the file name) where the object is stored in the
@@ -339,73 +346,6 @@ namespace Model
      */
     inline PutObjectRequest& WithStorageClass(StorageClass&& value) { SetStorageClass(std::move(value)); return *this;}
 
-
-    /**
-     * <p>Indicates the availability of an object while it is still uploading. If the
-     * value is set to <code>streaming</code>, the object is available for downloading
-     * after some initial buffering but before the object is uploaded completely. If
-     * the value is set to <code>standard</code>, the object is available for
-     * downloading only when it is uploaded completely. The default value for this
-     * header is <code>standard</code>.</p> <p>To use this header, you must also set
-     * the HTTP <code>Transfer-Encoding</code> header to <code>chunked</code>.</p>
-     */
-    inline const UploadAvailability& GetUploadAvailability() const{ return m_uploadAvailability; }
-
-    /**
-     * <p>Indicates the availability of an object while it is still uploading. If the
-     * value is set to <code>streaming</code>, the object is available for downloading
-     * after some initial buffering but before the object is uploaded completely. If
-     * the value is set to <code>standard</code>, the object is available for
-     * downloading only when it is uploaded completely. The default value for this
-     * header is <code>standard</code>.</p> <p>To use this header, you must also set
-     * the HTTP <code>Transfer-Encoding</code> header to <code>chunked</code>.</p>
-     */
-    inline bool UploadAvailabilityHasBeenSet() const { return m_uploadAvailabilityHasBeenSet; }
-
-    /**
-     * <p>Indicates the availability of an object while it is still uploading. If the
-     * value is set to <code>streaming</code>, the object is available for downloading
-     * after some initial buffering but before the object is uploaded completely. If
-     * the value is set to <code>standard</code>, the object is available for
-     * downloading only when it is uploaded completely. The default value for this
-     * header is <code>standard</code>.</p> <p>To use this header, you must also set
-     * the HTTP <code>Transfer-Encoding</code> header to <code>chunked</code>.</p>
-     */
-    inline void SetUploadAvailability(const UploadAvailability& value) { m_uploadAvailabilityHasBeenSet = true; m_uploadAvailability = value; }
-
-    /**
-     * <p>Indicates the availability of an object while it is still uploading. If the
-     * value is set to <code>streaming</code>, the object is available for downloading
-     * after some initial buffering but before the object is uploaded completely. If
-     * the value is set to <code>standard</code>, the object is available for
-     * downloading only when it is uploaded completely. The default value for this
-     * header is <code>standard</code>.</p> <p>To use this header, you must also set
-     * the HTTP <code>Transfer-Encoding</code> header to <code>chunked</code>.</p>
-     */
-    inline void SetUploadAvailability(UploadAvailability&& value) { m_uploadAvailabilityHasBeenSet = true; m_uploadAvailability = std::move(value); }
-
-    /**
-     * <p>Indicates the availability of an object while it is still uploading. If the
-     * value is set to <code>streaming</code>, the object is available for downloading
-     * after some initial buffering but before the object is uploaded completely. If
-     * the value is set to <code>standard</code>, the object is available for
-     * downloading only when it is uploaded completely. The default value for this
-     * header is <code>standard</code>.</p> <p>To use this header, you must also set
-     * the HTTP <code>Transfer-Encoding</code> header to <code>chunked</code>.</p>
-     */
-    inline PutObjectRequest& WithUploadAvailability(const UploadAvailability& value) { SetUploadAvailability(value); return *this;}
-
-    /**
-     * <p>Indicates the availability of an object while it is still uploading. If the
-     * value is set to <code>streaming</code>, the object is available for downloading
-     * after some initial buffering but before the object is uploaded completely. If
-     * the value is set to <code>standard</code>, the object is available for
-     * downloading only when it is uploaded completely. The default value for this
-     * header is <code>standard</code>.</p> <p>To use this header, you must also set
-     * the HTTP <code>Transfer-Encoding</code> header to <code>chunked</code>.</p>
-     */
-    inline PutObjectRequest& WithUploadAvailability(UploadAvailability&& value) { SetUploadAvailability(std::move(value)); return *this;}
-
   private:
 
 
@@ -417,9 +357,6 @@ namespace Model
 
     StorageClass m_storageClass;
     bool m_storageClassHasBeenSet;
-
-    UploadAvailability m_uploadAvailability;
-    bool m_uploadAvailabilityHasBeenSet;
   };
 
 } // namespace Model
