@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/mediastore-data/model/PutObjectRequest.h>
 #include <aws/core/AmazonWebServiceResult.h>
@@ -19,14 +29,11 @@ PutObjectRequest::PutObjectRequest() :
     m_pathHasBeenSet(false),
     m_cacheControlHasBeenSet(false),
     m_storageClass(StorageClass::NOT_SET),
-    m_storageClassHasBeenSet(false),
-    m_uploadAvailability(UploadAvailability::NOT_SET),
-    m_uploadAvailabilityHasBeenSet(false)
+    m_storageClassHasBeenSet(false)
 {
 }
 
 
-
 Aws::Http::HeaderValueCollection PutObjectRequest::GetRequestSpecificHeaders() const
 {
   Aws::Http::HeaderValueCollection headers;
@@ -43,11 +50,6 @@ Aws::Http::HeaderValueCollection PutObjectRequest::GetRequestSpecificHeaders() c
     headers.emplace("x-amz-storage-class", StorageClassMapper::GetNameForStorageClass(m_storageClass));
   }
 
-  if(m_uploadAvailabilityHasBeenSet)
-  {
-    headers.emplace("x-amz-upload-availability", UploadAvailabilityMapper::GetNameForUploadAvailability(m_uploadAvailability));
-  }
-
   return headers;
 
 }
