@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/core/utils/Outcome.h>
 #include <aws/core/auth/AWSAuthSigner.h>
@@ -45,7 +55,7 @@ static const char* ALLOCATION_TAG = "MobileClient";
 MobileClient::MobileClient(const Client::ClientConfiguration& clientConfiguration) :
   BASECLASS(clientConfiguration,
     Aws::MakeShared<AWSAuthV4Signer>(ALLOCATION_TAG, Aws::MakeShared<DefaultAWSCredentialsProviderChain>(ALLOCATION_TAG),
-        SERVICE_NAME, Aws::Region::ComputeSignerRegion(clientConfiguration.region)),
+        SERVICE_NAME, clientConfiguration.region),
     Aws::MakeShared<MobileErrorMarshaller>(ALLOCATION_TAG)),
     m_executor(clientConfiguration.executor)
 {
@@ -55,7 +65,7 @@ MobileClient::MobileClient(const Client::ClientConfiguration& clientConfiguratio
 MobileClient::MobileClient(const AWSCredentials& credentials, const Client::ClientConfiguration& clientConfiguration) :
   BASECLASS(clientConfiguration,
     Aws::MakeShared<AWSAuthV4Signer>(ALLOCATION_TAG, Aws::MakeShared<SimpleAWSCredentialsProvider>(ALLOCATION_TAG, credentials),
-         SERVICE_NAME, Aws::Region::ComputeSignerRegion(clientConfiguration.region)),
+         SERVICE_NAME, clientConfiguration.region),
     Aws::MakeShared<MobileErrorMarshaller>(ALLOCATION_TAG)),
     m_executor(clientConfiguration.executor)
 {
@@ -66,7 +76,7 @@ MobileClient::MobileClient(const std::shared_ptr<AWSCredentialsProvider>& creden
   const Client::ClientConfiguration& clientConfiguration) :
   BASECLASS(clientConfiguration,
     Aws::MakeShared<AWSAuthV4Signer>(ALLOCATION_TAG, credentialsProvider,
-         SERVICE_NAME, Aws::Region::ComputeSignerRegion(clientConfiguration.region)),
+         SERVICE_NAME, clientConfiguration.region),
     Aws::MakeShared<MobileErrorMarshaller>(ALLOCATION_TAG)),
     m_executor(clientConfiguration.executor)
 {
@@ -79,7 +89,6 @@ MobileClient::~MobileClient()
 
 void MobileClient::init(const ClientConfiguration& config)
 {
-  SetServiceClientName("mobile");
   m_configScheme = SchemeMapper::ToString(config.scheme);
   if (config.endpointOverride.empty())
   {
@@ -102,14 +111,21 @@ void MobileClient::OverrideEndpoint(const Aws::String& endpoint)
       m_uri = m_configScheme + "://" + endpoint;
   }
 }
-
 CreateProjectOutcome MobileClient::CreateProject(const CreateProjectRequest& request) const
 {
   Aws::Http::URI uri = m_uri;
   Aws::StringStream ss;
   ss << "/projects";
   uri.SetPath(uri.GetPath() + ss.str());
-  return CreateProjectOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return CreateProjectOutcome(CreateProjectResult(outcome.GetResult()));
+  }
+  else
+  {
+    return CreateProjectOutcome(outcome.GetError());
+  }
 }
 
 CreateProjectOutcomeCallable MobileClient::CreateProjectCallable(const CreateProjectRequest& request) const
@@ -142,7 +158,15 @@ DeleteProjectOutcome MobileClient::DeleteProject(const DeleteProjectRequest& req
   ss << "/projects/";
   ss << request.GetProjectId();
   uri.SetPath(uri.GetPath() + ss.str());
-  return DeleteProjectOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_DELETE, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_DELETE, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DeleteProjectOutcome(DeleteProjectResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DeleteProjectOutcome(outcome.GetError());
+  }
 }
 
 DeleteProjectOutcomeCallable MobileClient::DeleteProjectCallable(const DeleteProjectRequest& request) const
@@ -175,7 +199,15 @@ DescribeBundleOutcome MobileClient::DescribeBundle(const DescribeBundleRequest&
   ss << "/bundles/";
   ss << request.GetBundleId();
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeBundleOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_GET, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_GET, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeBundleOutcome(DescribeBundleResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeBundleOutcome(outcome.GetError());
+  }
 }
 
 DescribeBundleOutcomeCallable MobileClient::DescribeBundleCallable(const DescribeBundleRequest& request) const
@@ -207,7 +239,15 @@ DescribeProjectOutcome MobileClient::DescribeProject(const DescribeProjectReques
   Aws::StringStream ss;
   ss << "/project";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeProjectOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_GET, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_GET, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeProjectOutcome(DescribeProjectResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeProjectOutcome(outcome.GetError());
+  }
 }
 
 DescribeProjectOutcomeCallable MobileClient::DescribeProjectCallable(const DescribeProjectRequest& request) const
@@ -240,7 +280,15 @@ ExportBundleOutcome MobileClient::ExportBundle(const ExportBundleRequest& reques
   ss << "/bundles/";
   ss << request.GetBundleId();
   uri.SetPath(uri.GetPath() + ss.str());
-  return ExportBundleOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return ExportBundleOutcome(ExportBundleResult(outcome.GetResult()));
+  }
+  else
+  {
+    return ExportBundleOutcome(outcome.GetError());
+  }
 }
 
 ExportBundleOutcomeCallable MobileClient::ExportBundleCallable(const ExportBundleRequest& request) const
@@ -273,7 +321,15 @@ ExportProjectOutcome MobileClient::ExportProject(const ExportProjectRequest& req
   ss << "/exports/";
   ss << request.GetProjectId();
   uri.SetPath(uri.GetPath() + ss.str());
-  return ExportProjectOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return ExportProjectOutcome(ExportProjectResult(outcome.GetResult()));
+  }
+  else
+  {
+    return ExportProjectOutcome(outcome.GetError());
+  }
 }
 
 ExportProjectOutcomeCallable MobileClient::ExportProjectCallable(const ExportProjectRequest& request) const
@@ -300,7 +356,15 @@ ListBundlesOutcome MobileClient::ListBundles(const ListBundlesRequest& request)
   Aws::StringStream ss;
   ss << "/bundles";
   uri.SetPath(uri.GetPath() + ss.str());
-  return ListBundlesOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_GET, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_GET, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return ListBundlesOutcome(ListBundlesResult(outcome.GetResult()));
+  }
+  else
+  {
+    return ListBundlesOutcome(outcome.GetError());
+  }
 }
 
 ListBundlesOutcomeCallable MobileClient::ListBundlesCallable(const ListBundlesRequest& request) const
@@ -327,7 +391,15 @@ ListProjectsOutcome MobileClient::ListProjects(const ListProjectsRequest& reques
   Aws::StringStream ss;
   ss << "/projects";
   uri.SetPath(uri.GetPath() + ss.str());
-  return ListProjectsOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_GET, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_GET, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return ListProjectsOutcome(ListProjectsResult(outcome.GetResult()));
+  }
+  else
+  {
+    return ListProjectsOutcome(outcome.GetError());
+  }
 }
 
 ListProjectsOutcomeCallable MobileClient::ListProjectsCallable(const ListProjectsRequest& request) const
@@ -359,7 +431,15 @@ UpdateProjectOutcome MobileClient::UpdateProject(const UpdateProjectRequest& req
   Aws::StringStream ss;
   ss << "/update";
   uri.SetPath(uri.GetPath() + ss.str());
-  return UpdateProjectOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return UpdateProjectOutcome(UpdateProjectResult(outcome.GetResult()));
+  }
+  else
+  {
+    return UpdateProjectOutcome(outcome.GetError());
+  }
 }
 
 UpdateProjectOutcomeCallable MobileClient::UpdateProjectCallable(const UpdateProjectRequest& request) const
