@@ -1,23 +1,29 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/mq/MQ_EXPORTS.h>
-#include <aws/mq/model/AuthenticationStrategy.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/mq/model/BrokerState.h>
 #include <aws/mq/model/Configurations.h>
 #include <aws/core/utils/DateTime.h>
 #include <aws/mq/model/DeploymentMode.h>
-#include <aws/mq/model/EncryptionOptions.h>
 #include <aws/mq/model/EngineType.h>
-#include <aws/mq/model/LdapServerMetadataOutput.h>
 #include <aws/mq/model/LogsSummary.h>
 #include <aws/mq/model/WeeklyStartTime.h>
-#include <aws/mq/model/BrokerStorageType.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/mq/model/BrokerInstance.h>
 #include <aws/mq/model/UserSummary.h>
@@ -47,32 +53,6 @@ namespace Model
     DescribeBrokerResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
 
 
-    /**
-     * The authentication strategy used to secure the broker.
-     */
-    inline const AuthenticationStrategy& GetAuthenticationStrategy() const{ return m_authenticationStrategy; }
-
-    /**
-     * The authentication strategy used to secure the broker.
-     */
-    inline void SetAuthenticationStrategy(const AuthenticationStrategy& value) { m_authenticationStrategy = value; }
-
-    /**
-     * The authentication strategy used to secure the broker.
-     */
-    inline void SetAuthenticationStrategy(AuthenticationStrategy&& value) { m_authenticationStrategy = std::move(value); }
-
-    /**
-     * The authentication strategy used to secure the broker.
-     */
-    inline DescribeBrokerResult& WithAuthenticationStrategy(const AuthenticationStrategy& value) { SetAuthenticationStrategy(value); return *this;}
-
-    /**
-     * The authentication strategy used to secure the broker.
-     */
-    inline DescribeBrokerResult& WithAuthenticationStrategy(AuthenticationStrategy&& value) { SetAuthenticationStrategy(std::move(value)); return *this;}
-
-
     /**
      * Required. Enables automatic upgrades to new minor versions for brokers, as
      * Apache releases the versions. The automatic upgrades occur during the
@@ -364,32 +344,6 @@ namespace Model
     inline DescribeBrokerResult& WithDeploymentMode(DeploymentMode&& value) { SetDeploymentMode(std::move(value)); return *this;}
 
 
-    /**
-     * Encryption options for the broker.
-     */
-    inline const EncryptionOptions& GetEncryptionOptions() const{ return m_encryptionOptions; }
-
-    /**
-     * Encryption options for the broker.
-     */
-    inline void SetEncryptionOptions(const EncryptionOptions& value) { m_encryptionOptions = value; }
-
-    /**
-     * Encryption options for the broker.
-     */
-    inline void SetEncryptionOptions(EncryptionOptions&& value) { m_encryptionOptions = std::move(value); }
-
-    /**
-     * Encryption options for the broker.
-     */
-    inline DescribeBrokerResult& WithEncryptionOptions(const EncryptionOptions& value) { SetEncryptionOptions(value); return *this;}
-
-    /**
-     * Encryption options for the broker.
-     */
-    inline DescribeBrokerResult& WithEncryptionOptions(EncryptionOptions&& value) { SetEncryptionOptions(std::move(value)); return *this;}
-
-
     /**
      * Required. The type of broker engine. Note: Currently, Amazon MQ supports only
      * ACTIVEMQ.
@@ -500,37 +454,6 @@ namespace Model
     inline DescribeBrokerResult& WithHostInstanceType(const char* value) { SetHostInstanceType(value); return *this;}
 
 
-    /**
-     * The metadata of the LDAP server used to authenticate and authorize connections
-     * to the broker.
-     */
-    inline const LdapServerMetadataOutput& GetLdapServerMetadata() const{ return m_ldapServerMetadata; }
-
-    /**
-     * The metadata of the LDAP server used to authenticate and authorize connections
-     * to the broker.
-     */
-    inline void SetLdapServerMetadata(const LdapServerMetadataOutput& value) { m_ldapServerMetadata = value; }
-
-    /**
-     * The metadata of the LDAP server used to authenticate and authorize connections
-     * to the broker.
-     */
-    inline void SetLdapServerMetadata(LdapServerMetadataOutput&& value) { m_ldapServerMetadata = std::move(value); }
-
-    /**
-     * The metadata of the LDAP server used to authenticate and authorize connections
-     * to the broker.
-     */
-    inline DescribeBrokerResult& WithLdapServerMetadata(const LdapServerMetadataOutput& value) { SetLdapServerMetadata(value); return *this;}
-
-    /**
-     * The metadata of the LDAP server used to authenticate and authorize connections
-     * to the broker.
-     */
-    inline DescribeBrokerResult& WithLdapServerMetadata(LdapServerMetadataOutput&& value) { SetLdapServerMetadata(std::move(value)); return *this;}
-
-
     /**
      * The list of information about logs currently enabled and pending to be deployed
      * for the specified broker.
@@ -588,32 +511,6 @@ namespace Model
     inline DescribeBrokerResult& WithMaintenanceWindowStartTime(WeeklyStartTime&& value) { SetMaintenanceWindowStartTime(std::move(value)); return *this;}
 
 
-    /**
-     * The authentication strategy that will be applied when the broker is rebooted.
-     */
-    inline const AuthenticationStrategy& GetPendingAuthenticationStrategy() const{ return m_pendingAuthenticationStrategy; }
-
-    /**
-     * The authentication strategy that will be applied when the broker is rebooted.
-     */
-    inline void SetPendingAuthenticationStrategy(const AuthenticationStrategy& value) { m_pendingAuthenticationStrategy = value; }
-
-    /**
-     * The authentication strategy that will be applied when the broker is rebooted.
-     */
-    inline void SetPendingAuthenticationStrategy(AuthenticationStrategy&& value) { m_pendingAuthenticationStrategy = std::move(value); }
-
-    /**
-     * The authentication strategy that will be applied when the broker is rebooted.
-     */
-    inline DescribeBrokerResult& WithPendingAuthenticationStrategy(const AuthenticationStrategy& value) { SetPendingAuthenticationStrategy(value); return *this;}
-
-    /**
-     * The authentication strategy that will be applied when the broker is rebooted.
-     */
-    inline DescribeBrokerResult& WithPendingAuthenticationStrategy(AuthenticationStrategy&& value) { SetPendingAuthenticationStrategy(std::move(value)); return *this;}
-
-
     /**
      * The version of the broker engine to upgrade to. For a list of supported engine
      * versions, see
@@ -664,128 +561,6 @@ namespace Model
     inline DescribeBrokerResult& WithPendingEngineVersion(const char* value) { SetPendingEngineVersion(value); return *this;}
 
 
-    /**
-     * The host instance type of the broker to upgrade to. For a list of supported
-     * instance types, see
-     * https://docs.aws.amazon.com/amazon-mq/latest/developer-guide//broker.html#broker-instance-types
-     */
-    inline const Aws::String& GetPendingHostInstanceType() const{ return m_pendingHostInstanceType; }
-
-    /**
-     * The host instance type of the broker to upgrade to. For a list of supported
-     * instance types, see
-     * https://docs.aws.amazon.com/amazon-mq/latest/developer-guide//broker.html#broker-instance-types
-     */
-    inline void SetPendingHostInstanceType(const Aws::String& value) { m_pendingHostInstanceType = value; }
-
-    /**
-     * The host instance type of the broker to upgrade to. For a list of supported
-     * instance types, see
-     * https://docs.aws.amazon.com/amazon-mq/latest/developer-guide//broker.html#broker-instance-types
-     */
-    inline void SetPendingHostInstanceType(Aws::String&& value) { m_pendingHostInstanceType = std::move(value); }
-
-    /**
-     * The host instance type of the broker to upgrade to. For a list of supported
-     * instance types, see
-     * https://docs.aws.amazon.com/amazon-mq/latest/developer-guide//broker.html#broker-instance-types
-     */
-    inline void SetPendingHostInstanceType(const char* value) { m_pendingHostInstanceType.assign(value); }
-
-    /**
-     * The host instance type of the broker to upgrade to. For a list of supported
-     * instance types, see
-     * https://docs.aws.amazon.com/amazon-mq/latest/developer-guide//broker.html#broker-instance-types
-     */
-    inline DescribeBrokerResult& WithPendingHostInstanceType(const Aws::String& value) { SetPendingHostInstanceType(value); return *this;}
-
-    /**
-     * The host instance type of the broker to upgrade to. For a list of supported
-     * instance types, see
-     * https://docs.aws.amazon.com/amazon-mq/latest/developer-guide//broker.html#broker-instance-types
-     */
-    inline DescribeBrokerResult& WithPendingHostInstanceType(Aws::String&& value) { SetPendingHostInstanceType(std::move(value)); return *this;}
-
-    /**
-     * The host instance type of the broker to upgrade to. For a list of supported
-     * instance types, see
-     * https://docs.aws.amazon.com/amazon-mq/latest/developer-guide//broker.html#broker-instance-types
-     */
-    inline DescribeBrokerResult& WithPendingHostInstanceType(const char* value) { SetPendingHostInstanceType(value); return *this;}
-
-
-    /**
-     * The metadata of the LDAP server that will be used to authenticate and authorize
-     * connections to the broker once it is rebooted.
-     */
-    inline const LdapServerMetadataOutput& GetPendingLdapServerMetadata() const{ return m_pendingLdapServerMetadata; }
-
-    /**
-     * The metadata of the LDAP server that will be used to authenticate and authorize
-     * connections to the broker once it is rebooted.
-     */
-    inline void SetPendingLdapServerMetadata(const LdapServerMetadataOutput& value) { m_pendingLdapServerMetadata = value; }
-
-    /**
-     * The metadata of the LDAP server that will be used to authenticate and authorize
-     * connections to the broker once it is rebooted.
-     */
-    inline void SetPendingLdapServerMetadata(LdapServerMetadataOutput&& value) { m_pendingLdapServerMetadata = std::move(value); }
-
-    /**
-     * The metadata of the LDAP server that will be used to authenticate and authorize
-     * connections to the broker once it is rebooted.
-     */
-    inline DescribeBrokerResult& WithPendingLdapServerMetadata(const LdapServerMetadataOutput& value) { SetPendingLdapServerMetadata(value); return *this;}
-
-    /**
-     * The metadata of the LDAP server that will be used to authenticate and authorize
-     * connections to the broker once it is rebooted.
-     */
-    inline DescribeBrokerResult& WithPendingLdapServerMetadata(LdapServerMetadataOutput&& value) { SetPendingLdapServerMetadata(std::move(value)); return *this;}
-
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline const Aws::Vector<Aws::String>& GetPendingSecurityGroups() const{ return m_pendingSecurityGroups; }
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline void SetPendingSecurityGroups(const Aws::Vector<Aws::String>& value) { m_pendingSecurityGroups = value; }
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline void SetPendingSecurityGroups(Aws::Vector<Aws::String>&& value) { m_pendingSecurityGroups = std::move(value); }
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline DescribeBrokerResult& WithPendingSecurityGroups(const Aws::Vector<Aws::String>& value) { SetPendingSecurityGroups(value); return *this;}
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline DescribeBrokerResult& WithPendingSecurityGroups(Aws::Vector<Aws::String>&& value) { SetPendingSecurityGroups(std::move(value)); return *this;}
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline DescribeBrokerResult& AddPendingSecurityGroups(const Aws::String& value) { m_pendingSecurityGroups.push_back(value); return *this; }
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline DescribeBrokerResult& AddPendingSecurityGroups(Aws::String&& value) { m_pendingSecurityGroups.push_back(std::move(value)); return *this; }
-
-    /**
-     * The list of pending security groups to authorize connections to brokers.
-     */
-    inline DescribeBrokerResult& AddPendingSecurityGroups(const char* value) { m_pendingSecurityGroups.push_back(value); return *this; }
-
-
     /**
      * Required. Enables connections from applications outside of the VPC that hosts
      * the broker's subnets.
@@ -806,80 +581,54 @@ namespace Model
 
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * Required. The list of rules (1 minimum, 125 maximum) that authorize connections
      * to brokers.
      */
     inline const Aws::Vector<Aws::String>& GetSecurityGroups() const{ return m_securityGroups; }
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * Required. The list of rules (1 minimum, 125 maximum) that authorize connections
      * to brokers.
      */
     inline void SetSecurityGroups(const Aws::Vector<Aws::String>& value) { m_securityGroups = value; }
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * Required. The list of rules (1 minimum, 125 maximum) that authorize connections
      * to brokers.
      */
     inline void SetSecurityGroups(Aws::Vector<Aws::String>&& value) { m_securityGroups = std::move(value); }
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * Required. The list of rules (1 minimum, 125 maximum) that authorize connections
      * to brokers.
      */
     inline DescribeBrokerResult& WithSecurityGroups(const Aws::Vector<Aws::String>& value) { SetSecurityGroups(value); return *this;}
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * Required. The list of rules (1 minimum, 125 maximum) that authorize connections
      * to brokers.
      */
     inline DescribeBrokerResult& WithSecurityGroups(Aws::Vector<Aws::String>&& value) { SetSecurityGroups(std::move(value)); return *this;}
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * Required. The list of rules (1 minimum, 125 maximum) that authorize connections
      * to brokers.
      */
     inline DescribeBrokerResult& AddSecurityGroups(const Aws::String& value) { m_securityGroups.push_back(value); return *this; }
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * Required. The list of rules (1 minimum, 125 maximum) that authorize connections
      * to brokers.
      */
     inline DescribeBrokerResult& AddSecurityGroups(Aws::String&& value) { m_securityGroups.push_back(std::move(value)); return *this; }
 
     /**
-     * The list of security groups (1 minimum, 5 maximum) that authorizes connections
+     * Required. The list of rules (1 minimum, 125 maximum) that authorize connections
      * to brokers.
      */
     inline DescribeBrokerResult& AddSecurityGroups(const char* value) { m_securityGroups.push_back(value); return *this; }
 
 
-    /**
-     * The broker's storage type.
-     */
-    inline const BrokerStorageType& GetStorageType() const{ return m_storageType; }
-
-    /**
-     * The broker's storage type.
-     */
-    inline void SetStorageType(const BrokerStorageType& value) { m_storageType = value; }
-
-    /**
-     * The broker's storage type.
-     */
-    inline void SetStorageType(BrokerStorageType&& value) { m_storageType = std::move(value); }
-
-    /**
-     * The broker's storage type.
-     */
-    inline DescribeBrokerResult& WithStorageType(const BrokerStorageType& value) { SetStorageType(value); return *this;}
-
-    /**
-     * The broker's storage type.
-     */
-    inline DescribeBrokerResult& WithStorageType(BrokerStorageType&& value) { SetStorageType(std::move(value)); return *this;}
-
-
     /**
      * The list of groups (2 maximum) that define which subnets and IP ranges the
      * broker can use from different Availability Zones. A SINGLE_INSTANCE deployment
@@ -1043,8 +792,6 @@ namespace Model
 
   private:
 
-    AuthenticationStrategy m_authenticationStrategy;
-
     bool m_autoMinorVersionUpgrade;
 
     Aws::String m_brokerArn;
@@ -1063,36 +810,22 @@ namespace Model
 
     DeploymentMode m_deploymentMode;
 
-    EncryptionOptions m_encryptionOptions;
-
     EngineType m_engineType;
 
     Aws::String m_engineVersion;
 
     Aws::String m_hostInstanceType;
 
-    LdapServerMetadataOutput m_ldapServerMetadata;
-
     LogsSummary m_logs;
 
     WeeklyStartTime m_maintenanceWindowStartTime;
 
-    AuthenticationStrategy m_pendingAuthenticationStrategy;
-
     Aws::String m_pendingEngineVersion;
 
-    Aws::String m_pendingHostInstanceType;
-
-    LdapServerMetadataOutput m_pendingLdapServerMetadata;
-
-    Aws::Vector<Aws::String> m_pendingSecurityGroups;
-
     bool m_publiclyAccessible;
 
     Aws::Vector<Aws::String> m_securityGroups;
 
-    BrokerStorageType m_storageType;
-
     Aws::Vector<Aws::String> m_subnetIds;
 
     Aws::Map<Aws::String, Aws::String> m_tags;
