@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/neptune/Neptune_EXPORTS.h>
@@ -35,9 +45,9 @@ namespace Model
 {
 
   /**
-   * <p>Contains the details of an Amazon Neptune DB instance.</p> <p>This data type
-   * is used as a response element in the <a>DescribeDBInstances</a>
-   * action.</p><p><h3>See Also:</h3>   <a
+   * <p>Contains the details of an Amazon Neptune DB instance. </p> <p>This data type
+   * is used as a response element in the <a>DescribeDBInstances</a> action.
+   * </p><p><h3>See Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/neptune-2014-10-31/DBInstance">AWS
    * API Reference</a></p>
    */
@@ -400,56 +410,56 @@ namespace Model
     /**
      * <p> Specifies the daily time range during which automated backups are created if
      * automated backups are enabled, as determined by the
-     * <code>BackupRetentionPeriod</code>.</p>
+     * <code>BackupRetentionPeriod</code>. </p>
      */
     inline const Aws::String& GetPreferredBackupWindow() const{ return m_preferredBackupWindow; }
 
     /**
      * <p> Specifies the daily time range during which automated backups are created if
      * automated backups are enabled, as determined by the
-     * <code>BackupRetentionPeriod</code>.</p>
+     * <code>BackupRetentionPeriod</code>. </p>
      */
     inline bool PreferredBackupWindowHasBeenSet() const { return m_preferredBackupWindowHasBeenSet; }
 
     /**
      * <p> Specifies the daily time range during which automated backups are created if
      * automated backups are enabled, as determined by the
-     * <code>BackupRetentionPeriod</code>.</p>
+     * <code>BackupRetentionPeriod</code>. </p>
      */
     inline void SetPreferredBackupWindow(const Aws::String& value) { m_preferredBackupWindowHasBeenSet = true; m_preferredBackupWindow = value; }
 
     /**
      * <p> Specifies the daily time range during which automated backups are created if
      * automated backups are enabled, as determined by the
-     * <code>BackupRetentionPeriod</code>.</p>
+     * <code>BackupRetentionPeriod</code>. </p>
      */
     inline void SetPreferredBackupWindow(Aws::String&& value) { m_preferredBackupWindowHasBeenSet = true; m_preferredBackupWindow = std::move(value); }
 
     /**
      * <p> Specifies the daily time range during which automated backups are created if
      * automated backups are enabled, as determined by the
-     * <code>BackupRetentionPeriod</code>.</p>
+     * <code>BackupRetentionPeriod</code>. </p>
      */
     inline void SetPreferredBackupWindow(const char* value) { m_preferredBackupWindowHasBeenSet = true; m_preferredBackupWindow.assign(value); }
 
     /**
      * <p> Specifies the daily time range during which automated backups are created if
      * automated backups are enabled, as determined by the
-     * <code>BackupRetentionPeriod</code>.</p>
+     * <code>BackupRetentionPeriod</code>. </p>
      */
     inline DBInstance& WithPreferredBackupWindow(const Aws::String& value) { SetPreferredBackupWindow(value); return *this;}
 
     /**
      * <p> Specifies the daily time range during which automated backups are created if
      * automated backups are enabled, as determined by the
-     * <code>BackupRetentionPeriod</code>.</p>
+     * <code>BackupRetentionPeriod</code>. </p>
      */
     inline DBInstance& WithPreferredBackupWindow(Aws::String&& value) { SetPreferredBackupWindow(std::move(value)); return *this;}
 
     /**
      * <p> Specifies the daily time range during which automated backups are created if
      * automated backups are enabled, as determined by the
-     * <code>BackupRetentionPeriod</code>.</p>
+     * <code>BackupRetentionPeriod</code>. </p>
      */
     inline DBInstance& WithPreferredBackupWindow(const char* value) { SetPreferredBackupWindow(value); return *this;}
 
@@ -482,56 +492,56 @@ namespace Model
     /**
      * <p> Provides List of DB security group elements containing only
      * <code>DBSecurityGroup.Name</code> and <code>DBSecurityGroup.Status</code>
-     * subelements.</p>
+     * subelements. </p>
      */
     inline const Aws::Vector<DBSecurityGroupMembership>& GetDBSecurityGroups() const{ return m_dBSecurityGroups; }
 
     /**
      * <p> Provides List of DB security group elements containing only
      * <code>DBSecurityGroup.Name</code> and <code>DBSecurityGroup.Status</code>
-     * subelements.</p>
+     * subelements. </p>
      */
     inline bool DBSecurityGroupsHasBeenSet() const { return m_dBSecurityGroupsHasBeenSet; }
 
     /**
      * <p> Provides List of DB security group elements containing only
      * <code>DBSecurityGroup.Name</code> and <code>DBSecurityGroup.Status</code>
-     * subelements.</p>
+     * subelements. </p>
      */
     inline void SetDBSecurityGroups(const Aws::Vector<DBSecurityGroupMembership>& value) { m_dBSecurityGroupsHasBeenSet = true; m_dBSecurityGroups = value; }
 
     /**
      * <p> Provides List of DB security group elements containing only
      * <code>DBSecurityGroup.Name</code> and <code>DBSecurityGroup.Status</code>
-     * subelements.</p>
+     * subelements. </p>
      */
     inline void SetDBSecurityGroups(Aws::Vector<DBSecurityGroupMembership>&& value) { m_dBSecurityGroupsHasBeenSet = true; m_dBSecurityGroups = std::move(value); }
 
     /**
      * <p> Provides List of DB security group elements containing only
      * <code>DBSecurityGroup.Name</code> and <code>DBSecurityGroup.Status</code>
-     * subelements.</p>
+     * subelements. </p>
      */
     inline DBInstance& WithDBSecurityGroups(const Aws::Vector<DBSecurityGroupMembership>& value) { SetDBSecurityGroups(value); return *this;}
 
     /**
      * <p> Provides List of DB security group elements containing only
      * <code>DBSecurityGroup.Name</code> and <code>DBSecurityGroup.Status</code>
-     * subelements.</p>
+     * subelements. </p>
      */
     inline DBInstance& WithDBSecurityGroups(Aws::Vector<DBSecurityGroupMembership>&& value) { SetDBSecurityGroups(std::move(value)); return *this;}
 
     /**
      * <p> Provides List of DB security group elements containing only
      * <code>DBSecurityGroup.Name</code> and <code>DBSecurityGroup.Status</code>
-     * subelements.</p>
+     * subelements. </p>
      */
     inline DBInstance& AddDBSecurityGroups(const DBSecurityGroupMembership& value) { m_dBSecurityGroupsHasBeenSet = true; m_dBSecurityGroups.push_back(value); return *this; }
 
     /**
      * <p> Provides List of DB security group elements containing only
      * <code>DBSecurityGroup.Name</code> and <code>DBSecurityGroup.Status</code>
-     * subelements.</p>
+     * subelements. </p>
      */
     inline DBInstance& AddDBSecurityGroups(DBSecurityGroupMembership&& value) { m_dBSecurityGroupsHasBeenSet = true; m_dBSecurityGroups.push_back(std::move(value)); return *this; }
 
@@ -1146,83 +1156,91 @@ namespace Model
 
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>Provides the list of option group memberships for this DB instance.</p>
      */
     inline const Aws::Vector<OptionGroupMembership>& GetOptionGroupMemberships() const{ return m_optionGroupMemberships; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>Provides the list of option group memberships for this DB instance.</p>
      */
     inline bool OptionGroupMembershipsHasBeenSet() const { return m_optionGroupMembershipsHasBeenSet; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>Provides the list of option group memberships for this DB instance.</p>
      */
     inline void SetOptionGroupMemberships(const Aws::Vector<OptionGroupMembership>& value) { m_optionGroupMembershipsHasBeenSet = true; m_optionGroupMemberships = value; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>Provides the list of option group memberships for this DB instance.</p>
      */
     inline void SetOptionGroupMemberships(Aws::Vector<OptionGroupMembership>&& value) { m_optionGroupMembershipsHasBeenSet = true; m_optionGroupMemberships = std::move(value); }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>Provides the list of option group memberships for this DB instance.</p>
      */
     inline DBInstance& WithOptionGroupMemberships(const Aws::Vector<OptionGroupMembership>& value) { SetOptionGroupMemberships(value); return *this;}
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>Provides the list of option group memberships for this DB instance.</p>
      */
     inline DBInstance& WithOptionGroupMemberships(Aws::Vector<OptionGroupMembership>&& value) { SetOptionGroupMemberships(std::move(value)); return *this;}
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>Provides the list of option group memberships for this DB instance.</p>
      */
     inline DBInstance& AddOptionGroupMemberships(const OptionGroupMembership& value) { m_optionGroupMembershipsHasBeenSet = true; m_optionGroupMemberships.push_back(value); return *this; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>Provides the list of option group memberships for this DB instance.</p>
      */
     inline DBInstance& AddOptionGroupMemberships(OptionGroupMembership&& value) { m_optionGroupMembershipsHasBeenSet = true; m_optionGroupMemberships.push_back(std::move(value)); return *this; }
 
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>If present, specifies the name of the character set that this instance is
+     * associated with.</p>
      */
     inline const Aws::String& GetCharacterSetName() const{ return m_characterSetName; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>If present, specifies the name of the character set that this instance is
+     * associated with.</p>
      */
     inline bool CharacterSetNameHasBeenSet() const { return m_characterSetNameHasBeenSet; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>If present, specifies the name of the character set that this instance is
+     * associated with.</p>
      */
     inline void SetCharacterSetName(const Aws::String& value) { m_characterSetNameHasBeenSet = true; m_characterSetName = value; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>If present, specifies the name of the character set that this instance is
+     * associated with.</p>
      */
     inline void SetCharacterSetName(Aws::String&& value) { m_characterSetNameHasBeenSet = true; m_characterSetName = std::move(value); }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>If present, specifies the name of the character set that this instance is
+     * associated with.</p>
      */
     inline void SetCharacterSetName(const char* value) { m_characterSetNameHasBeenSet = true; m_characterSetName.assign(value); }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>If present, specifies the name of the character set that this instance is
+     * associated with.</p>
      */
     inline DBInstance& WithCharacterSetName(const Aws::String& value) { SetCharacterSetName(value); return *this;}
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>If present, specifies the name of the character set that this instance is
+     * associated with.</p>
      */
     inline DBInstance& WithCharacterSetName(Aws::String&& value) { SetCharacterSetName(std::move(value)); return *this;}
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>If present, specifies the name of the character set that this instance is
+     * associated with.</p>
      */
     inline DBInstance& WithCharacterSetName(const char* value) { SetCharacterSetName(value); return *this;}
 
@@ -1490,75 +1508,71 @@ namespace Model
 
 
     /**
-     * <p>Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p>Specifies whether the DB instance is encrypted.</p>
      */
     inline bool GetStorageEncrypted() const{ return m_storageEncrypted; }
 
     /**
-     * <p>Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p>Specifies whether the DB instance is encrypted.</p>
      */
     inline bool StorageEncryptedHasBeenSet() const { return m_storageEncryptedHasBeenSet; }
 
     /**
-     * <p>Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p>Specifies whether the DB instance is encrypted.</p>
      */
     inline void SetStorageEncrypted(bool value) { m_storageEncryptedHasBeenSet = true; m_storageEncrypted = value; }
 
     /**
-     * <p>Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p>Specifies whether the DB instance is encrypted.</p>
      */
     inline DBInstance& WithStorageEncrypted(bool value) { SetStorageEncrypted(value); return *this;}
 
 
     /**
-     * <p> Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p> If <code>StorageEncrypted</code> is true, the AWS KMS key identifier for the
+     * encrypted DB instance. </p>
      */
     inline const Aws::String& GetKmsKeyId() const{ return m_kmsKeyId; }
 
     /**
-     * <p> Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p> If <code>StorageEncrypted</code> is true, the AWS KMS key identifier for the
+     * encrypted DB instance. </p>
      */
     inline bool KmsKeyIdHasBeenSet() const { return m_kmsKeyIdHasBeenSet; }
 
     /**
-     * <p> Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p> If <code>StorageEncrypted</code> is true, the AWS KMS key identifier for the
+     * encrypted DB instance. </p>
      */
     inline void SetKmsKeyId(const Aws::String& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = value; }
 
     /**
-     * <p> Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p> If <code>StorageEncrypted</code> is true, the AWS KMS key identifier for the
+     * encrypted DB instance. </p>
      */
     inline void SetKmsKeyId(Aws::String&& value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId = std::move(value); }
 
     /**
-     * <p> Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p> If <code>StorageEncrypted</code> is true, the AWS KMS key identifier for the
+     * encrypted DB instance. </p>
      */
     inline void SetKmsKeyId(const char* value) { m_kmsKeyIdHasBeenSet = true; m_kmsKeyId.assign(value); }
 
     /**
-     * <p> Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p> If <code>StorageEncrypted</code> is true, the AWS KMS key identifier for the
+     * encrypted DB instance. </p>
      */
     inline DBInstance& WithKmsKeyId(const Aws::String& value) { SetKmsKeyId(value); return *this;}
 
     /**
-     * <p> Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p> If <code>StorageEncrypted</code> is true, the AWS KMS key identifier for the
+     * encrypted DB instance. </p>
      */
     inline DBInstance& WithKmsKeyId(Aws::String&& value) { SetKmsKeyId(std::move(value)); return *this;}
 
     /**
-     * <p> Not supported: The encryption for DB instances is managed by the DB
-     * cluster.</p>
+     * <p> If <code>StorageEncrypted</code> is true, the AWS KMS key identifier for the
+     * encrypted DB instance. </p>
      */
     inline DBInstance& WithKmsKeyId(const char* value) { SetKmsKeyId(value); return *this;}
 
@@ -1917,42 +1931,42 @@ namespace Model
 
 
     /**
-     * <p>Not supported.</p>
+     * <p>Not supported. </p>
      */
     inline const Aws::String& GetTimezone() const{ return m_timezone; }
 
     /**
-     * <p>Not supported.</p>
+     * <p>Not supported. </p>
      */
     inline bool TimezoneHasBeenSet() const { return m_timezoneHasBeenSet; }
 
     /**
-     * <p>Not supported.</p>
+     * <p>Not supported. </p>
      */
     inline void SetTimezone(const Aws::String& value) { m_timezoneHasBeenSet = true; m_timezone = value; }
 
     /**
-     * <p>Not supported.</p>
+     * <p>Not supported. </p>
      */
     inline void SetTimezone(Aws::String&& value) { m_timezoneHasBeenSet = true; m_timezone = std::move(value); }
 
     /**
-     * <p>Not supported.</p>
+     * <p>Not supported. </p>
      */
     inline void SetTimezone(const char* value) { m_timezoneHasBeenSet = true; m_timezone.assign(value); }
 
     /**
-     * <p>Not supported.</p>
+     * <p>Not supported. </p>
      */
     inline DBInstance& WithTimezone(const Aws::String& value) { SetTimezone(value); return *this;}
 
     /**
-     * <p>Not supported.</p>
+     * <p>Not supported. </p>
      */
     inline DBInstance& WithTimezone(Aws::String&& value) { SetTimezone(std::move(value)); return *this;}
 
     /**
-     * <p>Not supported.</p>
+     * <p>Not supported. </p>
      */
     inline DBInstance& WithTimezone(const char* value) { SetTimezone(value); return *this;}
 
@@ -1983,63 +1997,83 @@ namespace Model
 
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>True if Performance Insights is enabled for the DB instance, and otherwise
+     * false.</p>
      */
     inline bool GetPerformanceInsightsEnabled() const{ return m_performanceInsightsEnabled; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>True if Performance Insights is enabled for the DB instance, and otherwise
+     * false.</p>
      */
     inline bool PerformanceInsightsEnabledHasBeenSet() const { return m_performanceInsightsEnabledHasBeenSet; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>True if Performance Insights is enabled for the DB instance, and otherwise
+     * false.</p>
      */
     inline void SetPerformanceInsightsEnabled(bool value) { m_performanceInsightsEnabledHasBeenSet = true; m_performanceInsightsEnabled = value; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>True if Performance Insights is enabled for the DB instance, and otherwise
+     * false.</p>
      */
     inline DBInstance& WithPerformanceInsightsEnabled(bool value) { SetPerformanceInsightsEnabled(value); return *this;}
 
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>The AWS KMS key identifier for encryption of Performance Insights data. The
+     * KMS key ID is the Amazon Resource Name (ARN), KMS key identifier, or the KMS key
+     * alias for the KMS encryption key.</p>
      */
     inline const Aws::String& GetPerformanceInsightsKMSKeyId() const{ return m_performanceInsightsKMSKeyId; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>The AWS KMS key identifier for encryption of Performance Insights data. The
+     * KMS key ID is the Amazon Resource Name (ARN), KMS key identifier, or the KMS key
+     * alias for the KMS encryption key.</p>
      */
     inline bool PerformanceInsightsKMSKeyIdHasBeenSet() const { return m_performanceInsightsKMSKeyIdHasBeenSet; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>The AWS KMS key identifier for encryption of Performance Insights data. The
+     * KMS key ID is the Amazon Resource Name (ARN), KMS key identifier, or the KMS key
+     * alias for the KMS encryption key.</p>
      */
     inline void SetPerformanceInsightsKMSKeyId(const Aws::String& value) { m_performanceInsightsKMSKeyIdHasBeenSet = true; m_performanceInsightsKMSKeyId = value; }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>The AWS KMS key identifier for encryption of Performance Insights data. The
+     * KMS key ID is the Amazon Resource Name (ARN), KMS key identifier, or the KMS key
+     * alias for the KMS encryption key.</p>
      */
     inline void SetPerformanceInsightsKMSKeyId(Aws::String&& value) { m_performanceInsightsKMSKeyIdHasBeenSet = true; m_performanceInsightsKMSKeyId = std::move(value); }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>The AWS KMS key identifier for encryption of Performance Insights data. The
+     * KMS key ID is the Amazon Resource Name (ARN), KMS key identifier, or the KMS key
+     * alias for the KMS encryption key.</p>
      */
     inline void SetPerformanceInsightsKMSKeyId(const char* value) { m_performanceInsightsKMSKeyIdHasBeenSet = true; m_performanceInsightsKMSKeyId.assign(value); }
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>The AWS KMS key identifier for encryption of Performance Insights data. The
+     * KMS key ID is the Amazon Resource Name (ARN), KMS key identifier, or the KMS key
+     * alias for the KMS encryption key.</p>
      */
     inline DBInstance& WithPerformanceInsightsKMSKeyId(const Aws::String& value) { SetPerformanceInsightsKMSKeyId(value); return *this;}
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>The AWS KMS key identifier for encryption of Performance Insights data. The
+     * KMS key ID is the Amazon Resource Name (ARN), KMS key identifier, or the KMS key
+     * alias for the KMS encryption key.</p>
      */
     inline DBInstance& WithPerformanceInsightsKMSKeyId(Aws::String&& value) { SetPerformanceInsightsKMSKeyId(std::move(value)); return *this;}
 
     /**
-     * <p> <i>(Not supported by Neptune)</i> </p>
+     * <p>The AWS KMS key identifier for encryption of Performance Insights data. The
+     * KMS key ID is the Amazon Resource Name (ARN), KMS key identifier, or the KMS key
+     * alias for the KMS encryption key.</p>
      */
     inline DBInstance& WithPerformanceInsightsKMSKeyId(const char* value) { SetPerformanceInsightsKMSKeyId(value); return *this;}
 
@@ -2098,39 +2132,6 @@ namespace Model
      */
     inline DBInstance& AddEnabledCloudwatchLogsExports(const char* value) { m_enabledCloudwatchLogsExportsHasBeenSet = true; m_enabledCloudwatchLogsExports.push_back(value); return *this; }
 
-
-    /**
-     * <p>Indicates whether or not the DB instance has deletion protection enabled. The
-     * instance can't be deleted when deletion protection is enabled. See <a
-     * href="https://docs.aws.amazon.com/neptune/latest/userguide/manage-console-instances-delete.html">Deleting
-     * a DB Instance</a>.</p>
-     */
-    inline bool GetDeletionProtection() const{ return m_deletionProtection; }
-
-    /**
-     * <p>Indicates whether or not the DB instance has deletion protection enabled. The
-     * instance can't be deleted when deletion protection is enabled. See <a
-     * href="https://docs.aws.amazon.com/neptune/latest/userguide/manage-console-instances-delete.html">Deleting
-     * a DB Instance</a>.</p>
-     */
-    inline bool DeletionProtectionHasBeenSet() const { return m_deletionProtectionHasBeenSet; }
-
-    /**
-     * <p>Indicates whether or not the DB instance has deletion protection enabled. The
-     * instance can't be deleted when deletion protection is enabled. See <a
-     * href="https://docs.aws.amazon.com/neptune/latest/userguide/manage-console-instances-delete.html">Deleting
-     * a DB Instance</a>.</p>
-     */
-    inline void SetDeletionProtection(bool value) { m_deletionProtectionHasBeenSet = true; m_deletionProtection = value; }
-
-    /**
-     * <p>Indicates whether or not the DB instance has deletion protection enabled. The
-     * instance can't be deleted when deletion protection is enabled. See <a
-     * href="https://docs.aws.amazon.com/neptune/latest/userguide/manage-console-instances-delete.html">Deleting
-     * a DB Instance</a>.</p>
-     */
-    inline DBInstance& WithDeletionProtection(bool value) { SetDeletionProtection(value); return *this;}
-
   private:
 
     Aws::String m_dBInstanceIdentifier;
@@ -2285,9 +2286,6 @@ namespace Model
 
     Aws::Vector<Aws::String> m_enabledCloudwatchLogsExports;
     bool m_enabledCloudwatchLogsExportsHasBeenSet;
-
-    bool m_deletionProtection;
-    bool m_deletionProtectionHasBeenSet;
   };
 
 } // namespace Model
