@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/organizations/Organizations_EXPORTS.h>
@@ -20,7 +30,6 @@ namespace Model
     INVALID_SYNTAX_ORGANIZATION_ARN,
     INVALID_SYNTAX_POLICY_ID,
     INVALID_ENUM,
-    INVALID_ENUM_POLICY_TYPE,
     INVALID_LIST_MEMBER,
     MAX_LENGTH_EXCEEDED,
     MAX_VALUE_EXCEEDED,
@@ -35,10 +44,7 @@ namespace Model
     MOVING_ACCOUNT_BETWEEN_DIFFERENT_ROOTS,
     INVALID_FULL_NAME_TARGET,
     UNRECOGNIZED_SERVICE_PRINCIPAL,
-    INVALID_ROLE_NAME,
-    INVALID_SYSTEM_TAGS_PARAMETER,
-    DUPLICATE_TAG_KEY,
-    TARGET_NOT_SUPPORTED
+    INVALID_ROLE_NAME
   };
 
 namespace InvalidInputExceptionReasonMapper
