@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/pinpoint/Pinpoint_EXPORTS.h>
@@ -24,8 +34,7 @@ namespace Model
 {
 
   /**
-   * <p>Provides information about an activity that was performed by a
-   * campaign.</p><p><h3>See Also:</h3>   <a
+   * Activity definition<p><h3>See Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/pinpoint-2016-12-01/ActivityResponse">AWS
    * API Reference</a></p>
    */
@@ -39,506 +48,510 @@ namespace Model
 
 
     /**
-     * <p>The unique identifier for the application that the campaign applies to.</p>
+     * The ID of the application to which the campaign applies.
      */
     inline const Aws::String& GetApplicationId() const{ return m_applicationId; }
 
     /**
-     * <p>The unique identifier for the application that the campaign applies to.</p>
+     * The ID of the application to which the campaign applies.
      */
     inline bool ApplicationIdHasBeenSet() const { return m_applicationIdHasBeenSet; }
 
     /**
-     * <p>The unique identifier for the application that the campaign applies to.</p>
+     * The ID of the application to which the campaign applies.
      */
     inline void SetApplicationId(const Aws::String& value) { m_applicationIdHasBeenSet = true; m_applicationId = value; }
 
     /**
-     * <p>The unique identifier for the application that the campaign applies to.</p>
+     * The ID of the application to which the campaign applies.
      */
     inline void SetApplicationId(Aws::String&& value) { m_applicationIdHasBeenSet = true; m_applicationId = std::move(value); }
 
     /**
-     * <p>The unique identifier for the application that the campaign applies to.</p>
+     * The ID of the application to which the campaign applies.
      */
     inline void SetApplicationId(const char* value) { m_applicationIdHasBeenSet = true; m_applicationId.assign(value); }
 
     /**
-     * <p>The unique identifier for the application that the campaign applies to.</p>
+     * The ID of the application to which the campaign applies.
      */
     inline ActivityResponse& WithApplicationId(const Aws::String& value) { SetApplicationId(value); return *this;}
 
     /**
-     * <p>The unique identifier for the application that the campaign applies to.</p>
+     * The ID of the application to which the campaign applies.
      */
     inline ActivityResponse& WithApplicationId(Aws::String&& value) { SetApplicationId(std::move(value)); return *this;}
 
     /**
-     * <p>The unique identifier for the application that the campaign applies to.</p>
+     * The ID of the application to which the campaign applies.
      */
     inline ActivityResponse& WithApplicationId(const char* value) { SetApplicationId(value); return *this;}
 
 
     /**
-     * <p>The unique identifier for the campaign that the activity applies to.</p>
+     * The ID of the campaign to which the activity applies.
      */
     inline const Aws::String& GetCampaignId() const{ return m_campaignId; }
 
     /**
-     * <p>The unique identifier for the campaign that the activity applies to.</p>
+     * The ID of the campaign to which the activity applies.
      */
     inline bool CampaignIdHasBeenSet() const { return m_campaignIdHasBeenSet; }
 
     /**
-     * <p>The unique identifier for the campaign that the activity applies to.</p>
+     * The ID of the campaign to which the activity applies.
      */
     inline void SetCampaignId(const Aws::String& value) { m_campaignIdHasBeenSet = true; m_campaignId = value; }
 
     /**
-     * <p>The unique identifier for the campaign that the activity applies to.</p>
+     * The ID of the campaign to which the activity applies.
      */
     inline void SetCampaignId(Aws::String&& value) { m_campaignIdHasBeenSet = true; m_campaignId = std::move(value); }
 
     /**
-     * <p>The unique identifier for the campaign that the activity applies to.</p>
+     * The ID of the campaign to which the activity applies.
      */
     inline void SetCampaignId(const char* value) { m_campaignIdHasBeenSet = true; m_campaignId.assign(value); }
 
     /**
-     * <p>The unique identifier for the campaign that the activity applies to.</p>
+     * The ID of the campaign to which the activity applies.
      */
     inline ActivityResponse& WithCampaignId(const Aws::String& value) { SetCampaignId(value); return *this;}
 
     /**
-     * <p>The unique identifier for the campaign that the activity applies to.</p>
+     * The ID of the campaign to which the activity applies.
      */
     inline ActivityResponse& WithCampaignId(Aws::String&& value) { SetCampaignId(std::move(value)); return *this;}
 
     /**
-     * <p>The unique identifier for the campaign that the activity applies to.</p>
+     * The ID of the campaign to which the activity applies.
      */
     inline ActivityResponse& WithCampaignId(const char* value) { SetCampaignId(value); return *this;}
 
 
     /**
-     * <p>The actual time, in ISO 8601 format, when the activity was marked CANCELLED
-     * or COMPLETED.</p>
+     * The actual time the activity was marked CANCELLED or COMPLETED. Provided in ISO
+     * 8601 format.
      */
     inline const Aws::String& GetEnd() const{ return m_end; }
 
     /**
-     * <p>The actual time, in ISO 8601 format, when the activity was marked CANCELLED
-     * or COMPLETED.</p>
+     * The actual time the activity was marked CANCELLED or COMPLETED. Provided in ISO
+     * 8601 format.
      */
     inline bool EndHasBeenSet() const { return m_endHasBeenSet; }
 
     /**
-     * <p>The actual time, in ISO 8601 format, when the activity was marked CANCELLED
-     * or COMPLETED.</p>
+     * The actual time the activity was marked CANCELLED or COMPLETED. Provided in ISO
+     * 8601 format.
      */
     inline void SetEnd(const Aws::String& value) { m_endHasBeenSet = true; m_end = value; }
 
     /**
-     * <p>The actual time, in ISO 8601 format, when the activity was marked CANCELLED
-     * or COMPLETED.</p>
+     * The actual time the activity was marked CANCELLED or COMPLETED. Provided in ISO
+     * 8601 format.
      */
     inline void SetEnd(Aws::String&& value) { m_endHasBeenSet = true; m_end = std::move(value); }
 
     /**
-     * <p>The actual time, in ISO 8601 format, when the activity was marked CANCELLED
-     * or COMPLETED.</p>
+     * The actual time the activity was marked CANCELLED or COMPLETED. Provided in ISO
+     * 8601 format.
      */
     inline void SetEnd(const char* value) { m_endHasBeenSet = true; m_end.assign(value); }
 
     /**
-     * <p>The actual time, in ISO 8601 format, when the activity was marked CANCELLED
-     * or COMPLETED.</p>
+     * The actual time the activity was marked CANCELLED or COMPLETED. Provided in ISO
+     * 8601 format.
      */
     inline ActivityResponse& WithEnd(const Aws::String& value) { SetEnd(value); return *this;}
 
     /**
-     * <p>The actual time, in ISO 8601 format, when the activity was marked CANCELLED
-     * or COMPLETED.</p>
+     * The actual time the activity was marked CANCELLED or COMPLETED. Provided in ISO
+     * 8601 format.
      */
     inline ActivityResponse& WithEnd(Aws::String&& value) { SetEnd(std::move(value)); return *this;}
 
     /**
-     * <p>The actual time, in ISO 8601 format, when the activity was marked CANCELLED
-     * or COMPLETED.</p>
+     * The actual time the activity was marked CANCELLED or COMPLETED. Provided in ISO
+     * 8601 format.
      */
     inline ActivityResponse& WithEnd(const char* value) { SetEnd(value); return *this;}
 
 
     /**
-     * <p>The unique identifier for the activity.</p>
+     * The unique activity ID.
      */
     inline const Aws::String& GetId() const{ return m_id; }
 
     /**
-     * <p>The unique identifier for the activity.</p>
+     * The unique activity ID.
      */
     inline bool IdHasBeenSet() const { return m_idHasBeenSet; }
 
     /**
-     * <p>The unique identifier for the activity.</p>
+     * The unique activity ID.
      */
     inline void SetId(const Aws::String& value) { m_idHasBeenSet = true; m_id = value; }
 
     /**
-     * <p>The unique identifier for the activity.</p>
+     * The unique activity ID.
      */
     inline void SetId(Aws::String&& value) { m_idHasBeenSet = true; m_id = std::move(value); }
 
     /**
-     * <p>The unique identifier for the activity.</p>
+     * The unique activity ID.
      */
     inline void SetId(const char* value) { m_idHasBeenSet = true; m_id.assign(value); }
 
     /**
-     * <p>The unique identifier for the activity.</p>
+     * The unique activity ID.
      */
     inline ActivityResponse& WithId(const Aws::String& value) { SetId(value); return *this;}
 
     /**
-     * <p>The unique identifier for the activity.</p>
+     * The unique activity ID.
      */
     inline ActivityResponse& WithId(Aws::String&& value) { SetId(std::move(value)); return *this;}
 
     /**
-     * <p>The unique identifier for the activity.</p>
+     * The unique activity ID.
      */
     inline ActivityResponse& WithId(const char* value) { SetId(value); return *this;}
 
 
     /**
-     * <p>Specifies whether the activity succeeded. Possible values are SUCCESS and
-     * FAIL.</p>
+     * Indicates whether the activity succeeded.
+
+Valid values: SUCCESS, FAIL
      */
     inline const Aws::String& GetResult() const{ return m_result; }
 
     /**
-     * <p>Specifies whether the activity succeeded. Possible values are SUCCESS and
-     * FAIL.</p>
+     * Indicates whether the activity succeeded.
+
+Valid values: SUCCESS, FAIL
      */
     inline bool ResultHasBeenSet() const { return m_resultHasBeenSet; }
 
     /**
-     * <p>Specifies whether the activity succeeded. Possible values are SUCCESS and
-     * FAIL.</p>
+     * Indicates whether the activity succeeded.
+
+Valid values: SUCCESS, FAIL
      */
     inline void SetResult(const Aws::String& value) { m_resultHasBeenSet = true; m_result = value; }
 
     /**
-     * <p>Specifies whether the activity succeeded. Possible values are SUCCESS and
-     * FAIL.</p>
+     * Indicates whether the activity succeeded.
+
+Valid values: SUCCESS, FAIL
      */
     inline void SetResult(Aws::String&& value) { m_resultHasBeenSet = true; m_result = std::move(value); }
 
     /**
-     * <p>Specifies whether the activity succeeded. Possible values are SUCCESS and
-     * FAIL.</p>
+     * Indicates whether the activity succeeded.
+
+Valid values: SUCCESS, FAIL
      */
     inline void SetResult(const char* value) { m_resultHasBeenSet = true; m_result.assign(value); }
 
     /**
-     * <p>Specifies whether the activity succeeded. Possible values are SUCCESS and
-     * FAIL.</p>
+     * Indicates whether the activity succeeded.
+
+Valid values: SUCCESS, FAIL
      */
     inline ActivityResponse& WithResult(const Aws::String& value) { SetResult(value); return *this;}
 
     /**
-     * <p>Specifies whether the activity succeeded. Possible values are SUCCESS and
-     * FAIL.</p>
+     * Indicates whether the activity succeeded.
+
+Valid values: SUCCESS, FAIL
      */
     inline ActivityResponse& WithResult(Aws::String&& value) { SetResult(std::move(value)); return *this;}
 
     /**
-     * <p>Specifies whether the activity succeeded. Possible values are SUCCESS and
-     * FAIL.</p>
+     * Indicates whether the activity succeeded.
+
+Valid values: SUCCESS, FAIL
      */
     inline ActivityResponse& WithResult(const char* value) { SetResult(value); return *this;}
 
 
     /**
-     * <p>The scheduled start time, in ISO 8601 format, for the activity.</p>
+     * The scheduled start time for the activity in ISO 8601 format.
      */
     inline const Aws::String& GetScheduledStart() const{ return m_scheduledStart; }
 
     /**
-     * <p>The scheduled start time, in ISO 8601 format, for the activity.</p>
+     * The scheduled start time for the activity in ISO 8601 format.
      */
     inline bool ScheduledStartHasBeenSet() const { return m_scheduledStartHasBeenSet; }
 
     /**
-     * <p>The scheduled start time, in ISO 8601 format, for the activity.</p>
+     * The scheduled start time for the activity in ISO 8601 format.
      */
     inline void SetScheduledStart(const Aws::String& value) { m_scheduledStartHasBeenSet = true; m_scheduledStart = value; }
 
     /**
-     * <p>The scheduled start time, in ISO 8601 format, for the activity.</p>
+     * The scheduled start time for the activity in ISO 8601 format.
      */
     inline void SetScheduledStart(Aws::String&& value) { m_scheduledStartHasBeenSet = true; m_scheduledStart = std::move(value); }
 
     /**
-     * <p>The scheduled start time, in ISO 8601 format, for the activity.</p>
+     * The scheduled start time for the activity in ISO 8601 format.
      */
     inline void SetScheduledStart(const char* value) { m_scheduledStartHasBeenSet = true; m_scheduledStart.assign(value); }
 
     /**
-     * <p>The scheduled start time, in ISO 8601 format, for the activity.</p>
+     * The scheduled start time for the activity in ISO 8601 format.
      */
     inline ActivityResponse& WithScheduledStart(const Aws::String& value) { SetScheduledStart(value); return *this;}
 
     /**
-     * <p>The scheduled start time, in ISO 8601 format, for the activity.</p>
+     * The scheduled start time for the activity in ISO 8601 format.
      */
     inline ActivityResponse& WithScheduledStart(Aws::String&& value) { SetScheduledStart(std::move(value)); return *this;}
 
     /**
-     * <p>The scheduled start time, in ISO 8601 format, for the activity.</p>
+     * The scheduled start time for the activity in ISO 8601 format.
      */
     inline ActivityResponse& WithScheduledStart(const char* value) { SetScheduledStart(value); return *this;}
 
 
     /**
-     * <p>The actual start time, in ISO 8601 format, of the activity.</p>
+     * The actual start time of the activity in ISO 8601 format.
      */
     inline const Aws::String& GetStart() const{ return m_start; }
 
     /**
-     * <p>The actual start time, in ISO 8601 format, of the activity.</p>
+     * The actual start time of the activity in ISO 8601 format.
      */
     inline bool StartHasBeenSet() const { return m_startHasBeenSet; }
 
     /**
-     * <p>The actual start time, in ISO 8601 format, of the activity.</p>
+     * The actual start time of the activity in ISO 8601 format.
      */
     inline void SetStart(const Aws::String& value) { m_startHasBeenSet = true; m_start = value; }
 
     /**
-     * <p>The actual start time, in ISO 8601 format, of the activity.</p>
+     * The actual start time of the activity in ISO 8601 format.
      */
     inline void SetStart(Aws::String&& value) { m_startHasBeenSet = true; m_start = std::move(value); }
 
     /**
-     * <p>The actual start time, in ISO 8601 format, of the activity.</p>
+     * The actual start time of the activity in ISO 8601 format.
      */
     inline void SetStart(const char* value) { m_startHasBeenSet = true; m_start.assign(value); }
 
     /**
-     * <p>The actual start time, in ISO 8601 format, of the activity.</p>
+     * The actual start time of the activity in ISO 8601 format.
      */
     inline ActivityResponse& WithStart(const Aws::String& value) { SetStart(value); return *this;}
 
     /**
-     * <p>The actual start time, in ISO 8601 format, of the activity.</p>
+     * The actual start time of the activity in ISO 8601 format.
      */
     inline ActivityResponse& WithStart(Aws::String&& value) { SetStart(std::move(value)); return *this;}
 
     /**
-     * <p>The actual start time, in ISO 8601 format, of the activity.</p>
+     * The actual start time of the activity in ISO 8601 format.
      */
     inline ActivityResponse& WithStart(const char* value) { SetStart(value); return *this;}
 
 
     /**
-     * <p>The current status of the activity. Possible values are: PENDING,
-     * INITIALIZING, RUNNING, PAUSED, CANCELLED, and COMPLETED.</p>
+     * The state of the activity.
+
+Valid values: PENDING, INITIALIZING, RUNNING,
+     * PAUSED, CANCELLED, COMPLETED
      */
     inline const Aws::String& GetState() const{ return m_state; }
 
     /**
-     * <p>The current status of the activity. Possible values are: PENDING,
-     * INITIALIZING, RUNNING, PAUSED, CANCELLED, and COMPLETED.</p>
+     * The state of the activity.
+
+Valid values: PENDING, INITIALIZING, RUNNING,
+     * PAUSED, CANCELLED, COMPLETED
      */
     inline bool StateHasBeenSet() const { return m_stateHasBeenSet; }
 
     /**
-     * <p>The current status of the activity. Possible values are: PENDING,
-     * INITIALIZING, RUNNING, PAUSED, CANCELLED, and COMPLETED.</p>
+     * The state of the activity.
+
+Valid values: PENDING, INITIALIZING, RUNNING,
+     * PAUSED, CANCELLED, COMPLETED
      */
     inline void SetState(const Aws::String& value) { m_stateHasBeenSet = true; m_state = value; }
 
     /**
-     * <p>The current status of the activity. Possible values are: PENDING,
-     * INITIALIZING, RUNNING, PAUSED, CANCELLED, and COMPLETED.</p>
+     * The state of the activity.
+
+Valid values: PENDING, INITIALIZING, RUNNING,
+     * PAUSED, CANCELLED, COMPLETED
      */
     inline void SetState(Aws::String&& value) { m_stateHasBeenSet = true; m_state = std::move(value); }
 
     /**
-     * <p>The current status of the activity. Possible values are: PENDING,
-     * INITIALIZING, RUNNING, PAUSED, CANCELLED, and COMPLETED.</p>
+     * The state of the activity.
+
+Valid values: PENDING, INITIALIZING, RUNNING,
+     * PAUSED, CANCELLED, COMPLETED
      */
     inline void SetState(const char* value) { m_stateHasBeenSet = true; m_state.assign(value); }
 
     /**
-     * <p>The current status of the activity. Possible values are: PENDING,
-     * INITIALIZING, RUNNING, PAUSED, CANCELLED, and COMPLETED.</p>
+     * The state of the activity.
+
+Valid values: PENDING, INITIALIZING, RUNNING,
+     * PAUSED, CANCELLED, COMPLETED
      */
     inline ActivityResponse& WithState(const Aws::String& value) { SetState(value); return *this;}
 
     /**
-     * <p>The current status of the activity. Possible values are: PENDING,
-     * INITIALIZING, RUNNING, PAUSED, CANCELLED, and COMPLETED.</p>
+     * The state of the activity.
+
+Valid values: PENDING, INITIALIZING, RUNNING,
+     * PAUSED, CANCELLED, COMPLETED
      */
     inline ActivityResponse& WithState(Aws::String&& value) { SetState(std::move(value)); return *this;}
 
     /**
-     * <p>The current status of the activity. Possible values are: PENDING,
-     * INITIALIZING, RUNNING, PAUSED, CANCELLED, and COMPLETED.</p>
+     * The state of the activity.
+
+Valid values: PENDING, INITIALIZING, RUNNING,
+     * PAUSED, CANCELLED, COMPLETED
      */
     inline ActivityResponse& WithState(const char* value) { SetState(value); return *this;}
 
 
     /**
-     * <p>The total number of endpoints that the campaign successfully delivered
-     * messages to.</p>
+     * The total number of endpoints to which the campaign successfully delivered
+     * messages.
      */
     inline int GetSuccessfulEndpointCount() const{ return m_successfulEndpointCount; }
 
     /**
-     * <p>The total number of endpoints that the campaign successfully delivered
-     * messages to.</p>
+     * The total number of endpoints to which the campaign successfully delivered
+     * messages.
      */
     inline bool SuccessfulEndpointCountHasBeenSet() const { return m_successfulEndpointCountHasBeenSet; }
 
     /**
-     * <p>The total number of endpoints that the campaign successfully delivered
-     * messages to.</p>
+     * The total number of endpoints to which the campaign successfully delivered
+     * messages.
      */
     inline void SetSuccessfulEndpointCount(int value) { m_successfulEndpointCountHasBeenSet = true; m_successfulEndpointCount = value; }
 
     /**
-     * <p>The total number of endpoints that the campaign successfully delivered
-     * messages to.</p>
+     * The total number of endpoints to which the campaign successfully delivered
+     * messages.
      */
     inline ActivityResponse& WithSuccessfulEndpointCount(int value) { SetSuccessfulEndpointCount(value); return *this;}
 
 
     /**
-     * <p>The total number of time zones that were completed.</p>
+     * The total number of timezones completed.
      */
     inline int GetTimezonesCompletedCount() const{ return m_timezonesCompletedCount; }
 
     /**
-     * <p>The total number of time zones that were completed.</p>
+     * The total number of timezones completed.
      */
     inline bool TimezonesCompletedCountHasBeenSet() const { return m_timezonesCompletedCountHasBeenSet; }
 
     /**
-     * <p>The total number of time zones that were completed.</p>
+     * The total number of timezones completed.
      */
     inline void SetTimezonesCompletedCount(int value) { m_timezonesCompletedCountHasBeenSet = true; m_timezonesCompletedCount = value; }
 
     /**
-     * <p>The total number of time zones that were completed.</p>
+     * The total number of timezones completed.
      */
     inline ActivityResponse& WithTimezonesCompletedCount(int value) { SetTimezonesCompletedCount(value); return *this;}
 
 
     /**
-     * <p>The total number of unique time zones that are in the segment for the
-     * campaign.</p>
+     * The total number of unique timezones present in the segment.
      */
     inline int GetTimezonesTotalCount() const{ return m_timezonesTotalCount; }
 
     /**
-     * <p>The total number of unique time zones that are in the segment for the
-     * campaign.</p>
+     * The total number of unique timezones present in the segment.
      */
     inline bool TimezonesTotalCountHasBeenSet() const { return m_timezonesTotalCountHasBeenSet; }
 
     /**
-     * <p>The total number of unique time zones that are in the segment for the
-     * campaign.</p>
+     * The total number of unique timezones present in the segment.
      */
     inline void SetTimezonesTotalCount(int value) { m_timezonesTotalCountHasBeenSet = true; m_timezonesTotalCount = value; }
 
     /**
-     * <p>The total number of unique time zones that are in the segment for the
-     * campaign.</p>
+     * The total number of unique timezones present in the segment.
      */
     inline ActivityResponse& WithTimezonesTotalCount(int value) { SetTimezonesTotalCount(value); return *this;}
 
 
     /**
-     * <p>The total number of endpoints that the campaign attempted to deliver messages
-     * to.</p>
+     * The total number of endpoints to which the campaign attempts to deliver
+     * messages.
      */
     inline int GetTotalEndpointCount() const{ return m_totalEndpointCount; }
 
     /**
-     * <p>The total number of endpoints that the campaign attempted to deliver messages
-     * to.</p>
+     * The total number of endpoints to which the campaign attempts to deliver
+     * messages.
      */
     inline bool TotalEndpointCountHasBeenSet() const { return m_totalEndpointCountHasBeenSet; }
 
     /**
-     * <p>The total number of endpoints that the campaign attempted to deliver messages
-     * to.</p>
+     * The total number of endpoints to which the campaign attempts to deliver
+     * messages.
      */
     inline void SetTotalEndpointCount(int value) { m_totalEndpointCountHasBeenSet = true; m_totalEndpointCount = value; }
 
     /**
-     * <p>The total number of endpoints that the campaign attempted to deliver messages
-     * to.</p>
+     * The total number of endpoints to which the campaign attempts to deliver
+     * messages.
      */
     inline ActivityResponse& WithTotalEndpointCount(int value) { SetTotalEndpointCount(value); return *this;}
 
 
     /**
-     * <p>The unique identifier for the campaign treatment that the activity applies
-     * to. A treatment is a variation of a campaign that's used for A/B testing of a
-     * campaign.</p>
+     * The ID of a variation of the campaign used for A/B testing.
      */
     inline const Aws::String& GetTreatmentId() const{ return m_treatmentId; }
 
     /**
-     * <p>The unique identifier for the campaign treatment that the activity applies
-     * to. A treatment is a variation of a campaign that's used for A/B testing of a
-     * campaign.</p>
+     * The ID of a variation of the campaign used for A/B testing.
      */
     inline bool TreatmentIdHasBeenSet() const { return m_treatmentIdHasBeenSet; }
 
     /**
-     * <p>The unique identifier for the campaign treatment that the activity applies
-     * to. A treatment is a variation of a campaign that's used for A/B testing of a
-     * campaign.</p>
+     * The ID of a variation of the campaign used for A/B testing.
      */
     inline void SetTreatmentId(const Aws::String& value) { m_treatmentIdHasBeenSet = true; m_treatmentId = value; }
 
     /**
-     * <p>The unique identifier for the campaign treatment that the activity applies
-     * to. A treatment is a variation of a campaign that's used for A/B testing of a
-     * campaign.</p>
+     * The ID of a variation of the campaign used for A/B testing.
      */
     inline void SetTreatmentId(Aws::String&& value) { m_treatmentIdHasBeenSet = true; m_treatmentId = std::move(value); }
 
     /**
-     * <p>The unique identifier for the campaign treatment that the activity applies
-     * to. A treatment is a variation of a campaign that's used for A/B testing of a
-     * campaign.</p>
+     * The ID of a variation of the campaign used for A/B testing.
      */
     inline void SetTreatmentId(const char* value) { m_treatmentIdHasBeenSet = true; m_treatmentId.assign(value); }
 
     /**
-     * <p>The unique identifier for the campaign treatment that the activity applies
-     * to. A treatment is a variation of a campaign that's used for A/B testing of a
-     * campaign.</p>
+     * The ID of a variation of the campaign used for A/B testing.
      */
     inline ActivityResponse& WithTreatmentId(const Aws::String& value) { SetTreatmentId(value); return *this;}
 
     /**
-     * <p>The unique identifier for the campaign treatment that the activity applies
-     * to. A treatment is a variation of a campaign that's used for A/B testing of a
-     * campaign.</p>
+     * The ID of a variation of the campaign used for A/B testing.
      */
     inline ActivityResponse& WithTreatmentId(Aws::String&& value) { SetTreatmentId(std::move(value)); return *this;}
 
     /**
-     * <p>The unique identifier for the campaign treatment that the activity applies
-     * to. A treatment is a variation of a campaign that's used for A/B testing of a
-     * campaign.</p>
+     * The ID of a variation of the campaign used for A/B testing.
      */
     inline ActivityResponse& WithTreatmentId(const char* value) { SetTreatmentId(value); return *this;}
 
