@@ -1,18 +1,27 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/polly/Polly_EXPORTS.h>
 #include <aws/polly/PollyRequest.h>
-#include <aws/polly/model/Engine.h>
-#include <aws/polly/model/LanguageCode.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/polly/model/OutputFormat.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/polly/model/TextType.h>
 #include <aws/polly/model/VoiceId.h>
+#include <aws/polly/model/LanguageCode.h>
 #include <aws/polly/model/SpeechMarkType.h>
 #include <utility>
 
@@ -29,7 +38,7 @@ namespace Model
   {
   public:
     SynthesizeSpeechRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -43,134 +52,12 @@ namespace Model
 
   public:
 
-    /**
-     * <p>Specifies the engine (<code>standard</code> or <code>neural</code>) for
-     * Amazon Polly to use when processing input text for speech synthesis. Using a
-     * voice that is not supported for the engine selected will result in an error.</p>
-     */
-    inline const Engine& GetEngine() const{ return m_engine; }
-
-    /**
-     * <p>Specifies the engine (<code>standard</code> or <code>neural</code>) for
-     * Amazon Polly to use when processing input text for speech synthesis. Using a
-     * voice that is not supported for the engine selected will result in an error.</p>
-     */
-    inline bool EngineHasBeenSet() const { return m_engineHasBeenSet; }
-
-    /**
-     * <p>Specifies the engine (<code>standard</code> or <code>neural</code>) for
-     * Amazon Polly to use when processing input text for speech synthesis. Using a
-     * voice that is not supported for the engine selected will result in an error.</p>
-     */
-    inline void SetEngine(const Engine& value) { m_engineHasBeenSet = true; m_engine = value; }
-
-    /**
-     * <p>Specifies the engine (<code>standard</code> or <code>neural</code>) for
-     * Amazon Polly to use when processing input text for speech synthesis. Using a
-     * voice that is not supported for the engine selected will result in an error.</p>
-     */
-    inline void SetEngine(Engine&& value) { m_engineHasBeenSet = true; m_engine = std::move(value); }
-
-    /**
-     * <p>Specifies the engine (<code>standard</code> or <code>neural</code>) for
-     * Amazon Polly to use when processing input text for speech synthesis. Using a
-     * voice that is not supported for the engine selected will result in an error.</p>
-     */
-    inline SynthesizeSpeechRequest& WithEngine(const Engine& value) { SetEngine(value); return *this;}
-
-    /**
-     * <p>Specifies the engine (<code>standard</code> or <code>neural</code>) for
-     * Amazon Polly to use when processing input text for speech synthesis. Using a
-     * voice that is not supported for the engine selected will result in an error.</p>
-     */
-    inline SynthesizeSpeechRequest& WithEngine(Engine&& value) { SetEngine(std::move(value)); return *this;}
-
-
-    /**
-     * <p>Optional language code for the Synthesize Speech request. This is only
-     * necessary if using a bilingual voice, such as Aditi, which can be used for
-     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
-     * used and no language code is specified, Amazon Polly will use the default
-     * language of the bilingual voice. The default language for any voice is the one
-     * returned by the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
-     * operation for the <code>LanguageCode</code> parameter. For example, if no
-     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
-     */
-    inline const LanguageCode& GetLanguageCode() const{ return m_languageCode; }
-
-    /**
-     * <p>Optional language code for the Synthesize Speech request. This is only
-     * necessary if using a bilingual voice, such as Aditi, which can be used for
-     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
-     * used and no language code is specified, Amazon Polly will use the default
-     * language of the bilingual voice. The default language for any voice is the one
-     * returned by the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
-     * operation for the <code>LanguageCode</code> parameter. For example, if no
-     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
-     */
-    inline bool LanguageCodeHasBeenSet() const { return m_languageCodeHasBeenSet; }
-
-    /**
-     * <p>Optional language code for the Synthesize Speech request. This is only
-     * necessary if using a bilingual voice, such as Aditi, which can be used for
-     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
-     * used and no language code is specified, Amazon Polly will use the default
-     * language of the bilingual voice. The default language for any voice is the one
-     * returned by the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
-     * operation for the <code>LanguageCode</code> parameter. For example, if no
-     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
-     */
-    inline void SetLanguageCode(const LanguageCode& value) { m_languageCodeHasBeenSet = true; m_languageCode = value; }
-
-    /**
-     * <p>Optional language code for the Synthesize Speech request. This is only
-     * necessary if using a bilingual voice, such as Aditi, which can be used for
-     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
-     * used and no language code is specified, Amazon Polly will use the default
-     * language of the bilingual voice. The default language for any voice is the one
-     * returned by the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
-     * operation for the <code>LanguageCode</code> parameter. For example, if no
-     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
-     */
-    inline void SetLanguageCode(LanguageCode&& value) { m_languageCodeHasBeenSet = true; m_languageCode = std::move(value); }
-
-    /**
-     * <p>Optional language code for the Synthesize Speech request. This is only
-     * necessary if using a bilingual voice, such as Aditi, which can be used for
-     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
-     * used and no language code is specified, Amazon Polly will use the default
-     * language of the bilingual voice. The default language for any voice is the one
-     * returned by the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
-     * operation for the <code>LanguageCode</code> parameter. For example, if no
-     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
-     */
-    inline SynthesizeSpeechRequest& WithLanguageCode(const LanguageCode& value) { SetLanguageCode(value); return *this;}
-
-    /**
-     * <p>Optional language code for the Synthesize Speech request. This is only
-     * necessary if using a bilingual voice, such as Aditi, which can be used for
-     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
-     * used and no language code is specified, Amazon Polly will use the default
-     * language of the bilingual voice. The default language for any voice is the one
-     * returned by the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
-     * operation for the <code>LanguageCode</code> parameter. For example, if no
-     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
-     */
-    inline SynthesizeSpeechRequest& WithLanguageCode(LanguageCode&& value) { SetLanguageCode(std::move(value)); return *this;}
-
-
     /**
      * <p>List of one or more pronunciation lexicon names you want the service to apply
      * during synthesis. Lexicons are applied only if the language of the lexicon is
      * the same as the language of the voice. For information about storing lexicons,
      * see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
      */
     inline const Aws::Vector<Aws::String>& GetLexiconNames() const{ return m_lexiconNames; }
 
@@ -179,7 +66,7 @@ namespace Model
      * during synthesis. Lexicons are applied only if the language of the lexicon is
      * the same as the language of the voice. For information about storing lexicons,
      * see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
      */
     inline bool LexiconNamesHasBeenSet() const { return m_lexiconNamesHasBeenSet; }
 
@@ -188,7 +75,7 @@ namespace Model
      * during synthesis. Lexicons are applied only if the language of the lexicon is
      * the same as the language of the voice. For information about storing lexicons,
      * see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
      */
     inline void SetLexiconNames(const Aws::Vector<Aws::String>& value) { m_lexiconNamesHasBeenSet = true; m_lexiconNames = value; }
 
@@ -197,7 +84,7 @@ namespace Model
      * during synthesis. Lexicons are applied only if the language of the lexicon is
      * the same as the language of the voice. For information about storing lexicons,
      * see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
      */
     inline void SetLexiconNames(Aws::Vector<Aws::String>&& value) { m_lexiconNamesHasBeenSet = true; m_lexiconNames = std::move(value); }
 
@@ -206,7 +93,7 @@ namespace Model
      * during synthesis. Lexicons are applied only if the language of the lexicon is
      * the same as the language of the voice. For information about storing lexicons,
      * see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
      */
     inline SynthesizeSpeechRequest& WithLexiconNames(const Aws::Vector<Aws::String>& value) { SetLexiconNames(value); return *this;}
 
@@ -215,7 +102,7 @@ namespace Model
      * during synthesis. Lexicons are applied only if the language of the lexicon is
      * the same as the language of the voice. For information about storing lexicons,
      * see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
      */
     inline SynthesizeSpeechRequest& WithLexiconNames(Aws::Vector<Aws::String>&& value) { SetLexiconNames(std::move(value)); return *this;}
 
@@ -224,7 +111,7 @@ namespace Model
      * during synthesis. Lexicons are applied only if the language of the lexicon is
      * the same as the language of the voice. For information about storing lexicons,
      * see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
      */
     inline SynthesizeSpeechRequest& AddLexiconNames(const Aws::String& value) { m_lexiconNamesHasBeenSet = true; m_lexiconNames.push_back(value); return *this; }
 
@@ -233,7 +120,7 @@ namespace Model
      * during synthesis. Lexicons are applied only if the language of the lexicon is
      * the same as the language of the voice. For information about storing lexicons,
      * see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
      */
     inline SynthesizeSpeechRequest& AddLexiconNames(Aws::String&& value) { m_lexiconNamesHasBeenSet = true; m_lexiconNames.push_back(std::move(value)); return *this; }
 
@@ -242,7 +129,7 @@ namespace Model
      * during synthesis. Lexicons are applied only if the language of the lexicon is
      * the same as the language of the voice. For information about storing lexicons,
      * see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html">PutLexicon</a>.</p>
      */
     inline SynthesizeSpeechRequest& AddLexiconNames(const char* value) { m_lexiconNamesHasBeenSet = true; m_lexiconNames.push_back(value); return *this; }
 
@@ -297,74 +184,66 @@ namespace Model
 
 
     /**
-     * <p>The audio frequency specified in Hz.</p> <p>The valid values for mp3 and
-     * ogg_vorbis are "8000", "16000", "22050", and "24000". The default value for
-     * standard voices is "22050". The default value for neural voices is "24000".</p>
-     * <p>Valid values for pcm are "8000" and "16000" The default value is "16000".
-     * </p>
+     * <p> The audio frequency specified in Hz. </p> <p>The valid values for
+     * <code>mp3</code> and <code>ogg_vorbis</code> are "8000", "16000", and "22050".
+     * The default value is "22050". </p> <p> Valid values for <code>pcm</code> are
+     * "8000" and "16000" The default value is "16000". </p>
      */
     inline const Aws::String& GetSampleRate() const{ return m_sampleRate; }
 
     /**
-     * <p>The audio frequency specified in Hz.</p> <p>The valid values for mp3 and
-     * ogg_vorbis are "8000", "16000", "22050", and "24000". The default value for
-     * standard voices is "22050". The default value for neural voices is "24000".</p>
-     * <p>Valid values for pcm are "8000" and "16000" The default value is "16000".
-     * </p>
+     * <p> The audio frequency specified in Hz. </p> <p>The valid values for
+     * <code>mp3</code> and <code>ogg_vorbis</code> are "8000", "16000", and "22050".
+     * The default value is "22050". </p> <p> Valid values for <code>pcm</code> are
+     * "8000" and "16000" The default value is "16000". </p>
      */
     inline bool SampleRateHasBeenSet() const { return m_sampleRateHasBeenSet; }
 
     /**
-     * <p>The audio frequency specified in Hz.</p> <p>The valid values for mp3 and
-     * ogg_vorbis are "8000", "16000", "22050", and "24000". The default value for
-     * standard voices is "22050". The default value for neural voices is "24000".</p>
-     * <p>Valid values for pcm are "8000" and "16000" The default value is "16000".
-     * </p>
+     * <p> The audio frequency specified in Hz. </p> <p>The valid values for
+     * <code>mp3</code> and <code>ogg_vorbis</code> are "8000", "16000", and "22050".
+     * The default value is "22050". </p> <p> Valid values for <code>pcm</code> are
+     * "8000" and "16000" The default value is "16000". </p>
      */
     inline void SetSampleRate(const Aws::String& value) { m_sampleRateHasBeenSet = true; m_sampleRate = value; }
 
     /**
-     * <p>The audio frequency specified in Hz.</p> <p>The valid values for mp3 and
-     * ogg_vorbis are "8000", "16000", "22050", and "24000". The default value for
-     * standard voices is "22050". The default value for neural voices is "24000".</p>
-     * <p>Valid values for pcm are "8000" and "16000" The default value is "16000".
-     * </p>
+     * <p> The audio frequency specified in Hz. </p> <p>The valid values for
+     * <code>mp3</code> and <code>ogg_vorbis</code> are "8000", "16000", and "22050".
+     * The default value is "22050". </p> <p> Valid values for <code>pcm</code> are
+     * "8000" and "16000" The default value is "16000". </p>
      */
     inline void SetSampleRate(Aws::String&& value) { m_sampleRateHasBeenSet = true; m_sampleRate = std::move(value); }
 
     /**
-     * <p>The audio frequency specified in Hz.</p> <p>The valid values for mp3 and
-     * ogg_vorbis are "8000", "16000", "22050", and "24000". The default value for
-     * standard voices is "22050". The default value for neural voices is "24000".</p>
-     * <p>Valid values for pcm are "8000" and "16000" The default value is "16000".
-     * </p>
+     * <p> The audio frequency specified in Hz. </p> <p>The valid values for
+     * <code>mp3</code> and <code>ogg_vorbis</code> are "8000", "16000", and "22050".
+     * The default value is "22050". </p> <p> Valid values for <code>pcm</code> are
+     * "8000" and "16000" The default value is "16000". </p>
      */
     inline void SetSampleRate(const char* value) { m_sampleRateHasBeenSet = true; m_sampleRate.assign(value); }
 
     /**
-     * <p>The audio frequency specified in Hz.</p> <p>The valid values for mp3 and
-     * ogg_vorbis are "8000", "16000", "22050", and "24000". The default value for
-     * standard voices is "22050". The default value for neural voices is "24000".</p>
-     * <p>Valid values for pcm are "8000" and "16000" The default value is "16000".
-     * </p>
+     * <p> The audio frequency specified in Hz. </p> <p>The valid values for
+     * <code>mp3</code> and <code>ogg_vorbis</code> are "8000", "16000", and "22050".
+     * The default value is "22050". </p> <p> Valid values for <code>pcm</code> are
+     * "8000" and "16000" The default value is "16000". </p>
      */
     inline SynthesizeSpeechRequest& WithSampleRate(const Aws::String& value) { SetSampleRate(value); return *this;}
 
     /**
-     * <p>The audio frequency specified in Hz.</p> <p>The valid values for mp3 and
-     * ogg_vorbis are "8000", "16000", "22050", and "24000". The default value for
-     * standard voices is "22050". The default value for neural voices is "24000".</p>
-     * <p>Valid values for pcm are "8000" and "16000" The default value is "16000".
-     * </p>
+     * <p> The audio frequency specified in Hz. </p> <p>The valid values for
+     * <code>mp3</code> and <code>ogg_vorbis</code> are "8000", "16000", and "22050".
+     * The default value is "22050". </p> <p> Valid values for <code>pcm</code> are
+     * "8000" and "16000" The default value is "16000". </p>
      */
     inline SynthesizeSpeechRequest& WithSampleRate(Aws::String&& value) { SetSampleRate(std::move(value)); return *this;}
 
     /**
-     * <p>The audio frequency specified in Hz.</p> <p>The valid values for mp3 and
-     * ogg_vorbis are "8000", "16000", "22050", and "24000". The default value for
-     * standard voices is "22050". The default value for neural voices is "24000".</p>
-     * <p>Valid values for pcm are "8000" and "16000" The default value is "16000".
-     * </p>
+     * <p> The audio frequency specified in Hz. </p> <p>The valid values for
+     * <code>mp3</code> and <code>ogg_vorbis</code> are "8000", "16000", and "22050".
+     * The default value is "22050". </p> <p> Valid values for <code>pcm</code> are
+     * "8000" and "16000" The default value is "16000". </p>
      */
     inline SynthesizeSpeechRequest& WithSampleRate(const char* value) { SetSampleRate(value); return *this;}
 
@@ -462,42 +341,42 @@ namespace Model
     /**
      * <p> Specifies whether the input text is plain text or SSML. The default value is
      * plain text. For more information, see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
      */
     inline const TextType& GetTextType() const{ return m_textType; }
 
     /**
      * <p> Specifies whether the input text is plain text or SSML. The default value is
      * plain text. For more information, see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
      */
     inline bool TextTypeHasBeenSet() const { return m_textTypeHasBeenSet; }
 
     /**
      * <p> Specifies whether the input text is plain text or SSML. The default value is
      * plain text. For more information, see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
      */
     inline void SetTextType(const TextType& value) { m_textTypeHasBeenSet = true; m_textType = value; }
 
     /**
      * <p> Specifies whether the input text is plain text or SSML. The default value is
      * plain text. For more information, see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
      */
     inline void SetTextType(TextType&& value) { m_textTypeHasBeenSet = true; m_textType = std::move(value); }
 
     /**
      * <p> Specifies whether the input text is plain text or SSML. The default value is
      * plain text. For more information, see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
      */
     inline SynthesizeSpeechRequest& WithTextType(const TextType& value) { SetTextType(value); return *this;}
 
     /**
      * <p> Specifies whether the input text is plain text or SSML. The default value is
      * plain text. For more information, see <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/ssml.html">Using SSML</a>.</p>
      */
     inline SynthesizeSpeechRequest& WithTextType(TextType&& value) { SetTextType(std::move(value)); return *this;}
 
@@ -505,7 +384,7 @@ namespace Model
     /**
      * <p> Voice ID to use for the synthesis. You can get a list of available voice IDs
      * by calling the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
      * operation. </p>
      */
     inline const VoiceId& GetVoiceId() const{ return m_voiceId; }
@@ -513,7 +392,7 @@ namespace Model
     /**
      * <p> Voice ID to use for the synthesis. You can get a list of available voice IDs
      * by calling the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
      * operation. </p>
      */
     inline bool VoiceIdHasBeenSet() const { return m_voiceIdHasBeenSet; }
@@ -521,7 +400,7 @@ namespace Model
     /**
      * <p> Voice ID to use for the synthesis. You can get a list of available voice IDs
      * by calling the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
      * operation. </p>
      */
     inline void SetVoiceId(const VoiceId& value) { m_voiceIdHasBeenSet = true; m_voiceId = value; }
@@ -529,7 +408,7 @@ namespace Model
     /**
      * <p> Voice ID to use for the synthesis. You can get a list of available voice IDs
      * by calling the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
      * operation. </p>
      */
     inline void SetVoiceId(VoiceId&& value) { m_voiceIdHasBeenSet = true; m_voiceId = std::move(value); }
@@ -537,7 +416,7 @@ namespace Model
     /**
      * <p> Voice ID to use for the synthesis. You can get a list of available voice IDs
      * by calling the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
      * operation. </p>
      */
     inline SynthesizeSpeechRequest& WithVoiceId(const VoiceId& value) { SetVoiceId(value); return *this;}
@@ -545,19 +424,92 @@ namespace Model
     /**
      * <p> Voice ID to use for the synthesis. You can get a list of available voice IDs
      * by calling the <a
-     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * href="http://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
      * operation. </p>
      */
     inline SynthesizeSpeechRequest& WithVoiceId(VoiceId&& value) { SetVoiceId(std::move(value)); return *this;}
 
+
+    /**
+     * <p>Optional language code for the Synthesize Speech request. This is only
+     * necessary if using a bilingual voice, such as Aditi, which can be used for
+     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
+     * used and no language code is specified, Amazon Polly will use the default
+     * language of the bilingual voice. The default language for any voice is the one
+     * returned by the <a
+     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * operation for the <code>LanguageCode</code> parameter. For example, if no
+     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
+     */
+    inline const LanguageCode& GetLanguageCode() const{ return m_languageCode; }
+
+    /**
+     * <p>Optional language code for the Synthesize Speech request. This is only
+     * necessary if using a bilingual voice, such as Aditi, which can be used for
+     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
+     * used and no language code is specified, Amazon Polly will use the default
+     * language of the bilingual voice. The default language for any voice is the one
+     * returned by the <a
+     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * operation for the <code>LanguageCode</code> parameter. For example, if no
+     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
+     */
+    inline bool LanguageCodeHasBeenSet() const { return m_languageCodeHasBeenSet; }
+
+    /**
+     * <p>Optional language code for the Synthesize Speech request. This is only
+     * necessary if using a bilingual voice, such as Aditi, which can be used for
+     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
+     * used and no language code is specified, Amazon Polly will use the default
+     * language of the bilingual voice. The default language for any voice is the one
+     * returned by the <a
+     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * operation for the <code>LanguageCode</code> parameter. For example, if no
+     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
+     */
+    inline void SetLanguageCode(const LanguageCode& value) { m_languageCodeHasBeenSet = true; m_languageCode = value; }
+
+    /**
+     * <p>Optional language code for the Synthesize Speech request. This is only
+     * necessary if using a bilingual voice, such as Aditi, which can be used for
+     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
+     * used and no language code is specified, Amazon Polly will use the default
+     * language of the bilingual voice. The default language for any voice is the one
+     * returned by the <a
+     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * operation for the <code>LanguageCode</code> parameter. For example, if no
+     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
+     */
+    inline void SetLanguageCode(LanguageCode&& value) { m_languageCodeHasBeenSet = true; m_languageCode = std::move(value); }
+
+    /**
+     * <p>Optional language code for the Synthesize Speech request. This is only
+     * necessary if using a bilingual voice, such as Aditi, which can be used for
+     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
+     * used and no language code is specified, Amazon Polly will use the default
+     * language of the bilingual voice. The default language for any voice is the one
+     * returned by the <a
+     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * operation for the <code>LanguageCode</code> parameter. For example, if no
+     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
+     */
+    inline SynthesizeSpeechRequest& WithLanguageCode(const LanguageCode& value) { SetLanguageCode(value); return *this;}
+
+    /**
+     * <p>Optional language code for the Synthesize Speech request. This is only
+     * necessary if using a bilingual voice, such as Aditi, which can be used for
+     * either Indian English (en-IN) or Hindi (hi-IN). </p> <p>If a bilingual voice is
+     * used and no language code is specified, Amazon Polly will use the default
+     * language of the bilingual voice. The default language for any voice is the one
+     * returned by the <a
+     * href="https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html">DescribeVoices</a>
+     * operation for the <code>LanguageCode</code> parameter. For example, if no
+     * language code is specified, Aditi will use Indian English rather than Hindi.</p>
+     */
+    inline SynthesizeSpeechRequest& WithLanguageCode(LanguageCode&& value) { SetLanguageCode(std::move(value)); return *this;}
+
   private:
 
-    Engine m_engine;
-    bool m_engineHasBeenSet;
-
-    LanguageCode m_languageCode;
-    bool m_languageCodeHasBeenSet;
-
     Aws::Vector<Aws::String> m_lexiconNames;
     bool m_lexiconNamesHasBeenSet;
 
@@ -578,6 +530,9 @@ namespace Model
 
     VoiceId m_voiceId;
     bool m_voiceIdHasBeenSet;
+
+    LanguageCode m_languageCode;
+    bool m_languageCodeHasBeenSet;
   };
 
 } // namespace Model
