@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/rds/RDS_EXPORTS.h>
@@ -29,7 +39,7 @@ namespace Model
 
   /**
    * <p> This data type is used as a response element in the action
-   * <code>DescribeDBEngineVersions</code>. </p><p><h3>See Also:</h3>   <a
+   * <a>DescribeDBEngineVersions</a>. </p><p><h3>See Also:</h3>   <a
    * href="http://docs.aws.amazon.com/goto/WebAPI/rds-2014-10-31/DBEngineVersion">AWS
    * API Reference</a></p>
    */
@@ -251,42 +261,42 @@ namespace Model
 
     /**
      * <p> The default character set for new instances of this engine version, if the
-     * <code>CharacterSetName</code> parameter of the CreateDBInstance API isn't
+     * <code>CharacterSetName</code> parameter of the CreateDBInstance API is not
      * specified. </p>
      */
     inline const CharacterSet& GetDefaultCharacterSet() const{ return m_defaultCharacterSet; }
 
     /**
      * <p> The default character set for new instances of this engine version, if the
-     * <code>CharacterSetName</code> parameter of the CreateDBInstance API isn't
+     * <code>CharacterSetName</code> parameter of the CreateDBInstance API is not
      * specified. </p>
      */
     inline bool DefaultCharacterSetHasBeenSet() const { return m_defaultCharacterSetHasBeenSet; }
 
     /**
      * <p> The default character set for new instances of this engine version, if the
-     * <code>CharacterSetName</code> parameter of the CreateDBInstance API isn't
+     * <code>CharacterSetName</code> parameter of the CreateDBInstance API is not
      * specified. </p>
      */
     inline void SetDefaultCharacterSet(const CharacterSet& value) { m_defaultCharacterSetHasBeenSet = true; m_defaultCharacterSet = value; }
 
     /**
      * <p> The default character set for new instances of this engine version, if the
-     * <code>CharacterSetName</code> parameter of the CreateDBInstance API isn't
+     * <code>CharacterSetName</code> parameter of the CreateDBInstance API is not
      * specified. </p>
      */
     inline void SetDefaultCharacterSet(CharacterSet&& value) { m_defaultCharacterSetHasBeenSet = true; m_defaultCharacterSet = std::move(value); }
 
     /**
      * <p> The default character set for new instances of this engine version, if the
-     * <code>CharacterSetName</code> parameter of the CreateDBInstance API isn't
+     * <code>CharacterSetName</code> parameter of the CreateDBInstance API is not
      * specified. </p>
      */
     inline DBEngineVersion& WithDefaultCharacterSet(const CharacterSet& value) { SetDefaultCharacterSet(value); return *this;}
 
     /**
      * <p> The default character set for new instances of this engine version, if the
-     * <code>CharacterSetName</code> parameter of the CreateDBInstance API isn't
+     * <code>CharacterSetName</code> parameter of the CreateDBInstance API is not
      * specified. </p>
      */
     inline DBEngineVersion& WithDefaultCharacterSet(CharacterSet&& value) { SetDefaultCharacterSet(std::move(value)); return *this;}
@@ -536,95 +546,68 @@ namespace Model
 
 
     /**
-     * <p>Indicates whether the database engine version supports read replicas.</p>
+     * <p>Indicates whether the database engine version supports Read Replicas.</p>
      */
     inline bool GetSupportsReadReplica() const{ return m_supportsReadReplica; }
 
     /**
-     * <p>Indicates whether the database engine version supports read replicas.</p>
+     * <p>Indicates whether the database engine version supports Read Replicas.</p>
      */
     inline bool SupportsReadReplicaHasBeenSet() const { return m_supportsReadReplicaHasBeenSet; }
 
     /**
-     * <p>Indicates whether the database engine version supports read replicas.</p>
+     * <p>Indicates whether the database engine version supports Read Replicas.</p>
      */
     inline void SetSupportsReadReplica(bool value) { m_supportsReadReplicaHasBeenSet = true; m_supportsReadReplica = value; }
 
     /**
-     * <p>Indicates whether the database engine version supports read replicas.</p>
+     * <p>Indicates whether the database engine version supports Read Replicas.</p>
      */
     inline DBEngineVersion& WithSupportsReadReplica(bool value) { SetSupportsReadReplica(value); return *this;}
 
 
     /**
-     * <p>A list of the supported DB engine modes.</p>  <p> <code>global</code>
-     * engine mode only applies for global database clusters created with Aurora MySQL
-     * version 5.6.10a. For higher Aurora MySQL versions, the clusters in a global
-     * database use <code>provisioned</code> engine mode. </p> 
+     * <p>A list of the supported DB engine modes.</p>
      */
     inline const Aws::Vector<Aws::String>& GetSupportedEngineModes() const{ return m_supportedEngineModes; }
 
     /**
-     * <p>A list of the supported DB engine modes.</p>  <p> <code>global</code>
-     * engine mode only applies for global database clusters created with Aurora MySQL
-     * version 5.6.10a. For higher Aurora MySQL versions, the clusters in a global
-     * database use <code>provisioned</code> engine mode. </p> 
+     * <p>A list of the supported DB engine modes.</p>
      */
     inline bool SupportedEngineModesHasBeenSet() const { return m_supportedEngineModesHasBeenSet; }
 
     /**
-     * <p>A list of the supported DB engine modes.</p>  <p> <code>global</code>
-     * engine mode only applies for global database clusters created with Aurora MySQL
-     * version 5.6.10a. For higher Aurora MySQL versions, the clusters in a global
-     * database use <code>provisioned</code> engine mode. </p> 
+     * <p>A list of the supported DB engine modes.</p>
      */
     inline void SetSupportedEngineModes(const Aws::Vector<Aws::String>& value) { m_supportedEngineModesHasBeenSet = true; m_supportedEngineModes = value; }
 
     /**
-     * <p>A list of the supported DB engine modes.</p>  <p> <code>global</code>
-     * engine mode only applies for global database clusters created with Aurora MySQL
-     * version 5.6.10a. For higher Aurora MySQL versions, the clusters in a global
-     * database use <code>provisioned</code> engine mode. </p> 
+     * <p>A list of the supported DB engine modes.</p>
      */
     inline void SetSupportedEngineModes(Aws::Vector<Aws::String>&& value) { m_supportedEngineModesHasBeenSet = true; m_supportedEngineModes = std::move(value); }
 
     /**
-     * <p>A list of the supported DB engine modes.</p>  <p> <code>global</code>
-     * engine mode only applies for global database clusters created with Aurora MySQL
-     * version 5.6.10a. For higher Aurora MySQL versions, the clusters in a global
-     * database use <code>provisioned</code> engine mode. </p> 
+     * <p>A list of the supported DB engine modes.</p>
      */
     inline DBEngineVersion& WithSupportedEngineModes(const Aws::Vector<Aws::String>& value) { SetSupportedEngineModes(value); return *this;}
 
     /**
-     * <p>A list of the supported DB engine modes.</p>  <p> <code>global</code>
-     * engine mode only applies for global database clusters created with Aurora MySQL
-     * version 5.6.10a. For higher Aurora MySQL versions, the clusters in a global
-     * database use <code>provisioned</code> engine mode. </p> 
+     * <p>A list of the supported DB engine modes.</p>
      */
     inline DBEngineVersion& WithSupportedEngineModes(Aws::Vector<Aws::String>&& value) { SetSupportedEngineModes(std::move(value)); return *this;}
 
     /**
-     * <p>A list of the supported DB engine modes.</p>  <p> <code>global</code>
-     * engine mode only applies for global database clusters created with Aurora MySQL
-     * version 5.6.10a. For higher Aurora MySQL versions, the clusters in a global
-     * database use <code>provisioned</code> engine mode. </p> 
+     * <p>A list of the supported DB engine modes.</p>
      */
     inline DBEngineVersion& AddSupportedEngineModes(const Aws::String& value) { m_supportedEngineModesHasBeenSet = true; m_supportedEngineModes.push_back(value); return *this; }
 
     /**
-     * <p>A list of the supported DB engine modes.</p>  <p> <code>global</code>
-     * engine mode only applies for global database clusters created with Aurora MySQL
-     * version 5.6.10a. For higher Aurora MySQL versions, the clusters in a global
-     * database use <code>provisioned</code> engine mode. </p> 
+     * <p>A list of the supported DB engine modes.</p>
      */
     inline DBEngineVersion& AddSupportedEngineModes(Aws::String&& value) { m_supportedEngineModesHasBeenSet = true; m_supportedEngineModes.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>A list of the supported DB engine modes.</p>  <p> <code>global</code>
-     * engine mode only applies for global database clusters created with Aurora MySQL
-     * version 5.6.10a. For higher Aurora MySQL versions, the clusters in a global
-     * database use <code>provisioned</code> engine mode. </p> 
+     * <p>A list of the supported DB engine modes.</p>
      */
     inline DBEngineVersion& AddSupportedEngineModes(const char* value) { m_supportedEngineModesHasBeenSet = true; m_supportedEngineModes.push_back(value); return *this; }
 
@@ -683,105 +666,6 @@ namespace Model
      */
     inline DBEngineVersion& AddSupportedFeatureNames(const char* value) { m_supportedFeatureNamesHasBeenSet = true; m_supportedFeatureNames.push_back(value); return *this; }
 
-
-    /**
-     * <p>The status of the DB engine version, either <code>available</code> or
-     * <code>deprecated</code>.</p>
-     */
-    inline const Aws::String& GetStatus() const{ return m_status; }
-
-    /**
-     * <p>The status of the DB engine version, either <code>available</code> or
-     * <code>deprecated</code>.</p>
-     */
-    inline bool StatusHasBeenSet() const { return m_statusHasBeenSet; }
-
-    /**
-     * <p>The status of the DB engine version, either <code>available</code> or
-     * <code>deprecated</code>.</p>
-     */
-    inline void SetStatus(const Aws::String& value) { m_statusHasBeenSet = true; m_status = value; }
-
-    /**
-     * <p>The status of the DB engine version, either <code>available</code> or
-     * <code>deprecated</code>.</p>
-     */
-    inline void SetStatus(Aws::String&& value) { m_statusHasBeenSet = true; m_status = std::move(value); }
-
-    /**
-     * <p>The status of the DB engine version, either <code>available</code> or
-     * <code>deprecated</code>.</p>
-     */
-    inline void SetStatus(const char* value) { m_statusHasBeenSet = true; m_status.assign(value); }
-
-    /**
-     * <p>The status of the DB engine version, either <code>available</code> or
-     * <code>deprecated</code>.</p>
-     */
-    inline DBEngineVersion& WithStatus(const Aws::String& value) { SetStatus(value); return *this;}
-
-    /**
-     * <p>The status of the DB engine version, either <code>available</code> or
-     * <code>deprecated</code>.</p>
-     */
-    inline DBEngineVersion& WithStatus(Aws::String&& value) { SetStatus(std::move(value)); return *this;}
-
-    /**
-     * <p>The status of the DB engine version, either <code>available</code> or
-     * <code>deprecated</code>.</p>
-     */
-    inline DBEngineVersion& WithStatus(const char* value) { SetStatus(value); return *this;}
-
-
-    /**
-     * <p>A value that indicates whether you can use Aurora parallel query with a
-     * specific DB engine version.</p>
-     */
-    inline bool GetSupportsParallelQuery() const{ return m_supportsParallelQuery; }
-
-    /**
-     * <p>A value that indicates whether you can use Aurora parallel query with a
-     * specific DB engine version.</p>
-     */
-    inline bool SupportsParallelQueryHasBeenSet() const { return m_supportsParallelQueryHasBeenSet; }
-
-    /**
-     * <p>A value that indicates whether you can use Aurora parallel query with a
-     * specific DB engine version.</p>
-     */
-    inline void SetSupportsParallelQuery(bool value) { m_supportsParallelQueryHasBeenSet = true; m_supportsParallelQuery = value; }
-
-    /**
-     * <p>A value that indicates whether you can use Aurora parallel query with a
-     * specific DB engine version.</p>
-     */
-    inline DBEngineVersion& WithSupportsParallelQuery(bool value) { SetSupportsParallelQuery(value); return *this;}
-
-
-    /**
-     * <p>A value that indicates whether you can use Aurora global databases with a
-     * specific DB engine version.</p>
-     */
-    inline bool GetSupportsGlobalDatabases() const{ return m_supportsGlobalDatabases; }
-
-    /**
-     * <p>A value that indicates whether you can use Aurora global databases with a
-     * specific DB engine version.</p>
-     */
-    inline bool SupportsGlobalDatabasesHasBeenSet() const { return m_supportsGlobalDatabasesHasBeenSet; }
-
-    /**
-     * <p>A value that indicates whether you can use Aurora global databases with a
-     * specific DB engine version.</p>
-     */
-    inline void SetSupportsGlobalDatabases(bool value) { m_supportsGlobalDatabasesHasBeenSet = true; m_supportsGlobalDatabases = value; }
-
-    /**
-     * <p>A value that indicates whether you can use Aurora global databases with a
-     * specific DB engine version.</p>
-     */
-    inline DBEngineVersion& WithSupportsGlobalDatabases(bool value) { SetSupportsGlobalDatabases(value); return *this;}
-
   private:
 
     Aws::String m_engine;
@@ -825,15 +709,6 @@ namespace Model
 
     Aws::Vector<Aws::String> m_supportedFeatureNames;
     bool m_supportedFeatureNamesHasBeenSet;
-
-    Aws::String m_status;
-    bool m_statusHasBeenSet;
-
-    bool m_supportsParallelQuery;
-    bool m_supportsParallelQueryHasBeenSet;
-
-    bool m_supportsGlobalDatabases;
-    bool m_supportsGlobalDatabasesHasBeenSet;
   };
 
 } // namespace Model
