@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/redshift/model/Cluster.h>
 #include <aws/core/utils/xml/XmlSerializer.h>
@@ -24,7 +34,6 @@ Cluster::Cluster() :
     m_clusterIdentifierHasBeenSet(false),
     m_nodeTypeHasBeenSet(false),
     m_clusterStatusHasBeenSet(false),
-    m_clusterAvailabilityStatusHasBeenSet(false),
     m_modifyStatusHasBeenSet(false),
     m_masterUsernameHasBeenSet(false),
     m_dBNameHasBeenSet(false),
@@ -71,9 +80,6 @@ Cluster::Cluster() :
     m_snapshotScheduleIdentifierHasBeenSet(false),
     m_snapshotScheduleState(ScheduleState::NOT_SET),
     m_snapshotScheduleStateHasBeenSet(false),
-    m_expectedNextSnapshotScheduleTimeHasBeenSet(false),
-    m_expectedNextSnapshotScheduleTimeStatusHasBeenSet(false),
-    m_nextMaintenanceWindowStartTimeHasBeenSet(false),
     m_resizeInfoHasBeenSet(false)
 {
 }
@@ -82,7 +88,6 @@ Cluster::Cluster(const XmlNode& xmlNode) :
     m_clusterIdentifierHasBeenSet(false),
     m_nodeTypeHasBeenSet(false),
     m_clusterStatusHasBeenSet(false),
-    m_clusterAvailabilityStatusHasBeenSet(false),
     m_modifyStatusHasBeenSet(false),
     m_masterUsernameHasBeenSet(false),
     m_dBNameHasBeenSet(false),
@@ -129,9 +134,6 @@ Cluster::Cluster(const XmlNode& xmlNode) :
     m_snapshotScheduleIdentifierHasBeenSet(false),
     m_snapshotScheduleState(ScheduleState::NOT_SET),
     m_snapshotScheduleStateHasBeenSet(false),
-    m_expectedNextSnapshotScheduleTimeHasBeenSet(false),
-    m_expectedNextSnapshotScheduleTimeStatusHasBeenSet(false),
-    m_nextMaintenanceWindowStartTimeHasBeenSet(false),
     m_resizeInfoHasBeenSet(false)
 {
   *this = xmlNode;
@@ -146,43 +148,37 @@ Cluster& Cluster::operator =(const XmlNode& xmlNode)
     XmlNode clusterIdentifierNode = resultNode.FirstChild("ClusterIdentifier");
     if(!clusterIdentifierNode.IsNull())
     {
-      m_clusterIdentifier = Aws::Utils::Xml::DecodeEscapedXmlText(clusterIdentifierNode.GetText());
+      m_clusterIdentifier = StringUtils::Trim(clusterIdentifierNode.GetText().c_str());
       m_clusterIdentifierHasBeenSet = true;
     }
     XmlNode nodeTypeNode = resultNode.FirstChild("NodeType");
     if(!nodeTypeNode.IsNull())
     {
-      m_nodeType = Aws::Utils::Xml::DecodeEscapedXmlText(nodeTypeNode.GetText());
+      m_nodeType = StringUtils::Trim(nodeTypeNode.GetText().c_str());
       m_nodeTypeHasBeenSet = true;
     }
     XmlNode clusterStatusNode = resultNode.FirstChild("ClusterStatus");
     if(!clusterStatusNode.IsNull())
     {
-      m_clusterStatus = Aws::Utils::Xml::DecodeEscapedXmlText(clusterStatusNode.GetText());
+      m_clusterStatus = StringUtils::Trim(clusterStatusNode.GetText().c_str());
       m_clusterStatusHasBeenSet = true;
     }
-    XmlNode clusterAvailabilityStatusNode = resultNode.FirstChild("ClusterAvailabilityStatus");
-    if(!clusterAvailabilityStatusNode.IsNull())
-    {
-      m_clusterAvailabilityStatus = Aws::Utils::Xml::DecodeEscapedXmlText(clusterAvailabilityStatusNode.GetText());
-      m_clusterAvailabilityStatusHasBeenSet = true;
-    }
     XmlNode modifyStatusNode = resultNode.FirstChild("ModifyStatus");
     if(!modifyStatusNode.IsNull())
     {
-      m_modifyStatus = Aws::Utils::Xml::DecodeEscapedXmlText(modifyStatusNode.GetText());
+      m_modifyStatus = StringUtils::Trim(modifyStatusNode.GetText().c_str());
       m_modifyStatusHasBeenSet = true;
     }
     XmlNode masterUsernameNode = resultNode.FirstChild("MasterUsername");
     if(!masterUsernameNode.IsNull())
     {
-      m_masterUsername = Aws::Utils::Xml::DecodeEscapedXmlText(masterUsernameNode.GetText());
+      m_masterUsername = StringUtils::Trim(masterUsernameNode.GetText().c_str());
       m_masterUsernameHasBeenSet = true;
     }
     XmlNode dBNameNode = resultNode.FirstChild("DBName");
     if(!dBNameNode.IsNull())
     {
-      m_dBName = Aws::Utils::Xml::DecodeEscapedXmlText(dBNameNode.GetText());
+      m_dBName = StringUtils::Trim(dBNameNode.GetText().c_str());
       m_dBNameHasBeenSet = true;
     }
     XmlNode endpointNode = resultNode.FirstChild("Endpoint");
@@ -194,19 +190,19 @@ Cluster& Cluster::operator =(const XmlNode& xmlNode)
     XmlNode clusterCreateTimeNode = resultNode.FirstChild("ClusterCreateTime");
     if(!clusterCreateTimeNode.IsNull())
     {
-      m_clusterCreateTime = DateTime(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(clusterCreateTimeNode.GetText()).c_str()).c_str(), DateFormat::ISO_8601);
+      m_clusterCreateTime = DateTime(StringUtils::Trim(clusterCreateTimeNode.GetText().c_str()).c_str(), DateFormat::ISO_8601);
       m_clusterCreateTimeHasBeenSet = true;
     }
     XmlNode automatedSnapshotRetentionPeriodNode = resultNode.FirstChild("AutomatedSnapshotRetentionPeriod");
     if(!automatedSnapshotRetentionPeriodNode.IsNull())
     {
-      m_automatedSnapshotRetentionPeriod = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(automatedSnapshotRetentionPeriodNode.GetText()).c_str()).c_str());
+      m_automatedSnapshotRetentionPeriod = StringUtils::ConvertToInt32(StringUtils::Trim(automatedSnapshotRetentionPeriodNode.GetText().c_str()).c_str());
       m_automatedSnapshotRetentionPeriodHasBeenSet = true;
     }
     XmlNode manualSnapshotRetentionPeriodNode = resultNode.FirstChild("ManualSnapshotRetentionPeriod");
     if(!manualSnapshotRetentionPeriodNode.IsNull())
     {
-      m_manualSnapshotRetentionPeriod = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(manualSnapshotRetentionPeriodNode.GetText()).c_str()).c_str());
+      m_manualSnapshotRetentionPeriod = StringUtils::ConvertToInt32(StringUtils::Trim(manualSnapshotRetentionPeriodNode.GetText().c_str()).c_str());
       m_manualSnapshotRetentionPeriodHasBeenSet = true;
     }
     XmlNode clusterSecurityGroupsNode = resultNode.FirstChild("ClusterSecurityGroups");
@@ -248,25 +244,25 @@ Cluster& Cluster::operator =(const XmlNode& xmlNode)
     XmlNode clusterSubnetGroupNameNode = resultNode.FirstChild("ClusterSubnetGroupName");
     if(!clusterSubnetGroupNameNode.IsNull())
     {
-      m_clusterSubnetGroupName = Aws::Utils::Xml::DecodeEscapedXmlText(clusterSubnetGroupNameNode.GetText());
+      m_clusterSubnetGroupName = StringUtils::Trim(clusterSubnetGroupNameNode.GetText().c_str());
       m_clusterSubnetGroupNameHasBeenSet = true;
     }
     XmlNode vpcIdNode = resultNode.FirstChild("VpcId");
     if(!vpcIdNode.IsNull())
     {
-      m_vpcId = Aws::Utils::Xml::DecodeEscapedXmlText(vpcIdNode.GetText());
+      m_vpcId = StringUtils::Trim(vpcIdNode.GetText().c_str());
       m_vpcIdHasBeenSet = true;
     }
     XmlNode availabilityZoneNode = resultNode.FirstChild("AvailabilityZone");
     if(!availabilityZoneNode.IsNull())
     {
-      m_availabilityZone = Aws::Utils::Xml::DecodeEscapedXmlText(availabilityZoneNode.GetText());
+      m_availabilityZone = StringUtils::Trim(availabilityZoneNode.GetText().c_str());
       m_availabilityZoneHasBeenSet = true;
     }
     XmlNode preferredMaintenanceWindowNode = resultNode.FirstChild("PreferredMaintenanceWindow");
     if(!preferredMaintenanceWindowNode.IsNull())
     {
-      m_preferredMaintenanceWindow = Aws::Utils::Xml::DecodeEscapedXmlText(preferredMaintenanceWindowNode.GetText());
+      m_preferredMaintenanceWindow = StringUtils::Trim(preferredMaintenanceWindowNode.GetText().c_str());
       m_preferredMaintenanceWindowHasBeenSet = true;
     }
     XmlNode pendingModifiedValuesNode = resultNode.FirstChild("PendingModifiedValues");
@@ -278,31 +274,31 @@ Cluster& Cluster::operator =(const XmlNode& xmlNode)
     XmlNode clusterVersionNode = resultNode.FirstChild("ClusterVersion");
     if(!clusterVersionNode.IsNull())
     {
-      m_clusterVersion = Aws::Utils::Xml::DecodeEscapedXmlText(clusterVersionNode.GetText());
+      m_clusterVersion = StringUtils::Trim(clusterVersionNode.GetText().c_str());
       m_clusterVersionHasBeenSet = true;
     }
     XmlNode allowVersionUpgradeNode = resultNode.FirstChild("AllowVersionUpgrade");
     if(!allowVersionUpgradeNode.IsNull())
     {
-      m_allowVersionUpgrade = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(allowVersionUpgradeNode.GetText()).c_str()).c_str());
+      m_allowVersionUpgrade = StringUtils::ConvertToBool(StringUtils::Trim(allowVersionUpgradeNode.GetText().c_str()).c_str());
       m_allowVersionUpgradeHasBeenSet = true;
     }
     XmlNode numberOfNodesNode = resultNode.FirstChild("NumberOfNodes");
     if(!numberOfNodesNode.IsNull())
     {
-      m_numberOfNodes = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(numberOfNodesNode.GetText()).c_str()).c_str());
+      m_numberOfNodes = StringUtils::ConvertToInt32(StringUtils::Trim(numberOfNodesNode.GetText().c_str()).c_str());
       m_numberOfNodesHasBeenSet = true;
     }
     XmlNode publiclyAccessibleNode = resultNode.FirstChild("PubliclyAccessible");
     if(!publiclyAccessibleNode.IsNull())
     {
-      m_publiclyAccessible = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(publiclyAccessibleNode.GetText()).c_str()).c_str());
+      m_publiclyAccessible = StringUtils::ConvertToBool(StringUtils::Trim(publiclyAccessibleNode.GetText().c_str()).c_str());
       m_publiclyAccessibleHasBeenSet = true;
     }
     XmlNode encryptedNode = resultNode.FirstChild("Encrypted");
     if(!encryptedNode.IsNull())
     {
-      m_encrypted = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(encryptedNode.GetText()).c_str()).c_str());
+      m_encrypted = StringUtils::ConvertToBool(StringUtils::Trim(encryptedNode.GetText().c_str()).c_str());
       m_encryptedHasBeenSet = true;
     }
     XmlNode restoreStatusNode = resultNode.FirstChild("RestoreStatus");
@@ -332,7 +328,7 @@ Cluster& Cluster::operator =(const XmlNode& xmlNode)
     XmlNode clusterPublicKeyNode = resultNode.FirstChild("ClusterPublicKey");
     if(!clusterPublicKeyNode.IsNull())
     {
-      m_clusterPublicKey = Aws::Utils::Xml::DecodeEscapedXmlText(clusterPublicKeyNode.GetText());
+      m_clusterPublicKey = StringUtils::Trim(clusterPublicKeyNode.GetText().c_str());
       m_clusterPublicKeyHasBeenSet = true;
     }
     XmlNode clusterNodesNode = resultNode.FirstChild("ClusterNodes");
@@ -356,7 +352,7 @@ Cluster& Cluster::operator =(const XmlNode& xmlNode)
     XmlNode clusterRevisionNumberNode = resultNode.FirstChild("ClusterRevisionNumber");
     if(!clusterRevisionNumberNode.IsNull())
     {
-      m_clusterRevisionNumber = Aws::Utils::Xml::DecodeEscapedXmlText(clusterRevisionNumberNode.GetText());
+      m_clusterRevisionNumber = StringUtils::Trim(clusterRevisionNumberNode.GetText().c_str());
       m_clusterRevisionNumberHasBeenSet = true;
     }
     XmlNode tagsNode = resultNode.FirstChild("Tags");
@@ -374,13 +370,13 @@ Cluster& Cluster::operator =(const XmlNode& xmlNode)
     XmlNode kmsKeyIdNode = resultNode.FirstChild("KmsKeyId");
     if(!kmsKeyIdNode.IsNull())
     {
-      m_kmsKeyId = Aws::Utils::Xml::DecodeEscapedXmlText(kmsKeyIdNode.GetText());
+      m_kmsKeyId = StringUtils::Trim(kmsKeyIdNode.GetText().c_str());
       m_kmsKeyIdHasBeenSet = true;
     }
     XmlNode enhancedVpcRoutingNode = resultNode.FirstChild("EnhancedVpcRouting");
     if(!enhancedVpcRoutingNode.IsNull())
     {
-      m_enhancedVpcRouting = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(enhancedVpcRoutingNode.GetText()).c_str()).c_str());
+      m_enhancedVpcRouting = StringUtils::ConvertToBool(StringUtils::Trim(enhancedVpcRoutingNode.GetText().c_str()).c_str());
       m_enhancedVpcRoutingHasBeenSet = true;
     }
     XmlNode iamRolesNode = resultNode.FirstChild("IamRoles");
@@ -401,7 +397,7 @@ Cluster& Cluster::operator =(const XmlNode& xmlNode)
       XmlNode pendingActionsMember = pendingActionsNode.FirstChild("member");
       while(!pendingActionsMember.IsNull())
       {
-        m_pendingActions.push_back(pendingActionsMember.GetText());
+        m_pendingActions.push_back(StringUtils::Trim(pendingActionsMember.GetText().c_str()));
         pendingActionsMember = pendingActionsMember.NextNode("member");
       }
 
@@ -410,13 +406,13 @@ Cluster& Cluster::operator =(const XmlNode& xmlNode)
     XmlNode maintenanceTrackNameNode = resultNode.FirstChild("MaintenanceTrackName");
     if(!maintenanceTrackNameNode.IsNull())
     {
-      m_maintenanceTrackName = Aws::Utils::Xml::DecodeEscapedXmlText(maintenanceTrackNameNode.GetText());
+      m_maintenanceTrackName = StringUtils::Trim(maintenanceTrackNameNode.GetText().c_str());
       m_maintenanceTrackNameHasBeenSet = true;
     }
     XmlNode elasticResizeNumberOfNodeOptionsNode = resultNode.FirstChild("ElasticResizeNumberOfNodeOptions");
     if(!elasticResizeNumberOfNodeOptionsNode.IsNull())
     {
-      m_elasticResizeNumberOfNodeOptions = Aws::Utils::Xml::DecodeEscapedXmlText(elasticResizeNumberOfNodeOptionsNode.GetText());
+      m_elasticResizeNumberOfNodeOptions = StringUtils::Trim(elasticResizeNumberOfNodeOptionsNode.GetText().c_str());
       m_elasticResizeNumberOfNodeOptionsHasBeenSet = true;
     }
     XmlNode deferredMaintenanceWindowsNode = resultNode.FirstChild("DeferredMaintenanceWindows");
@@ -434,33 +430,15 @@ Cluster& Cluster::operator =(const XmlNode& xmlNode)
     XmlNode snapshotScheduleIdentifierNode = resultNode.FirstChild("SnapshotScheduleIdentifier");
     if(!snapshotScheduleIdentifierNode.IsNull())
     {
-      m_snapshotScheduleIdentifier = Aws::Utils::Xml::DecodeEscapedXmlText(snapshotScheduleIdentifierNode.GetText());
+      m_snapshotScheduleIdentifier = StringUtils::Trim(snapshotScheduleIdentifierNode.GetText().c_str());
       m_snapshotScheduleIdentifierHasBeenSet = true;
     }
     XmlNode snapshotScheduleStateNode = resultNode.FirstChild("SnapshotScheduleState");
     if(!snapshotScheduleStateNode.IsNull())
     {
-      m_snapshotScheduleState = ScheduleStateMapper::GetScheduleStateForName(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(snapshotScheduleStateNode.GetText()).c_str()).c_str());
+      m_snapshotScheduleState = ScheduleStateMapper::GetScheduleStateForName(StringUtils::Trim(snapshotScheduleStateNode.GetText().c_str()).c_str());
       m_snapshotScheduleStateHasBeenSet = true;
     }
-    XmlNode expectedNextSnapshotScheduleTimeNode = resultNode.FirstChild("ExpectedNextSnapshotScheduleTime");
-    if(!expectedNextSnapshotScheduleTimeNode.IsNull())
-    {
-      m_expectedNextSnapshotScheduleTime = DateTime(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(expectedNextSnapshotScheduleTimeNode.GetText()).c_str()).c_str(), DateFormat::ISO_8601);
-      m_expectedNextSnapshotScheduleTimeHasBeenSet = true;
-    }
-    XmlNode expectedNextSnapshotScheduleTimeStatusNode = resultNode.FirstChild("ExpectedNextSnapshotScheduleTimeStatus");
-    if(!expectedNextSnapshotScheduleTimeStatusNode.IsNull())
-    {
-      m_expectedNextSnapshotScheduleTimeStatus = Aws::Utils::Xml::DecodeEscapedXmlText(expectedNextSnapshotScheduleTimeStatusNode.GetText());
-      m_expectedNextSnapshotScheduleTimeStatusHasBeenSet = true;
-    }
-    XmlNode nextMaintenanceWindowStartTimeNode = resultNode.FirstChild("NextMaintenanceWindowStartTime");
-    if(!nextMaintenanceWindowStartTimeNode.IsNull())
-    {
-      m_nextMaintenanceWindowStartTime = DateTime(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(nextMaintenanceWindowStartTimeNode.GetText()).c_str()).c_str(), DateFormat::ISO_8601);
-      m_nextMaintenanceWindowStartTimeHasBeenSet = true;
-    }
     XmlNode resizeInfoNode = resultNode.FirstChild("ResizeInfo");
     if(!resizeInfoNode.IsNull())
     {
@@ -489,11 +467,6 @@ void Cluster::OutputToStream(Aws::OStream& oStream, const char* location, unsign
       oStream << location << index << locationValue << ".ClusterStatus=" << StringUtils::URLEncode(m_clusterStatus.c_str()) << "&";
   }
 
-  if(m_clusterAvailabilityStatusHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".ClusterAvailabilityStatus=" << StringUtils::URLEncode(m_clusterAvailabilityStatus.c_str()) << "&";
-  }
-
   if(m_modifyStatusHasBeenSet)
   {
       oStream << location << index << locationValue << ".ModifyStatus=" << StringUtils::URLEncode(m_modifyStatus.c_str()) << "&";
@@ -744,21 +717,6 @@ void Cluster::OutputToStream(Aws::OStream& oStream, const char* location, unsign
       oStream << location << index << locationValue << ".SnapshotScheduleState=" << ScheduleStateMapper::GetNameForScheduleState(m_snapshotScheduleState) << "&";
   }
 
-  if(m_expectedNextSnapshotScheduleTimeHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".ExpectedNextSnapshotScheduleTime=" << StringUtils::URLEncode(m_expectedNextSnapshotScheduleTime.ToGmtString(DateFormat::ISO_8601).c_str()) << "&";
-  }
-
-  if(m_expectedNextSnapshotScheduleTimeStatusHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".ExpectedNextSnapshotScheduleTimeStatus=" << StringUtils::URLEncode(m_expectedNextSnapshotScheduleTimeStatus.c_str()) << "&";
-  }
-
-  if(m_nextMaintenanceWindowStartTimeHasBeenSet)
-  {
-      oStream << location << index << locationValue << ".NextMaintenanceWindowStartTime=" << StringUtils::URLEncode(m_nextMaintenanceWindowStartTime.ToGmtString(DateFormat::ISO_8601).c_str()) << "&";
-  }
-
   if(m_resizeInfoHasBeenSet)
   {
       Aws::StringStream resizeInfoLocationAndMemberSs;
@@ -782,10 +740,6 @@ void Cluster::OutputToStream(Aws::OStream& oStream, const char* location) const
   {
       oStream << location << ".ClusterStatus=" << StringUtils::URLEncode(m_clusterStatus.c_str()) << "&";
   }
-  if(m_clusterAvailabilityStatusHasBeenSet)
-  {
-      oStream << location << ".ClusterAvailabilityStatus=" << StringUtils::URLEncode(m_clusterAvailabilityStatus.c_str()) << "&";
-  }
   if(m_modifyStatusHasBeenSet)
   {
       oStream << location << ".ModifyStatus=" << StringUtils::URLEncode(m_modifyStatus.c_str()) << "&";
@@ -998,18 +952,6 @@ void Cluster::OutputToStream(Aws::OStream& oStream, const char* location) const
   {
       oStream << location << ".SnapshotScheduleState=" << ScheduleStateMapper::GetNameForScheduleState(m_snapshotScheduleState) << "&";
   }
-  if(m_expectedNextSnapshotScheduleTimeHasBeenSet)
-  {
-      oStream << location << ".ExpectedNextSnapshotScheduleTime=" << StringUtils::URLEncode(m_expectedNextSnapshotScheduleTime.ToGmtString(DateFormat::ISO_8601).c_str()) << "&";
-  }
-  if(m_expectedNextSnapshotScheduleTimeStatusHasBeenSet)
-  {
-      oStream << location << ".ExpectedNextSnapshotScheduleTimeStatus=" << StringUtils::URLEncode(m_expectedNextSnapshotScheduleTimeStatus.c_str()) << "&";
-  }
-  if(m_nextMaintenanceWindowStartTimeHasBeenSet)
-  {
-      oStream << location << ".NextMaintenanceWindowStartTime=" << StringUtils::URLEncode(m_nextMaintenanceWindowStartTime.ToGmtString(DateFormat::ISO_8601).c_str()) << "&";
-  }
   if(m_resizeInfoHasBeenSet)
   {
       Aws::String resizeInfoLocationAndMember(location);
