@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/robomaker/RoboMaker_EXPORTS.h>
@@ -21,7 +31,6 @@ namespace Model
     SimulationApplicationCrash,
     BadPermissionsRobotApplication,
     BadPermissionsSimulationApplication,
-    BadPermissionsS3Object,
     BadPermissionsS3Output,
     BadPermissionsCloudwatchLogs,
     SubnetIpLimitExceeded,
@@ -29,17 +38,8 @@ namespace Model
     BadPermissionsUserCredentials,
     InvalidBundleRobotApplication,
     InvalidBundleSimulationApplication,
-    InvalidS3Resource,
-    LimitExceeded,
-    MismatchedEtag,
     RobotApplicationVersionMismatchedEtag,
     SimulationApplicationVersionMismatchedEtag,
-    ResourceNotFound,
-    RequestThrottled,
-    BatchTimedOut,
-    BatchCanceled,
-    InvalidInput,
-    WrongRegionS3Bucket,
     WrongRegionS3Output,
     WrongRegionRobotApplication,
     WrongRegionSimulationApplication
