@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/route53/Route53_EXPORTS.h>
@@ -25,11 +35,6 @@ namespace Model
     eu_west_3,
     eu_central_1,
     ap_east_1,
-    me_south_1,
-    us_gov_west_1,
-    us_gov_east_1,
-    us_iso_east_1,
-    us_isob_east_1,
     ap_southeast_1,
     ap_southeast_2,
     ap_south_1,
@@ -39,9 +44,7 @@ namespace Model
     eu_north_1,
     sa_east_1,
     ca_central_1,
-    cn_north_1,
-    af_south_1,
-    eu_south_1
+    cn_north_1
   };
 
 namespace VPCRegionMapper
