@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/s3/S3_EXPORTS.h>
@@ -29,7 +39,7 @@ namespace Model
   {
   public:
     ListObjectsV2Request();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -44,114 +54,42 @@ namespace Model
 
 
     /**
-     * <p>Bucket name to list. </p> <p>When using this API with an access point, you
-     * must direct requests to the access point hostname. The access point hostname
-     * takes the form
-     * <i>AccessPointName</i>-<i>AccountId</i>.s3-accesspoint.<i>Region</i>.amazonaws.com.
-     * When using this operation using an access point through the AWS SDKs, you
-     * provide the access point ARN in place of the bucket name. For more information
-     * about access point ARNs, see <a
-     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/using-access-points.html">Using
-     * Access Points</a> in the <i>Amazon Simple Storage Service Developer
-     * Guide</i>.</p>
+     * <p>Name of the bucket to list.</p>
      */
     inline const Aws::String& GetBucket() const{ return m_bucket; }
 
     /**
-     * <p>Bucket name to list. </p> <p>When using this API with an access point, you
-     * must direct requests to the access point hostname. The access point hostname
-     * takes the form
-     * <i>AccessPointName</i>-<i>AccountId</i>.s3-accesspoint.<i>Region</i>.amazonaws.com.
-     * When using this operation using an access point through the AWS SDKs, you
-     * provide the access point ARN in place of the bucket name. For more information
-     * about access point ARNs, see <a
-     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/using-access-points.html">Using
-     * Access Points</a> in the <i>Amazon Simple Storage Service Developer
-     * Guide</i>.</p>
+     * <p>Name of the bucket to list.</p>
      */
     inline bool BucketHasBeenSet() const { return m_bucketHasBeenSet; }
 
     /**
-     * <p>Bucket name to list. </p> <p>When using this API with an access point, you
-     * must direct requests to the access point hostname. The access point hostname
-     * takes the form
-     * <i>AccessPointName</i>-<i>AccountId</i>.s3-accesspoint.<i>Region</i>.amazonaws.com.
-     * When using this operation using an access point through the AWS SDKs, you
-     * provide the access point ARN in place of the bucket name. For more information
-     * about access point ARNs, see <a
-     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/using-access-points.html">Using
-     * Access Points</a> in the <i>Amazon Simple Storage Service Developer
-     * Guide</i>.</p>
+     * <p>Name of the bucket to list.</p>
      */
     inline void SetBucket(const Aws::String& value) { m_bucketHasBeenSet = true; m_bucket = value; }
 
     /**
-     * <p>Bucket name to list. </p> <p>When using this API with an access point, you
-     * must direct requests to the access point hostname. The access point hostname
-     * takes the form
-     * <i>AccessPointName</i>-<i>AccountId</i>.s3-accesspoint.<i>Region</i>.amazonaws.com.
-     * When using this operation using an access point through the AWS SDKs, you
-     * provide the access point ARN in place of the bucket name. For more information
-     * about access point ARNs, see <a
-     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/using-access-points.html">Using
-     * Access Points</a> in the <i>Amazon Simple Storage Service Developer
-     * Guide</i>.</p>
+     * <p>Name of the bucket to list.</p>
      */
     inline void SetBucket(Aws::String&& value) { m_bucketHasBeenSet = true; m_bucket = std::move(value); }
 
     /**
-     * <p>Bucket name to list. </p> <p>When using this API with an access point, you
-     * must direct requests to the access point hostname. The access point hostname
-     * takes the form
-     * <i>AccessPointName</i>-<i>AccountId</i>.s3-accesspoint.<i>Region</i>.amazonaws.com.
-     * When using this operation using an access point through the AWS SDKs, you
-     * provide the access point ARN in place of the bucket name. For more information
-     * about access point ARNs, see <a
-     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/using-access-points.html">Using
-     * Access Points</a> in the <i>Amazon Simple Storage Service Developer
-     * Guide</i>.</p>
+     * <p>Name of the bucket to list.</p>
      */
     inline void SetBucket(const char* value) { m_bucketHasBeenSet = true; m_bucket.assign(value); }
 
     /**
-     * <p>Bucket name to list. </p> <p>When using this API with an access point, you
-     * must direct requests to the access point hostname. The access point hostname
-     * takes the form
-     * <i>AccessPointName</i>-<i>AccountId</i>.s3-accesspoint.<i>Region</i>.amazonaws.com.
-     * When using this operation using an access point through the AWS SDKs, you
-     * provide the access point ARN in place of the bucket name. For more information
-     * about access point ARNs, see <a
-     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/using-access-points.html">Using
-     * Access Points</a> in the <i>Amazon Simple Storage Service Developer
-     * Guide</i>.</p>
+     * <p>Name of the bucket to list.</p>
      */
     inline ListObjectsV2Request& WithBucket(const Aws::String& value) { SetBucket(value); return *this;}
 
     /**
-     * <p>Bucket name to list. </p> <p>When using this API with an access point, you
-     * must direct requests to the access point hostname. The access point hostname
-     * takes the form
-     * <i>AccessPointName</i>-<i>AccountId</i>.s3-accesspoint.<i>Region</i>.amazonaws.com.
-     * When using this operation using an access point through the AWS SDKs, you
-     * provide the access point ARN in place of the bucket name. For more information
-     * about access point ARNs, see <a
-     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/using-access-points.html">Using
-     * Access Points</a> in the <i>Amazon Simple Storage Service Developer
-     * Guide</i>.</p>
+     * <p>Name of the bucket to list.</p>
      */
     inline ListObjectsV2Request& WithBucket(Aws::String&& value) { SetBucket(std::move(value)); return *this;}
 
     /**
-     * <p>Bucket name to list. </p> <p>When using this API with an access point, you
-     * must direct requests to the access point hostname. The access point hostname
-     * takes the form
-     * <i>AccessPointName</i>-<i>AccountId</i>.s3-accesspoint.<i>Region</i>.amazonaws.com.
-     * When using this operation using an access point through the AWS SDKs, you
-     * provide the access point ARN in place of the bucket name. For more information
-     * about access point ARNs, see <a
-     * href="https://docs.aws.amazon.com/AmazonS3/latest/dev/using-access-points.html">Using
-     * Access Points</a> in the <i>Amazon Simple Storage Service Developer
-     * Guide</i>.</p>
+     * <p>Name of the bucket to list.</p>
      */
     inline ListObjectsV2Request& WithBucket(const char* value) { SetBucket(value); return *this;}
 
@@ -229,30 +167,26 @@ namespace Model
 
 
     /**
-     * <p>Sets the maximum number of keys returned in the response. By default the API
-     * returns up to 1,000 key names. The response might contain fewer keys but will
-     * never contain more.</p>
+     * <p>Sets the maximum number of keys returned in the response. The response might
+     * contain fewer keys but will never contain more.</p>
      */
     inline int GetMaxKeys() const{ return m_maxKeys; }
 
     /**
-     * <p>Sets the maximum number of keys returned in the response. By default the API
-     * returns up to 1,000 key names. The response might contain fewer keys but will
-     * never contain more.</p>
+     * <p>Sets the maximum number of keys returned in the response. The response might
+     * contain fewer keys but will never contain more.</p>
      */
     inline bool MaxKeysHasBeenSet() const { return m_maxKeysHasBeenSet; }
 
     /**
-     * <p>Sets the maximum number of keys returned in the response. By default the API
-     * returns up to 1,000 key names. The response might contain fewer keys but will
-     * never contain more.</p>
+     * <p>Sets the maximum number of keys returned in the response. The response might
+     * contain fewer keys but will never contain more.</p>
      */
     inline void SetMaxKeys(int value) { m_maxKeysHasBeenSet = true; m_maxKeys = value; }
 
     /**
-     * <p>Sets the maximum number of keys returned in the response. By default the API
-     * returns up to 1,000 key names. The response might contain fewer keys but will
-     * never contain more.</p>
+     * <p>Sets the maximum number of keys returned in the response. The response might
+     * contain fewer keys but will never contain more.</p>
      */
     inline ListObjectsV2Request& WithMaxKeys(int value) { SetMaxKeys(value); return *this;}
 
@@ -301,56 +235,56 @@ namespace Model
     /**
      * <p>ContinuationToken indicates Amazon S3 that the list is being continued on
      * this bucket with a token. ContinuationToken is obfuscated and is not a real
-     * key.</p>
+     * key</p>
      */
     inline const Aws::String& GetContinuationToken() const{ return m_continuationToken; }
 
     /**
      * <p>ContinuationToken indicates Amazon S3 that the list is being continued on
      * this bucket with a token. ContinuationToken is obfuscated and is not a real
-     * key.</p>
+     * key</p>
      */
     inline bool ContinuationTokenHasBeenSet() const { return m_continuationTokenHasBeenSet; }
 
     /**
      * <p>ContinuationToken indicates Amazon S3 that the list is being continued on
      * this bucket with a token. ContinuationToken is obfuscated and is not a real
-     * key.</p>
+     * key</p>
      */
     inline void SetContinuationToken(const Aws::String& value) { m_continuationTokenHasBeenSet = true; m_continuationToken = value; }
 
     /**
      * <p>ContinuationToken indicates Amazon S3 that the list is being continued on
      * this bucket with a token. ContinuationToken is obfuscated and is not a real
-     * key.</p>
+     * key</p>
      */
     inline void SetContinuationToken(Aws::String&& value) { m_continuationTokenHasBeenSet = true; m_continuationToken = std::move(value); }
 
     /**
      * <p>ContinuationToken indicates Amazon S3 that the list is being continued on
      * this bucket with a token. ContinuationToken is obfuscated and is not a real
-     * key.</p>
+     * key</p>
      */
     inline void SetContinuationToken(const char* value) { m_continuationTokenHasBeenSet = true; m_continuationToken.assign(value); }
 
     /**
      * <p>ContinuationToken indicates Amazon S3 that the list is being continued on
      * this bucket with a token. ContinuationToken is obfuscated and is not a real
-     * key.</p>
+     * key</p>
      */
     inline ListObjectsV2Request& WithContinuationToken(const Aws::String& value) { SetContinuationToken(value); return *this;}
 
     /**
      * <p>ContinuationToken indicates Amazon S3 that the list is being continued on
      * this bucket with a token. ContinuationToken is obfuscated and is not a real
-     * key.</p>
+     * key</p>
      */
     inline ListObjectsV2Request& WithContinuationToken(Aws::String&& value) { SetContinuationToken(std::move(value)); return *this;}
 
     /**
      * <p>ContinuationToken indicates Amazon S3 that the list is being continued on
      * this bucket with a token. ContinuationToken is obfuscated and is not a real
-     * key.</p>
+     * key</p>
      */
     inline ListObjectsV2Request& WithContinuationToken(const char* value) { SetContinuationToken(value); return *this;}
 
@@ -358,28 +292,28 @@ namespace Model
     /**
      * <p>The owner field is not present in listV2 by default, if you want to return
      * owner field with each key in the result then set the fetch owner field to
-     * true.</p>
+     * true</p>
      */
     inline bool GetFetchOwner() const{ return m_fetchOwner; }
 
     /**
      * <p>The owner field is not present in listV2 by default, if you want to return
      * owner field with each key in the result then set the fetch owner field to
-     * true.</p>
+     * true</p>
      */
     inline bool FetchOwnerHasBeenSet() const { return m_fetchOwnerHasBeenSet; }
 
     /**
      * <p>The owner field is not present in listV2 by default, if you want to return
      * owner field with each key in the result then set the fetch owner field to
-     * true.</p>
+     * true</p>
      */
     inline void SetFetchOwner(bool value) { m_fetchOwnerHasBeenSet = true; m_fetchOwner = value; }
 
     /**
      * <p>The owner field is not present in listV2 by default, if you want to return
      * owner field with each key in the result then set the fetch owner field to
-     * true.</p>
+     * true</p>
      */
     inline ListObjectsV2Request& WithFetchOwner(bool value) { SetFetchOwner(value); return *this;}
 
@@ -387,56 +321,56 @@ namespace Model
     /**
      * <p>StartAfter is where you want Amazon S3 to start listing from. Amazon S3
      * starts listing after this specified key. StartAfter can be any key in the
-     * bucket.</p>
+     * bucket</p>
      */
     inline const Aws::String& GetStartAfter() const{ return m_startAfter; }
 
     /**
      * <p>StartAfter is where you want Amazon S3 to start listing from. Amazon S3
      * starts listing after this specified key. StartAfter can be any key in the
-     * bucket.</p>
+     * bucket</p>
      */
     inline bool StartAfterHasBeenSet() const { return m_startAfterHasBeenSet; }
 
     /**
      * <p>StartAfter is where you want Amazon S3 to start listing from. Amazon S3
      * starts listing after this specified key. StartAfter can be any key in the
-     * bucket.</p>
+     * bucket</p>
      */
     inline void SetStartAfter(const Aws::String& value) { m_startAfterHasBeenSet = true; m_startAfter = value; }
 
     /**
      * <p>StartAfter is where you want Amazon S3 to start listing from. Amazon S3
      * starts listing after this specified key. StartAfter can be any key in the
-     * bucket.</p>
+     * bucket</p>
      */
     inline void SetStartAfter(Aws::String&& value) { m_startAfterHasBeenSet = true; m_startAfter = std::move(value); }
 
     /**
      * <p>StartAfter is where you want Amazon S3 to start listing from. Amazon S3
      * starts listing after this specified key. StartAfter can be any key in the
-     * bucket.</p>
+     * bucket</p>
      */
     inline void SetStartAfter(const char* value) { m_startAfterHasBeenSet = true; m_startAfter.assign(value); }
 
     /**
      * <p>StartAfter is where you want Amazon S3 to start listing from. Amazon S3
      * starts listing after this specified key. StartAfter can be any key in the
-     * bucket.</p>
+     * bucket</p>
      */
     inline ListObjectsV2Request& WithStartAfter(const Aws::String& value) { SetStartAfter(value); return *this;}
 
     /**
      * <p>StartAfter is where you want Amazon S3 to start listing from. Amazon S3
      * starts listing after this specified key. StartAfter can be any key in the
-     * bucket.</p>
+     * bucket</p>
      */
     inline ListObjectsV2Request& WithStartAfter(Aws::String&& value) { SetStartAfter(std::move(value)); return *this;}
 
     /**
      * <p>StartAfter is where you want Amazon S3 to start listing from. Amazon S3
      * starts listing after this specified key. StartAfter can be any key in the
-     * bucket.</p>
+     * bucket</p>
      */
     inline ListObjectsV2Request& WithStartAfter(const char* value) { SetStartAfter(value); return *this;}
 
@@ -484,63 +418,6 @@ namespace Model
     inline ListObjectsV2Request& WithRequestPayer(RequestPayer&& value) { SetRequestPayer(std::move(value)); return *this;}
 
 
-    /**
-     * <p>The account id of the expected bucket owner. If the bucket is owned by a
-     * different account, the request will fail with an HTTP <code>403 (Access
-     * Denied)</code> error.</p>
-     */
-    inline const Aws::String& GetExpectedBucketOwner() const{ return m_expectedBucketOwner; }
-
-    /**
-     * <p>The account id of the expected bucket owner. If the bucket is owned by a
-     * different account, the request will fail with an HTTP <code>403 (Access
-     * Denied)</code> error.</p>
-     */
-    inline bool ExpectedBucketOwnerHasBeenSet() const { return m_expectedBucketOwnerHasBeenSet; }
-
-    /**
-     * <p>The account id of the expected bucket owner. If the bucket is owned by a
-     * different account, the request will fail with an HTTP <code>403 (Access
-     * Denied)</code> error.</p>
-     */
-    inline void SetExpectedBucketOwner(const Aws::String& value) { m_expectedBucketOwnerHasBeenSet = true; m_expectedBucketOwner = value; }
-
-    /**
-     * <p>The account id of the expected bucket owner. If the bucket is owned by a
-     * different account, the request will fail with an HTTP <code>403 (Access
-     * Denied)</code> error.</p>
-     */
-    inline void SetExpectedBucketOwner(Aws::String&& value) { m_expectedBucketOwnerHasBeenSet = true; m_expectedBucketOwner = std::move(value); }
-
-    /**
-     * <p>The account id of the expected bucket owner. If the bucket is owned by a
-     * different account, the request will fail with an HTTP <code>403 (Access
-     * Denied)</code> error.</p>
-     */
-    inline void SetExpectedBucketOwner(const char* value) { m_expectedBucketOwnerHasBeenSet = true; m_expectedBucketOwner.assign(value); }
-
-    /**
-     * <p>The account id of the expected bucket owner. If the bucket is owned by a
-     * different account, the request will fail with an HTTP <code>403 (Access
-     * Denied)</code> error.</p>
-     */
-    inline ListObjectsV2Request& WithExpectedBucketOwner(const Aws::String& value) { SetExpectedBucketOwner(value); return *this;}
-
-    /**
-     * <p>The account id of the expected bucket owner. If the bucket is owned by a
-     * different account, the request will fail with an HTTP <code>403 (Access
-     * Denied)</code> error.</p>
-     */
-    inline ListObjectsV2Request& WithExpectedBucketOwner(Aws::String&& value) { SetExpectedBucketOwner(std::move(value)); return *this;}
-
-    /**
-     * <p>The account id of the expected bucket owner. If the bucket is owned by a
-     * different account, the request will fail with an HTTP <code>403 (Access
-     * Denied)</code> error.</p>
-     */
-    inline ListObjectsV2Request& WithExpectedBucketOwner(const char* value) { SetExpectedBucketOwner(value); return *this;}
-
-
     
     inline const Aws::Map<Aws::String, Aws::String>& GetCustomizedAccessLogTag() const{ return m_customizedAccessLogTag; }
 
@@ -609,9 +486,6 @@ namespace Model
     RequestPayer m_requestPayer;
     bool m_requestPayerHasBeenSet;
 
-    Aws::String m_expectedBucketOwner;
-    bool m_expectedBucketOwnerHasBeenSet;
-
     Aws::Map<Aws::String, Aws::String> m_customizedAccessLogTag;
     bool m_customizedAccessLogTagHasBeenSet;
   };
