@@ -1,21 +1,28 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/sagemaker/SageMaker_EXPORTS.h>
 #include <aws/sagemaker/SageMakerRequest.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
-#include <aws/sagemaker/model/ModelClientConfig.h>
 #include <aws/sagemaker/model/BatchStrategy.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/sagemaker/model/TransformInput.h>
 #include <aws/sagemaker/model/TransformOutput.h>
 #include <aws/sagemaker/model/TransformResources.h>
-#include <aws/sagemaker/model/DataProcessing.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
-#include <aws/sagemaker/model/ExperimentConfig.h>
 #include <aws/sagemaker/model/Tag.h>
 #include <utility>
 
@@ -32,7 +39,7 @@ namespace Model
   {
   public:
     CreateTransformJobRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -152,94 +159,37 @@ namespace Model
 
     /**
      * <p>The maximum number of parallel requests that can be sent to each instance in
-     * a transform job. If <code>MaxConcurrentTransforms</code> is set to
-     * <code>0</code> or left unset, Amazon SageMaker checks the optional
-     * execution-parameters to determine the settings for your chosen algorithm. If the
-     * execution-parameters endpoint is not enabled, the default value is
-     * <code>1</code>. For more information on execution-parameters, see <a
-     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-batch-code.html#your-algorithms-batch-code-how-containe-serves-requests">How
-     * Containers Serve Requests</a>. For built-in algorithms, you don't need to set a
-     * value for <code>MaxConcurrentTransforms</code>.</p>
+     * a transform job. The default value is <code>1</code>. To allow Amazon SageMaker
+     * to determine the appropriate number for <code>MaxConcurrentTransforms</code>,
+     * set the value to <code>0</code>.</p>
      */
     inline int GetMaxConcurrentTransforms() const{ return m_maxConcurrentTransforms; }
 
     /**
      * <p>The maximum number of parallel requests that can be sent to each instance in
-     * a transform job. If <code>MaxConcurrentTransforms</code> is set to
-     * <code>0</code> or left unset, Amazon SageMaker checks the optional
-     * execution-parameters to determine the settings for your chosen algorithm. If the
-     * execution-parameters endpoint is not enabled, the default value is
-     * <code>1</code>. For more information on execution-parameters, see <a
-     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-batch-code.html#your-algorithms-batch-code-how-containe-serves-requests">How
-     * Containers Serve Requests</a>. For built-in algorithms, you don't need to set a
-     * value for <code>MaxConcurrentTransforms</code>.</p>
+     * a transform job. The default value is <code>1</code>. To allow Amazon SageMaker
+     * to determine the appropriate number for <code>MaxConcurrentTransforms</code>,
+     * set the value to <code>0</code>.</p>
      */
     inline bool MaxConcurrentTransformsHasBeenSet() const { return m_maxConcurrentTransformsHasBeenSet; }
 
     /**
      * <p>The maximum number of parallel requests that can be sent to each instance in
-     * a transform job. If <code>MaxConcurrentTransforms</code> is set to
-     * <code>0</code> or left unset, Amazon SageMaker checks the optional
-     * execution-parameters to determine the settings for your chosen algorithm. If the
-     * execution-parameters endpoint is not enabled, the default value is
-     * <code>1</code>. For more information on execution-parameters, see <a
-     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-batch-code.html#your-algorithms-batch-code-how-containe-serves-requests">How
-     * Containers Serve Requests</a>. For built-in algorithms, you don't need to set a
-     * value for <code>MaxConcurrentTransforms</code>.</p>
+     * a transform job. The default value is <code>1</code>. To allow Amazon SageMaker
+     * to determine the appropriate number for <code>MaxConcurrentTransforms</code>,
+     * set the value to <code>0</code>.</p>
      */
     inline void SetMaxConcurrentTransforms(int value) { m_maxConcurrentTransformsHasBeenSet = true; m_maxConcurrentTransforms = value; }
 
     /**
      * <p>The maximum number of parallel requests that can be sent to each instance in
-     * a transform job. If <code>MaxConcurrentTransforms</code> is set to
-     * <code>0</code> or left unset, Amazon SageMaker checks the optional
-     * execution-parameters to determine the settings for your chosen algorithm. If the
-     * execution-parameters endpoint is not enabled, the default value is
-     * <code>1</code>. For more information on execution-parameters, see <a
-     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-batch-code.html#your-algorithms-batch-code-how-containe-serves-requests">How
-     * Containers Serve Requests</a>. For built-in algorithms, you don't need to set a
-     * value for <code>MaxConcurrentTransforms</code>.</p>
+     * a transform job. The default value is <code>1</code>. To allow Amazon SageMaker
+     * to determine the appropriate number for <code>MaxConcurrentTransforms</code>,
+     * set the value to <code>0</code>.</p>
      */
     inline CreateTransformJobRequest& WithMaxConcurrentTransforms(int value) { SetMaxConcurrentTransforms(value); return *this;}
 
 
-    /**
-     * <p>Configures the timeout and maximum number of retries for processing a
-     * transform job invocation.</p>
-     */
-    inline const ModelClientConfig& GetModelClientConfig() const{ return m_modelClientConfig; }
-
-    /**
-     * <p>Configures the timeout and maximum number of retries for processing a
-     * transform job invocation.</p>
-     */
-    inline bool ModelClientConfigHasBeenSet() const { return m_modelClientConfigHasBeenSet; }
-
-    /**
-     * <p>Configures the timeout and maximum number of retries for processing a
-     * transform job invocation.</p>
-     */
-    inline void SetModelClientConfig(const ModelClientConfig& value) { m_modelClientConfigHasBeenSet = true; m_modelClientConfig = value; }
-
-    /**
-     * <p>Configures the timeout and maximum number of retries for processing a
-     * transform job invocation.</p>
-     */
-    inline void SetModelClientConfig(ModelClientConfig&& value) { m_modelClientConfigHasBeenSet = true; m_modelClientConfig = std::move(value); }
-
-    /**
-     * <p>Configures the timeout and maximum number of retries for processing a
-     * transform job invocation.</p>
-     */
-    inline CreateTransformJobRequest& WithModelClientConfig(const ModelClientConfig& value) { SetModelClientConfig(value); return *this;}
-
-    /**
-     * <p>Configures the timeout and maximum number of retries for processing a
-     * transform job invocation.</p>
-     */
-    inline CreateTransformJobRequest& WithModelClientConfig(ModelClientConfig&& value) { SetModelClientConfig(std::move(value)); return *this;}
-
-
     /**
      * <p>The maximum allowed size of the payload, in MB. A <i>payload</i> is the data
      * portion of a record (without metadata). The value in <code>MaxPayloadInMB</code>
@@ -301,14 +251,14 @@ namespace Model
      * <p>Specifies the number of records to include in a mini-batch for an HTTP
      * inference request. A <i>record</i> <i/> is a single unit of input data that
      * inference can be made on. For example, a single line in a CSV file is a record.
-     * </p> <p>To enable the batch strategy, you must set the <code>SplitType</code>
-     * property to <code>Line</code>, <code>RecordIO</code>, or
-     * <code>TFRecord</code>.</p> <p>To use only one record when making an HTTP
-     * invocation request to a container, set <code>BatchStrategy</code> to
-     * <code>SingleRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
-     * <p>To fit as many records in a mini-batch as can fit within the
-     * <code>MaxPayloadInMB</code> limit, set <code>BatchStrategy</code> to
-     * <code>MultiRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
+     * </p> <p>To enable the batch strategy, you must set <code>SplitType</code> to
+     * <code>Line</code>, <code>RecordIO</code>, or <code>TFRecord</code>.</p> <p>To
+     * use only one record when making an HTTP invocation request to a container, set
+     * <code>BatchStrategy</code> to <code>SingleRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p> <p>To fit as many records in a
+     * mini-batch as can fit within the <code>MaxPayloadInMB</code> limit, set
+     * <code>BatchStrategy</code> to <code>MultiRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p>
      */
     inline const BatchStrategy& GetBatchStrategy() const{ return m_batchStrategy; }
 
@@ -316,14 +266,14 @@ namespace Model
      * <p>Specifies the number of records to include in a mini-batch for an HTTP
      * inference request. A <i>record</i> <i/> is a single unit of input data that
      * inference can be made on. For example, a single line in a CSV file is a record.
-     * </p> <p>To enable the batch strategy, you must set the <code>SplitType</code>
-     * property to <code>Line</code>, <code>RecordIO</code>, or
-     * <code>TFRecord</code>.</p> <p>To use only one record when making an HTTP
-     * invocation request to a container, set <code>BatchStrategy</code> to
-     * <code>SingleRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
-     * <p>To fit as many records in a mini-batch as can fit within the
-     * <code>MaxPayloadInMB</code> limit, set <code>BatchStrategy</code> to
-     * <code>MultiRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
+     * </p> <p>To enable the batch strategy, you must set <code>SplitType</code> to
+     * <code>Line</code>, <code>RecordIO</code>, or <code>TFRecord</code>.</p> <p>To
+     * use only one record when making an HTTP invocation request to a container, set
+     * <code>BatchStrategy</code> to <code>SingleRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p> <p>To fit as many records in a
+     * mini-batch as can fit within the <code>MaxPayloadInMB</code> limit, set
+     * <code>BatchStrategy</code> to <code>MultiRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p>
      */
     inline bool BatchStrategyHasBeenSet() const { return m_batchStrategyHasBeenSet; }
 
@@ -331,14 +281,14 @@ namespace Model
      * <p>Specifies the number of records to include in a mini-batch for an HTTP
      * inference request. A <i>record</i> <i/> is a single unit of input data that
      * inference can be made on. For example, a single line in a CSV file is a record.
-     * </p> <p>To enable the batch strategy, you must set the <code>SplitType</code>
-     * property to <code>Line</code>, <code>RecordIO</code>, or
-     * <code>TFRecord</code>.</p> <p>To use only one record when making an HTTP
-     * invocation request to a container, set <code>BatchStrategy</code> to
-     * <code>SingleRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
-     * <p>To fit as many records in a mini-batch as can fit within the
-     * <code>MaxPayloadInMB</code> limit, set <code>BatchStrategy</code> to
-     * <code>MultiRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
+     * </p> <p>To enable the batch strategy, you must set <code>SplitType</code> to
+     * <code>Line</code>, <code>RecordIO</code>, or <code>TFRecord</code>.</p> <p>To
+     * use only one record when making an HTTP invocation request to a container, set
+     * <code>BatchStrategy</code> to <code>SingleRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p> <p>To fit as many records in a
+     * mini-batch as can fit within the <code>MaxPayloadInMB</code> limit, set
+     * <code>BatchStrategy</code> to <code>MultiRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p>
      */
     inline void SetBatchStrategy(const BatchStrategy& value) { m_batchStrategyHasBeenSet = true; m_batchStrategy = value; }
 
@@ -346,14 +296,14 @@ namespace Model
      * <p>Specifies the number of records to include in a mini-batch for an HTTP
      * inference request. A <i>record</i> <i/> is a single unit of input data that
      * inference can be made on. For example, a single line in a CSV file is a record.
-     * </p> <p>To enable the batch strategy, you must set the <code>SplitType</code>
-     * property to <code>Line</code>, <code>RecordIO</code>, or
-     * <code>TFRecord</code>.</p> <p>To use only one record when making an HTTP
-     * invocation request to a container, set <code>BatchStrategy</code> to
-     * <code>SingleRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
-     * <p>To fit as many records in a mini-batch as can fit within the
-     * <code>MaxPayloadInMB</code> limit, set <code>BatchStrategy</code> to
-     * <code>MultiRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
+     * </p> <p>To enable the batch strategy, you must set <code>SplitType</code> to
+     * <code>Line</code>, <code>RecordIO</code>, or <code>TFRecord</code>.</p> <p>To
+     * use only one record when making an HTTP invocation request to a container, set
+     * <code>BatchStrategy</code> to <code>SingleRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p> <p>To fit as many records in a
+     * mini-batch as can fit within the <code>MaxPayloadInMB</code> limit, set
+     * <code>BatchStrategy</code> to <code>MultiRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p>
      */
     inline void SetBatchStrategy(BatchStrategy&& value) { m_batchStrategyHasBeenSet = true; m_batchStrategy = std::move(value); }
 
@@ -361,14 +311,14 @@ namespace Model
      * <p>Specifies the number of records to include in a mini-batch for an HTTP
      * inference request. A <i>record</i> <i/> is a single unit of input data that
      * inference can be made on. For example, a single line in a CSV file is a record.
-     * </p> <p>To enable the batch strategy, you must set the <code>SplitType</code>
-     * property to <code>Line</code>, <code>RecordIO</code>, or
-     * <code>TFRecord</code>.</p> <p>To use only one record when making an HTTP
-     * invocation request to a container, set <code>BatchStrategy</code> to
-     * <code>SingleRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
-     * <p>To fit as many records in a mini-batch as can fit within the
-     * <code>MaxPayloadInMB</code> limit, set <code>BatchStrategy</code> to
-     * <code>MultiRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
+     * </p> <p>To enable the batch strategy, you must set <code>SplitType</code> to
+     * <code>Line</code>, <code>RecordIO</code>, or <code>TFRecord</code>.</p> <p>To
+     * use only one record when making an HTTP invocation request to a container, set
+     * <code>BatchStrategy</code> to <code>SingleRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p> <p>To fit as many records in a
+     * mini-batch as can fit within the <code>MaxPayloadInMB</code> limit, set
+     * <code>BatchStrategy</code> to <code>MultiRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p>
      */
     inline CreateTransformJobRequest& WithBatchStrategy(const BatchStrategy& value) { SetBatchStrategy(value); return *this;}
 
@@ -376,14 +326,14 @@ namespace Model
      * <p>Specifies the number of records to include in a mini-batch for an HTTP
      * inference request. A <i>record</i> <i/> is a single unit of input data that
      * inference can be made on. For example, a single line in a CSV file is a record.
-     * </p> <p>To enable the batch strategy, you must set the <code>SplitType</code>
-     * property to <code>Line</code>, <code>RecordIO</code>, or
-     * <code>TFRecord</code>.</p> <p>To use only one record when making an HTTP
-     * invocation request to a container, set <code>BatchStrategy</code> to
-     * <code>SingleRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
-     * <p>To fit as many records in a mini-batch as can fit within the
-     * <code>MaxPayloadInMB</code> limit, set <code>BatchStrategy</code> to
-     * <code>MultiRecord</code> and <code>SplitType</code> to <code>Line</code>.</p>
+     * </p> <p>To enable the batch strategy, you must set <code>SplitType</code> to
+     * <code>Line</code>, <code>RecordIO</code>, or <code>TFRecord</code>.</p> <p>To
+     * use only one record when making an HTTP invocation request to a container, set
+     * <code>BatchStrategy</code> to <code>SingleRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p> <p>To fit as many records in a
+     * mini-batch as can fit within the <code>MaxPayloadInMB</code> limit, set
+     * <code>BatchStrategy</code> to <code>MultiRecord</code> and
+     * <code>SplitType</code> to <code>Line</code>.</p>
      */
     inline CreateTransformJobRequest& WithBatchStrategy(BatchStrategy&& value) { SetBatchStrategy(std::move(value)); return *this;}
 
@@ -566,79 +516,6 @@ namespace Model
     inline CreateTransformJobRequest& WithTransformResources(TransformResources&& value) { SetTransformResources(std::move(value)); return *this;}
 
 
-    /**
-     * <p>The data structure used to specify the data to be used for inference in a
-     * batch transform job and to associate the data that is relevant to the prediction
-     * results in the output. The input filter provided allows you to exclude input
-     * data that is not needed for inference in a batch transform job. The output
-     * filter provided allows you to include input data relevant to interpreting the
-     * predictions in the output from the job. For more information, see <a
-     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html">Associate
-     * Prediction Results with their Corresponding Input Records</a>.</p>
-     */
-    inline const DataProcessing& GetDataProcessing() const{ return m_dataProcessing; }
-
-    /**
-     * <p>The data structure used to specify the data to be used for inference in a
-     * batch transform job and to associate the data that is relevant to the prediction
-     * results in the output. The input filter provided allows you to exclude input
-     * data that is not needed for inference in a batch transform job. The output
-     * filter provided allows you to include input data relevant to interpreting the
-     * predictions in the output from the job. For more information, see <a
-     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html">Associate
-     * Prediction Results with their Corresponding Input Records</a>.</p>
-     */
-    inline bool DataProcessingHasBeenSet() const { return m_dataProcessingHasBeenSet; }
-
-    /**
-     * <p>The data structure used to specify the data to be used for inference in a
-     * batch transform job and to associate the data that is relevant to the prediction
-     * results in the output. The input filter provided allows you to exclude input
-     * data that is not needed for inference in a batch transform job. The output
-     * filter provided allows you to include input data relevant to interpreting the
-     * predictions in the output from the job. For more information, see <a
-     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html">Associate
-     * Prediction Results with their Corresponding Input Records</a>.</p>
-     */
-    inline void SetDataProcessing(const DataProcessing& value) { m_dataProcessingHasBeenSet = true; m_dataProcessing = value; }
-
-    /**
-     * <p>The data structure used to specify the data to be used for inference in a
-     * batch transform job and to associate the data that is relevant to the prediction
-     * results in the output. The input filter provided allows you to exclude input
-     * data that is not needed for inference in a batch transform job. The output
-     * filter provided allows you to include input data relevant to interpreting the
-     * predictions in the output from the job. For more information, see <a
-     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html">Associate
-     * Prediction Results with their Corresponding Input Records</a>.</p>
-     */
-    inline void SetDataProcessing(DataProcessing&& value) { m_dataProcessingHasBeenSet = true; m_dataProcessing = std::move(value); }
-
-    /**
-     * <p>The data structure used to specify the data to be used for inference in a
-     * batch transform job and to associate the data that is relevant to the prediction
-     * results in the output. The input filter provided allows you to exclude input
-     * data that is not needed for inference in a batch transform job. The output
-     * filter provided allows you to include input data relevant to interpreting the
-     * predictions in the output from the job. For more information, see <a
-     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html">Associate
-     * Prediction Results with their Corresponding Input Records</a>.</p>
-     */
-    inline CreateTransformJobRequest& WithDataProcessing(const DataProcessing& value) { SetDataProcessing(value); return *this;}
-
-    /**
-     * <p>The data structure used to specify the data to be used for inference in a
-     * batch transform job and to associate the data that is relevant to the prediction
-     * results in the output. The input filter provided allows you to exclude input
-     * data that is not needed for inference in a batch transform job. The output
-     * filter provided allows you to include input data relevant to interpreting the
-     * predictions in the output from the job. For more information, see <a
-     * href="https://docs.aws.amazon.com/sagemaker/latest/dg/batch-transform-data-processing.html">Associate
-     * Prediction Results with their Corresponding Input Records</a>.</p>
-     */
-    inline CreateTransformJobRequest& WithDataProcessing(DataProcessing&& value) { SetDataProcessing(std::move(value)); return *this;}
-
-
     /**
      * <p>(Optional) An array of key-value pairs. For more information, see <a
      * href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html#allocation-what">Using
@@ -703,25 +580,6 @@ namespace Model
      */
     inline CreateTransformJobRequest& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
-
-    
-    inline const ExperimentConfig& GetExperimentConfig() const{ return m_experimentConfig; }
-
-    
-    inline bool ExperimentConfigHasBeenSet() const { return m_experimentConfigHasBeenSet; }
-
-    
-    inline void SetExperimentConfig(const ExperimentConfig& value) { m_experimentConfigHasBeenSet = true; m_experimentConfig = value; }
-
-    
-    inline void SetExperimentConfig(ExperimentConfig&& value) { m_experimentConfigHasBeenSet = true; m_experimentConfig = std::move(value); }
-
-    
-    inline CreateTransformJobRequest& WithExperimentConfig(const ExperimentConfig& value) { SetExperimentConfig(value); return *this;}
-
-    
-    inline CreateTransformJobRequest& WithExperimentConfig(ExperimentConfig&& value) { SetExperimentConfig(std::move(value)); return *this;}
-
   private:
 
     Aws::String m_transformJobName;
@@ -733,9 +591,6 @@ namespace Model
     int m_maxConcurrentTransforms;
     bool m_maxConcurrentTransformsHasBeenSet;
 
-    ModelClientConfig m_modelClientConfig;
-    bool m_modelClientConfigHasBeenSet;
-
     int m_maxPayloadInMB;
     bool m_maxPayloadInMBHasBeenSet;
 
@@ -754,14 +609,8 @@ namespace Model
     TransformResources m_transformResources;
     bool m_transformResourcesHasBeenSet;
 
-    DataProcessing m_dataProcessing;
-    bool m_dataProcessingHasBeenSet;
-
     Aws::Vector<Tag> m_tags;
     bool m_tagsHasBeenSet;
-
-    ExperimentConfig m_experimentConfig;
-    bool m_experimentConfigHasBeenSet;
   };
 
 } // namespace Model
