@@ -1,21 +1,28 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/sagemaker/SageMaker_EXPORTS.h>
-#include <aws/core/utils/memory/stl/AWSString.h>
-#include <aws/sagemaker/model/HyperParameterTuningJobObjective.h>
-#include <aws/sagemaker/model/ParameterRanges.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <aws/sagemaker/model/HyperParameterAlgorithmSpecification.h>
+#include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/sagemaker/model/VpcConfig.h>
 #include <aws/sagemaker/model/OutputDataConfig.h>
 #include <aws/sagemaker/model/ResourceConfig.h>
 #include <aws/sagemaker/model/StoppingCondition.h>
-#include <aws/sagemaker/model/CheckpointConfig.h>
 #include <aws/sagemaker/model/Channel.h>
 #include <utility>
 
@@ -49,85 +56,6 @@ namespace Model
     Aws::Utils::Json::JsonValue Jsonize() const;
 
 
-    /**
-     * <p>The job definition name.</p>
-     */
-    inline const Aws::String& GetDefinitionName() const{ return m_definitionName; }
-
-    /**
-     * <p>The job definition name.</p>
-     */
-    inline bool DefinitionNameHasBeenSet() const { return m_definitionNameHasBeenSet; }
-
-    /**
-     * <p>The job definition name.</p>
-     */
-    inline void SetDefinitionName(const Aws::String& value) { m_definitionNameHasBeenSet = true; m_definitionName = value; }
-
-    /**
-     * <p>The job definition name.</p>
-     */
-    inline void SetDefinitionName(Aws::String&& value) { m_definitionNameHasBeenSet = true; m_definitionName = std::move(value); }
-
-    /**
-     * <p>The job definition name.</p>
-     */
-    inline void SetDefinitionName(const char* value) { m_definitionNameHasBeenSet = true; m_definitionName.assign(value); }
-
-    /**
-     * <p>The job definition name.</p>
-     */
-    inline HyperParameterTrainingJobDefinition& WithDefinitionName(const Aws::String& value) { SetDefinitionName(value); return *this;}
-
-    /**
-     * <p>The job definition name.</p>
-     */
-    inline HyperParameterTrainingJobDefinition& WithDefinitionName(Aws::String&& value) { SetDefinitionName(std::move(value)); return *this;}
-
-    /**
-     * <p>The job definition name.</p>
-     */
-    inline HyperParameterTrainingJobDefinition& WithDefinitionName(const char* value) { SetDefinitionName(value); return *this;}
-
-
-    
-    inline const HyperParameterTuningJobObjective& GetTuningObjective() const{ return m_tuningObjective; }
-
-    
-    inline bool TuningObjectiveHasBeenSet() const { return m_tuningObjectiveHasBeenSet; }
-
-    
-    inline void SetTuningObjective(const HyperParameterTuningJobObjective& value) { m_tuningObjectiveHasBeenSet = true; m_tuningObjective = value; }
-
-    
-    inline void SetTuningObjective(HyperParameterTuningJobObjective&& value) { m_tuningObjectiveHasBeenSet = true; m_tuningObjective = std::move(value); }
-
-    
-    inline HyperParameterTrainingJobDefinition& WithTuningObjective(const HyperParameterTuningJobObjective& value) { SetTuningObjective(value); return *this;}
-
-    
-    inline HyperParameterTrainingJobDefinition& WithTuningObjective(HyperParameterTuningJobObjective&& value) { SetTuningObjective(std::move(value)); return *this;}
-
-
-    
-    inline const ParameterRanges& GetHyperParameterRanges() const{ return m_hyperParameterRanges; }
-
-    
-    inline bool HyperParameterRangesHasBeenSet() const { return m_hyperParameterRangesHasBeenSet; }
-
-    
-    inline void SetHyperParameterRanges(const ParameterRanges& value) { m_hyperParameterRangesHasBeenSet = true; m_hyperParameterRanges = value; }
-
-    
-    inline void SetHyperParameterRanges(ParameterRanges&& value) { m_hyperParameterRangesHasBeenSet = true; m_hyperParameterRanges = std::move(value); }
-
-    
-    inline HyperParameterTrainingJobDefinition& WithHyperParameterRanges(const ParameterRanges& value) { SetHyperParameterRanges(value); return *this;}
-
-    
-    inline HyperParameterTrainingJobDefinition& WithHyperParameterRanges(ParameterRanges&& value) { SetHyperParameterRanges(std::move(value)); return *this;}
-
-
     /**
      * <p>Specifies the values of hyperparameters that do not change for the tuning
      * job.</p>
@@ -514,50 +442,68 @@ namespace Model
 
 
     /**
-     * <p>Specifies a limit to how long a model hyperparameter training job can run. It
-     * also specifies how long you are willing to wait for a managed spot training job
-     * to complete. When the job reaches the a limit, Amazon SageMaker ends the
-     * training job. Use this API to cap model training costs.</p>
+     * <p>Sets a maximum duration for the training jobs that the tuning job launches.
+     * Use this parameter to limit model training costs. </p> <p>To stop a job, Amazon
+     * SageMaker sends the algorithm the <code>SIGTERM</code> signal. This delays job
+     * termination for 120 seconds. Algorithms might use this 120-second window to save
+     * the model artifacts.</p> <p>When Amazon SageMaker terminates a job because the
+     * stopping condition has been met, training algorithms provided by Amazon
+     * SageMaker save the intermediate results of the job.</p>
      */
     inline const StoppingCondition& GetStoppingCondition() const{ return m_stoppingCondition; }
 
     /**
-     * <p>Specifies a limit to how long a model hyperparameter training job can run. It
-     * also specifies how long you are willing to wait for a managed spot training job
-     * to complete. When the job reaches the a limit, Amazon SageMaker ends the
-     * training job. Use this API to cap model training costs.</p>
+     * <p>Sets a maximum duration for the training jobs that the tuning job launches.
+     * Use this parameter to limit model training costs. </p> <p>To stop a job, Amazon
+     * SageMaker sends the algorithm the <code>SIGTERM</code> signal. This delays job
+     * termination for 120 seconds. Algorithms might use this 120-second window to save
+     * the model artifacts.</p> <p>When Amazon SageMaker terminates a job because the
+     * stopping condition has been met, training algorithms provided by Amazon
+     * SageMaker save the intermediate results of the job.</p>
      */
     inline bool StoppingConditionHasBeenSet() const { return m_stoppingConditionHasBeenSet; }
 
     /**
-     * <p>Specifies a limit to how long a model hyperparameter training job can run. It
-     * also specifies how long you are willing to wait for a managed spot training job
-     * to complete. When the job reaches the a limit, Amazon SageMaker ends the
-     * training job. Use this API to cap model training costs.</p>
+     * <p>Sets a maximum duration for the training jobs that the tuning job launches.
+     * Use this parameter to limit model training costs. </p> <p>To stop a job, Amazon
+     * SageMaker sends the algorithm the <code>SIGTERM</code> signal. This delays job
+     * termination for 120 seconds. Algorithms might use this 120-second window to save
+     * the model artifacts.</p> <p>When Amazon SageMaker terminates a job because the
+     * stopping condition has been met, training algorithms provided by Amazon
+     * SageMaker save the intermediate results of the job.</p>
      */
     inline void SetStoppingCondition(const StoppingCondition& value) { m_stoppingConditionHasBeenSet = true; m_stoppingCondition = value; }
 
     /**
-     * <p>Specifies a limit to how long a model hyperparameter training job can run. It
-     * also specifies how long you are willing to wait for a managed spot training job
-     * to complete. When the job reaches the a limit, Amazon SageMaker ends the
-     * training job. Use this API to cap model training costs.</p>
+     * <p>Sets a maximum duration for the training jobs that the tuning job launches.
+     * Use this parameter to limit model training costs. </p> <p>To stop a job, Amazon
+     * SageMaker sends the algorithm the <code>SIGTERM</code> signal. This delays job
+     * termination for 120 seconds. Algorithms might use this 120-second window to save
+     * the model artifacts.</p> <p>When Amazon SageMaker terminates a job because the
+     * stopping condition has been met, training algorithms provided by Amazon
+     * SageMaker save the intermediate results of the job.</p>
      */
     inline void SetStoppingCondition(StoppingCondition&& value) { m_stoppingConditionHasBeenSet = true; m_stoppingCondition = std::move(value); }
 
     /**
-     * <p>Specifies a limit to how long a model hyperparameter training job can run. It
-     * also specifies how long you are willing to wait for a managed spot training job
-     * to complete. When the job reaches the a limit, Amazon SageMaker ends the
-     * training job. Use this API to cap model training costs.</p>
+     * <p>Sets a maximum duration for the training jobs that the tuning job launches.
+     * Use this parameter to limit model training costs. </p> <p>To stop a job, Amazon
+     * SageMaker sends the algorithm the <code>SIGTERM</code> signal. This delays job
+     * termination for 120 seconds. Algorithms might use this 120-second window to save
+     * the model artifacts.</p> <p>When Amazon SageMaker terminates a job because the
+     * stopping condition has been met, training algorithms provided by Amazon
+     * SageMaker save the intermediate results of the job.</p>
      */
     inline HyperParameterTrainingJobDefinition& WithStoppingCondition(const StoppingCondition& value) { SetStoppingCondition(value); return *this;}
 
     /**
-     * <p>Specifies a limit to how long a model hyperparameter training job can run. It
-     * also specifies how long you are willing to wait for a managed spot training job
-     * to complete. When the job reaches the a limit, Amazon SageMaker ends the
-     * training job. Use this API to cap model training costs.</p>
+     * <p>Sets a maximum duration for the training jobs that the tuning job launches.
+     * Use this parameter to limit model training costs. </p> <p>To stop a job, Amazon
+     * SageMaker sends the algorithm the <code>SIGTERM</code> signal. This delays job
+     * termination for 120 seconds. Algorithms might use this 120-second window to save
+     * the model artifacts.</p> <p>When Amazon SageMaker terminates a job because the
+     * stopping condition has been met, training algorithms provided by Amazon
+     * SageMaker save the intermediate results of the job.</p>
      */
     inline HyperParameterTrainingJobDefinition& WithStoppingCondition(StoppingCondition&& value) { SetStoppingCondition(std::move(value)); return *this;}
 
@@ -568,7 +514,8 @@ namespace Model
      * training. If network isolation is used for training jobs that are configured to
      * use a VPC, Amazon SageMaker downloads and uploads customer data and model
      * artifacts through the specified VPC, but the training container does not have
-     * network access.</p>
+     * network access.</p> <note> <p>The Semantic Segmentation built-in algorithm does
+     * not support network isolation.</p> </note>
      */
     inline bool GetEnableNetworkIsolation() const{ return m_enableNetworkIsolation; }
 
@@ -578,7 +525,8 @@ namespace Model
      * training. If network isolation is used for training jobs that are configured to
      * use a VPC, Amazon SageMaker downloads and uploads customer data and model
      * artifacts through the specified VPC, but the training container does not have
-     * network access.</p>
+     * network access.</p> <note> <p>The Semantic Segmentation built-in algorithm does
+     * not support network isolation.</p> </note>
      */
     inline bool EnableNetworkIsolationHasBeenSet() const { return m_enableNetworkIsolationHasBeenSet; }
 
@@ -588,7 +536,8 @@ namespace Model
      * training. If network isolation is used for training jobs that are configured to
      * use a VPC, Amazon SageMaker downloads and uploads customer data and model
      * artifacts through the specified VPC, but the training container does not have
-     * network access.</p>
+     * network access.</p> <note> <p>The Semantic Segmentation built-in algorithm does
+     * not support network isolation.</p> </note>
      */
     inline void SetEnableNetworkIsolation(bool value) { m_enableNetworkIsolationHasBeenSet = true; m_enableNetworkIsolation = value; }
 
@@ -598,7 +547,8 @@ namespace Model
      * training. If network isolation is used for training jobs that are configured to
      * use a VPC, Amazon SageMaker downloads and uploads customer data and model
      * artifacts through the specified VPC, but the training container does not have
-     * network access.</p>
+     * network access.</p> <note> <p>The Semantic Segmentation built-in algorithm does
+     * not support network isolation.</p> </note>
      */
     inline HyperParameterTrainingJobDefinition& WithEnableNetworkIsolation(bool value) { SetEnableNetworkIsolation(value); return *this;}
 
@@ -639,61 +589,8 @@ namespace Model
      */
     inline HyperParameterTrainingJobDefinition& WithEnableInterContainerTrafficEncryption(bool value) { SetEnableInterContainerTrafficEncryption(value); return *this;}
 
-
-    /**
-     * <p>A Boolean indicating whether managed spot training is enabled
-     * (<code>True</code>) or not (<code>False</code>).</p>
-     */
-    inline bool GetEnableManagedSpotTraining() const{ return m_enableManagedSpotTraining; }
-
-    /**
-     * <p>A Boolean indicating whether managed spot training is enabled
-     * (<code>True</code>) or not (<code>False</code>).</p>
-     */
-    inline bool EnableManagedSpotTrainingHasBeenSet() const { return m_enableManagedSpotTrainingHasBeenSet; }
-
-    /**
-     * <p>A Boolean indicating whether managed spot training is enabled
-     * (<code>True</code>) or not (<code>False</code>).</p>
-     */
-    inline void SetEnableManagedSpotTraining(bool value) { m_enableManagedSpotTrainingHasBeenSet = true; m_enableManagedSpotTraining = value; }
-
-    /**
-     * <p>A Boolean indicating whether managed spot training is enabled
-     * (<code>True</code>) or not (<code>False</code>).</p>
-     */
-    inline HyperParameterTrainingJobDefinition& WithEnableManagedSpotTraining(bool value) { SetEnableManagedSpotTraining(value); return *this;}
-
-
-    
-    inline const CheckpointConfig& GetCheckpointConfig() const{ return m_checkpointConfig; }
-
-    
-    inline bool CheckpointConfigHasBeenSet() const { return m_checkpointConfigHasBeenSet; }
-
-    
-    inline void SetCheckpointConfig(const CheckpointConfig& value) { m_checkpointConfigHasBeenSet = true; m_checkpointConfig = value; }
-
-    
-    inline void SetCheckpointConfig(CheckpointConfig&& value) { m_checkpointConfigHasBeenSet = true; m_checkpointConfig = std::move(value); }
-
-    
-    inline HyperParameterTrainingJobDefinition& WithCheckpointConfig(const CheckpointConfig& value) { SetCheckpointConfig(value); return *this;}
-
-    
-    inline HyperParameterTrainingJobDefinition& WithCheckpointConfig(CheckpointConfig&& value) { SetCheckpointConfig(std::move(value)); return *this;}
-
   private:
 
-    Aws::String m_definitionName;
-    bool m_definitionNameHasBeenSet;
-
-    HyperParameterTuningJobObjective m_tuningObjective;
-    bool m_tuningObjectiveHasBeenSet;
-
-    ParameterRanges m_hyperParameterRanges;
-    bool m_hyperParameterRangesHasBeenSet;
-
     Aws::Map<Aws::String, Aws::String> m_staticHyperParameters;
     bool m_staticHyperParametersHasBeenSet;
 
@@ -723,12 +620,6 @@ namespace Model
 
     bool m_enableInterContainerTrafficEncryption;
     bool m_enableInterContainerTrafficEncryptionHasBeenSet;
-
-    bool m_enableManagedSpotTraining;
-    bool m_enableManagedSpotTrainingHasBeenSet;
-
-    CheckpointConfig m_checkpointConfig;
-    bool m_checkpointConfigHasBeenSet;
   };
 
 } // namespace Model
