@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/snowball/Snowball_EXPORTS.h>
@@ -12,7 +22,6 @@
 #include <aws/snowball/model/SnowballType.h>
 #include <aws/snowball/model/ShippingOption.h>
 #include <aws/snowball/model/Notification.h>
-#include <aws/snowball/model/TaxDocuments.h>
 #include <utility>
 
 namespace Aws
@@ -28,7 +37,7 @@ namespace Model
   {
   public:
     CreateClusterRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -213,7 +222,7 @@ namespace Model
     /**
      * <p>The <code>KmsKeyARN</code> value that you want to associate with this
      * cluster. <code>KmsKeyARN</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
+     * href="http://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
      * API action in AWS Key Management Service (AWS KMS). </p>
      */
     inline const Aws::String& GetKmsKeyARN() const{ return m_kmsKeyARN; }
@@ -221,7 +230,7 @@ namespace Model
     /**
      * <p>The <code>KmsKeyARN</code> value that you want to associate with this
      * cluster. <code>KmsKeyARN</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
+     * href="http://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
      * API action in AWS Key Management Service (AWS KMS). </p>
      */
     inline bool KmsKeyARNHasBeenSet() const { return m_kmsKeyARNHasBeenSet; }
@@ -229,7 +238,7 @@ namespace Model
     /**
      * <p>The <code>KmsKeyARN</code> value that you want to associate with this
      * cluster. <code>KmsKeyARN</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
+     * href="http://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
      * API action in AWS Key Management Service (AWS KMS). </p>
      */
     inline void SetKmsKeyARN(const Aws::String& value) { m_kmsKeyARNHasBeenSet = true; m_kmsKeyARN = value; }
@@ -237,7 +246,7 @@ namespace Model
     /**
      * <p>The <code>KmsKeyARN</code> value that you want to associate with this
      * cluster. <code>KmsKeyARN</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
+     * href="http://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
      * API action in AWS Key Management Service (AWS KMS). </p>
      */
     inline void SetKmsKeyARN(Aws::String&& value) { m_kmsKeyARNHasBeenSet = true; m_kmsKeyARN = std::move(value); }
@@ -245,7 +254,7 @@ namespace Model
     /**
      * <p>The <code>KmsKeyARN</code> value that you want to associate with this
      * cluster. <code>KmsKeyARN</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
+     * href="http://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
      * API action in AWS Key Management Service (AWS KMS). </p>
      */
     inline void SetKmsKeyARN(const char* value) { m_kmsKeyARNHasBeenSet = true; m_kmsKeyARN.assign(value); }
@@ -253,7 +262,7 @@ namespace Model
     /**
      * <p>The <code>KmsKeyARN</code> value that you want to associate with this
      * cluster. <code>KmsKeyARN</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
+     * href="http://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
      * API action in AWS Key Management Service (AWS KMS). </p>
      */
     inline CreateClusterRequest& WithKmsKeyARN(const Aws::String& value) { SetKmsKeyARN(value); return *this;}
@@ -261,7 +270,7 @@ namespace Model
     /**
      * <p>The <code>KmsKeyARN</code> value that you want to associate with this
      * cluster. <code>KmsKeyARN</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
+     * href="http://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
      * API action in AWS Key Management Service (AWS KMS). </p>
      */
     inline CreateClusterRequest& WithKmsKeyARN(Aws::String&& value) { SetKmsKeyARN(std::move(value)); return *this;}
@@ -269,7 +278,7 @@ namespace Model
     /**
      * <p>The <code>KmsKeyARN</code> value that you want to associate with this
      * cluster. <code>KmsKeyARN</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
+     * href="http://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html">CreateKey</a>
      * API action in AWS Key Management Service (AWS KMS). </p>
      */
     inline CreateClusterRequest& WithKmsKeyARN(const char* value) { SetKmsKeyARN(value); return *this;}
@@ -278,7 +287,7 @@ namespace Model
     /**
      * <p>The <code>RoleARN</code> that you want to associate with this cluster.
      * <code>RoleArn</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
+     * href="http://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
      * API action in AWS Identity and Access Management (IAM).</p>
      */
     inline const Aws::String& GetRoleARN() const{ return m_roleARN; }
@@ -286,7 +295,7 @@ namespace Model
     /**
      * <p>The <code>RoleARN</code> that you want to associate with this cluster.
      * <code>RoleArn</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
+     * href="http://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
      * API action in AWS Identity and Access Management (IAM).</p>
      */
     inline bool RoleARNHasBeenSet() const { return m_roleARNHasBeenSet; }
@@ -294,7 +303,7 @@ namespace Model
     /**
      * <p>The <code>RoleARN</code> that you want to associate with this cluster.
      * <code>RoleArn</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
+     * href="http://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
      * API action in AWS Identity and Access Management (IAM).</p>
      */
     inline void SetRoleARN(const Aws::String& value) { m_roleARNHasBeenSet = true; m_roleARN = value; }
@@ -302,7 +311,7 @@ namespace Model
     /**
      * <p>The <code>RoleARN</code> that you want to associate with this cluster.
      * <code>RoleArn</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
+     * href="http://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
      * API action in AWS Identity and Access Management (IAM).</p>
      */
     inline void SetRoleARN(Aws::String&& value) { m_roleARNHasBeenSet = true; m_roleARN = std::move(value); }
@@ -310,7 +319,7 @@ namespace Model
     /**
      * <p>The <code>RoleARN</code> that you want to associate with this cluster.
      * <code>RoleArn</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
+     * href="http://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
      * API action in AWS Identity and Access Management (IAM).</p>
      */
     inline void SetRoleARN(const char* value) { m_roleARNHasBeenSet = true; m_roleARN.assign(value); }
@@ -318,7 +327,7 @@ namespace Model
     /**
      * <p>The <code>RoleARN</code> that you want to associate with this cluster.
      * <code>RoleArn</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
+     * href="http://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
      * API action in AWS Identity and Access Management (IAM).</p>
      */
     inline CreateClusterRequest& WithRoleARN(const Aws::String& value) { SetRoleARN(value); return *this;}
@@ -326,7 +335,7 @@ namespace Model
     /**
      * <p>The <code>RoleARN</code> that you want to associate with this cluster.
      * <code>RoleArn</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
+     * href="http://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
      * API action in AWS Identity and Access Management (IAM).</p>
      */
     inline CreateClusterRequest& WithRoleARN(Aws::String&& value) { SetRoleARN(std::move(value)); return *this;}
@@ -334,51 +343,51 @@ namespace Model
     /**
      * <p>The <code>RoleARN</code> that you want to associate with this cluster.
      * <code>RoleArn</code> values are created by using the <a
-     * href="https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
+     * href="http://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html">CreateRole</a>
      * API action in AWS Identity and Access Management (IAM).</p>
      */
     inline CreateClusterRequest& WithRoleARN(const char* value) { SetRoleARN(value); return *this;}
 
 
     /**
-     * <p>The type of AWS Snowball device to use for this cluster. </p>  <p>For
-     * cluster jobs, AWS Snowball currently supports only the <code>EDGE</code> device
-     * type.</p> 
+     * <p>The type of AWS Snowball device to use for this cluster. The only supported
+     * device types for cluster jobs are <code>EDGE</code>, <code>EDGE_C</code>, and
+     * <code>EDGE_CG</code>.</p>
      */
     inline const SnowballType& GetSnowballType() const{ return m_snowballType; }
 
     /**
-     * <p>The type of AWS Snowball device to use for this cluster. </p>  <p>For
-     * cluster jobs, AWS Snowball currently supports only the <code>EDGE</code> device
-     * type.</p> 
+     * <p>The type of AWS Snowball device to use for this cluster. The only supported
+     * device types for cluster jobs are <code>EDGE</code>, <code>EDGE_C</code>, and
+     * <code>EDGE_CG</code>.</p>
      */
     inline bool SnowballTypeHasBeenSet() const { return m_snowballTypeHasBeenSet; }
 
     /**
-     * <p>The type of AWS Snowball device to use for this cluster. </p>  <p>For
-     * cluster jobs, AWS Snowball currently supports only the <code>EDGE</code> device
-     * type.</p> 
+     * <p>The type of AWS Snowball device to use for this cluster. The only supported
+     * device types for cluster jobs are <code>EDGE</code>, <code>EDGE_C</code>, and
+     * <code>EDGE_CG</code>.</p>
      */
     inline void SetSnowballType(const SnowballType& value) { m_snowballTypeHasBeenSet = true; m_snowballType = value; }
 
     /**
-     * <p>The type of AWS Snowball device to use for this cluster. </p>  <p>For
-     * cluster jobs, AWS Snowball currently supports only the <code>EDGE</code> device
-     * type.</p> 
+     * <p>The type of AWS Snowball device to use for this cluster. The only supported
+     * device types for cluster jobs are <code>EDGE</code>, <code>EDGE_C</code>, and
+     * <code>EDGE_CG</code>.</p>
      */
     inline void SetSnowballType(SnowballType&& value) { m_snowballTypeHasBeenSet = true; m_snowballType = std::move(value); }
 
     /**
-     * <p>The type of AWS Snowball device to use for this cluster. </p>  <p>For
-     * cluster jobs, AWS Snowball currently supports only the <code>EDGE</code> device
-     * type.</p> 
+     * <p>The type of AWS Snowball device to use for this cluster. The only supported
+     * device types for cluster jobs are <code>EDGE</code>, <code>EDGE_C</code>, and
+     * <code>EDGE_CG</code>.</p>
      */
     inline CreateClusterRequest& WithSnowballType(const SnowballType& value) { SetSnowballType(value); return *this;}
 
     /**
-     * <p>The type of AWS Snowball device to use for this cluster. </p>  <p>For
-     * cluster jobs, AWS Snowball currently supports only the <code>EDGE</code> device
-     * type.</p> 
+     * <p>The type of AWS Snowball device to use for this cluster. The only supported
+     * device types for cluster jobs are <code>EDGE</code>, <code>EDGE_C</code>, and
+     * <code>EDGE_CG</code>.</p>
      */
     inline CreateClusterRequest& WithSnowballType(SnowballType&& value) { SetSnowballType(std::move(value)); return *this;}
 
@@ -387,22 +396,14 @@ namespace Model
      * <p>The shipping speed for each node in this cluster. This speed doesn't dictate
      * how soon you'll get each Snowball Edge device, rather it represents how quickly
      * each device moves to its destination while in transit. Regional shipping speeds
-     * are as follows: </p> <ul> <li> <p>In Australia, you have access to express
-     * shipping. Typically, Snowballs shipped express are delivered in about a day.</p>
+     * are as follows:</p> <ul> <li> <p>In Australia, you have access to express
+     * shipping. Typically, devices shipped express are delivered in about a day.</p>
      * </li> <li> <p>In the European Union (EU), you have access to express shipping.
-     * Typically, Snowballs shipped express are delivered in about a day. In addition,
-     * most countries in the EU have access to standard shipping, which typically takes
-     * less than a week, one way.</p> </li> <li> <p>In India, Snowballs are delivered
-     * in one to seven days.</p> </li> <li> <p>In the United States of America (US),
-     * you have access to one-day shipping and two-day shipping.</p> </li> </ul> <ul>
-     * <li> <p>In Australia, you have access to express shipping. Typically, devices
-     * shipped express are delivered in about a day.</p> </li> <li> <p>In the European
-     * Union (EU), you have access to express shipping. Typically, Snowball Edges
-     * shipped express are delivered in about a day. In addition, most countries in the
-     * EU have access to standard shipping, which typically takes less than a week, one
-     * way.</p> </li> <li> <p>In India, Snowball Edges are delivered in one to seven
-     * days.</p> </li> <li> <p>In the US, you have access to one-day shipping and
-     * two-day shipping.</p> </li> </ul>
+     * Typically, Snowball Edges shipped express are delivered in about a day. In
+     * addition, most countries in the EU have access to standard shipping, which
+     * typically takes less than a week, one way.</p> </li> <li> <p>In India, devices
+     * are delivered in one to seven days.</p> </li> <li> <p>In the US, you have access
+     * to one-day shipping and two-day shipping.</p> </li> </ul>
      */
     inline const ShippingOption& GetShippingOption() const{ return m_shippingOption; }
 
@@ -410,22 +411,14 @@ namespace Model
      * <p>The shipping speed for each node in this cluster. This speed doesn't dictate
      * how soon you'll get each Snowball Edge device, rather it represents how quickly
      * each device moves to its destination while in transit. Regional shipping speeds
-     * are as follows: </p> <ul> <li> <p>In Australia, you have access to express
-     * shipping. Typically, Snowballs shipped express are delivered in about a day.</p>
+     * are as follows:</p> <ul> <li> <p>In Australia, you have access to express
+     * shipping. Typically, devices shipped express are delivered in about a day.</p>
      * </li> <li> <p>In the European Union (EU), you have access to express shipping.
-     * Typically, Snowballs shipped express are delivered in about a day. In addition,
-     * most countries in the EU have access to standard shipping, which typically takes
-     * less than a week, one way.</p> </li> <li> <p>In India, Snowballs are delivered
-     * in one to seven days.</p> </li> <li> <p>In the United States of America (US),
-     * you have access to one-day shipping and two-day shipping.</p> </li> </ul> <ul>
-     * <li> <p>In Australia, you have access to express shipping. Typically, devices
-     * shipped express are delivered in about a day.</p> </li> <li> <p>In the European
-     * Union (EU), you have access to express shipping. Typically, Snowball Edges
-     * shipped express are delivered in about a day. In addition, most countries in the
-     * EU have access to standard shipping, which typically takes less than a week, one
-     * way.</p> </li> <li> <p>In India, Snowball Edges are delivered in one to seven
-     * days.</p> </li> <li> <p>In the US, you have access to one-day shipping and
-     * two-day shipping.</p> </li> </ul>
+     * Typically, Snowball Edges shipped express are delivered in about a day. In
+     * addition, most countries in the EU have access to standard shipping, which
+     * typically takes less than a week, one way.</p> </li> <li> <p>In India, devices
+     * are delivered in one to seven days.</p> </li> <li> <p>In the US, you have access
+     * to one-day shipping and two-day shipping.</p> </li> </ul>
      */
     inline bool ShippingOptionHasBeenSet() const { return m_shippingOptionHasBeenSet; }
 
@@ -433,22 +426,14 @@ namespace Model
      * <p>The shipping speed for each node in this cluster. This speed doesn't dictate
      * how soon you'll get each Snowball Edge device, rather it represents how quickly
      * each device moves to its destination while in transit. Regional shipping speeds
-     * are as follows: </p> <ul> <li> <p>In Australia, you have access to express
-     * shipping. Typically, Snowballs shipped express are delivered in about a day.</p>
+     * are as follows:</p> <ul> <li> <p>In Australia, you have access to express
+     * shipping. Typically, devices shipped express are delivered in about a day.</p>
      * </li> <li> <p>In the European Union (EU), you have access to express shipping.
-     * Typically, Snowballs shipped express are delivered in about a day. In addition,
-     * most countries in the EU have access to standard shipping, which typically takes
-     * less than a week, one way.</p> </li> <li> <p>In India, Snowballs are delivered
-     * in one to seven days.</p> </li> <li> <p>In the United States of America (US),
-     * you have access to one-day shipping and two-day shipping.</p> </li> </ul> <ul>
-     * <li> <p>In Australia, you have access to express shipping. Typically, devices
-     * shipped express are delivered in about a day.</p> </li> <li> <p>In the European
-     * Union (EU), you have access to express shipping. Typically, Snowball Edges
-     * shipped express are delivered in about a day. In addition, most countries in the
-     * EU have access to standard shipping, which typically takes less than a week, one
-     * way.</p> </li> <li> <p>In India, Snowball Edges are delivered in one to seven
-     * days.</p> </li> <li> <p>In the US, you have access to one-day shipping and
-     * two-day shipping.</p> </li> </ul>
+     * Typically, Snowball Edges shipped express are delivered in about a day. In
+     * addition, most countries in the EU have access to standard shipping, which
+     * typically takes less than a week, one way.</p> </li> <li> <p>In India, devices
+     * are delivered in one to seven days.</p> </li> <li> <p>In the US, you have access
+     * to one-day shipping and two-day shipping.</p> </li> </ul>
      */
     inline void SetShippingOption(const ShippingOption& value) { m_shippingOptionHasBeenSet = true; m_shippingOption = value; }
 
@@ -456,22 +441,14 @@ namespace Model
      * <p>The shipping speed for each node in this cluster. This speed doesn't dictate
      * how soon you'll get each Snowball Edge device, rather it represents how quickly
      * each device moves to its destination while in transit. Regional shipping speeds
-     * are as follows: </p> <ul> <li> <p>In Australia, you have access to express
-     * shipping. Typically, Snowballs shipped express are delivered in about a day.</p>
+     * are as follows:</p> <ul> <li> <p>In Australia, you have access to express
+     * shipping. Typically, devices shipped express are delivered in about a day.</p>
      * </li> <li> <p>In the European Union (EU), you have access to express shipping.
-     * Typically, Snowballs shipped express are delivered in about a day. In addition,
-     * most countries in the EU have access to standard shipping, which typically takes
-     * less than a week, one way.</p> </li> <li> <p>In India, Snowballs are delivered
-     * in one to seven days.</p> </li> <li> <p>In the United States of America (US),
-     * you have access to one-day shipping and two-day shipping.</p> </li> </ul> <ul>
-     * <li> <p>In Australia, you have access to express shipping. Typically, devices
-     * shipped express are delivered in about a day.</p> </li> <li> <p>In the European
-     * Union (EU), you have access to express shipping. Typically, Snowball Edges
-     * shipped express are delivered in about a day. In addition, most countries in the
-     * EU have access to standard shipping, which typically takes less than a week, one
-     * way.</p> </li> <li> <p>In India, Snowball Edges are delivered in one to seven
-     * days.</p> </li> <li> <p>In the US, you have access to one-day shipping and
-     * two-day shipping.</p> </li> </ul>
+     * Typically, Snowball Edges shipped express are delivered in about a day. In
+     * addition, most countries in the EU have access to standard shipping, which
+     * typically takes less than a week, one way.</p> </li> <li> <p>In India, devices
+     * are delivered in one to seven days.</p> </li> <li> <p>In the US, you have access
+     * to one-day shipping and two-day shipping.</p> </li> </ul>
      */
     inline void SetShippingOption(ShippingOption&& value) { m_shippingOptionHasBeenSet = true; m_shippingOption = std::move(value); }
 
@@ -479,22 +456,14 @@ namespace Model
      * <p>The shipping speed for each node in this cluster. This speed doesn't dictate
      * how soon you'll get each Snowball Edge device, rather it represents how quickly
      * each device moves to its destination while in transit. Regional shipping speeds
-     * are as follows: </p> <ul> <li> <p>In Australia, you have access to express
-     * shipping. Typically, Snowballs shipped express are delivered in about a day.</p>
+     * are as follows:</p> <ul> <li> <p>In Australia, you have access to express
+     * shipping. Typically, devices shipped express are delivered in about a day.</p>
      * </li> <li> <p>In the European Union (EU), you have access to express shipping.
-     * Typically, Snowballs shipped express are delivered in about a day. In addition,
-     * most countries in the EU have access to standard shipping, which typically takes
-     * less than a week, one way.</p> </li> <li> <p>In India, Snowballs are delivered
-     * in one to seven days.</p> </li> <li> <p>In the United States of America (US),
-     * you have access to one-day shipping and two-day shipping.</p> </li> </ul> <ul>
-     * <li> <p>In Australia, you have access to express shipping. Typically, devices
-     * shipped express are delivered in about a day.</p> </li> <li> <p>In the European
-     * Union (EU), you have access to express shipping. Typically, Snowball Edges
-     * shipped express are delivered in about a day. In addition, most countries in the
-     * EU have access to standard shipping, which typically takes less than a week, one
-     * way.</p> </li> <li> <p>In India, Snowball Edges are delivered in one to seven
-     * days.</p> </li> <li> <p>In the US, you have access to one-day shipping and
-     * two-day shipping.</p> </li> </ul>
+     * Typically, Snowball Edges shipped express are delivered in about a day. In
+     * addition, most countries in the EU have access to standard shipping, which
+     * typically takes less than a week, one way.</p> </li> <li> <p>In India, devices
+     * are delivered in one to seven days.</p> </li> <li> <p>In the US, you have access
+     * to one-day shipping and two-day shipping.</p> </li> </ul>
      */
     inline CreateClusterRequest& WithShippingOption(const ShippingOption& value) { SetShippingOption(value); return *this;}
 
@@ -502,22 +471,14 @@ namespace Model
      * <p>The shipping speed for each node in this cluster. This speed doesn't dictate
      * how soon you'll get each Snowball Edge device, rather it represents how quickly
      * each device moves to its destination while in transit. Regional shipping speeds
-     * are as follows: </p> <ul> <li> <p>In Australia, you have access to express
-     * shipping. Typically, Snowballs shipped express are delivered in about a day.</p>
+     * are as follows:</p> <ul> <li> <p>In Australia, you have access to express
+     * shipping. Typically, devices shipped express are delivered in about a day.</p>
      * </li> <li> <p>In the European Union (EU), you have access to express shipping.
-     * Typically, Snowballs shipped express are delivered in about a day. In addition,
-     * most countries in the EU have access to standard shipping, which typically takes
-     * less than a week, one way.</p> </li> <li> <p>In India, Snowballs are delivered
-     * in one to seven days.</p> </li> <li> <p>In the United States of America (US),
-     * you have access to one-day shipping and two-day shipping.</p> </li> </ul> <ul>
-     * <li> <p>In Australia, you have access to express shipping. Typically, devices
-     * shipped express are delivered in about a day.</p> </li> <li> <p>In the European
-     * Union (EU), you have access to express shipping. Typically, Snowball Edges
-     * shipped express are delivered in about a day. In addition, most countries in the
-     * EU have access to standard shipping, which typically takes less than a week, one
-     * way.</p> </li> <li> <p>In India, Snowball Edges are delivered in one to seven
-     * days.</p> </li> <li> <p>In the US, you have access to one-day shipping and
-     * two-day shipping.</p> </li> </ul>
+     * Typically, Snowball Edges shipped express are delivered in about a day. In
+     * addition, most countries in the EU have access to standard shipping, which
+     * typically takes less than a week, one way.</p> </li> <li> <p>In India, devices
+     * are delivered in one to seven days.</p> </li> <li> <p>In the US, you have access
+     * to one-day shipping and two-day shipping.</p> </li> </ul>
      */
     inline CreateClusterRequest& WithShippingOption(ShippingOption&& value) { SetShippingOption(std::move(value)); return *this;}
 
@@ -607,37 +568,6 @@ namespace Model
      */
     inline CreateClusterRequest& WithForwardingAddressId(const char* value) { SetForwardingAddressId(value); return *this;}
 
-
-    /**
-     * <p>The tax documents required in your AWS Region.</p>
-     */
-    inline const TaxDocuments& GetTaxDocuments() const{ return m_taxDocuments; }
-
-    /**
-     * <p>The tax documents required in your AWS Region.</p>
-     */
-    inline bool TaxDocumentsHasBeenSet() const { return m_taxDocumentsHasBeenSet; }
-
-    /**
-     * <p>The tax documents required in your AWS Region.</p>
-     */
-    inline void SetTaxDocuments(const TaxDocuments& value) { m_taxDocumentsHasBeenSet = true; m_taxDocuments = value; }
-
-    /**
-     * <p>The tax documents required in your AWS Region.</p>
-     */
-    inline void SetTaxDocuments(TaxDocuments&& value) { m_taxDocumentsHasBeenSet = true; m_taxDocuments = std::move(value); }
-
-    /**
-     * <p>The tax documents required in your AWS Region.</p>
-     */
-    inline CreateClusterRequest& WithTaxDocuments(const TaxDocuments& value) { SetTaxDocuments(value); return *this;}
-
-    /**
-     * <p>The tax documents required in your AWS Region.</p>
-     */
-    inline CreateClusterRequest& WithTaxDocuments(TaxDocuments&& value) { SetTaxDocuments(std::move(value)); return *this;}
-
   private:
 
     JobType m_jobType;
@@ -669,9 +599,6 @@ namespace Model
 
     Aws::String m_forwardingAddressId;
     bool m_forwardingAddressIdHasBeenSet;
-
-    TaxDocuments m_taxDocuments;
-    bool m_taxDocumentsHasBeenSet;
   };
 
 } // namespace Model
