@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/states/model/ExecutionSucceededEventDetails.h>
 #include <aws/core/utils/json/JsonSerializer.h>
@@ -19,14 +29,12 @@ namespace Model
 {
 
 ExecutionSucceededEventDetails::ExecutionSucceededEventDetails() : 
-    m_outputHasBeenSet(false),
-    m_outputDetailsHasBeenSet(false)
+    m_outputHasBeenSet(false)
 {
 }
 
 ExecutionSucceededEventDetails::ExecutionSucceededEventDetails(JsonView jsonValue) : 
-    m_outputHasBeenSet(false),
-    m_outputDetailsHasBeenSet(false)
+    m_outputHasBeenSet(false)
 {
   *this = jsonValue;
 }
@@ -40,13 +48,6 @@ ExecutionSucceededEventDetails& ExecutionSucceededEventDetails::operator =(JsonV
     m_outputHasBeenSet = true;
   }
 
-  if(jsonValue.ValueExists("outputDetails"))
-  {
-    m_outputDetails = jsonValue.GetObject("outputDetails");
-
-    m_outputDetailsHasBeenSet = true;
-  }
-
   return *this;
 }
 
@@ -60,12 +61,6 @@ JsonValue ExecutionSucceededEventDetails::Jsonize() const
 
   }
 
-  if(m_outputDetailsHasBeenSet)
-  {
-   payload.WithObject("outputDetails", m_outputDetails.Jsonize());
-
-  }
-
   return payload;
 }
 
