@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #pragma once
 #include <aws/storagegateway/StorageGateway_EXPORTS.h>
@@ -27,7 +37,7 @@ namespace Model
   {
   public:
     CreateTapesRequest();
-
+    
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
     // Note: this is not true for response, multiple operations may have the same response name,
@@ -42,81 +52,81 @@ namespace Model
     /**
      * <p>The unique Amazon Resource Name (ARN) that represents the gateway to
      * associate the virtual tapes with. Use the <a>ListGateways</a> operation to
-     * return a list of gateways for your account and AWS Region.</p>
+     * return a list of gateways for your account and region.</p>
      */
     inline const Aws::String& GetGatewayARN() const{ return m_gatewayARN; }
 
     /**
      * <p>The unique Amazon Resource Name (ARN) that represents the gateway to
      * associate the virtual tapes with. Use the <a>ListGateways</a> operation to
-     * return a list of gateways for your account and AWS Region.</p>
+     * return a list of gateways for your account and region.</p>
      */
     inline bool GatewayARNHasBeenSet() const { return m_gatewayARNHasBeenSet; }
 
     /**
      * <p>The unique Amazon Resource Name (ARN) that represents the gateway to
      * associate the virtual tapes with. Use the <a>ListGateways</a> operation to
-     * return a list of gateways for your account and AWS Region.</p>
+     * return a list of gateways for your account and region.</p>
      */
     inline void SetGatewayARN(const Aws::String& value) { m_gatewayARNHasBeenSet = true; m_gatewayARN = value; }
 
     /**
      * <p>The unique Amazon Resource Name (ARN) that represents the gateway to
      * associate the virtual tapes with. Use the <a>ListGateways</a> operation to
-     * return a list of gateways for your account and AWS Region.</p>
+     * return a list of gateways for your account and region.</p>
      */
     inline void SetGatewayARN(Aws::String&& value) { m_gatewayARNHasBeenSet = true; m_gatewayARN = std::move(value); }
 
     /**
      * <p>The unique Amazon Resource Name (ARN) that represents the gateway to
      * associate the virtual tapes with. Use the <a>ListGateways</a> operation to
-     * return a list of gateways for your account and AWS Region.</p>
+     * return a list of gateways for your account and region.</p>
      */
     inline void SetGatewayARN(const char* value) { m_gatewayARNHasBeenSet = true; m_gatewayARN.assign(value); }
 
     /**
      * <p>The unique Amazon Resource Name (ARN) that represents the gateway to
      * associate the virtual tapes with. Use the <a>ListGateways</a> operation to
-     * return a list of gateways for your account and AWS Region.</p>
+     * return a list of gateways for your account and region.</p>
      */
     inline CreateTapesRequest& WithGatewayARN(const Aws::String& value) { SetGatewayARN(value); return *this;}
 
     /**
      * <p>The unique Amazon Resource Name (ARN) that represents the gateway to
      * associate the virtual tapes with. Use the <a>ListGateways</a> operation to
-     * return a list of gateways for your account and AWS Region.</p>
+     * return a list of gateways for your account and region.</p>
      */
     inline CreateTapesRequest& WithGatewayARN(Aws::String&& value) { SetGatewayARN(std::move(value)); return *this;}
 
     /**
      * <p>The unique Amazon Resource Name (ARN) that represents the gateway to
      * associate the virtual tapes with. Use the <a>ListGateways</a> operation to
-     * return a list of gateways for your account and AWS Region.</p>
+     * return a list of gateways for your account and region.</p>
      */
     inline CreateTapesRequest& WithGatewayARN(const char* value) { SetGatewayARN(value); return *this;}
 
 
     /**
-     * <p>The size, in bytes, of the virtual tapes that you want to create.</p> 
-     * <p>The size must be aligned by gigabyte (1024*1024*1024 bytes).</p> 
+     * <p>The size, in bytes, of the virtual tapes that you want to create.</p> <note>
+     * <p>The size must be aligned by gigabyte (1024*1024*1024 byte).</p> </note>
      */
     inline long long GetTapeSizeInBytes() const{ return m_tapeSizeInBytes; }
 
     /**
-     * <p>The size, in bytes, of the virtual tapes that you want to create.</p> 
-     * <p>The size must be aligned by gigabyte (1024*1024*1024 bytes).</p> 
+     * <p>The size, in bytes, of the virtual tapes that you want to create.</p> <note>
+     * <p>The size must be aligned by gigabyte (1024*1024*1024 byte).</p> </note>
      */
     inline bool TapeSizeInBytesHasBeenSet() const { return m_tapeSizeInBytesHasBeenSet; }
 
     /**
-     * <p>The size, in bytes, of the virtual tapes that you want to create.</p> 
-     * <p>The size must be aligned by gigabyte (1024*1024*1024 bytes).</p> 
+     * <p>The size, in bytes, of the virtual tapes that you want to create.</p> <note>
+     * <p>The size must be aligned by gigabyte (1024*1024*1024 byte).</p> </note>
      */
     inline void SetTapeSizeInBytes(long long value) { m_tapeSizeInBytesHasBeenSet = true; m_tapeSizeInBytes = value; }
 
     /**
-     * <p>The size, in bytes, of the virtual tapes that you want to create.</p> 
-     * <p>The size must be aligned by gigabyte (1024*1024*1024 bytes).</p> 
+     * <p>The size, in bytes, of the virtual tapes that you want to create.</p> <note>
+     * <p>The size must be aligned by gigabyte (1024*1024*1024 byte).</p> </note>
      */
     inline CreateTapesRequest& WithTapeSizeInBytes(long long value) { SetTapeSizeInBytes(value); return *this;}
 
@@ -124,64 +134,64 @@ namespace Model
     /**
      * <p>A unique identifier that you use to retry a request. If you retry a request,
      * use the same <code>ClientToken</code> you specified in the initial request.</p>
-     *  <p>Using the same <code>ClientToken</code> prevents creating the tape
-     * multiple times.</p> 
+     * <note> <p>Using the same <code>ClientToken</code> prevents creating the tape
+     * multiple times.</p> </note>
      */
     inline const Aws::String& GetClientToken() const{ return m_clientToken; }
 
     /**
      * <p>A unique identifier that you use to retry a request. If you retry a request,
      * use the same <code>ClientToken</code> you specified in the initial request.</p>
-     *  <p>Using the same <code>ClientToken</code> prevents creating the tape
-     * multiple times.</p> 
+     * <note> <p>Using the same <code>ClientToken</code> prevents creating the tape
+     * multiple times.</p> </note>
      */
     inline bool ClientTokenHasBeenSet() const { return m_clientTokenHasBeenSet; }
 
     /**
      * <p>A unique identifier that you use to retry a request. If you retry a request,
      * use the same <code>ClientToken</code> you specified in the initial request.</p>
-     *  <p>Using the same <code>ClientToken</code> prevents creating the tape
-     * multiple times.</p> 
+     * <note> <p>Using the same <code>ClientToken</code> prevents creating the tape
+     * multiple times.</p> </note>
      */
     inline void SetClientToken(const Aws::String& value) { m_clientTokenHasBeenSet = true; m_clientToken = value; }
 
     /**
      * <p>A unique identifier that you use to retry a request. If you retry a request,
      * use the same <code>ClientToken</code> you specified in the initial request.</p>
-     *  <p>Using the same <code>ClientToken</code> prevents creating the tape
-     * multiple times.</p> 
+     * <note> <p>Using the same <code>ClientToken</code> prevents creating the tape
+     * multiple times.</p> </note>
      */
     inline void SetClientToken(Aws::String&& value) { m_clientTokenHasBeenSet = true; m_clientToken = std::move(value); }
 
     /**
      * <p>A unique identifier that you use to retry a request. If you retry a request,
      * use the same <code>ClientToken</code> you specified in the initial request.</p>
-     *  <p>Using the same <code>ClientToken</code> prevents creating the tape
-     * multiple times.</p> 
+     * <note> <p>Using the same <code>ClientToken</code> prevents creating the tape
+     * multiple times.</p> </note>
      */
     inline void SetClientToken(const char* value) { m_clientTokenHasBeenSet = true; m_clientToken.assign(value); }
 
     /**
      * <p>A unique identifier that you use to retry a request. If you retry a request,
      * use the same <code>ClientToken</code> you specified in the initial request.</p>
-     *  <p>Using the same <code>ClientToken</code> prevents creating the tape
-     * multiple times.</p> 
+     * <note> <p>Using the same <code>ClientToken</code> prevents creating the tape
+     * multiple times.</p> </note>
      */
     inline CreateTapesRequest& WithClientToken(const Aws::String& value) { SetClientToken(value); return *this;}
 
     /**
      * <p>A unique identifier that you use to retry a request. If you retry a request,
      * use the same <code>ClientToken</code> you specified in the initial request.</p>
-     *  <p>Using the same <code>ClientToken</code> prevents creating the tape
-     * multiple times.</p> 
+     * <note> <p>Using the same <code>ClientToken</code> prevents creating the tape
+     * multiple times.</p> </note>
      */
     inline CreateTapesRequest& WithClientToken(Aws::String&& value) { SetClientToken(std::move(value)); return *this;}
 
     /**
      * <p>A unique identifier that you use to retry a request. If you retry a request,
      * use the same <code>ClientToken</code> you specified in the initial request.</p>
-     *  <p>Using the same <code>ClientToken</code> prevents creating the tape
-     * multiple times.</p> 
+     * <note> <p>Using the same <code>ClientToken</code> prevents creating the tape
+     * multiple times.</p> </note>
      */
     inline CreateTapesRequest& WithClientToken(const char* value) { SetClientToken(value); return *this;}
 
@@ -209,159 +219,147 @@ namespace Model
 
     /**
      * <p>A prefix that you append to the barcode of the virtual tape you are creating.
-     * This prefix makes the barcode unique.</p>  <p>The prefix must be 1 to 4
+     * This prefix makes the barcode unique.</p> <note> <p>The prefix must be 1 to 4
      * characters in length and must be one of the uppercase letters from A to Z.</p>
-     * 
+     * </note>
      */
     inline const Aws::String& GetTapeBarcodePrefix() const{ return m_tapeBarcodePrefix; }
 
     /**
      * <p>A prefix that you append to the barcode of the virtual tape you are creating.
-     * This prefix makes the barcode unique.</p>  <p>The prefix must be 1 to 4
+     * This prefix makes the barcode unique.</p> <note> <p>The prefix must be 1 to 4
      * characters in length and must be one of the uppercase letters from A to Z.</p>
-     * 
+     * </note>
      */
     inline bool TapeBarcodePrefixHasBeenSet() const { return m_tapeBarcodePrefixHasBeenSet; }
 
     /**
      * <p>A prefix that you append to the barcode of the virtual tape you are creating.
-     * This prefix makes the barcode unique.</p>  <p>The prefix must be 1 to 4
+     * This prefix makes the barcode unique.</p> <note> <p>The prefix must be 1 to 4
      * characters in length and must be one of the uppercase letters from A to Z.</p>
-     * 
+     * </note>
      */
     inline void SetTapeBarcodePrefix(const Aws::String& value) { m_tapeBarcodePrefixHasBeenSet = true; m_tapeBarcodePrefix = value; }
 
     /**
      * <p>A prefix that you append to the barcode of the virtual tape you are creating.
-     * This prefix makes the barcode unique.</p>  <p>The prefix must be 1 to 4
+     * This prefix makes the barcode unique.</p> <note> <p>The prefix must be 1 to 4
      * characters in length and must be one of the uppercase letters from A to Z.</p>
-     * 
+     * </note>
      */
     inline void SetTapeBarcodePrefix(Aws::String&& value) { m_tapeBarcodePrefixHasBeenSet = true; m_tapeBarcodePrefix = std::move(value); }
 
     /**
      * <p>A prefix that you append to the barcode of the virtual tape you are creating.
-     * This prefix makes the barcode unique.</p>  <p>The prefix must be 1 to 4
+     * This prefix makes the barcode unique.</p> <note> <p>The prefix must be 1 to 4
      * characters in length and must be one of the uppercase letters from A to Z.</p>
-     * 
+     * </note>
      */
     inline void SetTapeBarcodePrefix(const char* value) { m_tapeBarcodePrefixHasBeenSet = true; m_tapeBarcodePrefix.assign(value); }
 
     /**
      * <p>A prefix that you append to the barcode of the virtual tape you are creating.
-     * This prefix makes the barcode unique.</p>  <p>The prefix must be 1 to 4
+     * This prefix makes the barcode unique.</p> <note> <p>The prefix must be 1 to 4
      * characters in length and must be one of the uppercase letters from A to Z.</p>
-     * 
+     * </note>
      */
     inline CreateTapesRequest& WithTapeBarcodePrefix(const Aws::String& value) { SetTapeBarcodePrefix(value); return *this;}
 
     /**
      * <p>A prefix that you append to the barcode of the virtual tape you are creating.
-     * This prefix makes the barcode unique.</p>  <p>The prefix must be 1 to 4
+     * This prefix makes the barcode unique.</p> <note> <p>The prefix must be 1 to 4
      * characters in length and must be one of the uppercase letters from A to Z.</p>
-     * 
+     * </note>
      */
     inline CreateTapesRequest& WithTapeBarcodePrefix(Aws::String&& value) { SetTapeBarcodePrefix(std::move(value)); return *this;}
 
     /**
      * <p>A prefix that you append to the barcode of the virtual tape you are creating.
-     * This prefix makes the barcode unique.</p>  <p>The prefix must be 1 to 4
+     * This prefix makes the barcode unique.</p> <note> <p>The prefix must be 1 to 4
      * characters in length and must be one of the uppercase letters from A to Z.</p>
-     * 
+     * </note>
      */
     inline CreateTapesRequest& WithTapeBarcodePrefix(const char* value) { SetTapeBarcodePrefix(value); return *this;}
 
 
     /**
-     * <p>Set to <code>true</code> to use Amazon S3 server-side encryption with your
-     * own AWS KMS key, or <code>false</code> to use a key managed by Amazon S3.
-     * Optional.</p> <p>Valid Values: <code>true</code> | <code>false</code> </p>
+     * <p>True to use Amazon S3 server side encryption with your own AWS KMS key, or
+     * false to use a key managed by Amazon S3. Optional.</p>
      */
     inline bool GetKMSEncrypted() const{ return m_kMSEncrypted; }
 
     /**
-     * <p>Set to <code>true</code> to use Amazon S3 server-side encryption with your
-     * own AWS KMS key, or <code>false</code> to use a key managed by Amazon S3.
-     * Optional.</p> <p>Valid Values: <code>true</code> | <code>false</code> </p>
+     * <p>True to use Amazon S3 server side encryption with your own AWS KMS key, or
+     * false to use a key managed by Amazon S3. Optional.</p>
      */
     inline bool KMSEncryptedHasBeenSet() const { return m_kMSEncryptedHasBeenSet; }
 
     /**
-     * <p>Set to <code>true</code> to use Amazon S3 server-side encryption with your
-     * own AWS KMS key, or <code>false</code> to use a key managed by Amazon S3.
-     * Optional.</p> <p>Valid Values: <code>true</code> | <code>false</code> </p>
+     * <p>True to use Amazon S3 server side encryption with your own AWS KMS key, or
+     * false to use a key managed by Amazon S3. Optional.</p>
      */
     inline void SetKMSEncrypted(bool value) { m_kMSEncryptedHasBeenSet = true; m_kMSEncrypted = value; }
 
     /**
-     * <p>Set to <code>true</code> to use Amazon S3 server-side encryption with your
-     * own AWS KMS key, or <code>false</code> to use a key managed by Amazon S3.
-     * Optional.</p> <p>Valid Values: <code>true</code> | <code>false</code> </p>
+     * <p>True to use Amazon S3 server side encryption with your own AWS KMS key, or
+     * false to use a key managed by Amazon S3. Optional.</p>
      */
     inline CreateTapesRequest& WithKMSEncrypted(bool value) { SetKMSEncrypted(value); return *this;}
 
 
     /**
-     * <p>The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used
-     * for Amazon S3 server-side encryption. Storage Gateway does not support
-     * asymmetric CMKs. This value can only be set when <code>KMSEncrypted</code> is
-     * <code>true</code>. Optional.</p>
+     * <p>The Amazon Resource Name (ARN) of the AWS KMS key used for Amazon S3 server
+     * side encryption. This value can only be set when KMSEncrypted is true.
+     * Optional.</p>
      */
     inline const Aws::String& GetKMSKey() const{ return m_kMSKey; }
 
     /**
-     * <p>The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used
-     * for Amazon S3 server-side encryption. Storage Gateway does not support
-     * asymmetric CMKs. This value can only be set when <code>KMSEncrypted</code> is
-     * <code>true</code>. Optional.</p>
+     * <p>The Amazon Resource Name (ARN) of the AWS KMS key used for Amazon S3 server
+     * side encryption. This value can only be set when KMSEncrypted is true.
+     * Optional.</p>
      */
     inline bool KMSKeyHasBeenSet() const { return m_kMSKeyHasBeenSet; }
 
     /**
-     * <p>The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used
-     * for Amazon S3 server-side encryption. Storage Gateway does not support
-     * asymmetric CMKs. This value can only be set when <code>KMSEncrypted</code> is
-     * <code>true</code>. Optional.</p>
+     * <p>The Amazon Resource Name (ARN) of the AWS KMS key used for Amazon S3 server
+     * side encryption. This value can only be set when KMSEncrypted is true.
+     * Optional.</p>
      */
     inline void SetKMSKey(const Aws::String& value) { m_kMSKeyHasBeenSet = true; m_kMSKey = value; }
 
     /**
-     * <p>The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used
-     * for Amazon S3 server-side encryption. Storage Gateway does not support
-     * asymmetric CMKs. This value can only be set when <code>KMSEncrypted</code> is
-     * <code>true</code>. Optional.</p>
+     * <p>The Amazon Resource Name (ARN) of the AWS KMS key used for Amazon S3 server
+     * side encryption. This value can only be set when KMSEncrypted is true.
+     * Optional.</p>
      */
     inline void SetKMSKey(Aws::String&& value) { m_kMSKeyHasBeenSet = true; m_kMSKey = std::move(value); }
 
     /**
-     * <p>The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used
-     * for Amazon S3 server-side encryption. Storage Gateway does not support
-     * asymmetric CMKs. This value can only be set when <code>KMSEncrypted</code> is
-     * <code>true</code>. Optional.</p>
+     * <p>The Amazon Resource Name (ARN) of the AWS KMS key used for Amazon S3 server
+     * side encryption. This value can only be set when KMSEncrypted is true.
+     * Optional.</p>
      */
     inline void SetKMSKey(const char* value) { m_kMSKeyHasBeenSet = true; m_kMSKey.assign(value); }
 
     /**
-     * <p>The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used
-     * for Amazon S3 server-side encryption. Storage Gateway does not support
-     * asymmetric CMKs. This value can only be set when <code>KMSEncrypted</code> is
-     * <code>true</code>. Optional.</p>
+     * <p>The Amazon Resource Name (ARN) of the AWS KMS key used for Amazon S3 server
+     * side encryption. This value can only be set when KMSEncrypted is true.
+     * Optional.</p>
      */
     inline CreateTapesRequest& WithKMSKey(const Aws::String& value) { SetKMSKey(value); return *this;}
 
     /**
-     * <p>The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used
-     * for Amazon S3 server-side encryption. Storage Gateway does not support
-     * asymmetric CMKs. This value can only be set when <code>KMSEncrypted</code> is
-     * <code>true</code>. Optional.</p>
+     * <p>The Amazon Resource Name (ARN) of the AWS KMS key used for Amazon S3 server
+     * side encryption. This value can only be set when KMSEncrypted is true.
+     * Optional.</p>
      */
     inline CreateTapesRequest& WithKMSKey(Aws::String&& value) { SetKMSKey(std::move(value)); return *this;}
 
     /**
-     * <p>The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used
-     * for Amazon S3 server-side encryption. Storage Gateway does not support
-     * asymmetric CMKs. This value can only be set when <code>KMSEncrypted</code> is
-     * <code>true</code>. Optional.</p>
+     * <p>The Amazon Resource Name (ARN) of the AWS KMS key used for Amazon S3 server
+     * side encryption. This value can only be set when KMSEncrypted is true.
+     * Optional.</p>
      */
     inline CreateTapesRequest& WithKMSKey(const char* value) { SetKMSKey(value); return *this;}
 
@@ -370,9 +368,8 @@ namespace Model
      * <p>The ID of the pool that you want to add your tape to for archiving. The tape
      * in this pool is archived in the S3 storage class that is associated with the
      * pool. When you use your backup application to eject the tape, the tape is
-     * archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive)
-     * that corresponds to the pool.</p> <p>Valid Values: <code>GLACIER</code> |
-     * <code>DEEP_ARCHIVE</code> </p>
+     * archived directly into the storage class (Glacier or Deep Archive) that
+     * corresponds to the pool.</p> <p>Valid values: "GLACIER", "DEEP_ARCHIVE"</p>
      */
     inline const Aws::String& GetPoolId() const{ return m_poolId; }
 
@@ -380,9 +377,8 @@ namespace Model
      * <p>The ID of the pool that you want to add your tape to for archiving. The tape
      * in this pool is archived in the S3 storage class that is associated with the
      * pool. When you use your backup application to eject the tape, the tape is
-     * archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive)
-     * that corresponds to the pool.</p> <p>Valid Values: <code>GLACIER</code> |
-     * <code>DEEP_ARCHIVE</code> </p>
+     * archived directly into the storage class (Glacier or Deep Archive) that
+     * corresponds to the pool.</p> <p>Valid values: "GLACIER", "DEEP_ARCHIVE"</p>
      */
     inline bool PoolIdHasBeenSet() const { return m_poolIdHasBeenSet; }
 
@@ -390,9 +386,8 @@ namespace Model
      * <p>The ID of the pool that you want to add your tape to for archiving. The tape
      * in this pool is archived in the S3 storage class that is associated with the
      * pool. When you use your backup application to eject the tape, the tape is
-     * archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive)
-     * that corresponds to the pool.</p> <p>Valid Values: <code>GLACIER</code> |
-     * <code>DEEP_ARCHIVE</code> </p>
+     * archived directly into the storage class (Glacier or Deep Archive) that
+     * corresponds to the pool.</p> <p>Valid values: "GLACIER", "DEEP_ARCHIVE"</p>
      */
     inline void SetPoolId(const Aws::String& value) { m_poolIdHasBeenSet = true; m_poolId = value; }
 
@@ -400,9 +395,8 @@ namespace Model
      * <p>The ID of the pool that you want to add your tape to for archiving. The tape
      * in this pool is archived in the S3 storage class that is associated with the
      * pool. When you use your backup application to eject the tape, the tape is
-     * archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive)
-     * that corresponds to the pool.</p> <p>Valid Values: <code>GLACIER</code> |
-     * <code>DEEP_ARCHIVE</code> </p>
+     * archived directly into the storage class (Glacier or Deep Archive) that
+     * corresponds to the pool.</p> <p>Valid values: "GLACIER", "DEEP_ARCHIVE"</p>
      */
     inline void SetPoolId(Aws::String&& value) { m_poolIdHasBeenSet = true; m_poolId = std::move(value); }
 
@@ -410,9 +404,8 @@ namespace Model
      * <p>The ID of the pool that you want to add your tape to for archiving. The tape
      * in this pool is archived in the S3 storage class that is associated with the
      * pool. When you use your backup application to eject the tape, the tape is
-     * archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive)
-     * that corresponds to the pool.</p> <p>Valid Values: <code>GLACIER</code> |
-     * <code>DEEP_ARCHIVE</code> </p>
+     * archived directly into the storage class (Glacier or Deep Archive) that
+     * corresponds to the pool.</p> <p>Valid values: "GLACIER", "DEEP_ARCHIVE"</p>
      */
     inline void SetPoolId(const char* value) { m_poolIdHasBeenSet = true; m_poolId.assign(value); }
 
@@ -420,9 +413,8 @@ namespace Model
      * <p>The ID of the pool that you want to add your tape to for archiving. The tape
      * in this pool is archived in the S3 storage class that is associated with the
      * pool. When you use your backup application to eject the tape, the tape is
-     * archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive)
-     * that corresponds to the pool.</p> <p>Valid Values: <code>GLACIER</code> |
-     * <code>DEEP_ARCHIVE</code> </p>
+     * archived directly into the storage class (Glacier or Deep Archive) that
+     * corresponds to the pool.</p> <p>Valid values: "GLACIER", "DEEP_ARCHIVE"</p>
      */
     inline CreateTapesRequest& WithPoolId(const Aws::String& value) { SetPoolId(value); return *this;}
 
@@ -430,9 +422,8 @@ namespace Model
      * <p>The ID of the pool that you want to add your tape to for archiving. The tape
      * in this pool is archived in the S3 storage class that is associated with the
      * pool. When you use your backup application to eject the tape, the tape is
-     * archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive)
-     * that corresponds to the pool.</p> <p>Valid Values: <code>GLACIER</code> |
-     * <code>DEEP_ARCHIVE</code> </p>
+     * archived directly into the storage class (Glacier or Deep Archive) that
+     * corresponds to the pool.</p> <p>Valid values: "GLACIER", "DEEP_ARCHIVE"</p>
      */
     inline CreateTapesRequest& WithPoolId(Aws::String&& value) { SetPoolId(std::move(value)); return *this;}
 
@@ -440,107 +431,81 @@ namespace Model
      * <p>The ID of the pool that you want to add your tape to for archiving. The tape
      * in this pool is archived in the S3 storage class that is associated with the
      * pool. When you use your backup application to eject the tape, the tape is
-     * archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive)
-     * that corresponds to the pool.</p> <p>Valid Values: <code>GLACIER</code> |
-     * <code>DEEP_ARCHIVE</code> </p>
+     * archived directly into the storage class (Glacier or Deep Archive) that
+     * corresponds to the pool.</p> <p>Valid values: "GLACIER", "DEEP_ARCHIVE"</p>
      */
     inline CreateTapesRequest& WithPoolId(const char* value) { SetPoolId(value); return *this;}
 
 
-    /**
-     * <p>Set to <code>TRUE</code> if the tape you are creating is to be configured as
-     * a write-once-read-many (WORM) tape.</p>
-     */
-    inline bool GetWorm() const{ return m_worm; }
-
-    /**
-     * <p>Set to <code>TRUE</code> if the tape you are creating is to be configured as
-     * a write-once-read-many (WORM) tape.</p>
-     */
-    inline bool WormHasBeenSet() const { return m_wormHasBeenSet; }
-
-    /**
-     * <p>Set to <code>TRUE</code> if the tape you are creating is to be configured as
-     * a write-once-read-many (WORM) tape.</p>
-     */
-    inline void SetWorm(bool value) { m_wormHasBeenSet = true; m_worm = value; }
-
-    /**
-     * <p>Set to <code>TRUE</code> if the tape you are creating is to be configured as
-     * a write-once-read-many (WORM) tape.</p>
-     */
-    inline CreateTapesRequest& WithWorm(bool value) { SetWorm(value); return *this;}
-
-
     /**
      * <p>A list of up to 50 tags that can be assigned to a virtual tape. Each tag is a
-     * key-value pair.</p>  <p>Valid characters for key and value are letters,
+     * key-value pair.</p> <note> <p>Valid characters for key and value are letters,
      * spaces, and numbers representable in UTF-8 format, and the following special
      * characters: + - = . _ : / @. The maximum length of a tag's key is 128
-     * characters, and the maximum length for a tag's value is 256.</p> 
+     * characters, and the maximum length for a tag's value is 256.</p> </note>
      */
     inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
 
     /**
      * <p>A list of up to 50 tags that can be assigned to a virtual tape. Each tag is a
-     * key-value pair.</p>  <p>Valid characters for key and value are letters,
+     * key-value pair.</p> <note> <p>Valid characters for key and value are letters,
      * spaces, and numbers representable in UTF-8 format, and the following special
      * characters: + - = . _ : / @. The maximum length of a tag's key is 128
-     * characters, and the maximum length for a tag's value is 256.</p> 
+     * characters, and the maximum length for a tag's value is 256.</p> </note>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
      * <p>A list of up to 50 tags that can be assigned to a virtual tape. Each tag is a
-     * key-value pair.</p>  <p>Valid characters for key and value are letters,
+     * key-value pair.</p> <note> <p>Valid characters for key and value are letters,
      * spaces, and numbers representable in UTF-8 format, and the following special
      * characters: + - = . _ : / @. The maximum length of a tag's key is 128
-     * characters, and the maximum length for a tag's value is 256.</p> 
+     * characters, and the maximum length for a tag's value is 256.</p> </note>
      */
     inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
      * <p>A list of up to 50 tags that can be assigned to a virtual tape. Each tag is a
-     * key-value pair.</p>  <p>Valid characters for key and value are letters,
+     * key-value pair.</p> <note> <p>Valid characters for key and value are letters,
      * spaces, and numbers representable in UTF-8 format, and the following special
      * characters: + - = . _ : / @. The maximum length of a tag's key is 128
-     * characters, and the maximum length for a tag's value is 256.</p> 
+     * characters, and the maximum length for a tag's value is 256.</p> </note>
      */
     inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
      * <p>A list of up to 50 tags that can be assigned to a virtual tape. Each tag is a
-     * key-value pair.</p>  <p>Valid characters for key and value are letters,
+     * key-value pair.</p> <note> <p>Valid characters for key and value are letters,
      * spaces, and numbers representable in UTF-8 format, and the following special
      * characters: + - = . _ : / @. The maximum length of a tag's key is 128
-     * characters, and the maximum length for a tag's value is 256.</p> 
+     * characters, and the maximum length for a tag's value is 256.</p> </note>
      */
     inline CreateTapesRequest& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
 
     /**
      * <p>A list of up to 50 tags that can be assigned to a virtual tape. Each tag is a
-     * key-value pair.</p>  <p>Valid characters for key and value are letters,
+     * key-value pair.</p> <note> <p>Valid characters for key and value are letters,
      * spaces, and numbers representable in UTF-8 format, and the following special
      * characters: + - = . _ : / @. The maximum length of a tag's key is 128
-     * characters, and the maximum length for a tag's value is 256.</p> 
+     * characters, and the maximum length for a tag's value is 256.</p> </note>
      */
     inline CreateTapesRequest& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
      * <p>A list of up to 50 tags that can be assigned to a virtual tape. Each tag is a
-     * key-value pair.</p>  <p>Valid characters for key and value are letters,
+     * key-value pair.</p> <note> <p>Valid characters for key and value are letters,
      * spaces, and numbers representable in UTF-8 format, and the following special
      * characters: + - = . _ : / @. The maximum length of a tag's key is 128
-     * characters, and the maximum length for a tag's value is 256.</p> 
+     * characters, and the maximum length for a tag's value is 256.</p> </note>
      */
     inline CreateTapesRequest& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
 
     /**
      * <p>A list of up to 50 tags that can be assigned to a virtual tape. Each tag is a
-     * key-value pair.</p>  <p>Valid characters for key and value are letters,
+     * key-value pair.</p> <note> <p>Valid characters for key and value are letters,
      * spaces, and numbers representable in UTF-8 format, and the following special
      * characters: + - = . _ : / @. The maximum length of a tag's key is 128
-     * characters, and the maximum length for a tag's value is 256.</p> 
+     * characters, and the maximum length for a tag's value is 256.</p> </note>
      */
     inline CreateTapesRequest& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
@@ -570,9 +535,6 @@ namespace Model
     Aws::String m_poolId;
     bool m_poolIdHasBeenSet;
 
-    bool m_worm;
-    bool m_wormHasBeenSet;
-
     Aws::Vector<Tag> m_tags;
     bool m_tagsHasBeenSet;
   };
