@@ -1,7 +1,17 @@
-﻿/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+﻿/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 #include <aws/core/utils/Outcome.h>
 #include <aws/core/auth/AWSAuthSigner.h>
@@ -21,7 +31,6 @@
 #include <aws/worklink/WorkLinkEndpoint.h>
 #include <aws/worklink/WorkLinkErrorMarshaller.h>
 #include <aws/worklink/model/AssociateDomainRequest.h>
-#include <aws/worklink/model/AssociateWebsiteAuthorizationProviderRequest.h>
 #include <aws/worklink/model/AssociateWebsiteCertificateAuthorityRequest.h>
 #include <aws/worklink/model/CreateFleetRequest.h>
 #include <aws/worklink/model/DeleteFleetRequest.h>
@@ -34,19 +43,14 @@
 #include <aws/worklink/model/DescribeIdentityProviderConfigurationRequest.h>
 #include <aws/worklink/model/DescribeWebsiteCertificateAuthorityRequest.h>
 #include <aws/worklink/model/DisassociateDomainRequest.h>
-#include <aws/worklink/model/DisassociateWebsiteAuthorizationProviderRequest.h>
 #include <aws/worklink/model/DisassociateWebsiteCertificateAuthorityRequest.h>
 #include <aws/worklink/model/ListDevicesRequest.h>
 #include <aws/worklink/model/ListDomainsRequest.h>
 #include <aws/worklink/model/ListFleetsRequest.h>
-#include <aws/worklink/model/ListTagsForResourceRequest.h>
-#include <aws/worklink/model/ListWebsiteAuthorizationProvidersRequest.h>
 #include <aws/worklink/model/ListWebsiteCertificateAuthoritiesRequest.h>
 #include <aws/worklink/model/RestoreDomainAccessRequest.h>
 #include <aws/worklink/model/RevokeDomainAccessRequest.h>
 #include <aws/worklink/model/SignOutUserRequest.h>
-#include <aws/worklink/model/TagResourceRequest.h>
-#include <aws/worklink/model/UntagResourceRequest.h>
 #include <aws/worklink/model/UpdateAuditStreamConfigurationRequest.h>
 #include <aws/worklink/model/UpdateCompanyNetworkConfigurationRequest.h>
 #include <aws/worklink/model/UpdateDevicePolicyConfigurationRequest.h>
@@ -69,7 +73,7 @@ static const char* ALLOCATION_TAG = "WorkLinkClient";
 WorkLinkClient::WorkLinkClient(const Client::ClientConfiguration& clientConfiguration) :
   BASECLASS(clientConfiguration,
     Aws::MakeShared<AWSAuthV4Signer>(ALLOCATION_TAG, Aws::MakeShared<DefaultAWSCredentialsProviderChain>(ALLOCATION_TAG),
-        SERVICE_NAME, Aws::Region::ComputeSignerRegion(clientConfiguration.region)),
+        SERVICE_NAME, clientConfiguration.region),
     Aws::MakeShared<WorkLinkErrorMarshaller>(ALLOCATION_TAG)),
     m_executor(clientConfiguration.executor)
 {
@@ -79,7 +83,7 @@ WorkLinkClient::WorkLinkClient(const Client::ClientConfiguration& clientConfigur
 WorkLinkClient::WorkLinkClient(const AWSCredentials& credentials, const Client::ClientConfiguration& clientConfiguration) :
   BASECLASS(clientConfiguration,
     Aws::MakeShared<AWSAuthV4Signer>(ALLOCATION_TAG, Aws::MakeShared<SimpleAWSCredentialsProvider>(ALLOCATION_TAG, credentials),
-         SERVICE_NAME, Aws::Region::ComputeSignerRegion(clientConfiguration.region)),
+         SERVICE_NAME, clientConfiguration.region),
     Aws::MakeShared<WorkLinkErrorMarshaller>(ALLOCATION_TAG)),
     m_executor(clientConfiguration.executor)
 {
@@ -90,7 +94,7 @@ WorkLinkClient::WorkLinkClient(const std::shared_ptr<AWSCredentialsProvider>& cr
   const Client::ClientConfiguration& clientConfiguration) :
   BASECLASS(clientConfiguration,
     Aws::MakeShared<AWSAuthV4Signer>(ALLOCATION_TAG, credentialsProvider,
-         SERVICE_NAME, Aws::Region::ComputeSignerRegion(clientConfiguration.region)),
+         SERVICE_NAME, clientConfiguration.region),
     Aws::MakeShared<WorkLinkErrorMarshaller>(ALLOCATION_TAG)),
     m_executor(clientConfiguration.executor)
 {
@@ -103,7 +107,6 @@ WorkLinkClient::~WorkLinkClient()
 
 void WorkLinkClient::init(const ClientConfiguration& config)
 {
-  SetServiceClientName("WorkLink");
   m_configScheme = SchemeMapper::ToString(config.scheme);
   if (config.endpointOverride.empty())
   {
@@ -126,14 +129,21 @@ void WorkLinkClient::OverrideEndpoint(const Aws::String& endpoint)
       m_uri = m_configScheme + "://" + endpoint;
   }
 }
-
 AssociateDomainOutcome WorkLinkClient::AssociateDomain(const AssociateDomainRequest& request) const
 {
   Aws::Http::URI uri = m_uri;
   Aws::StringStream ss;
   ss << "/associateDomain";
   uri.SetPath(uri.GetPath() + ss.str());
-  return AssociateDomainOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return AssociateDomainOutcome(AssociateDomainResult(outcome.GetResult()));
+  }
+  else
+  {
+    return AssociateDomainOutcome(outcome.GetError());
+  }
 }
 
 AssociateDomainOutcomeCallable WorkLinkClient::AssociateDomainCallable(const AssociateDomainRequest& request) const
@@ -154,40 +164,21 @@ void WorkLinkClient::AssociateDomainAsyncHelper(const AssociateDomainRequest& re
   handler(this, request, AssociateDomain(request), context);
 }
 
-AssociateWebsiteAuthorizationProviderOutcome WorkLinkClient::AssociateWebsiteAuthorizationProvider(const AssociateWebsiteAuthorizationProviderRequest& request) const
-{
-  Aws::Http::URI uri = m_uri;
-  Aws::StringStream ss;
-  ss << "/associateWebsiteAuthorizationProvider";
-  uri.SetPath(uri.GetPath() + ss.str());
-  return AssociateWebsiteAuthorizationProviderOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
-}
-
-AssociateWebsiteAuthorizationProviderOutcomeCallable WorkLinkClient::AssociateWebsiteAuthorizationProviderCallable(const AssociateWebsiteAuthorizationProviderRequest& request) const
-{
-  auto task = Aws::MakeShared< std::packaged_task< AssociateWebsiteAuthorizationProviderOutcome() > >(ALLOCATION_TAG, [this, request](){ return this->AssociateWebsiteAuthorizationProvider(request); } );
-  auto packagedFunction = [task]() { (*task)(); };
-  m_executor->Submit(packagedFunction);
-  return task->get_future();
-}
-
-void WorkLinkClient::AssociateWebsiteAuthorizationProviderAsync(const AssociateWebsiteAuthorizationProviderRequest& request, const AssociateWebsiteAuthorizationProviderResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  m_executor->Submit( [this, request, handler, context](){ this->AssociateWebsiteAuthorizationProviderAsyncHelper( request, handler, context ); } );
-}
-
-void WorkLinkClient::AssociateWebsiteAuthorizationProviderAsyncHelper(const AssociateWebsiteAuthorizationProviderRequest& request, const AssociateWebsiteAuthorizationProviderResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  handler(this, request, AssociateWebsiteAuthorizationProvider(request), context);
-}
-
 AssociateWebsiteCertificateAuthorityOutcome WorkLinkClient::AssociateWebsiteCertificateAuthority(const AssociateWebsiteCertificateAuthorityRequest& request) const
 {
   Aws::Http::URI uri = m_uri;
   Aws::StringStream ss;
   ss << "/associateWebsiteCertificateAuthority";
   uri.SetPath(uri.GetPath() + ss.str());
-  return AssociateWebsiteCertificateAuthorityOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return AssociateWebsiteCertificateAuthorityOutcome(AssociateWebsiteCertificateAuthorityResult(outcome.GetResult()));
+  }
+  else
+  {
+    return AssociateWebsiteCertificateAuthorityOutcome(outcome.GetError());
+  }
 }
 
 AssociateWebsiteCertificateAuthorityOutcomeCallable WorkLinkClient::AssociateWebsiteCertificateAuthorityCallable(const AssociateWebsiteCertificateAuthorityRequest& request) const
@@ -214,7 +205,15 @@ CreateFleetOutcome WorkLinkClient::CreateFleet(const CreateFleetRequest& request
   Aws::StringStream ss;
   ss << "/createFleet";
   uri.SetPath(uri.GetPath() + ss.str());
-  return CreateFleetOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return CreateFleetOutcome(CreateFleetResult(outcome.GetResult()));
+  }
+  else
+  {
+    return CreateFleetOutcome(outcome.GetError());
+  }
 }
 
 CreateFleetOutcomeCallable WorkLinkClient::CreateFleetCallable(const CreateFleetRequest& request) const
@@ -241,7 +240,15 @@ DeleteFleetOutcome WorkLinkClient::DeleteFleet(const DeleteFleetRequest& request
   Aws::StringStream ss;
   ss << "/deleteFleet";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DeleteFleetOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DeleteFleetOutcome(DeleteFleetResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DeleteFleetOutcome(outcome.GetError());
+  }
 }
 
 DeleteFleetOutcomeCallable WorkLinkClient::DeleteFleetCallable(const DeleteFleetRequest& request) const
@@ -268,7 +275,15 @@ DescribeAuditStreamConfigurationOutcome WorkLinkClient::DescribeAuditStreamConfi
   Aws::StringStream ss;
   ss << "/describeAuditStreamConfiguration";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeAuditStreamConfigurationOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeAuditStreamConfigurationOutcome(DescribeAuditStreamConfigurationResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeAuditStreamConfigurationOutcome(outcome.GetError());
+  }
 }
 
 DescribeAuditStreamConfigurationOutcomeCallable WorkLinkClient::DescribeAuditStreamConfigurationCallable(const DescribeAuditStreamConfigurationRequest& request) const
@@ -295,7 +310,15 @@ DescribeCompanyNetworkConfigurationOutcome WorkLinkClient::DescribeCompanyNetwor
   Aws::StringStream ss;
   ss << "/describeCompanyNetworkConfiguration";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeCompanyNetworkConfigurationOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeCompanyNetworkConfigurationOutcome(DescribeCompanyNetworkConfigurationResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeCompanyNetworkConfigurationOutcome(outcome.GetError());
+  }
 }
 
 DescribeCompanyNetworkConfigurationOutcomeCallable WorkLinkClient::DescribeCompanyNetworkConfigurationCallable(const DescribeCompanyNetworkConfigurationRequest& request) const
@@ -322,7 +345,15 @@ DescribeDeviceOutcome WorkLinkClient::DescribeDevice(const DescribeDeviceRequest
   Aws::StringStream ss;
   ss << "/describeDevice";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeDeviceOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeDeviceOutcome(DescribeDeviceResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeDeviceOutcome(outcome.GetError());
+  }
 }
 
 DescribeDeviceOutcomeCallable WorkLinkClient::DescribeDeviceCallable(const DescribeDeviceRequest& request) const
@@ -349,7 +380,15 @@ DescribeDevicePolicyConfigurationOutcome WorkLinkClient::DescribeDevicePolicyCon
   Aws::StringStream ss;
   ss << "/describeDevicePolicyConfiguration";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeDevicePolicyConfigurationOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeDevicePolicyConfigurationOutcome(DescribeDevicePolicyConfigurationResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeDevicePolicyConfigurationOutcome(outcome.GetError());
+  }
 }
 
 DescribeDevicePolicyConfigurationOutcomeCallable WorkLinkClient::DescribeDevicePolicyConfigurationCallable(const DescribeDevicePolicyConfigurationRequest& request) const
@@ -376,7 +415,15 @@ DescribeDomainOutcome WorkLinkClient::DescribeDomain(const DescribeDomainRequest
   Aws::StringStream ss;
   ss << "/describeDomain";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeDomainOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeDomainOutcome(DescribeDomainResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeDomainOutcome(outcome.GetError());
+  }
 }
 
 DescribeDomainOutcomeCallable WorkLinkClient::DescribeDomainCallable(const DescribeDomainRequest& request) const
@@ -403,7 +450,15 @@ DescribeFleetMetadataOutcome WorkLinkClient::DescribeFleetMetadata(const Describ
   Aws::StringStream ss;
   ss << "/describeFleetMetadata";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeFleetMetadataOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeFleetMetadataOutcome(DescribeFleetMetadataResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeFleetMetadataOutcome(outcome.GetError());
+  }
 }
 
 DescribeFleetMetadataOutcomeCallable WorkLinkClient::DescribeFleetMetadataCallable(const DescribeFleetMetadataRequest& request) const
@@ -430,7 +485,15 @@ DescribeIdentityProviderConfigurationOutcome WorkLinkClient::DescribeIdentityPro
   Aws::StringStream ss;
   ss << "/describeIdentityProviderConfiguration";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeIdentityProviderConfigurationOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeIdentityProviderConfigurationOutcome(DescribeIdentityProviderConfigurationResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeIdentityProviderConfigurationOutcome(outcome.GetError());
+  }
 }
 
 DescribeIdentityProviderConfigurationOutcomeCallable WorkLinkClient::DescribeIdentityProviderConfigurationCallable(const DescribeIdentityProviderConfigurationRequest& request) const
@@ -457,7 +520,15 @@ DescribeWebsiteCertificateAuthorityOutcome WorkLinkClient::DescribeWebsiteCertif
   Aws::StringStream ss;
   ss << "/describeWebsiteCertificateAuthority";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DescribeWebsiteCertificateAuthorityOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DescribeWebsiteCertificateAuthorityOutcome(DescribeWebsiteCertificateAuthorityResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DescribeWebsiteCertificateAuthorityOutcome(outcome.GetError());
+  }
 }
 
 DescribeWebsiteCertificateAuthorityOutcomeCallable WorkLinkClient::DescribeWebsiteCertificateAuthorityCallable(const DescribeWebsiteCertificateAuthorityRequest& request) const
@@ -484,7 +555,15 @@ DisassociateDomainOutcome WorkLinkClient::DisassociateDomain(const DisassociateD
   Aws::StringStream ss;
   ss << "/disassociateDomain";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DisassociateDomainOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DisassociateDomainOutcome(DisassociateDomainResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DisassociateDomainOutcome(outcome.GetError());
+  }
 }
 
 DisassociateDomainOutcomeCallable WorkLinkClient::DisassociateDomainCallable(const DisassociateDomainRequest& request) const
@@ -505,40 +584,21 @@ void WorkLinkClient::DisassociateDomainAsyncHelper(const DisassociateDomainReque
   handler(this, request, DisassociateDomain(request), context);
 }
 
-DisassociateWebsiteAuthorizationProviderOutcome WorkLinkClient::DisassociateWebsiteAuthorizationProvider(const DisassociateWebsiteAuthorizationProviderRequest& request) const
-{
-  Aws::Http::URI uri = m_uri;
-  Aws::StringStream ss;
-  ss << "/disassociateWebsiteAuthorizationProvider";
-  uri.SetPath(uri.GetPath() + ss.str());
-  return DisassociateWebsiteAuthorizationProviderOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
-}
-
-DisassociateWebsiteAuthorizationProviderOutcomeCallable WorkLinkClient::DisassociateWebsiteAuthorizationProviderCallable(const DisassociateWebsiteAuthorizationProviderRequest& request) const
-{
-  auto task = Aws::MakeShared< std::packaged_task< DisassociateWebsiteAuthorizationProviderOutcome() > >(ALLOCATION_TAG, [this, request](){ return this->DisassociateWebsiteAuthorizationProvider(request); } );
-  auto packagedFunction = [task]() { (*task)(); };
-  m_executor->Submit(packagedFunction);
-  return task->get_future();
-}
-
-void WorkLinkClient::DisassociateWebsiteAuthorizationProviderAsync(const DisassociateWebsiteAuthorizationProviderRequest& request, const DisassociateWebsiteAuthorizationProviderResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  m_executor->Submit( [this, request, handler, context](){ this->DisassociateWebsiteAuthorizationProviderAsyncHelper( request, handler, context ); } );
-}
-
-void WorkLinkClient::DisassociateWebsiteAuthorizationProviderAsyncHelper(const DisassociateWebsiteAuthorizationProviderRequest& request, const DisassociateWebsiteAuthorizationProviderResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  handler(this, request, DisassociateWebsiteAuthorizationProvider(request), context);
-}
-
 DisassociateWebsiteCertificateAuthorityOutcome WorkLinkClient::DisassociateWebsiteCertificateAuthority(const DisassociateWebsiteCertificateAuthorityRequest& request) const
 {
   Aws::Http::URI uri = m_uri;
   Aws::StringStream ss;
   ss << "/disassociateWebsiteCertificateAuthority";
   uri.SetPath(uri.GetPath() + ss.str());
-  return DisassociateWebsiteCertificateAuthorityOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return DisassociateWebsiteCertificateAuthorityOutcome(DisassociateWebsiteCertificateAuthorityResult(outcome.GetResult()));
+  }
+  else
+  {
+    return DisassociateWebsiteCertificateAuthorityOutcome(outcome.GetError());
+  }
 }
 
 DisassociateWebsiteCertificateAuthorityOutcomeCallable WorkLinkClient::DisassociateWebsiteCertificateAuthorityCallable(const DisassociateWebsiteCertificateAuthorityRequest& request) const
@@ -565,7 +625,15 @@ ListDevicesOutcome WorkLinkClient::ListDevices(const ListDevicesRequest& request
   Aws::StringStream ss;
   ss << "/listDevices";
   uri.SetPath(uri.GetPath() + ss.str());
-  return ListDevicesOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return ListDevicesOutcome(ListDevicesResult(outcome.GetResult()));
+  }
+  else
+  {
+    return ListDevicesOutcome(outcome.GetError());
+  }
 }
 
 ListDevicesOutcomeCallable WorkLinkClient::ListDevicesCallable(const ListDevicesRequest& request) const
@@ -592,7 +660,15 @@ ListDomainsOutcome WorkLinkClient::ListDomains(const ListDomainsRequest& request
   Aws::StringStream ss;
   ss << "/listDomains";
   uri.SetPath(uri.GetPath() + ss.str());
-  return ListDomainsOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return ListDomainsOutcome(ListDomainsResult(outcome.GetResult()));
+  }
+  else
+  {
+    return ListDomainsOutcome(outcome.GetError());
+  }
 }
 
 ListDomainsOutcomeCallable WorkLinkClient::ListDomainsCallable(const ListDomainsRequest& request) const
@@ -619,7 +695,15 @@ ListFleetsOutcome WorkLinkClient::ListFleets(const ListFleetsRequest& request) c
   Aws::StringStream ss;
   ss << "/listFleets";
   uri.SetPath(uri.GetPath() + ss.str());
-  return ListFleetsOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return ListFleetsOutcome(ListFleetsResult(outcome.GetResult()));
+  }
+  else
+  {
+    return ListFleetsOutcome(outcome.GetError());
+  }
 }
 
 ListFleetsOutcomeCallable WorkLinkClient::ListFleetsCallable(const ListFleetsRequest& request) const
@@ -640,73 +724,21 @@ void WorkLinkClient::ListFleetsAsyncHelper(const ListFleetsRequest& request, con
   handler(this, request, ListFleets(request), context);
 }
 
-ListTagsForResourceOutcome WorkLinkClient::ListTagsForResource(const ListTagsForResourceRequest& request) const
-{
-  if (!request.ResourceArnHasBeenSet())
-  {
-    AWS_LOGSTREAM_ERROR("ListTagsForResource", "Required field: ResourceArn, is not set");
-    return ListTagsForResourceOutcome(Aws::Client::AWSError<WorkLinkErrors>(WorkLinkErrors::MISSING_PARAMETER, "MISSING_PARAMETER", "Missing required field [ResourceArn]", false));
-  }
-  Aws::Http::URI uri = m_uri;
-  Aws::StringStream ss;
-  ss << "/tags/";
-  ss << request.GetResourceArn();
-  uri.SetPath(uri.GetPath() + ss.str());
-  return ListTagsForResourceOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_GET, Aws::Auth::SIGV4_SIGNER));
-}
-
-ListTagsForResourceOutcomeCallable WorkLinkClient::ListTagsForResourceCallable(const ListTagsForResourceRequest& request) const
-{
-  auto task = Aws::MakeShared< std::packaged_task< ListTagsForResourceOutcome() > >(ALLOCATION_TAG, [this, request](){ return this->ListTagsForResource(request); } );
-  auto packagedFunction = [task]() { (*task)(); };
-  m_executor->Submit(packagedFunction);
-  return task->get_future();
-}
-
-void WorkLinkClient::ListTagsForResourceAsync(const ListTagsForResourceRequest& request, const ListTagsForResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  m_executor->Submit( [this, request, handler, context](){ this->ListTagsForResourceAsyncHelper( request, handler, context ); } );
-}
-
-void WorkLinkClient::ListTagsForResourceAsyncHelper(const ListTagsForResourceRequest& request, const ListTagsForResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  handler(this, request, ListTagsForResource(request), context);
-}
-
-ListWebsiteAuthorizationProvidersOutcome WorkLinkClient::ListWebsiteAuthorizationProviders(const ListWebsiteAuthorizationProvidersRequest& request) const
-{
-  Aws::Http::URI uri = m_uri;
-  Aws::StringStream ss;
-  ss << "/listWebsiteAuthorizationProviders";
-  uri.SetPath(uri.GetPath() + ss.str());
-  return ListWebsiteAuthorizationProvidersOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
-}
-
-ListWebsiteAuthorizationProvidersOutcomeCallable WorkLinkClient::ListWebsiteAuthorizationProvidersCallable(const ListWebsiteAuthorizationProvidersRequest& request) const
-{
-  auto task = Aws::MakeShared< std::packaged_task< ListWebsiteAuthorizationProvidersOutcome() > >(ALLOCATION_TAG, [this, request](){ return this->ListWebsiteAuthorizationProviders(request); } );
-  auto packagedFunction = [task]() { (*task)(); };
-  m_executor->Submit(packagedFunction);
-  return task->get_future();
-}
-
-void WorkLinkClient::ListWebsiteAuthorizationProvidersAsync(const ListWebsiteAuthorizationProvidersRequest& request, const ListWebsiteAuthorizationProvidersResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  m_executor->Submit( [this, request, handler, context](){ this->ListWebsiteAuthorizationProvidersAsyncHelper( request, handler, context ); } );
-}
-
-void WorkLinkClient::ListWebsiteAuthorizationProvidersAsyncHelper(const ListWebsiteAuthorizationProvidersRequest& request, const ListWebsiteAuthorizationProvidersResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  handler(this, request, ListWebsiteAuthorizationProviders(request), context);
-}
-
 ListWebsiteCertificateAuthoritiesOutcome WorkLinkClient::ListWebsiteCertificateAuthorities(const ListWebsiteCertificateAuthoritiesRequest& request) const
 {
   Aws::Http::URI uri = m_uri;
   Aws::StringStream ss;
   ss << "/listWebsiteCertificateAuthorities";
   uri.SetPath(uri.GetPath() + ss.str());
-  return ListWebsiteCertificateAuthoritiesOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return ListWebsiteCertificateAuthoritiesOutcome(ListWebsiteCertificateAuthoritiesResult(outcome.GetResult()));
+  }
+  else
+  {
+    return ListWebsiteCertificateAuthoritiesOutcome(outcome.GetError());
+  }
 }
 
 ListWebsiteCertificateAuthoritiesOutcomeCallable WorkLinkClient::ListWebsiteCertificateAuthoritiesCallable(const ListWebsiteCertificateAuthoritiesRequest& request) const
@@ -733,7 +765,15 @@ RestoreDomainAccessOutcome WorkLinkClient::RestoreDomainAccess(const RestoreDoma
   Aws::StringStream ss;
   ss << "/restoreDomainAccess";
   uri.SetPath(uri.GetPath() + ss.str());
-  return RestoreDomainAccessOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return RestoreDomainAccessOutcome(RestoreDomainAccessResult(outcome.GetResult()));
+  }
+  else
+  {
+    return RestoreDomainAccessOutcome(outcome.GetError());
+  }
 }
 
 RestoreDomainAccessOutcomeCallable WorkLinkClient::RestoreDomainAccessCallable(const RestoreDomainAccessRequest& request) const
@@ -760,7 +800,15 @@ RevokeDomainAccessOutcome WorkLinkClient::RevokeDomainAccess(const RevokeDomainA
   Aws::StringStream ss;
   ss << "/revokeDomainAccess";
   uri.SetPath(uri.GetPath() + ss.str());
-  return RevokeDomainAccessOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return RevokeDomainAccessOutcome(RevokeDomainAccessResult(outcome.GetResult()));
+  }
+  else
+  {
+    return RevokeDomainAccessOutcome(outcome.GetError());
+  }
 }
 
 RevokeDomainAccessOutcomeCallable WorkLinkClient::RevokeDomainAccessCallable(const RevokeDomainAccessRequest& request) const
@@ -787,7 +835,15 @@ SignOutUserOutcome WorkLinkClient::SignOutUser(const SignOutUserRequest& request
   Aws::StringStream ss;
   ss << "/signOutUser";
   uri.SetPath(uri.GetPath() + ss.str());
-  return SignOutUserOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return SignOutUserOutcome(SignOutUserResult(outcome.GetResult()));
+  }
+  else
+  {
+    return SignOutUserOutcome(outcome.GetError());
+  }
 }
 
 SignOutUserOutcomeCallable WorkLinkClient::SignOutUserCallable(const SignOutUserRequest& request) const
@@ -808,84 +864,21 @@ void WorkLinkClient::SignOutUserAsyncHelper(const SignOutUserRequest& request, c
   handler(this, request, SignOutUser(request), context);
 }
 
-TagResourceOutcome WorkLinkClient::TagResource(const TagResourceRequest& request) const
-{
-  if (!request.ResourceArnHasBeenSet())
-  {
-    AWS_LOGSTREAM_ERROR("TagResource", "Required field: ResourceArn, is not set");
-    return TagResourceOutcome(Aws::Client::AWSError<WorkLinkErrors>(WorkLinkErrors::MISSING_PARAMETER, "MISSING_PARAMETER", "Missing required field [ResourceArn]", false));
-  }
-  Aws::Http::URI uri = m_uri;
-  Aws::StringStream ss;
-  ss << "/tags/";
-  ss << request.GetResourceArn();
-  uri.SetPath(uri.GetPath() + ss.str());
-  return TagResourceOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
-}
-
-TagResourceOutcomeCallable WorkLinkClient::TagResourceCallable(const TagResourceRequest& request) const
-{
-  auto task = Aws::MakeShared< std::packaged_task< TagResourceOutcome() > >(ALLOCATION_TAG, [this, request](){ return this->TagResource(request); } );
-  auto packagedFunction = [task]() { (*task)(); };
-  m_executor->Submit(packagedFunction);
-  return task->get_future();
-}
-
-void WorkLinkClient::TagResourceAsync(const TagResourceRequest& request, const TagResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  m_executor->Submit( [this, request, handler, context](){ this->TagResourceAsyncHelper( request, handler, context ); } );
-}
-
-void WorkLinkClient::TagResourceAsyncHelper(const TagResourceRequest& request, const TagResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  handler(this, request, TagResource(request), context);
-}
-
-UntagResourceOutcome WorkLinkClient::UntagResource(const UntagResourceRequest& request) const
-{
-  if (!request.ResourceArnHasBeenSet())
-  {
-    AWS_LOGSTREAM_ERROR("UntagResource", "Required field: ResourceArn, is not set");
-    return UntagResourceOutcome(Aws::Client::AWSError<WorkLinkErrors>(WorkLinkErrors::MISSING_PARAMETER, "MISSING_PARAMETER", "Missing required field [ResourceArn]", false));
-  }
-  if (!request.TagKeysHasBeenSet())
-  {
-    AWS_LOGSTREAM_ERROR("UntagResource", "Required field: TagKeys, is not set");
-    return UntagResourceOutcome(Aws::Client::AWSError<WorkLinkErrors>(WorkLinkErrors::MISSING_PARAMETER, "MISSING_PARAMETER", "Missing required field [TagKeys]", false));
-  }
-  Aws::Http::URI uri = m_uri;
-  Aws::StringStream ss;
-  ss << "/tags/";
-  ss << request.GetResourceArn();
-  uri.SetPath(uri.GetPath() + ss.str());
-  return UntagResourceOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_DELETE, Aws::Auth::SIGV4_SIGNER));
-}
-
-UntagResourceOutcomeCallable WorkLinkClient::UntagResourceCallable(const UntagResourceRequest& request) const
-{
-  auto task = Aws::MakeShared< std::packaged_task< UntagResourceOutcome() > >(ALLOCATION_TAG, [this, request](){ return this->UntagResource(request); } );
-  auto packagedFunction = [task]() { (*task)(); };
-  m_executor->Submit(packagedFunction);
-  return task->get_future();
-}
-
-void WorkLinkClient::UntagResourceAsync(const UntagResourceRequest& request, const UntagResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  m_executor->Submit( [this, request, handler, context](){ this->UntagResourceAsyncHelper( request, handler, context ); } );
-}
-
-void WorkLinkClient::UntagResourceAsyncHelper(const UntagResourceRequest& request, const UntagResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context) const
-{
-  handler(this, request, UntagResource(request), context);
-}
-
 UpdateAuditStreamConfigurationOutcome WorkLinkClient::UpdateAuditStreamConfiguration(const UpdateAuditStreamConfigurationRequest& request) const
 {
   Aws::Http::URI uri = m_uri;
   Aws::StringStream ss;
   ss << "/updateAuditStreamConfiguration";
   uri.SetPath(uri.GetPath() + ss.str());
-  return UpdateAuditStreamConfigurationOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return UpdateAuditStreamConfigurationOutcome(UpdateAuditStreamConfigurationResult(outcome.GetResult()));
+  }
+  else
+  {
+    return UpdateAuditStreamConfigurationOutcome(outcome.GetError());
+  }
 }
 
 UpdateAuditStreamConfigurationOutcomeCallable WorkLinkClient::UpdateAuditStreamConfigurationCallable(const UpdateAuditStreamConfigurationRequest& request) const
@@ -912,7 +905,15 @@ UpdateCompanyNetworkConfigurationOutcome WorkLinkClient::UpdateCompanyNetworkCon
   Aws::StringStream ss;
   ss << "/updateCompanyNetworkConfiguration";
   uri.SetPath(uri.GetPath() + ss.str());
-  return UpdateCompanyNetworkConfigurationOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return UpdateCompanyNetworkConfigurationOutcome(UpdateCompanyNetworkConfigurationResult(outcome.GetResult()));
+  }
+  else
+  {
+    return UpdateCompanyNetworkConfigurationOutcome(outcome.GetError());
+  }
 }
 
 UpdateCompanyNetworkConfigurationOutcomeCallable WorkLinkClient::UpdateCompanyNetworkConfigurationCallable(const UpdateCompanyNetworkConfigurationRequest& request) const
@@ -939,7 +940,15 @@ UpdateDevicePolicyConfigurationOutcome WorkLinkClient::UpdateDevicePolicyConfigu
   Aws::StringStream ss;
   ss << "/updateDevicePolicyConfiguration";
   uri.SetPath(uri.GetPath() + ss.str());
-  return UpdateDevicePolicyConfigurationOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return UpdateDevicePolicyConfigurationOutcome(UpdateDevicePolicyConfigurationResult(outcome.GetResult()));
+  }
+  else
+  {
+    return UpdateDevicePolicyConfigurationOutcome(outcome.GetError());
+  }
 }
 
 UpdateDevicePolicyConfigurationOutcomeCallable WorkLinkClient::UpdateDevicePolicyConfigurationCallable(const UpdateDevicePolicyConfigurationRequest& request) const
@@ -966,7 +975,15 @@ UpdateDomainMetadataOutcome WorkLinkClient::UpdateDomainMetadata(const UpdateDom
   Aws::StringStream ss;
   ss << "/updateDomainMetadata";
   uri.SetPath(uri.GetPath() + ss.str());
-  return UpdateDomainMetadataOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return UpdateDomainMetadataOutcome(UpdateDomainMetadataResult(outcome.GetResult()));
+  }
+  else
+  {
+    return UpdateDomainMetadataOutcome(outcome.GetError());
+  }
 }
 
 UpdateDomainMetadataOutcomeCallable WorkLinkClient::UpdateDomainMetadataCallable(const UpdateDomainMetadataRequest& request) const
@@ -993,7 +1010,15 @@ UpdateFleetMetadataOutcome WorkLinkClient::UpdateFleetMetadata(const UpdateFleet
   Aws::StringStream ss;
   ss << "/UpdateFleetMetadata";
   uri.SetPath(uri.GetPath() + ss.str());
-  return UpdateFleetMetadataOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return UpdateFleetMetadataOutcome(UpdateFleetMetadataResult(outcome.GetResult()));
+  }
+  else
+  {
+    return UpdateFleetMetadataOutcome(outcome.GetError());
+  }
 }
 
 UpdateFleetMetadataOutcomeCallable WorkLinkClient::UpdateFleetMetadataCallable(const UpdateFleetMetadataRequest& request) const
@@ -1020,7 +1045,15 @@ UpdateIdentityProviderConfigurationOutcome WorkLinkClient::UpdateIdentityProvide
   Aws::StringStream ss;
   ss << "/updateIdentityProviderConfiguration";
   uri.SetPath(uri.GetPath() + ss.str());
-  return UpdateIdentityProviderConfigurationOutcome(MakeRequest(uri, request, Aws::Http::HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER));
+  JsonOutcome outcome = MakeRequest(uri, request, HttpMethod::HTTP_POST, Aws::Auth::SIGV4_SIGNER);
+  if(outcome.IsSuccess())
+  {
+    return UpdateIdentityProviderConfigurationOutcome(UpdateIdentityProviderConfigurationResult(outcome.GetResult()));
+  }
+  else
+  {
+    return UpdateIdentityProviderConfigurationOutcome(outcome.GetError());
+  }
 }
 
 UpdateIdentityProviderConfigurationOutcomeCallable WorkLinkClient::UpdateIdentityProviderConfigurationCallable(const UpdateIdentityProviderConfigurationRequest& request) const
