@@ -1,7 +1,17 @@
-/**
- * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
- * SPDX-License-Identifier: Apache-2.0.
- */
+/*
+* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+*
+* Licensed under the Apache License, Version 2.0 (the "License").
+* You may not use this file except in compliance with the License.
+* A copy of the License is located at
+*
+*  http://aws.amazon.com/apache2.0
+*
+* or in the "license" file accompanying this file. This file is distributed
+* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+* express or implied. See the License for the specific language governing
+* permissions and limitations under the License.
+*/
 
 package com.amazonaws.util.awsclientgenerator.domainmodels.codegeneration;
 
@@ -11,7 +21,6 @@ import lombok.Getter;
 import lombok.Setter;
 
 import java.util.*;
-import java.util.stream.Collectors;
 
 @Data
 public class ServiceModel {
@@ -20,13 +29,11 @@ public class ServiceModel {
     String runtimeMajorVersionUpperBound;
     String runtimeMinorVersion;
     String namespace;
-    String serviceName;
     Metadata metadata;
     String documentation;
     String licenseText;
     Map<String, Shape> shapes;
     Map<String, Operation> operations;
-    boolean enableVirtualOperations;
     Collection<Error> serviceErrors;
 
     @Getter(AccessLevel.PRIVATE)
@@ -38,10 +45,7 @@ public class ServiceModel {
     Set<String> outputShapes = new HashSet<>();
 
     public boolean hasStreamingRequestShapes() {
-        return shapes.values().parallelStream().anyMatch(shape -> shape.isRequest() && (shape.hasStreamMembers() || shape.hasEventStreamMembers()));
+        return shapes.values().parallelStream().anyMatch(shape -> shape.isRequest() && shape.hasStreamMembers());
     }
 
-    public Collection<Error> getNonCoreServiceErrors() {
-        return serviceErrors.stream().filter(e -> !e.isCoreError()).collect(Collectors.toSet());
-    }
 }
