@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python2
 #
 # Copyright (C) 2018-present MongoDB, Inc.
 #
@@ -28,7 +28,8 @@
 # it in the license file.
 #
 """Test cases for IDL parser."""
-# pylint: disable=too-many-lines
+
+from __future__ import absolute_import, print_function, unicode_literals
 
 import textwrap
 import unittest
@@ -235,7 +236,9 @@ class TestParser(testcase.IDLTestcase):
             textwrap.dedent("""
         types:
             - foo:
-            """), idl.errors.ERROR_ID_IS_NODE_TYPE, multiple=True)
+            """),
+            idl.errors.ERROR_ID_IS_NODE_TYPE,
+            multiple=True)
 
         # test list instead of scalar
         self.assert_parse_fail(
@@ -243,7 +246,9 @@ class TestParser(testcase.IDLTestcase):
         types:
             foo:
                 - bar
-            """), idl.errors.ERROR_ID_IS_NODE_TYPE, multiple=True)
+            """),
+            idl.errors.ERROR_ID_IS_NODE_TYPE,
+            multiple=True)
 
         # test map instead of scalar
         self.assert_parse_fail(
@@ -252,7 +257,9 @@ class TestParser(testcase.IDLTestcase):
             foo:
                 description:
                     foo: bar
-            """), idl.errors.ERROR_ID_IS_NODE_TYPE, multiple=True)
+            """),
+            idl.errors.ERROR_ID_IS_NODE_TYPE,
+            multiple=True)
 
         # test missing bson_serialization_type field
         self.assert_parse_fail(
@@ -285,7 +292,6 @@ class TestParser(testcase.IDLTestcase):
                 strict: true
                 immutable: true
                 inline_chained_structs: true
-                generate_comparison_operators: true
                 fields:
                     foo: bar
             """))
@@ -299,7 +305,6 @@ class TestParser(testcase.IDLTestcase):
                 strict: false
                 immutable: false
                 inline_chained_structs: false
-                generate_comparison_operators: false
                 fields:
                     foo: bar
             """))
@@ -357,39 +362,6 @@ class TestParser(testcase.IDLTestcase):
                     foo: bar
             """), idl.errors.ERROR_ID_IS_NODE_VALID_BOOL)
 
-        # inline_chained_structs is a bool
-        self.assert_parse_fail(
-            textwrap.dedent("""
-        structs:
-            foo:
-                description: foo
-                inline_chained_structs: bar
-                fields:
-                    foo: bar
-            """), idl.errors.ERROR_ID_IS_NODE_VALID_BOOL)
-
-        # generate_comparison_operators is a bool
-        self.assert_parse_fail(
-            textwrap.dedent("""
-        structs:
-            foo:
-                description: foo
-                generate_comparison_operators: bar
-                fields:
-                    foo: bar
-            """), idl.errors.ERROR_ID_IS_NODE_VALID_BOOL)
-
-        # cpp_name is not allowed
-        self.assert_parse_fail(
-            textwrap.dedent("""
-        structs:
-            foo:
-                description: foo
-                cpp_name: bar
-                fields:
-                    foo: bar
-            """), idl.errors.ERROR_ID_UNKNOWN_NODE)
-
     def test_field_positive(self):
         # type: () -> None
         """Positive field test cases."""
@@ -417,7 +389,6 @@ class TestParser(testcase.IDLTestcase):
                         optional: true
                         ignore: true
                         cpp_name: bar
-                        comparison_order: 3
             """))
 
         # Test false bools
@@ -476,47 +447,6 @@ class TestParser(testcase.IDLTestcase):
                         ignore: bar
             """), idl.errors.ERROR_ID_IS_NODE_VALID_BOOL)
 
-        # Test bad int scalar
-        self.assert_parse_fail(
-            textwrap.dedent("""
-        structs:
-            foo:
-                description: foo
-                strict: false
-                fields:
-                    foo:
-                        type: string
-                        comparison_order:
-                            - a
-                            - b
-            """), idl.errors.ERROR_ID_IS_NODE_TYPE)
-
-        # Test bad int
-        self.assert_parse_fail(
-            textwrap.dedent("""
-        structs:
-            foo:
-                description: foo
-                strict: false
-                fields:
-                    foo:
-                        type: string
-                        comparison_order: 3.14159
-            """), idl.errors.ERROR_ID_IS_NODE_VALID_INT)
-
-        # Test bad negative int
-        self.assert_parse_fail(
-            textwrap.dedent("""
-        structs:
-            foo:
-                description: foo
-                strict: false
-                fields:
-                    foo:
-                        type: string
-                        comparison_order: -1
-            """), idl.errors.ERROR_ID_IS_NODE_VALID_NON_NEGATIVE_INT)
-
     def test_name_collisions_negative(self):
         # type: () -> None
         """Negative tests for type collisions."""
@@ -729,7 +659,9 @@ class TestParser(testcase.IDLTestcase):
             textwrap.dedent("""
         enums:
             - foo:
-            """), idl.errors.ERROR_ID_IS_NODE_TYPE, multiple=True)
+            """),
+            idl.errors.ERROR_ID_IS_NODE_TYPE,
+            multiple=True)
 
         # test list instead of scalar
         self.assert_parse_fail(
@@ -737,7 +669,9 @@ class TestParser(testcase.IDLTestcase):
         enums:
             foo:
                 - bar
-            """), idl.errors.ERROR_ID_IS_NODE_TYPE, multiple=True)
+            """),
+            idl.errors.ERROR_ID_IS_NODE_TYPE,
+            multiple=True)
 
         # test missing type field
         self.assert_parse_fail(
@@ -838,10 +772,6 @@ class TestParser(testcase.IDLTestcase):
                 description: foo
                 strict: true
                 namespace: ignored
-                immutable: true
-                inline_chained_structs: true
-                generate_comparison_operators: true
-                cpp_name: foo
                 fields:
                     foo: bar
             """))
@@ -854,9 +784,6 @@ class TestParser(testcase.IDLTestcase):
                 description: foo
                 strict: false
                 namespace: ignored
-                immutable: false
-                inline_chained_structs: false
-                generate_comparison_operators: false
                 fields:
                     foo: bar
             """))
@@ -883,16 +810,6 @@ class TestParser(testcase.IDLTestcase):
                     foo: bar
             """))
 
-        # No fields
-        self.assert_parse(
-            textwrap.dedent("""
-        commands:
-            foo:
-                description: foo
-                namespace: ignored
-                strict: true
-            """))
-
     def test_command_negative(self):
         # type: () -> None
         """Negative command test cases."""
@@ -904,6 +821,16 @@ class TestParser(testcase.IDLTestcase):
             foo: foo
             """), idl.errors.ERROR_ID_IS_NODE_TYPE)
 
+        # Missing fields
+        self.assert_parse_fail(
+            textwrap.dedent("""
+        commands:
+            foo:
+                description: foo
+                namespace: ignored
+                strict: true
+            """), idl.errors.ERROR_ID_EMPTY_FIELDS)
+
         # unknown field
         self.assert_parse_fail(
             textwrap.dedent("""
@@ -962,8 +889,7 @@ class TestParser(testcase.IDLTestcase):
         """)
 
         # Commands and structs with same name
-        self.assert_parse_fail(
-            test_preamble + textwrap.dedent("""
+        self.assert_parse_fail(test_preamble + textwrap.dedent("""
             commands: 
                 foo:
                     description: foo
@@ -979,8 +905,7 @@ class TestParser(testcase.IDLTestcase):
             """), idl.errors.ERROR_ID_DUPLICATE_SYMBOL)
 
         # Commands and types with same name
-        self.assert_parse_fail(
-            test_preamble + textwrap.dedent("""
+        self.assert_parse_fail(test_preamble + textwrap.dedent("""
             commands: 
                 string:
                     description: foo
@@ -990,18 +915,6 @@ class TestParser(testcase.IDLTestcase):
                         foo: string
             """), idl.errors.ERROR_ID_DUPLICATE_SYMBOL)
 
-        # Namespace concatenate_with_db
-        self.assert_parse_fail(
-            textwrap.dedent("""
-        commands:
-            foo:
-                description: foo
-                namespace: concatenate_with_db
-                type: foobar
-                fields:
-                    foo: bar
-            """), idl.errors.ERROR_ID_IS_COMMAND_TYPE_EXTRANEOUS)
-
     def test_command_doc_sequence_positive(self):
         # type: () -> None
         """Positive supports_doc_sequence test cases."""
@@ -1051,78 +964,6 @@ class TestParser(testcase.IDLTestcase):
                         supports_doc_sequence: foo
             """), idl.errors.ERROR_ID_IS_NODE_VALID_BOOL)
 
-    def test_command_type_positive(self):
-        # type: () -> None
-        """Positive command custom type test cases."""
-        # string
-        self.assert_parse(
-            textwrap.dedent("""
-        commands:
-            foo:
-                description: foo
-                strict: true
-                namespace: type
-                type: string
-                fields:
-                    foo: bar
-            """))
-
-        # array of string
-        self.assert_parse(
-            textwrap.dedent("""
-        commands:
-            foo:
-                description: foo
-                strict: true
-                namespace: type
-                type: array<string>
-                fields:
-                    foo: bar
-            """))
-
-        # no fields
-        self.assert_parse(
-            textwrap.dedent("""
-        commands:
-            foo:
-                description: foo
-                strict: true
-                namespace: type
-                type: string
-            """))
-
-    def test_command_type_negative(self):
-        # type: () -> None
-        """Negative command type test cases."""
-
-        # supports_doc_sequence must be a bool
-        self.assert_parse_fail(
-            textwrap.dedent("""
-        commands:
-            foo:
-                description: foo
-                namespace: type
-                fields:
-                    foo: bar
-            """), idl.errors.ERROR_ID_MISSING_REQUIRED_FIELD)
-
-    def test_scalar_or_mapping_negative(self):
-        # type: () -> None
-        """Negative test for scalar_or_mapping type."""
-
-        # Test for scalar_or_mapping with a sequence.
-        self.assert_parse_fail(
-            textwrap.dedent("""
-        server_parameters:
-            foo:
-                set_at: startup
-                description: bar
-                cpp_varname: baz
-                default:
-                - one
-                - two
-            """), idl.errors.ERROR_ID_IS_NODE_TYPE_SCALAR_OR_MAPPING)
-
 
 if __name__ == '__main__':
 
