@@ -1,6 +1,10 @@
+// @tags: [
+//   requires_fastcount,
+//   requires_non_retryable_writes,
+//   uses_multiple_connections,
+// ]
+
 // Test removal of Records that have been reused since the remove operation began.  SERVER-5198
-//
-// @tags: [requires_parallel_shell]
 
 t = db.jstests_removeb;
 t.drop();
@@ -13,6 +17,9 @@ t.remove({});
 
 // Insert some data.
 for (i = 0; i < 20000; ++i) {
+    if (i % 100 == 0) {
+        print(i + " of first set of 20000 documents inserted");
+    }
     t.insert({a: i});
 }
 
@@ -25,7 +32,7 @@ p = startParallelShell(
     'for( i = 20000; i < 40000; ++i ) {' +
     '    db.jstests_removeb.insert( { a:i } );' +
     '    if (i % 1000 == 0) {' +
-    '        print( i-20000 + \" of 20000 documents inserted\" );' +
+    '        print( i-20000 + \" of second set of 20000 documents inserted\" );' +
     '    }' +
     '}');
 
