@@ -1,7 +1,10 @@
 /**
  * Tests the behavior of views when the backing view or collection is changed.
- *
- * @tags: [requires_collmod_command, requires_find_command]
+ * @tags: [
+ *   assumes_superuser_permissions,
+ *   requires_find_command,
+ *   requires_non_retryable_commands,
+ * ]
  */
 (function() {
     "use strict";
@@ -28,7 +31,7 @@
     let assertFindResultEq = function(collName, expected) {
         let res = viewDB.runCommand({find: collName, filter: {}, projection: {_id: 0, a: 1, b: 1}});
         assert.commandWorked(res);
-        let arr = new DBCommandCursor(db.getMongo(), res).toArray();
+        let arr = new DBCommandCursor(db, res).toArray();
         let errmsg = tojson({expected: expected, got: arr});
         assert(arrayEq(arr, expected), errmsg);
     };
