@@ -3,7 +3,12 @@
 //
 // This test asserts that a journaled write to a mongod running with --nojournal should be rejected,
 // so cannot be run on the ephemeralForTest storage engine, as it accepts all journaled writes.
-// @tags: [SERVER-21420]
+// @tags: [SERVER-21420, rocks_requires_fcv36]
+
+// Checking UUID consistency involves talking to the shard primaries, but by the end of this test,
+// one shard does not have a primary.
+TestData.skipCheckingUUIDsConsistentAcrossCluster = true;
+TestData.skipCheckDBHashes = true;
 
 (function() {
     'use strict';
