@@ -14,7 +14,7 @@
         ldapQueryPassword: TestData.ldapQueryPassword,
         ldapAuthzQueryTemplate: TestData.ldapAuthzQueryTemplate,
         ldapUserToDNMapping: '[{match: "(.+)", substitution: "cn={0},dc=percona,dc=com"}]',
-        setParameter: {authenticationMechanisms: 'PLAIN,SCRAM-SHA-256,SCRAM-SHA-1'}
+        setParameter: {authenticationMechanisms: 'PLAIN,SCRAM-SHA-1'}
     });
 
     assert(conn, "Cannot start mongod instance");
@@ -41,8 +41,6 @@
                 return 'cn=' + name + ',dc=percona,dc=com';
             }
         );
-        
-        db.logout();
     });
 
     MongoRunner.stopMongod(conn);
