@@ -13,7 +13,7 @@
         ldapQueryUser: TestData.ldapQueryUser,
         ldapQueryPassword: TestData.ldapQueryPassword,
         ldapAuthzQueryTemplate: TestData.ldapAuthzQueryTemplate,
-        setParameter: {authenticationMechanisms: 'PLAIN,SCRAM-SHA-256,SCRAM-SHA-1'}
+        setParameter: {authenticationMechanisms: 'PLAIN,SCRAM-SHA-1'}
     });
 
     assert(conn, "Cannot start mongod instance");
@@ -36,8 +36,6 @@
 
         // ensure user have got correct set of privileges
         checkConnectionStatus(username, db.runCommand({connectionStatus: 1}));
-        
-        db.logout();
     });
 
     MongoRunner.stopMongod(conn);
