@@ -245,11 +245,12 @@ var _kill_sessions_api_module = (function() {
     CursorHandle.prototype.assertCursorKillLogMessages = function(hostsToCheck) {
         for (let hostToCheck of hostsToCheck) {
             if (hostToCheck.host in this._cursors) {
-                assert(checkLog.checkContainsOnce(
-                           hostToCheck,
-                           'killing cursor: ' + this._cursors[hostToCheck.host].exactValueString +
-                               ' as part of killing session(s)'),
-                       "cursor kill was not logged by " + hostToCheck.host);
+                let targetCursorId = this._cursors[hostToCheck.host].exactValueString;
+                assert.doesNotThrow(function() {
+                    checkLog.contains(
+                        hostToCheck,
+                        'killing cursor: ' + targetCursorId + ' as part of killing session(s)');
+                }, [], "cursor kill was not logged by " + hostToCheck.host);
             }
         }
     };
