@@ -2,6 +2,10 @@
 (function() {
     "use script";
 
+    // This test makes assertions about the number of sessions, which are not compatible with
+    // implicit sessions.
+    TestData.disableImplicitSessions = true;
+
     var res;
     var refresh = {refreshLogicalSessionCacheNow: 1};
     var startSession = {startSession: 1};
