@@ -6,6 +6,11 @@
 load("jstests/replsets/rslib.js");
 
 (function() {
+    "use strict";
+
+    // TODO SERVER-35447: Multiple users cannot be authenticated on one connection within a session.
+    TestData.disableImplicitSessions = true;
+
     var name = "rs_auth1";
     var port = allocatePorts(5);
     var path = "jstests/libs/";
@@ -25,21 +30,22 @@ load("jstests/replsets/rslib.js");
 
     MongoRunner.stopMongod(m);
 
-    print("reset permissions");
-    run("chmod", "644", key1_644);
+    if (!_isWindows()) {
+        print("reset permissions");
+        run("chmod", "644", key1_644);
 
-    print("try starting mongod");
-    m = runMongoProgram("mongod",
-                        "--keyFile",
-                        key1_644,
-                        "--port",
-                        port[0],
-                        "--dbpath",
-                        MongoRunner.dataPath + name);
+        print("try starting mongod");
+        m = runMongoProgram("mongod",
+                            "--keyFile",
+                            key1_644,
+                            "--port",
+                            port[0],
+                            "--dbpath",
+                            MongoRunner.dataPath + name);
 
-    print("should fail with wrong permissions");
-    assert.eq(
-        m, _isWindows() ? 100 : 1, "mongod should exit w/ 1 (EXIT_FAILURE): permissions too open");
+        print("should fail with wrong permissions");
+        assert.eq(m, 1, "mongod should exit w/ 1 (EXIT_FAILURE): permissions too open");
+    }
 
     // Pre-populate the data directory for the first replica set node, to be started later, with
     // a user's credentials.
