@@ -5,6 +5,8 @@
  */
 
 var ElectionHandoffTest = (function() {
+
+    load("jstests/libs/check_log.js");
     load("jstests/replsets/rslib.js");
 
     const kStepDownPeriodSecs = 30;
@@ -19,9 +21,6 @@ var ElectionHandoffTest = (function() {
      * are:
      *   stepDownBySignal - When this option is set, the primary will be stepped down by stopping
      *                      and restarting with sigterm, rather than with a replSetStepDown command
-     *   stepDownPeriodSecs - The number of seconds to step down the primary.
-     *   secondaryCatchUpPeriodSecs - The number of seconds that the mongod will wait for an
-     *                                electable secondary to catch up to the primary.
      */
     function testElectionHandoff(rst, initialPrimaryId, expectedCandidateId, options = {}) {
         const config = rst.getReplSetConfigFromNode();
@@ -56,16 +55,15 @@ var ElectionHandoffTest = (function() {
             {"a": 1}, {writeConcern: {w: rst.nodes.length}}));
         rst.awaitNodesAgreeOnAppliedOpTime();
 
-        // Step down the current primary. Skip validation since it prevents election handoff.
+        // Step down the current primary.
         if (options["stepDownBySignal"]) {
-            rst.stop(initialPrimaryId, kSIGTERM, {skipValidation: true}, {forRestart: true});
+            rst.stop(initialPrimaryId, kSIGTERM, {}, {forRestart: true});
             rst.start(initialPrimaryId, {}, true);
         } else {
-            assert.commandWorked(primary.adminCommand({
-                replSetStepDown: options.stepDownPeriodSecs || kStepDownPeriodSecs,
-                secondaryCatchUpPeriodSecs:
-                    options.secondaryCatchUpPeriodSecs || kStepDownPeriodSecs / 2
-            }));
+            assert.adminCommandWorkedAllowingNetworkError(primary, {
+                replSetStepDown: kStepDownPeriodSecs,
+                secondaryCatchUpPeriodSecs: kStepDownPeriodSecs / 2
+            });
         }
 
         jsTestLog(`Checking that the secondary with id ${expectedCandidateId} is stepped up...`);
@@ -78,10 +76,10 @@ var ElectionHandoffTest = (function() {
         // If there are only two nodes in the set, verify that the old primary voted "yes".
         if (numNodes === 2) {
             checkLog.contains(expectedCandidate,
-                              `skipping dry run and running for election in term ${term + 1}`);
+                              `skipping dry run and running for election in term ${term+1}`);
             checkLog.contains(
                 expectedCandidate,
-                `VoteRequester(term ${term + 1}) received a yes vote from ${primary.host}`);
+                `VoteRequester(term ${term+1}) received a yes vote from ${primary.host}`);
         }
 
         rst.awaitNodesAgreeOnPrimary();
@@ -89,4 +87,5 @@ var ElectionHandoffTest = (function() {
     }
 
     return {testElectionHandoff: testElectionHandoff, stepDownPeriodSecs: kStepDownPeriodSecs};
-})();
+
+})();
\ No newline at end of file
