@@ -1,5 +1,9 @@
 /*
  * Run the kill_sessions tests against a sharded cluster.
+ *
+ * TODO SERVER-45385: These tests can be enabled in multiversion once the logging of session cursor
+ * cleanup has been backported and released in last-stable.
+ * @tags: [multiversion_incompatible]
  */
 
 load("jstests/libs/kill_sessions.js");
@@ -14,6 +18,7 @@ load("jstests/libs/kill_sessions.js");
     function runTests(needAuth) {
         var other = {
             rs: true,
+            rsOptions: {nojournal: ""},
             rs0: {nodes: 3},
             rs1: {nodes: 3},
         };
