@@ -3,17 +3,17 @@
 (function() {
     'use strict';
 
-    const CLIENT_NAME = 'C=US,ST=New York,L=New York City,O=MongoDB,OU=KernelUser,CN=client';
+    const CLIENT_NAME = 'CN=client,OU=KernelUser,O=MongoDB,L=New York City,ST=New York,C=US';
     const CLIENT_CERT = 'jstests/libs/client.pem';
     const SERVER_CERT = 'jstests/libs/server.pem';
     const CA_CERT = 'jstests/libs/ca.pem';
     const SELF_SIGNED_CERT = 'jstests/libs/client-self-signed.pem';
 
     function testClient(conn, cert, name, shouldSucceed) {
-        const auth = {
-            mechanism: 'MONGODB-X509',
-            user: name
-        };
+        let auth = {mechanism: 'MONGODB-X509'};
+        if (name !== null) {
+            auth.user = name;
+        }
         const script = 'assert(db.getSiblingDB(\'$external\').auth(' + tojson(auth) + '));';
         clearRawMongoProgramOutput();
         const exitCode = runMongoProgram('mongo',
@@ -44,6 +44,8 @@
 
         testClient(conn, CLIENT_CERT, CLIENT_NAME, true);
         testClient(conn, SELF_SIGNED_CERT, CLIENT_NAME, false);
+        testClient(conn, CLIENT_CERT, null, true);
+        testClient(conn, SELF_SIGNED_CERT, null, false);
     }
 
     // Standalone.
