@@ -21,6 +21,8 @@ Usage: $0 [OPTIONS]
         --psm_ver           PSM_VER(mandatory)
         --psm_release       PSM_RELEASE(mandatory)
         --mongo_tools_tag   MONGO_TOOLS_TAG(mandatory)
+        --special_targets   Special targets for tests
+        --jenkins_mode      If it is set it means that this script is used on jenkins infrastructure
         --debug             build debug tarball
         
         --help) usage ;;
@@ -57,7 +59,9 @@ parse_arguments() {
             --psm_ver=*) PSM_VER="$val" ;;
             --psm_release=*) PSM_RELEASE="$val" ;;
             --mongo_tools_tag=*) MONGO_TOOLS_TAG="$val" ;;
+            --jenkins_mode=*) JENKINS_MODE="$val" ;;
             --debug=*) DEBUG="$val" ;;
+            --special_targets=*) SPECIAL_TAR="$val" ;;
             --help) usage ;;
             *)
               if test -n "$pick_args"
@@ -93,18 +97,6 @@ add_percona_yum_repo(){
     return
 }
 
-add_percona_apt_repo(){
-  if [ ! -f /etc/apt/sources.list.d/percona-dev.list ]; then
-    cat >/etc/apt/sources.list.d/percona-dev.list <<EOL
-deb http://jenkins.percona.com/apt-repo/ @@DIST@@ main
-deb-src http://jenkins.percona.com/apt-repo/ @@DIST@@ main
-EOL
-    sed -i "s:@@DIST@@:$OS_NAME:g" /etc/apt/sources.list.d/percona-dev.list
-  fi
-  wget -qO - http://jenkins.percona.com/apt-repo/8507EFA5.pub | apt-key add -
-  return
-}
-
 get_sources(){
     cd "${WORKDIR}"
     if [ "${SOURCE}" = 0 ]
@@ -115,13 +107,8 @@ get_sources(){
     PRODUCT=percona-server-mongodb
     echo "PRODUCT=${PRODUCT}" > percona-server-mongodb-36.properties
 
-    PRODUCT_FULL=${PRODUCT}-${PSM_VER}-${PSM_RELEASE}
-    echo "PRODUCT_FULL=${PRODUCT_FULL}" >> percona-server-mongodb-36.properties
-    echo "VERSION=${PSM_VER}" >> percona-server-mongodb-36.properties
-    echo "RELEASE=$PSM_RELEASE" >> percona-server-mongodb-36.properties
     echo "PSM_BRANCH=${PSM_BRANCH}" >> percona-server-mongodb-36.properties
     echo "JEMALLOC_TAG=${JEMALLOC_TAG}" >> percona-server-mongodb-36.properties
-    echo "MONGO_TOOLS_TAG=${MONGO_TOOLS_TAG}" >> percona-server-mongodb-36.properties
     echo "BUILD_NUMBER=${BUILD_NUMBER}" >> percona-server-mongodb-36.properties
     echo "BUILD_ID=${BUILD_ID}" >> percona-server-mongodb-36.properties
     git clone "$REPO"
@@ -138,14 +125,31 @@ get_sources(){
         git clean -xdf
         git checkout "$BRANCH"
     fi
+
     REVISION=$(git rev-parse --short HEAD)
     # create a proper version.json
     REVISION_LONG=$(git rev-parse HEAD)
+
+    if [ -n "${JENKINS_MODE}" ]; then
+        git remote add upstream https://github.com/mongodb/mongo.git
+        git fetch upstream --tags
+
+        PSM_VER=$(git describe --tags --abbrev=0 | sed 's/^psmdb-//' | sed 's/^r//' | awk -F '-' '{if ($2 ~ /^rc/) {print $0} else {print $1}}')
+        MONGO_TOOLS_TAG="r${PSM_VER}"
+    fi
+
     echo "{" > version.json
     echo "    \"version\": \"${PSM_VER}-${PSM_RELEASE}\"," >> version.json
     echo "    \"githash\": \"${REVISION_LONG}\"" >> version.json
     echo "}" >> version.json
     #
+
+    PRODUCT_FULL=${PRODUCT}-${PSM_VER}-${PSM_RELEASE}
+    echo "PRODUCT_FULL=${PRODUCT_FULL}" >> ${WORKDIR}/percona-server-mongodb-36.properties
+    echo "VERSION=${PSM_VER}" >> ${WORKDIR}/percona-server-mongodb-36.properties
+    echo "RELEASE=${PSM_RELEASE}" >> ${WORKDIR}/percona-server-mongodb-36.properties
+    echo "MONGO_TOOLS_TAG=${MONGO_TOOLS_TAG}" >> ${WORKDIR}/percona-server-mongodb-36.properties
+
     echo "REVISION=${REVISION}" >> ${WORKDIR}/percona-server-mongodb-36.properties
     rm -fr debian rpm
     cp -a percona-packaging/manpages .
@@ -170,6 +174,15 @@ get_sources(){
     sed -i 's:/bin/sh:/bin/sh -x:' percona-server-mongodb/src/third_party/rocksdb/build_tools/build_detect_platform
 
     mv percona-server-mongodb ${PRODUCT}-${PSM_VER}-${PSM_RELEASE}
+    cd ${PRODUCT}-${PSM_VER}-${PSM_RELEASE}
+        git clone https://github.com/aws/aws-sdk-cpp.git
+            cd aws-sdk-cpp
+                git reset --hard
+                git clean -xdf
+                git checkout 1.7.91
+                mkdir build
+                sed -i 's:AWS_EVENT_STREAM_SHA:AWS_EVENT_STREAM_TAG:g' third-party/cmake/BuildAwsEventStream.cmake
+    cd ../../
     tar --owner=0 --group=0 --exclude=.* -czf ${PRODUCT}-${PSM_VER}-${PSM_RELEASE}.tar.gz ${PRODUCT}-${PSM_VER}-${PSM_RELEASE}
     echo "UPLOAD=UPLOAD/experimental/BUILDS/${PRODUCT}-3.6/${PRODUCT}-${PSM_VER}-${PSM_RELEASE}/${PSM_BRANCH}/${REVISION}/${BUILD_ID}" >> percona-server-mongodb-36.properties
     mkdir $WORKDIR/source_tarball
@@ -223,7 +236,7 @@ install_gcc_54_deb(){
             mv libstdc++.so /usr/local/gcc-5.4.0/lib64/
         fi
     fi
-    if [ x"${DEBIAN}" = xtrusty -o x"${DEBIAN}" = xxenial ]; then
+    if [ x"${DEBIAN}" = xtrusty -o x"${DEBIAN}" = xxenial -o x"${DEBIAN}" = xfocal ]; then
         wget https://jenkins.percona.com/downloads/gcc-5.4.0/gcc-5.4.0_ubuntu-${DEBIAN}-x64.tar.gz -O /tmp/gcc-5.4.0_ubuntu-${DEBIAN}-x64.tar.gz
         tar -zxf /tmp/gcc-5.4.0_ubuntu-${DEBIAN}-x64.tar.gz
         rm -rf /usr/local/gcc-5.4.0
@@ -261,6 +274,34 @@ fix_rules(){
     sed -i 's:release:release --disable-warnings-as-errors :g' debian/rules
 }
 
+aws_sdk_build(){
+    cd $WORKDIR
+        git clone https://github.com/aws/aws-sdk-cpp.git
+        cd aws-sdk-cpp
+            git reset --hard
+            git clean -xdf
+            git checkout 1.7.91
+            mkdir build
+            sed -i 's:AWS_EVENT_STREAM_SHA:AWS_EVENT_STREAM_TAG:g' third-party/cmake/BuildAwsEventStream.cmake
+            cd build
+            CMAKE_CMD="cmake"
+            if [ -f /etc/redhat-release ]; then
+                RHEL=$(rpm --eval %rhel)
+                if [ x"$RHEL" = x6 ]; then
+                    CMAKE_CMD="cmake3"
+                fi
+            fi
+            set_compiler
+            if [ -z "${CC}" -a -z "${CXX}" ]; then
+                ${CMAKE_CMD} .. -DCMAKE_BUILD_TYPE=Release -DBUILD_ONLY="s3" -DBUILD_SHARED_LIBS=OFF -DMINIMIZE_SIZE=ON?
+            else
+                ${CMAKE_CMD} CC=${CC} CXX=${CXX} .. -DCMAKE_BUILD_TYPE=Release -DBUILD_ONLY="s3" -DBUILD_SHARED_LIBS=OFF -DMINIMIZE_SIZE=ON
+            fi
+            make -j4
+            make install
+    cd ${WORKDIR}
+}
+
 install_deps() {
     if [ $INSTALL = 0 ]
     then
@@ -280,43 +321,94 @@ install_deps() {
       wget http://jenkins.percona.com/yum-repo/percona-dev.repo
       mv -f percona-dev.repo /etc/yum.repos.d/
       yum clean all
-      yum -y install epel-release
+      if [ x"$RHEL" != "x8" ]; then
+          yum -y install epel-release
+      fi
       rm -fr /usr/local/gcc-5.4.0
       RHEL=$(rpm --eval %rhel)
       if [ x"$RHEL" = x6 ]; then
-        yum -y install rpmbuild rpm-build libpcap-devel gcc make cmake gcc-c++ openssl-devel cyrus-sasl-devel snappy-devel zlib-devel bzip2-devel libpcap-devel scons make rpm-build rpmbuild percona-devtoolset-gcc percona-devtoolset-binutils percona-devtoolset-gcc-c++ percona-devtoolset-libstdc++-devel percona-devtoolset-valgrind-devel python27 python27-devel libcurl-devel
+        yum -y install rpmbuild rpm-build libpcap-devel gcc make cmake gcc-c++ openssl-devel cyrus-sasl-devel snappy-devel zlib-devel bzip2-devel libpcap-devel scons make rpm-build rpmbuild percona-devtoolset-gcc percona-devtoolset-binutils percona-devtoolset-gcc-c++ percona-devtoolset-libstdc++-devel percona-devtoolset-valgrind-devel python27 python27-devel libcurl-devel e2fsprogs-devel expat-devel lz4-devel git cmake3
+        yum -y install openldap-devel
         wget https://bootstrap.pypa.io/get-pip.py
         python2.7 get-pip.py
         rm -rf /usr/bin/python2
         ln -s /usr/bin/python2.7 /usr/bin/python2
+        wget http://curl.haxx.se/download/curl-7.26.0.tar.gz
+        tar -xvzf curl-7.26.0.tar.gz
+        cd curl-7.26.0
+          ./configure
+          make
+          make install
+        cd ../
+      elif [ x"$RHEL" = x7 ]; then
+        yum -y install rpmbuild rpm-build libpcap-devel gcc make cmake gcc-c++ openssl-devel cyrus-sasl-devel snappy-devel zlib-devel bzip2-devel scons rpmlint rpm-build git python-pip python-devel libopcodes libcurl-devel e2fsprogs-devel expat-devel lz4-devel
+        yum -y install openldap-devel
       else
-        yum -y install rpmbuild rpm-build libpcap-devel gcc make cmake gcc-c++ openssl-devel cyrus-sasl-devel snappy-devel zlib-devel bzip2-devel scons rpmlint rpm-build git python-pip python-devel libopcodes libcurl-devel
+        yum -y install bzip2-devel libpcap-devel snappy-devel gcc gcc-c++ rpm-build rpmlint
+        yum -y install cmake cyrus-sasl-devel make openssl-devel zlib-devel libcurl-devel git
+        yum -y install python2-scons python2-pip python36-devel
+        yum -y install redhat-rpm-config python2-devel e2fsprogs-devel expat-devel lz4-devel
+        yum -y install openldap-devel
+        pip2.7 install --user setuptools --upgrade
+        pip3.6 install --user typing pyyaml regex Cheetah3
+        pip2.7 install --user typing pyyaml regex Cheetah
       fi
       install_golang
       install_gcc_54_centos
     else
       export DEBIAN=$(lsb_release -sc)
       export ARCH=$(echo $(uname -m) | sed -e 's:i686:i386:g')
-      INSTALL_LIST="python python-dev valgrind scons liblz4-dev devscripts debhelper debconf libpcap-dev libbz2-dev libsnappy-dev pkg-config zlib1g-dev libzlcore-dev dh-systemd libsasl2-dev gcc g++ cmake curl libcurl4-openssl-dev libssl-dev"
+      if [ x"${DEBIAN}" = xjessie ]; then
+        cat >/etc/apt/sources.list.d/stretch.list <<EOL
+deb http://httpredir.debian.org/debian stretch main
+EOL
+        apt-get -y update
+        DEBIAN_FRONTEND=noninteractive apt-get -y install cmake
+        rm -f /etc/apt/sources.list.d/stretch.list
+        apt-get -y update
+      fi
+      apt-get -y update
+      INSTALL_LIST="valgrind scons liblz4-dev devscripts debhelper debconf libpcap-dev libbz2-dev libsnappy-dev pkg-config zlib1g-dev libzlcore-dev dh-systemd libsasl2-dev gcc g++ cmake curl libcurl4-openssl-dev libssl-dev libldap2-dev"
+      if [ x"${DEBIAN}" = xfocal ]; then
+        INSTALL_LIST="${INSTALL_LIST} python2 python2-dev "
+      else
+        INSTALL_LIST="${INSTALL_LIST} python python-dev "
+      fi
       until apt-get -y install dirmngr; do
         sleep 1
         echo "waiting"
       done
-      add_percona_apt_repo
-      until apt-get update; do
-        sleep 1
-        echo "waiting"
-      done
       until apt-get -y install ${INSTALL_LIST}; do
         sleep 1
         echo "waiting"
       done
+      apt-get -y install libext2fs-dev || apt-get -y install e2fslibs-dev
       install_golang
       install_gcc_54_deb
       wget https://bootstrap.pypa.io/get-pip.py
+      if [ x"${DEBIAN}" = "xfocal" ]; then
+        ln -s /usr/bin/python2 /usr/bin/python
+      fi
       python get-pip.py
       easy_install pip
     fi
+    if [ x"${DEBIAN}" = "xstretch" ]; then
+      LIBCURL_DEPS="libidn2-0-dev libkrb5-dev libldap2-dev libnghttp2-dev libnss3-dev libpsl-dev librtmp-dev libssh2-1-dev libssl1.0-dev"
+      until DEBIAN_FRONTEND=noninteractive apt-get -y install ${LIBCURL_DEPS}; do
+        sleep 1
+        echo "waiting"
+      done
+      wget http://curl.haxx.se/download/curl-7.66.0.tar.gz
+      tar -xvzf curl-7.66.0.tar.gz
+        cd curl-7.66.0
+        ./configure --enable-static --disable-shared --disable-dependency-tracking --disable-symbol-hiding --enable-versioned-symbols --enable-threaded-resolver --with-lber-lib=lber --with-gssapi=/usr --with-libssh2 --with-nghttp2 --with-zsh-functions-dir=/usr/share/zsh/vendor-completions --with-ca-path=/etc/ssl/certs --with-ca-bundle=/etc/ssl/certs/ca-certificates.crt --with-ssl
+        make
+        make install
+      cd ../
+      CURL_LINKFLAGS=$(pkg-config libcurl --static --libs)
+      export LDFLAGS="${LDFLAGS} ${CURL_LINKFLAGS}"
+    fi
+    aws_sdk_build
     return;
 }
 
@@ -440,8 +532,10 @@ build_rpm(){
     tar vxzf ${TARF} --wildcards '*/buildscripts' --strip=1
     if [ "x${RHEL}" == "x6" ]; then
     pip2.7 install --user -r buildscripts/requirements.txt
-    else
+    elif [ x"$RHEL" = x7 ]; then
     pip install --user -r buildscripts/requirements.txt
+    else
+    pip3 install --user -r buildscripts/requirements.txt
     fi
     #
     cd $WORKDIR
@@ -455,6 +549,7 @@ build_rpm(){
     echo "CC and CXX should be modified once correct compiller would be installed on Centosed"
     export CC=/usr/local/gcc-5.4.0/bin/gcc-5.4
     export CXX=/usr/local/gcc-5.4.0/bin/g++-5.4
+    export LD_LIBRARY_PATH=/usr/local/gcc-5.4.0/lib:/usr/local/gcc-5.4.0/lib64:$LD_LIBRARY_PATH
     #
     echo "RHEL=${RHEL}" >> percona-server-mongodb-36.properties
     echo "ARCH=${ARCH}" >> percona-server-mongodb-36.properties
@@ -468,6 +563,7 @@ build_rpm(){
         export PATH="/usr/local/go/bin:$PATH:$GOPATH"
         export GOBINPATH="/usr/local/go/bin"
     #fi
+    export LD_LIBRARY_PATH=/usr/local/lib:$LD_LIBRARY_PATH
     rpmbuild --define "_topdir ${WORKDIR}/rpmbuild" --define "dist .$OS_NAME" --rebuild rpmbuild/SRPMS/$SRC_RPM
 
     return_code=$?
@@ -575,7 +671,11 @@ build_deb(){
     sed -i 's|go build|go build -a -x|' mongo-tools/build.sh
     sed -i 's|exit $ec||' mongo-tools/build.sh
     dch -m -D "${DEBIAN}" --force-distribution -v "${VERSION}-${RELEASE}.${DEBIAN}" 'Update distribution'
-
+    export LD_LIBRARY_PATH=/usr/local/lib:$LD_LIBRARY_PATH
+    if [ x"${DEBIAN}" = "xstretch" ]; then
+      CURL_LINKFLAGS=$(pkg-config libcurl --static --libs)
+      export LINKFLAGS="${LINKFLAGS} ${CURL_LINKFLAGS}"
+    fi
     dpkg-buildpackage -rfakeroot -us -uc -b
     mkdir -p $CURDIR/deb
     mkdir -p $WORKDIR/deb
@@ -597,13 +697,15 @@ build_tarball(){
     source /opt/percona-devtoolset/enable
     fi
     #
+    if [ "x$OS" = "xdeb" ]; then
     export DEBIAN_VERSION="$(lsb_release -sc)"
     export DEBIAN="$(lsb_release -sc)"
+    fi
     export PATH=/usr/local/go/bin:$PATH
     #
     set_compiler
     #
-    PSM_TARGETS="mongod mongos mongo mongobridge perconadecrypt"
+    PSM_TARGETS="mongod mongos mongo mongobridge perconadecrypt $SPECIAL_TAR"
     TARBALL_SUFFIX=""
     if [ ${DEBUG} = 1 ]; then
     TARBALL_SUFFIX=".dbg"
@@ -640,8 +742,10 @@ build_tarball(){
     export CXXFLAGS="${CFLAGS} -Wno-error=deprecated-declarations"
     fi
     export INSTALLDIR=${WORKDIR}/install
+    export AWS_LIBS=/usr/local
     export PORTABLE=1
     export USE_SSE=1
+    export LD_LIBRARY_PATH=/usr/local/gcc-5.4.0/lib:/usr/local/gcc-5.4.0/lib64:$LD_LIBRARY_PATH
     #
     # RocksDB
     pushd ${PSMDIR}/src/third_party/rocksdb
@@ -664,12 +768,53 @@ build_tarball(){
     #
     # Finally build Percona Server for MongoDB with SCons
     cd ${PSMDIR_ABS}
-    pip install --user -r buildscripts/requirements.txt
+    PIP_CMD=pip
+    if [ x"$RHEL" = "x8" ]; then
+    PIP_CMD=pip3
+    fi
+    ${PIP_CMD} install --user -r buildscripts/requirements.txt
+    if [ -f /etc/redhat-release ]; then
+        RHEL=$(rpm --eval %rhel)
+        if [ $RHEL = 7 ]; then
+            if [ -d aws-sdk-cpp ]; then
+                rm -rf aws-sdk-cpp
+            fi
+            export INSTALLDIR=$PWD/../install
+            export INSTALLDIR_AWS=$PWD/../install_aws
+            git clone https://github.com/aws/aws-sdk-cpp.git
+            cd aws-sdk-cpp
+            git reset --hard
+            git clean -xdf
+            git checkout 1.7.91
+            mkdir build
+            sed -i 's:AWS_EVENT_STREAM_SHA:AWS_EVENT_STREAM_TAG:g' third-party/cmake/BuildAwsEventStream.cmake
+            cd build
+            set_compiler
+            if [ -z "${CC}" -a -z "${CXX}" ]; then
+                cmake .. -DCMAKE_BUILD_TYPE=Release -DBUILD_ONLY="s3" -DBUILD_SHARED_LIBS=OFF -DMINIMIZE_SIZE=ON -DCMAKE_INSTALL_PREFIX="${INSTALLDIR_AWS}" || exit $?
+            else
+                cmake CC=${CC} CXX=${CXX} .. -DCMAKE_BUILD_TYPE=Release -DBUILD_ONLY="s3" -DBUILD_SHARED_LIBS=OFF -DMINIMIZE_SIZE=ON -DCMAKE_INSTALL_PREFIX="${INSTALLDIR_AWS}" || exit $?
+            fi
+            make -j4 || exit $?
+            make install
+            mkdir -p ${INSTALLDIR}/include/
+            mkdir -p ${INSTALLDIR}/lib/
+            mv ${INSTALLDIR_AWS}/include/* ${INSTALLDIR}/include/
+            mv ${INSTALLDIR_AWS}/lib*/* ${INSTALLDIR}/lib/
+            cd ../../
+
+        fi
+    fi
+    export LD_LIBRARY_PATH=/usr/local/lib:$LD_LIBRARY_PATH
+    if [ x"${DEBIAN}" = "xstretch" ]; then
+      CURL_LINKFLAGS=$(pkg-config libcurl --static --libs)
+      export LINKFLAGS="${LINKFLAGS} ${CURL_LINKFLAGS}"
+    fi
     if [ ${DEBUG} = 0 ]; then
-        buildscripts/scons.py CC=${CC} CXX=${CXX} --disable-warnings-as-errors --release --ssl --opt=on -j$NJOBS --use-sasl-client --wiredtiger --audit --rocksdb --inmemory --hotbackup CPPPATH=${INSTALLDIR}/include LIBPATH=${INSTALLDIR}/lib ${PSM_TARGETS}
+        buildscripts/scons.py CC=${CC} CXX=${CXX} --disable-warnings-as-errors --release --ssl --opt=on -j$NJOBS --use-sasl-client --wiredtiger --audit --rocksdb --inmemory --hotbackup CPPPATH="${INSTALLDIR}/include ${AWS_LIBS}/include" LIBPATH="${INSTALLDIR}/lib ${AWS_LIBS}/lib ${AWS_LIBS}/lib64" LINKFLAGS="${LINKFLAGS}" ${PSM_TARGETS} || exit $?
     else
         buildscripts/scons.py CC=${CC} CXX=${CXX} --disable-warnings-as-errors --audit --ssl --dbg=on -j$NJOBS --use-sasl-client \
-        CPPPATH=${INSTALLDIR}/include LIBPATH=${INSTALLDIR}/lib --rocksdb --wiredtiger --inmemory --hotbackup ${PSM_TARGETS}
+        CPPPATH="${INSTALLDIR}/include ${AWS_LIBS}/include" LIBPATH="${INSTALLDIR}/lib ${AWS_LIBS}/lib ${AWS_LIBS}/lib64" LINKFLAGS="${LINKFLAGS}" --rocksdb --wiredtiger --inmemory --hotbackup ${PSM_TARGETS} || exit $?
     fi
     #
     # scons install doesn't work - it installs the binaries not linked with fractal tree
