@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -36,114 +37,51 @@
 #include "mongo/bson/bsontypes.h"
 #include "mongo/bson/json.h"
 #include "mongo/client/mongo_uri.h"
-#include "mongo/db/service_context_test_fixture.h"
 #include "mongo/unittest/unittest.h"
 
 #include <boost/filesystem/operations.hpp>
-#include <boost/optional.hpp>
-#include <boost/optional/optional_io.hpp>
 
 namespace mongo {
 namespace {
-using transport::ConnectSSLMode;
-constexpr auto kEnableSSL = ConnectSSLMode::kEnableSSL;
-constexpr auto kDisableSSL = ConnectSSLMode::kDisableSSL;
-constexpr auto kGlobalSSLMode = ConnectSSLMode::kGlobalSSLMode;
+using mongo::MongoURI;
 
 struct URITestCase {
     std::string URI;
     std::string uname;
     std::string password;
-    ConnectionString::ConnectionType type;
+    mongo::ConnectionString::ConnectionType type;
     std::string setname;
     size_t numservers;
-    MongoURI::OptionsMap options;
+    size_t numOptions;
     std::string database;
-    ConnectSSLMode sslMode;
 };
 
 struct InvalidURITestCase {
     std::string URI;
-    boost::optional<ErrorCodes::Error> code;
-    InvalidURITestCase(std::string aURI, boost::optional<ErrorCodes::Error> aCode = boost::none) {
-        URI = std::move(aURI);
-        code = std::move(aCode);
-    }
 };
 
-void compareOptions(size_t lineNumber,
-                    StringData uri,
-                    const MongoURI::OptionsMap& connection,
-                    const MongoURI::OptionsMap& expected) {
-    std::vector<std::pair<MongoURI::CaseInsensitiveString, std::string>> options(begin(connection),
-                                                                                 end(connection));
-    std::sort(begin(options), end(options));
-    std::vector<std::pair<MongoURI::CaseInsensitiveString, std::string>> expectedOptions(
-        begin(expected), end(expected));
-    std::sort(begin(expectedOptions), end(expectedOptions));
-
-    for (std::size_t i = 0; i < std::min(options.size(), expectedOptions.size()); ++i) {
-        if (options[i] != expectedOptions[i]) {
-            unittest::log() << "Option: \"tolower(" << options[i].first.original()
-                            << ")=" << options[i].second << "\" doesn't equal: \"tolower("
-                            << expectedOptions[i].first.original()
-                            << ")=" << expectedOptions[i].second << "\""
-                            << " data on line: " << lineNumber << std::endl;
-            std::cerr << "Failing URI: \"" << uri << "\""
-                      << " data on line: " << lineNumber << std::endl;
-            ASSERT(false);
-        }
-    }
-    ASSERT_EQ(options.size(), expectedOptions.size()) << "Failing URI: "
-                                                      << " data on line: " << lineNumber << uri;
-}
-
-const ConnectionString::ConnectionType kMaster = ConnectionString::MASTER;
-const ConnectionString::ConnectionType kSet = ConnectionString::SET;
+const mongo::ConnectionString::ConnectionType kMaster = mongo::ConnectionString::MASTER;
+const mongo::ConnectionString::ConnectionType kSet = mongo::ConnectionString::SET;
 
 const URITestCase validCases[] = {
 
-    {"mongodb://user:pwd@127.0.0.1", "user", "pwd", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user:pwd@127.0.0.1", "user", "pwd", kMaster, "", 1, 0, ""},
 
-    {"mongodb://user@127.0.0.1", "user", "", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user@127.0.0.1", "user", "", kMaster, "", 1, 0, ""},
 
-    {"mongodb://localhost/?foo=bar", "", "", kMaster, "", 1, {{"foo", "bar"}}, "", kGlobalSSLMode},
+    {"mongodb://localhost/?foo=bar", "", "", kMaster, "", 1, 1, ""},
 
-    {"mongodb://localhost,/?foo=bar", "", "", kMaster, "", 1, {{"foo", "bar"}}, "", kGlobalSSLMode},
+    {"mongodb://localhost,/?foo=bar", "", "", kMaster, "", 1, 1, ""},
 
-    {"mongodb://user:pwd@127.0.0.1:1234", "user", "pwd", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user:pwd@127.0.0.1:1234", "user", "pwd", kMaster, "", 1, 0, ""},
 
-    {"mongodb://user@127.0.0.1:1234", "user", "", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user@127.0.0.1:1234", "user", "", kMaster, "", 1, 0, ""},
 
-    {"mongodb://127.0.0.1:1234/dbName?foo=a&c=b",
-     "",
-     "",
-     kMaster,
-     "",
-     1,
-     {{"foo", "a"}, {"c", "b"}},
-     "dbName",
-     kGlobalSSLMode},
+    {"mongodb://127.0.0.1:1234/dbName?foo=a&c=b", "", "", kMaster, "", 1, 2, "dbName"},
 
-    {"mongodb://127.0.0.1/dbName?foo=a&c=b",
-     "",
-     "",
-     kMaster,
-     "",
-     1,
-     {{"foo", "a"}, {"c", "b"}},
-     "dbName",
-     kGlobalSSLMode},
+    {"mongodb://127.0.0.1/dbName?foo=a&c=b", "", "", kMaster, "", 1, 2, "dbName"},
 
-    {"mongodb://user:pwd@127.0.0.1,/dbName?foo=a&c=b",
-     "user",
-     "pwd",
-     kMaster,
-     "",
-     1,
-     {{"foo", "a"}, {"c", "b"}},
-     "dbName",
-     kGlobalSSLMode},
+    {"mongodb://user:pwd@127.0.0.1,/dbName?foo=a&c=b", "user", "pwd", kMaster, "", 1, 2, "dbName"},
 
     {"mongodb://user:pwd@127.0.0.1,127.0.0.2/dbname?a=b&replicaSet=replName",
      "user",
@@ -151,9 +89,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"a", "b"}, {"replicaSet", "replName"}},
-     "dbname",
-     kGlobalSSLMode},
+     2,
+     "dbname"},
 
     {"mongodb://needs%20encoding%25%23!%3C%3E:pwd@127.0.0.1,127.0.0.2/"
      "dbname?a=b&replicaSet=replName",
@@ -162,9 +99,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"a", "b"}, {"replicaSet", "replName"}},
-     "dbname",
-     kGlobalSSLMode},
+     2,
+     "dbname"},
 
     {"mongodb://needs%20encoding%25%23!%3C%3E:pwd@127.0.0.1,127.0.0.2/"
      "db@name?a=b&replicaSet=replName",
@@ -173,9 +109,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"a", "b"}, {"replicaSet", "replName"}},
-     "db@name",
-     kGlobalSSLMode},
+     2,
+     "db@name"},
 
     {"mongodb://user:needs%20encoding%25%23!%3C%3E@127.0.0.1,127.0.0.2/"
      "dbname?a=b&replicaSet=replName",
@@ -184,9 +119,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"a", "b"}, {"replicaSet", "replName"}},
-     "dbname",
-     kGlobalSSLMode},
+     2,
+     "dbname"},
 
     {"mongodb://user:pwd@127.0.0.1,127.0.0.2/dbname?a=b&replicaSet=needs%20encoding%25%23!%3C%3E",
      "user",
@@ -194,9 +128,8 @@ const URITestCase validCases[] = {
      kSet,
      "needs encoding%#!<>",
      2,
-     {{"a", "b"}, {"replicaSet", "needs encoding%#!<>"}},
-     "dbname",
-     kGlobalSSLMode},
+     2,
+     "dbname"},
 
     {"mongodb://user:pwd@127.0.0.1,127.0.0.2/needsencoding%40hello?a=b&replicaSet=replName",
      "user",
@@ -204,9 +137,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"a", "b"}, {"replicaSet", "replName"}},
-     "needsencoding@hello",
-     kGlobalSSLMode},
+     2,
+     "needsencoding@hello"},
 
     {"mongodb://user:pwd@127.0.0.1,127.0.0.2/?replicaSet=replName",
      "user",
@@ -214,9 +146,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+     1,
+     ""},
 
     {"mongodb://user@127.0.0.1,127.0.0.2/?replicaSet=replName",
      "user",
@@ -224,19 +155,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
-
-    {"mongodb://user@127.0.0.1,127.0.0.2/?replicaset=replName",
-     "user",
-     "",
-     kSet,
-     "replName",
-     2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+     1,
+     ""},
 
     {"mongodb://127.0.0.1,127.0.0.2/dbName?foo=a&c=b&replicaSet=replName",
      "",
@@ -244,9 +164,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"foo", "a"}, {"c", "b"}, {"replicaSet", "replName"}},
-     "dbName",
-     kGlobalSSLMode},
+     3,
+     "dbName"},
 
     {"mongodb://user:pwd@127.0.0.1:1234,127.0.0.2:1234/?replicaSet=replName",
      "user",
@@ -254,9 +173,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+     1,
+     ""},
 
     {"mongodb://user@127.0.0.1:1234,127.0.0.2:1234/?replicaSet=replName",
      "user",
@@ -264,9 +182,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+     1,
+     ""},
 
     {"mongodb://127.0.0.1:1234,127.0.0.1:1234/dbName?foo=a&c=b&replicaSet=replName",
      "",
@@ -274,37 +191,20 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"foo", "a"}, {"c", "b"}, {"replicaSet", "replName"}},
-     "dbName",
-     kGlobalSSLMode},
+     3,
+     "dbName"},
 
-    {"mongodb://user:pwd@[::1]", "user", "pwd", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user:pwd@[::1]", "user", "pwd", kMaster, "", 1, 0, ""},
 
-    {"mongodb://user@[::1]", "user", "", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user@[::1]", "user", "", kMaster, "", 1, 0, ""},
 
-    {"mongodb://[::1]/dbName?foo=a&c=b",
-     "",
-     "",
-     kMaster,
-     "",
-     1,
-     {{"foo", "a"}, {"c", "b"}},
-     "dbName",
-     kGlobalSSLMode},
+    {"mongodb://[::1]/dbName?foo=a&c=b", "", "", kMaster, "", 1, 2, "dbName"},
 
-    {"mongodb://user:pwd@[::1]:1234", "user", "pwd", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user:pwd@[::1]:1234", "user", "pwd", kMaster, "", 1, 0, ""},
 
-    {"mongodb://user@[::1]:1234", "user", "", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user@[::1]:1234", "user", "", kMaster, "", 1, 0, ""},
 
-    {"mongodb://[::1]:1234/dbName?foo=a&c=b",
-     "",
-     "",
-     kMaster,
-     "",
-     1,
-     {{"foo", "a"}, {"c", "b"}},
-     "dbName",
-     kGlobalSSLMode},
+    {"mongodb://[::1]:1234/dbName?foo=a&c=b", "", "", kMaster, "", 1, 2, "dbName"},
 
     {"mongodb://user:pwd@[::1],127.0.0.2/?replicaSet=replName",
      "user",
@@ -312,19 +212,10 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+     1,
+     ""},
 
-    {"mongodb://user@[::1],127.0.0.2/?replicaSet=replName",
-     "user",
-     "",
-     kSet,
-     "replName",
-     2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+    {"mongodb://user@[::1],127.0.0.2/?replicaSet=replName", "user", "", kSet, "replName", 2, 1, ""},
 
     {"mongodb://[::1],127.0.0.2/dbName?foo=a&c=b&replicaSet=replName",
      "",
@@ -332,9 +223,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"foo", "a"}, {"c", "b"}, {"replicaSet", "replName"}},
-     "dbName",
-     kGlobalSSLMode},
+     3,
+     "dbName"},
 
     {"mongodb://user:pwd@[::1]:1234,127.0.0.2:1234/?replicaSet=replName",
      "user",
@@ -342,9 +232,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+     1,
+     ""},
 
     {"mongodb://user@[::1]:1234,127.0.0.2:1234/?replicaSet=replName",
      "user",
@@ -352,9 +241,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+     1,
+     ""},
 
     {"mongodb://[::1]:1234,[::1]:1234/dbName?foo=a&c=b&replicaSet=replName",
      "",
@@ -362,37 +250,20 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"foo", "a"}, {"c", "b"}, {"replicaSet", "replName"}},
-     "dbName",
-     kGlobalSSLMode},
+     3,
+     "dbName"},
 
-    {"mongodb://user:pwd@[::1]", "user", "pwd", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user:pwd@[::1]", "user", "pwd", kMaster, "", 1, 0, ""},
 
-    {"mongodb://user@[::1]", "user", "", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user@[::1]", "user", "", kMaster, "", 1, 0, ""},
 
-    {"mongodb://[::1]/dbName?foo=a&c=b",
-     "",
-     "",
-     kMaster,
-     "",
-     1,
-     {{"foo", "a"}, {"c", "b"}},
-     "dbName",
-     kGlobalSSLMode},
+    {"mongodb://[::1]/dbName?foo=a&c=b", "", "", kMaster, "", 1, 2, "dbName"},
 
-    {"mongodb://user:pwd@[::1]:1234", "user", "pwd", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user:pwd@[::1]:1234", "user", "pwd", kMaster, "", 1, 0, ""},
 
-    {"mongodb://user@[::1]:1234", "user", "", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://user@[::1]:1234", "user", "", kMaster, "", 1, 0, ""},
 
-    {"mongodb://[::1]:1234/dbName?foo=a&c=b",
-     "",
-     "",
-     kMaster,
-     "",
-     1,
-     {{"foo", "a"}, {"c", "b"}},
-     "dbName",
-     kGlobalSSLMode},
+    {"mongodb://[::1]:1234/dbName?foo=a&c=b", "", "", kMaster, "", 1, 2, "dbName"},
 
     {"mongodb://user:pwd@[::1],127.0.0.2/?replicaSet=replName",
      "user",
@@ -400,19 +271,10 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+     1,
+     ""},
 
-    {"mongodb://user@[::1],127.0.0.2/?replicaSet=replName",
-     "user",
-     "",
-     kSet,
-     "replName",
-     2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+    {"mongodb://user@[::1],127.0.0.2/?replicaSet=replName", "user", "", kSet, "replName", 2, 1, ""},
 
     {"mongodb://[::1],127.0.0.2/dbName?foo=a&c=b&replicaSet=replName",
      "",
@@ -420,9 +282,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"foo", "a"}, {"c", "b"}, {"replicaSet", "replName"}},
-     "dbName",
-     kGlobalSSLMode},
+     3,
+     "dbName"},
 
     {"mongodb://user:pwd@[::1]:1234,127.0.0.2:1234/?replicaSet=replName",
      "user",
@@ -430,9 +291,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+     1,
+     ""},
 
     {"mongodb://user@[::1]:1234,127.0.0.2:1234/?replicaSet=replName",
      "user",
@@ -440,9 +300,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
+     1,
+     ""},
 
     {"mongodb://[::1]:1234,[::1]:1234/dbName?foo=a&c=b&replicaSet=replName",
      "",
@@ -450,9 +309,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"foo", "a"}, {"c", "b"}, {"replicaSet", "replName"}},
-     "dbName",
-     kGlobalSSLMode},
+     3,
+     "dbName"},
 
     {"mongodb://user:pwd@[::1]/?authMechanism=GSSAPI&authMechanismProperties=SERVICE_NAME:foobar",
      "user",
@@ -460,9 +318,8 @@ const URITestCase validCases[] = {
      kMaster,
      "",
      1,
-     {{"authmechanism", "GSSAPI"}, {"authmechanismproperties", "SERVICE_NAME:foobar"}},
-     "",
-     kGlobalSSLMode},
+     2,
+     ""},
 
     {"mongodb://user:pwd@[::1]/?authMechanism=GSSAPI&gssapiServiceName=foobar",
      "user",
@@ -470,11 +327,10 @@ const URITestCase validCases[] = {
      kMaster,
      "",
      1,
-     {{"authmechanism", "GSSAPI"}, {"gssapiServiceName", "foobar"}},
-     "",
-     kGlobalSSLMode},
+     2,
+     ""},
 
-    {"mongodb://%2Ftmp%2Fmongodb-27017.sock", "", "", kMaster, "", 1, {}, "", kGlobalSSLMode},
+    {"mongodb://%2Ftmp%2Fmongodb-27017.sock", "", "", kMaster, "", 1, 0, ""},
 
     {"mongodb://%2Ftmp%2Fmongodb-27017.sock,%2Ftmp%2Fmongodb-27018.sock/?replicaSet=replName",
      "",
@@ -482,14 +338,8 @@ const URITestCase validCases[] = {
      kSet,
      "replName",
      2,
-     {{"replicaSet", "replName"}},
-     "",
-     kGlobalSSLMode},
-
-    {"mongodb://localhost/?ssl=true", "", "", kMaster, "", 1, {{"ssl", "true"}}, "", kEnableSSL},
-    {"mongodb://localhost/?ssl=false", "", "", kMaster, "", 1, {{"ssl", "false"}}, "", kDisableSSL},
-    {"mongodb://localhost/?tls=true", "", "", kMaster, "", 1, {{"tls", "true"}}, "", kEnableSSL},
-    {"mongodb://localhost/?tls=false", "", "", kMaster, "", 1, {{"tls", "false"}}, "", kDisableSSL},
+     1,
+     ""},
 };
 
 const InvalidURITestCase invalidCases[] = {
@@ -507,9 +357,6 @@ const InvalidURITestCase invalidCases[] = {
     // Host list must actually be comma separated.
     {"mongodb://localhost:27017localhost:27018"},
 
-    // % symbol in password must be escaped.
-    {"mongodb://localhost:pass%word@127.0.0.1:27017", ErrorCodes::duplicateCodeForTest(51040)},
-
     // Domain sockets have to end in ".sock".
     {"mongodb://%2Fnotareal%2Fdomainsock"},
 
@@ -560,41 +407,37 @@ const InvalidURITestCase invalidCases[] = {
 
     // Missing an entire key-value pair
     {"mongodb://127.0.0.1:1234/dbName?foo=a&&c=b"},
-
-    // Illegal value for ssl/tls.
-    {"mongodb://127.0.0.1:1234/dbName?ssl=blah", ErrorCodes::duplicateCodeForTest(51041)},
-    {"mongodb://127.0.0.1:1234/dbName?tls=blah", ErrorCodes::duplicateCodeForTest(51041)},
 };
 
 // Helper Method to take a filename for a json file and return the array of tests inside of it
-BSONObj getBsonFromJsonFile(std::string fileName) {
+mongo::BSONObj getBsonFromJsonFile(std::string fileName) {
     boost::filesystem::path directoryPath = boost::filesystem::current_path();
     boost::filesystem::path filePath(directoryPath / "src" / "mongo" / "client" /
                                      "mongo_uri_tests" / fileName);
     std::string filename(filePath.string());
     std::ifstream infile(filename.c_str());
     std::string data((std::istreambuf_iterator<char>(infile)), std::istreambuf_iterator<char>());
-    BSONObj obj = fromjson(data);
-    ASSERT_TRUE(obj.valid(BSONVersion::kLatest));
+    mongo::BSONObj obj = mongo::fromjson(data);
+    ASSERT_TRUE(obj.valid(mongo::BSONVersion::kLatest));
     ASSERT_TRUE(obj.hasField("tests"));
-    BSONObj arr = obj.getField("tests").embeddedObject().getOwned();
+    mongo::BSONObj arr = obj.getField("tests").embeddedObject().getOwned();
     ASSERT_TRUE(arr.couldBeArray());
     return arr;
 }
 
 // Helper method to take a BSONElement and either extract its string or return an empty string
-std::string returnStringFromElementOrNull(BSONElement element) {
+std::string returnStringFromElementOrNull(mongo::BSONElement element) {
     ASSERT_TRUE(!element.eoo());
-    if (element.type() == jstNULL) {
+    if (element.type() == mongo::jstNULL) {
         return std::string();
     }
-    ASSERT_EQ(element.type(), String);
+    ASSERT_EQ(element.type(), mongo::String);
     return element.String();
 }
 
 // Helper method to take a valid test case, parse() it, and assure the output is correct
 void testValidURIFormat(URITestCase testCase) {
-    unittest::log() << "Testing URI: " << testCase.URI << '\n';
+    mongo::unittest::log() << "Testing URI: " << testCase.URI << '\n';
     std::string errMsg;
     const auto cs_status = MongoURI::parse(testCase.URI);
     ASSERT_OK(cs_status);
@@ -604,7 +447,7 @@ void testValidURIFormat(URITestCase testCase) {
     ASSERT_EQ(testCase.type, result.type());
     ASSERT_EQ(testCase.setname, result.getSetName());
     ASSERT_EQ(testCase.numservers, result.getServers().size());
-    compareOptions(0, testCase.URI, result.getOptions(), testCase.options);
+    ASSERT_EQ(testCase.numOptions, result.getOptions().size());
     ASSERT_EQ(testCase.database, result.getDatabase());
 }
 
@@ -622,16 +465,13 @@ TEST(MongoURI, InvalidURIs) {
 
     for (size_t i = 0; i != numCases; ++i) {
         const InvalidURITestCase testCase = invalidCases[i];
-        unittest::log() << "Testing URI: " << testCase.URI << '\n';
+        mongo::unittest::log() << "Testing URI: " << testCase.URI << '\n';
         auto cs_status = MongoURI::parse(testCase.URI);
         ASSERT_NOT_OK(cs_status);
-        if (testCase.code) {
-            ASSERT_EQUALS(*testCase.code, cs_status.getStatus());
-        }
     }
 }
 
-TEST_F(ServiceContextTest, ValidButBadURIsFailToConnect) {
+TEST(MongoURI, ValidButBadURIsFailToConnect) {
     // "invalid" is a TLD that cannot exit on the public internet (see rfc2606). It should always
     // parse as a valid URI, but connecting should always fail.
     auto sw_uri = MongoURI::parse("mongodb://user:pass@hostname.invalid:12345");
@@ -640,7 +480,7 @@ TEST_F(ServiceContextTest, ValidButBadURIsFailToConnect) {
     ASSERT_TRUE(uri.isValid());
 
     std::string errmsg;
-    auto dbclient = uri.connect(StringData(), errmsg);
+    auto dbclient = uri.connect(mongo::StringData(), errmsg);
     ASSERT_EQ(dbclient, static_cast<decltype(dbclient)>(nullptr));
 }
 
@@ -657,7 +497,7 @@ TEST(MongoURI, CloneURIForServer) {
     auto& uriOptions = uri.getOptions();
     ASSERT_EQ(uriOptions.at("ssl"), "true");
 
-    auto clonedURI = uri.cloneURIForServer(HostAndPort{"localhost:27020"}, StringData());
+    auto clonedURI = uri.cloneURIForServer(mongo::HostAndPort{"localhost:27020"});
 
     ASSERT_EQ(clonedURI.type(), kMaster);
     ASSERT_TRUE(clonedURI.getSetName().empty());
@@ -687,7 +527,7 @@ TEST(MongoURI, specTests) {
         const auto testBson = getBsonFromJsonFile(file);
 
         for (const auto& testElement : testBson) {
-            ASSERT_EQ(testElement.type(), Object);
+            ASSERT_EQ(testElement.type(), mongo::Object);
             const auto test = testElement.Obj();
 
             // First extract the valid field and the uri field
@@ -698,13 +538,13 @@ TEST(MongoURI, specTests) {
 
             const auto uriDoc = test.getField("uri");
             ASSERT_FALSE(uriDoc.eoo());
-            ASSERT_EQ(uriDoc.type(), String);
+            ASSERT_EQ(uriDoc.type(), mongo::String);
             const auto uri = uriDoc.String();
 
             if (!valid) {
                 // This uri string is invalid --> parse the uri and ensure it fails
-                const InvalidURITestCase testCase = InvalidURITestCase{uri};
-                unittest::log() << "Testing URI: " << testCase.URI << '\n';
+                const InvalidURITestCase testCase = {uri};
+                mongo::unittest::log() << "Testing URI: " << testCase.URI << '\n';
                 auto cs_status = MongoURI::parse(testCase.URI);
                 ASSERT_NOT_OK(cs_status);
             } else {
@@ -715,8 +555,8 @@ TEST(MongoURI, specTests) {
 
                 const auto auth = test.getField("auth");
                 ASSERT_FALSE(auth.eoo());
-                if (auth.type() != jstNULL) {
-                    ASSERT_EQ(auth.type(), Object);
+                if (auth.type() != mongo::jstNULL) {
+                    ASSERT_EQ(auth.type(), mongo::Object);
                     const auto authObj = auth.embeddedObject();
                     database = returnStringFromElementOrNull(authObj.getField("db"));
                     username = returnStringFromElementOrNull(authObj.getField("username"));
@@ -726,41 +566,36 @@ TEST(MongoURI, specTests) {
                 // parse the hosts
                 const auto hosts = test.getField("hosts");
                 ASSERT_FALSE(hosts.eoo());
-                ASSERT_EQ(hosts.type(), Array);
+                ASSERT_EQ(hosts.type(), mongo::Array);
                 const auto numHosts = static_cast<size_t>(hosts.Obj().nFields());
 
                 // parse the options
-                ConnectionString::ConnectionType connectionType = kMaster;
+                mongo::ConnectionString::ConnectionType connectionType = kMaster;
                 size_t numOptions = 0;
                 std::string setName;
                 const auto optionsElement = test.getField("options");
                 ASSERT_FALSE(optionsElement.eoo());
-                MongoURI::OptionsMap options;
-                if (optionsElement.type() != jstNULL) {
-                    ASSERT_EQ(optionsElement.type(), Object);
+                if (optionsElement.type() != mongo::jstNULL) {
+                    ASSERT_EQ(optionsElement.type(), mongo::Object);
                     const auto optionsObj = optionsElement.Obj();
                     numOptions = optionsObj.nFields();
                     const auto replsetElement = optionsObj.getField("replicaSet");
                     if (!replsetElement.eoo()) {
-                        ASSERT_EQ(replsetElement.type(), String);
+                        ASSERT_EQ(replsetElement.type(), mongo::String);
                         setName = replsetElement.String();
                         connectionType = kSet;
                     }
-
-                    for (auto&& field : optionsElement.Obj()) {
-                        if (field.type() == String) {
-                            options[field.fieldNameStringData()] = field.String();
-                        } else if (field.isNumber()) {
-                            options[field.fieldNameStringData()] = std::to_string(field.Int());
-                        } else {
-                            MONGO_UNREACHABLE;
-                        }
-                    }
                 }
 
                 // Create the URITestCase abnd
-                const URITestCase testCase = {
-                    uri, username, password, connectionType, setName, numHosts, options, database};
+                const URITestCase testCase = {uri,
+                                              username,
+                                              password,
+                                              connectionType,
+                                              setName,
+                                              numHosts,
+                                              numOptions,
+                                              database};
                 testValidURIFormat(testCase);
             }
         }
@@ -768,6 +603,7 @@ TEST(MongoURI, specTests) {
 }
 
 TEST(MongoURI, srvRecordTest) {
+    using namespace mongo;
     enum Expectation : bool { success = true, failure = false };
     const struct {
         int lineNumber;
@@ -776,7 +612,7 @@ TEST(MongoURI, srvRecordTest) {
         std::string password;
         std::string database;
         std::vector<HostAndPort> hosts;
-        std::map<MongoURI::CaseInsensitiveString, std::string> options;
+        std::map<std::string, std::string> options;
         Expectation expectation;
     } tests[] = {
         // Test some non-SRV URIs to make sure that they do not perform expansions
@@ -804,7 +640,7 @@ TEST(MongoURI, srvRecordTest) {
          "",
          "",
          "",
-         {{"localhost.test.build.10gen.cc", 27017}, {"localhost.test.build.10gen.cc", 27018}},
+         {{"localhost.test.build.10gen.cc.", 27017}, {"localhost.test.build.10gen.cc.", 27018}},
          {{"ssl", "true"}},
          success},
 
@@ -814,7 +650,7 @@ TEST(MongoURI, srvRecordTest) {
          "",
          "",
          "",
-         {{"localhost.test.build.10gen.cc", 27017}, {"localhost.test.build.10gen.cc", 27018}},
+         {{"localhost.test.build.10gen.cc.", 27017}, {"localhost.test.build.10gen.cc.", 27018}},
          {{"ssl", "false"}},
          success},
 
@@ -825,11 +661,10 @@ TEST(MongoURI, srvRecordTest) {
          "",
          "",
          {
-             {"localhost.sub.test.build.10gen.cc", 27017},
+             {"localhost.sub.test.build.10gen.cc.", 27017},
          },
          {
-             {"ssl", "true"},
-             {"replicaSet", "repl0"},
+             {"ssl", "true"}, {"replicaSet", "repl0"},
          },
          success},
 
@@ -840,11 +675,10 @@ TEST(MongoURI, srvRecordTest) {
          "",
          "",
          {
-             {"localhost.sub.test.build.10gen.cc", 27017},
+             {"localhost.sub.test.build.10gen.cc.", 27017},
          },
          {
-             {"ssl", "true"},
-             {"replicaSet", "repl0"},
+             {"ssl", "true"}, {"replicaSet", "repl0"},
          },
          success},
 
@@ -854,7 +688,7 @@ TEST(MongoURI, srvRecordTest) {
          "user",
          "password",
          "database",
-         {{"localhost.test.build.10gen.cc", 27018}, {"localhost.test.build.10gen.cc", 27019}},
+         {{"localhost.test.build.10gen.cc.", 27018}, {"localhost.test.build.10gen.cc.", 27019}},
          {{"someOption", "someValue"}, {"someOtherOption", "someOtherValue"}, {"ssl", "true"}},
          success},
 
@@ -865,7 +699,7 @@ TEST(MongoURI, srvRecordTest) {
          "user",
          "password",
          "database",
-         {{"localhost.test.build.10gen.cc", 27017}},
+         {{"localhost.test.build.10gen.cc.", 27017}},
          {{"someOption", "someValue"}, {"someOtherOption", "someOtherValue"}, {"ssl", "true"}},
          success},
 
@@ -876,7 +710,7 @@ TEST(MongoURI, srvRecordTest) {
          "user",
          "password",
          "database",
-         {{"localhost.test.build.10gen.cc", 27017}},
+         {{"localhost.test.build.10gen.cc.", 27017}},
          {{"someOption", "someValue"},
           {"someOtherOption", "someOtherValue"},
           {"replicaSet", "repl0"},
@@ -890,7 +724,7 @@ TEST(MongoURI, srvRecordTest) {
          "user",
          "password",
          "database",
-         {{"localhost.test.build.10gen.cc", 27017}},
+         {{"localhost.test.build.10gen.cc.", 27017}},
          {{"someOption", "someValue"},
           {"someOtherOption", "someOtherValue"},
           {"replicaSet", "repl0"},
@@ -990,20 +824,41 @@ TEST(MongoURI, srvRecordTest) {
     for (const auto& test : tests) {
         auto rs = MongoURI::parse(test.uri);
         if (test.expectation == failure) {
-            ASSERT_FALSE(rs.getStatus().isOK())
-                << "Failing URI: " << test.uri << " data on line: " << test.lineNumber;
+            ASSERT_FALSE(rs.getStatus().isOK()) << "Failing URI: " << test.uri
+                                                << " data on line: " << test.lineNumber;
             continue;
         }
         ASSERT_OK(rs.getStatus()) << "Failed on URI: " << test.uri
                                   << " data on line: " << test.lineNumber;
         auto rv = rs.getValue();
-        ASSERT_EQ(rv.getUser(), test.user)
-            << "Failed on URI: " << test.uri << " data on line: " << test.lineNumber;
-        ASSERT_EQ(rv.getPassword(), test.password)
-            << "Failed on URI: " << test.uri << " data on line : " << test.lineNumber;
-        ASSERT_EQ(rv.getDatabase(), test.database)
-            << "Failed on URI: " << test.uri << " data on line : " << test.lineNumber;
-        compareOptions(test.lineNumber, test.uri, rv.getOptions(), test.options);
+        ASSERT_EQ(rv.getUser(), test.user) << "Failed on URI: " << test.uri
+                                           << " data on line: " << test.lineNumber;
+        ASSERT_EQ(rv.getPassword(), test.password) << "Failed on URI: " << test.uri
+                                                   << " data on line : " << test.lineNumber;
+        ASSERT_EQ(rv.getDatabase(), test.database) << "Failed on URI: " << test.uri
+                                                   << " data on line : " << test.lineNumber;
+        std::vector<std::pair<std::string, std::string>> options(begin(rv.getOptions()),
+                                                                 end(rv.getOptions()));
+        std::sort(begin(options), end(options));
+        std::vector<std::pair<std::string, std::string>> expectedOptions(begin(test.options),
+                                                                         end(test.options));
+        std::sort(begin(expectedOptions), end(expectedOptions));
+
+        for (std::size_t i = 0; i < std::min(options.size(), expectedOptions.size()); ++i) {
+            if (options[i] != expectedOptions[i]) {
+                mongo::unittest::log() << "Option: \"" << options[i].first << "="
+                                       << options[i].second << "\" doesn't equal: \""
+                                       << expectedOptions[i].first << "="
+                                       << expectedOptions[i].second << "\""
+                                       << " data on line: " << test.lineNumber << std::endl;
+                std::cerr << "Failing URI: \"" << test.uri << "\""
+                          << " data on line: " << test.lineNumber << std::endl;
+                ASSERT(false);
+            }
+        }
+        ASSERT_EQ(options.size(), expectedOptions.size()) << "Failing URI: "
+                                                          << " data on line: " << test.lineNumber
+                                                          << test.uri;
 
         std::vector<HostAndPort> hosts(begin(rv.getServers()), end(rv.getServers()));
         std::sort(begin(hosts), end(hosts));
@@ -1011,9 +866,9 @@ TEST(MongoURI, srvRecordTest) {
         std::sort(begin(expectedHosts), end(expectedHosts));
 
         for (std::size_t i = 0; i < std::min(hosts.size(), expectedHosts.size()); ++i) {
-            ASSERT_EQ(hosts[i], expectedHosts[i])
-                << "Failed on URI: " << test.uri << " at host number" << i
-                << " data on line: " << test.lineNumber;
+            ASSERT_EQ(hosts[i], expectedHosts[i]) << "Failed on URI: " << test.uri
+                                                  << " at host number" << i
+                                                  << " data on line: " << test.lineNumber;
         }
         ASSERT_TRUE(hosts.size() == expectedHosts.size())
             << "Failed on URI: " << test.uri << " Found " << hosts.size() << " hosts, expected "
