@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -31,13 +32,14 @@
 
 #include <string>
 
+#include "mongo/base/disallow_copying.h"
 #include "mongo/base/status.h"
 #include "mongo/db/auth/authz_manager_external_state.h"
 #include "mongo/db/auth/role_graph.h"
 #include "mongo/db/auth/role_name.h"
 #include "mongo/db/auth/user_name.h"
-#include "mongo/platform/mutex.h"
 #include "mongo/stdx/functional.h"
+#include "mongo/stdx/mutex.h"
 
 namespace mongo {
 
@@ -50,8 +52,7 @@ class Document;
  * and user information are stored locally.
  */
 class AuthzManagerExternalStateLocal : public AuthzManagerExternalState {
-    AuthzManagerExternalStateLocal(const AuthzManagerExternalStateLocal&) = delete;
-    AuthzManagerExternalStateLocal& operator=(const AuthzManagerExternalStateLocal&) = delete;
+    MONGO_DISALLOW_COPYING(AuthzManagerExternalStateLocal);
 
 public:
     virtual ~AuthzManagerExternalStateLocal() = default;
@@ -60,7 +61,7 @@ public:
 
     Status getStoredAuthorizationVersion(OperationContext* opCtx, int* outVersion) override;
     Status getUserDescription(OperationContext* opCtx,
-                              const UserRequest& userRequest,
+                              const UserName& userName,
                               BSONObj* result) override;
     Status getRoleDescription(OperationContext* opCtx,
                               const RoleName& roleName,
@@ -73,7 +74,7 @@ public:
                                AuthenticationRestrictionsFormat,
                                BSONObj* result) override;
     Status getRoleDescriptionsForDB(OperationContext* opCtx,
-                                    StringData dbname,
+                                    const std::string& dbname,
                                     PrivilegeFormat showPrivileges,
                                     AuthenticationRestrictionsFormat,
                                     bool showBuiltinRoles,
@@ -103,12 +104,11 @@ public:
                          const BSONObj& projection,
                          const stdx::function<void(const BSONObj&)>& resultProcessor) = 0;
 
-    void logOp(OperationContext* opCtx,
-               AuthorizationManagerImpl* authManager,
-               const char* op,
-               const NamespaceString& ns,
-               const BSONObj& o,
-               const BSONObj* o2) final;
+    virtual void logOp(OperationContext* opCtx,
+                       const char* op,
+                       const NamespaceString& ns,
+                       const BSONObj& o,
+                       const BSONObj* o2);
 
     /**
      * Takes a user document, and processes it with the RoleGraph, in order to recursively
@@ -161,7 +161,7 @@ private:
     /**
      * Guards _roleGraphState and _roleGraph.
      */
-    Mutex _roleGraphMutex = MONGO_MAKE_LATCH("AuthzManagerExternalStateLocal::_roleGraphMutex");
+    stdx::mutex _roleGraphMutex;
 };
 
 }  // namespace mongo
