@@ -1,23 +1,25 @@
-/*
- *    Copyright (C) 2016 MongoDB Inc.
+
+/**
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects for
+ *    must comply with the Server Side Public License in all respects for
  *    all of the code used other than as permitted herein. If you modify file(s)
  *    with this exception, you may extend this exception to your version of the
  *    file(s), but you are not obligated to do so. If you do not wish to do so,
@@ -192,8 +194,8 @@ SCRAMStepsResult runSteps(NativeSaslAuthenticationSession* saslServerSession,
         if (result.status != Status::OK()) {
             return result;
         }
-        std::cout << result.outcome.toString() << ": " << clientOutput << std::endl;
         interposers.execute(result.outcome, clientOutput);
+        std::cout << result.outcome.toString() << ": " << clientOutput << std::endl;
         result.outcome.next();
 
         // Server step
@@ -218,7 +220,7 @@ protected:
 
     ServiceContextNoop serviceContext;
     ServiceContextNoop::UniqueClient client;
-    ServiceContextNoop::UniqueOperationContext txn;
+    ServiceContextNoop::UniqueOperationContext opCtx;
 
     AuthzManagerExternalStateMock* authzManagerExternalState;
     std::unique_ptr<AuthorizationManager> authzManager;
@@ -229,7 +231,7 @@ protected:
 
     void setUp() {
         client = serviceContext.makeClient("test");
-        txn = serviceContext.makeOperationContext(client.get());
+        opCtx = serviceContext.makeOperationContext(client.get());
 
         auto uniqueAuthzManagerExternalStateMock =
             stdx::make_unique<AuthzManagerExternalStateMock>();
@@ -240,8 +242,9 @@ protected:
             stdx::make_unique<AuthzSessionExternalStateMock>(authzManager.get()));
 
         saslServerSession = stdx::make_unique<NativeSaslAuthenticationSession>(authzSession.get());
-        saslServerSession->setOpCtxt(txn.get());
-        saslServerSession->start("test", "SCRAM-SHA-1", "mongodb", "MockServer.test", 1, false);
+        saslServerSession->setOpCtxt(opCtx.get());
+        saslServerSession->start("test", "SCRAM-SHA-1", "mongodb", "MockServer.test", 1, false)
+            .transitional_ignore();
         saslClientSession = stdx::make_unique<NativeSaslClientSession>();
         saslClientSession->setParameter(NativeSaslClientSession::parameterMechanism, "SCRAM-SHA-1");
         saslClientSession->setParameter(NativeSaslClientSession::parameterServiceName, "mongodb");
@@ -253,8 +256,10 @@ protected:
 };
 
 TEST_F(SCRAMSHA1Fixture, testServerStep1DoesNotIncludeNonceFromClientStep1) {
-    authzManagerExternalState->insertPrivilegeDocument(
-        txn.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj());
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj())
+        .transitional_ignore();
 
     saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
     saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
@@ -276,8 +281,10 @@ TEST_F(SCRAMSHA1Fixture, testServerStep1DoesNotIncludeNonceFromClientStep1) {
 }
 
 TEST_F(SCRAMSHA1Fixture, testClientStep2DoesNotIncludeNonceFromServerStep1) {
-    authzManagerExternalState->insertPrivilegeDocument(
-        txn.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj());
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj())
+        .transitional_ignore();
 
     saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
     saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
@@ -298,8 +305,10 @@ TEST_F(SCRAMSHA1Fixture, testClientStep2DoesNotIncludeNonceFromServerStep1) {
 }
 
 TEST_F(SCRAMSHA1Fixture, testClientStep2GivesBadProof) {
-    authzManagerExternalState->insertPrivilegeDocument(
-        txn.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj());
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj())
+        .transitional_ignore();
 
     saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
     saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
@@ -323,8 +332,10 @@ TEST_F(SCRAMSHA1Fixture, testClientStep2GivesBadProof) {
 }
 
 TEST_F(SCRAMSHA1Fixture, testServerStep2GivesBadVerifier) {
-    authzManagerExternalState->insertPrivilegeDocument(
-        txn.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj());
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj())
+        .transitional_ignore();
 
     saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
     saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
@@ -358,8 +369,10 @@ TEST_F(SCRAMSHA1Fixture, testServerStep2GivesBadVerifier) {
 
 
 TEST_F(SCRAMSHA1Fixture, testSCRAM) {
-    authzManagerExternalState->insertPrivilegeDocument(
-        txn.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj());
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj())
+        .transitional_ignore();
 
     saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
     saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
@@ -370,9 +383,78 @@ TEST_F(SCRAMSHA1Fixture, testSCRAM) {
     ASSERT_EQ(goalState, runSteps(saslServerSession.get(), saslClientSession.get()));
 }
 
+TEST_F(SCRAMSHA1Fixture, testSCRAMWithChannelBindingSupportedByClient) {
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj())
+        .transitional_ignore();
+
+    saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
+    saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
+                                    createPasswordDigest("sajack", "sajack"));
+
+    ASSERT_OK(saslClientSession->initialize());
+
+    SCRAMMutators mutator;
+    mutator.setMutator(SaslTestState(SaslTestState::kClient, 1), [](std::string& clientMessage) {
+        clientMessage.replace(clientMessage.begin(), clientMessage.begin() + 1, "y");
+    });
+
+    ASSERT_EQ(goalState, runSteps(saslServerSession.get(), saslClientSession.get(), mutator));
+}
+
+TEST_F(SCRAMSHA1Fixture, testSCRAMWithChannelBindingRequiredByClient) {
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj())
+        .transitional_ignore();
+
+    saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
+    saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
+                                    createPasswordDigest("sajack", "sajack"));
+
+    ASSERT_OK(saslClientSession->initialize());
+
+    SCRAMMutators mutator;
+    mutator.setMutator(SaslTestState(SaslTestState::kClient, 1), [](std::string& clientMessage) {
+        clientMessage.replace(clientMessage.begin(), clientMessage.begin() + 1, "p=tls-unique");
+    });
+
+    ASSERT_EQ(
+        SCRAMStepsResult(SaslTestState(SaslTestState::kServer, 1),
+                         Status(ErrorCodes::BadValue, "Server does not support channel binding")),
+        runSteps(saslServerSession.get(), saslClientSession.get(), mutator));
+}
+
+TEST_F(SCRAMSHA1Fixture, testSCRAMWithInvalidChannelBinding) {
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj())
+        .transitional_ignore();
+
+    saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
+    saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
+                                    createPasswordDigest("sajack", "sajack"));
+
+    ASSERT_OK(saslClientSession->initialize());
+
+    SCRAMMutators mutator;
+    mutator.setMutator(SaslTestState(SaslTestState::kClient, 1), [](std::string& clientMessage) {
+        clientMessage.replace(clientMessage.begin(), clientMessage.begin() + 1, "v=illegalGarbage");
+    });
+
+    ASSERT_EQ(
+        SCRAMStepsResult(SaslTestState(SaslTestState::kServer, 1),
+                         Status(ErrorCodes::BadValue,
+                                "Incorrect SCRAM-SHA-1 client message prefix: v=illegalGarbage")),
+        runSteps(saslServerSession.get(), saslClientSession.get(), mutator));
+}
+
 TEST_F(SCRAMSHA1Fixture, testNULLInPassword) {
-    authzManagerExternalState->insertPrivilegeDocument(
-        txn.get(), generateSCRAMUserDocument("sajack", "saj\0ack"), BSONObj());
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("sajack", "saj\0ack"), BSONObj())
+        .transitional_ignore();
 
     saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
     saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
@@ -385,8 +467,10 @@ TEST_F(SCRAMSHA1Fixture, testNULLInPassword) {
 
 
 TEST_F(SCRAMSHA1Fixture, testCommasInUsernameAndPassword) {
-    authzManagerExternalState->insertPrivilegeDocument(
-        txn.get(), generateSCRAMUserDocument("s,a,jack", "s,a,jack"), BSONObj());
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("s,a,jack", "s,a,jack"), BSONObj())
+        .transitional_ignore();
 
     saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "s,a,jack");
     saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
@@ -410,8 +494,10 @@ TEST_F(SCRAMSHA1Fixture, testIncorrectUser) {
 }
 
 TEST_F(SCRAMSHA1Fixture, testIncorrectPassword) {
-    authzManagerExternalState->insertPrivilegeDocument(
-        txn.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj());
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateSCRAMUserDocument("sajack", "sajack"), BSONObj())
+        .transitional_ignore();
 
     saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
     saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
@@ -426,8 +512,10 @@ TEST_F(SCRAMSHA1Fixture, testIncorrectPassword) {
 }
 
 TEST_F(SCRAMSHA1Fixture, testMONGODBCR) {
-    authzManagerExternalState->insertPrivilegeDocument(
-        txn.get(), generateMONGODBCRUserDocument("sajack", "sajack"), BSONObj());
+    authzManagerExternalState
+        ->insertPrivilegeDocument(
+            opCtx.get(), generateMONGODBCRUserDocument("sajack", "sajack"), BSONObj())
+        .transitional_ignore();
 
     saslClientSession->setParameter(NativeSaslClientSession::parameterUser, "sajack");
     saslClientSession->setParameter(NativeSaslClientSession::parameterPassword,
