@@ -1,28 +1,31 @@
-/*    Copyright 2013 10gen Inc.
+
+/**
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects
- *    for all of the code used other than as permitted herein. If you modify
- *    file(s) with this exception, you may extend this exception to your
- *    version of the file(s), but you are not obligated to do so. If you do not
- *    wish to do so, delete this exception statement from your version. If you
- *    delete this exception statement from all source files in the program,
- *    then also delete it in the license file.
+ *    must comply with the Server Side Public License in all respects for
+ *    all of the code used other than as permitted herein. If you modify file(s)
+ *    with this exception, you may extend this exception to your version of the
+ *    file(s), but you are not obligated to do so. If you do not wish to do so,
+ *    delete this exception statement from your version. If you delete this
+ *    exception statement from all source files in the program, then also delete
+ *    it in the license file.
  */
 
 #pragma once
@@ -33,6 +36,7 @@
 #include "mongo/base/disallow_copying.h"
 #include "mongo/db/auth/privilege.h"
 #include "mongo/db/auth/resource_pattern.h"
+#include "mongo/db/auth/restriction_set.h"
 #include "mongo/db/auth/role_name.h"
 #include "mongo/db/auth/user_name.h"
 #include "mongo/platform/atomic_word.h"
@@ -73,9 +77,9 @@ public:
             // 128bit -> 16octets -> * 4/3 -> 21.333 -> padded to 24
             const size_t kEncodedSaltLength = 24;
 
-            return (salt.size() == kEncodedSaltLength) &&
-                (serverKey.size() == kEncodedSHA1Length) &&
-                (storedKey.size() == kEncodedSHA1Length);
+            return (salt.size() == kEncodedSaltLength) && base64::validate(salt) &&
+                (serverKey.size() == kEncodedSHA1Length) && base64::validate(serverKey) &&
+                (storedKey.size() == kEncodedSHA1Length) && base64::validate(storedKey);
         }
     };
     struct CredentialData {
@@ -105,6 +109,11 @@ public:
      */
     const UserName& getName() const;
 
+    /**
+     * Returns a digest of the user's identity
+     */
+    const SHA256Block& getDigest() const;
+
     /**
      * Returns an iterator over the names of the user's direct roles
      */
@@ -150,11 +159,6 @@ public:
      */
     uint32_t getRefCount() const;
 
-    /**
-     * Clones this user into a new, valid User object with refcount of 0.
-     */
-    User* clone() const;
-
     // Mutators below.  Mutation functions should *only* be called by the AuthorizationManager
 
     /**
@@ -198,6 +202,19 @@ public:
      */
     void addPrivileges(const PrivilegeVector& privileges);
 
+    /**
+     * Replaces any existing authentication restrictions with "restrictions".
+     */
+    void setRestrictions(RestrictionDocuments restrictions) &;
+
+    /**
+     * Gets any set authentication restrictions.
+     */
+    const RestrictionDocuments& getRestrictions() const& noexcept {
+        return _restrictions;
+    }
+    void getRestrictions() && = delete;
+
     /**
      * Marks this instance of the User object as invalid, most likely because information about
      * the user has been updated and needs to be reloaded from the AuthorizationManager.
@@ -230,6 +247,9 @@ private:
 
     UserName _name;
 
+    // Digest of the full username
+    SHA256Block _digest;
+
     // Maps resource name to privilege on that resource
     ResourcePrivilegeMap _privileges;
 
@@ -242,6 +262,9 @@ private:
     // Credential information.
     CredentialData _credentials;
 
+    // Restrictions which must be met by a Client in order to authenticate as this user.
+    RestrictionDocuments _restrictions;
+
     // _refCount and _isInvalidated are modified exclusively by the AuthorizationManager
     // _isInvalidated can be read by any consumer of User, but _refCount can only be
     // meaningfully read by the AuthorizationManager, as _refCount is guarded by the AM's _lock
