@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -34,11 +35,8 @@
 #include <string>
 
 
-#include "mongo/base/clonable_ptr.h"
-#include "mongo/base/status_with.h"
+#include "mongo/base/disallow_copying.h"
 #include "mongo/base/string_data.h"
-#include "mongo/bson/bsonelement.h"
-#include "mongo/bson/bsonobjbuilder.h"
 
 namespace mongo {
 
@@ -52,18 +50,6 @@ public:
     UserName() : _splitPoint(0) {}
     UserName(StringData user, StringData dbname);
 
-    /**
-     * Parses a string of the form "db.username" into a UserName object.
-     */
-    static StatusWith<UserName> parse(StringData userNameStr);
-
-    /*
-     * These methods support parsing usernames from IDL
-     */
-    static UserName parseFromBSON(const BSONElement& elem);
-    void serializeToBSON(StringData fieldName, BSONObjBuilder* bob) const;
-    void serializeToBSON(BSONArrayBuilder* bob) const;
-
     /**
      * Gets the user part of a UserName.
      */
@@ -85,13 +71,6 @@ public:
         return _fullName;
     }
 
-    /**
-     * Gets the full unambiguous unique name of a user as a string, formatted as "db.user"
-     */
-    std::string getUnambiguousName() const {
-        return str::stream() << getDB() << "." << getUser();
-    }
-
     /**
      * Stringifies the object, for logging/debugging.
      */
@@ -111,14 +90,7 @@ public:
         return getUser() < rhs.getUser() || (getUser() == rhs.getUser() && getDB() < rhs.getDB());
     }
 
-    template <typename H>
-    friend H AbslHashValue(H h, const UserName& userName) {
-        return H::combine(std::move(h), userName.getFullName());
-    }
-
 private:
-    void _serializeToSubObj(BSONObjBuilder* sub) const;
-
     std::string _fullName;  // The full name, stored as a string.  "user@db".
     size_t _splitPoint;     // The index of the "@" separating the user and db name parts.
 };
@@ -131,11 +103,13 @@ std::ostream& operator<<(std::ostream& os, const UserName& name);
 class UserNameIterator {
 public:
     class Impl {
+        MONGO_DISALLOW_COPYING(Impl);
+
     public:
-        Impl() = default;
+        Impl(){};
         virtual ~Impl(){};
-        std::unique_ptr<Impl> clone() const {
-            return std::unique_ptr<Impl>(doClone());
+        static Impl* clone(Impl* orig) {
+            return orig ? orig->doClone() : NULL;
         }
         virtual bool more() const = 0;
         virtual const UserName& get() const = 0;
@@ -146,8 +120,14 @@ public:
         virtual Impl* doClone() const = 0;
     };
 
-    UserNameIterator() = default;
-    explicit UserNameIterator(std::unique_ptr<Impl> impl) : _impl(std::move(impl)) {}
+    UserNameIterator() : _impl(nullptr) {}
+    UserNameIterator(const UserNameIterator& other) : _impl(Impl::clone(other._impl.get())) {}
+    explicit UserNameIterator(Impl* impl) : _impl(impl) {}
+
+    UserNameIterator& operator=(const UserNameIterator& other) {
+        _impl.reset(Impl::clone(other._impl.get()));
+        return *this;
+    }
 
     bool more() const {
         return _impl.get() && _impl->more();
@@ -168,27 +148,29 @@ public:
     }
 
 private:
-    clonable_ptr<Impl> _impl;
+    std::unique_ptr<Impl> _impl;
 };
 
 
 template <typename ContainerIterator>
 class UserNameContainerIteratorImpl : public UserNameIterator::Impl {
+    MONGO_DISALLOW_COPYING(UserNameContainerIteratorImpl);
+
 public:
     UserNameContainerIteratorImpl(const ContainerIterator& begin, const ContainerIterator& end)
         : _curr(begin), _end(end) {}
-    ~UserNameContainerIteratorImpl() override {}
-    bool more() const override {
+    virtual ~UserNameContainerIteratorImpl() {}
+    virtual bool more() const {
         return _curr != _end;
     }
-    const UserName& next() override {
+    virtual const UserName& next() {
         return *(_curr++);
     }
-    const UserName& get() const override {
+    virtual const UserName& get() const {
         return *_curr;
     }
-    UserNameIterator::Impl* doClone() const override {
-        return new UserNameContainerIteratorImpl(*this);
+    virtual UserNameIterator::Impl* doClone() const {
+        return new UserNameContainerIteratorImpl(_curr, _end);
     }
 
 private:
@@ -199,8 +181,7 @@ private:
 template <typename ContainerIterator>
 UserNameIterator makeUserNameIterator(const ContainerIterator& begin,
                                       const ContainerIterator& end) {
-    return UserNameIterator(
-        std::make_unique<UserNameContainerIteratorImpl<ContainerIterator>>(begin, end));
+    return UserNameIterator(new UserNameContainerIteratorImpl<ContainerIterator>(begin, end));
 }
 
 template <typename Container>
@@ -208,13 +189,4 @@ UserNameIterator makeUserNameIteratorForContainer(const Container& container) {
     return makeUserNameIterator(container.begin(), container.end());
 }
 
-template <typename Container>
-Container userNameIteratorToContainer(UserNameIterator it) {
-    Container container;
-    while (it.more()) {
-        container.emplace_back(it.next());
-    }
-    return container;
-}
-
 }  // namespace mongo
