@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -29,11 +30,9 @@
 
 #include "mongo/platform/basic.h"
 
-#include <memory>
 #include <set>
 
 #include "mongo/db/catalog/create_collection.h"
-#include "mongo/db/catalog/database_holder.h"
 #include "mongo/db/catalog/drop_database.h"
 #include "mongo/db/client.h"
 #include "mongo/db/concurrency/write_conflict_exception.h"
@@ -42,7 +41,6 @@
 #include "mongo/db/namespace_string.h"
 #include "mongo/db/op_observer.h"
 #include "mongo/db/op_observer_noop.h"
-#include "mongo/db/op_observer_registry.h"
 #include "mongo/db/operation_context.h"
 #include "mongo/db/repl/drop_pending_collection_reaper.h"
 #include "mongo/db/repl/oplog.h"
@@ -51,9 +49,10 @@
 #include "mongo/db/repl/replication_coordinator_mock.h"
 #include "mongo/db/repl/storage_interface_mock.h"
 #include "mongo/db/service_context_d_test_fixture.h"
+#include "mongo/stdx/memory.h"
 #include "mongo/unittest/unittest.h"
 #include "mongo/util/assert_util.h"
-#include "mongo/util/str.h"
+#include "mongo/util/mongoutils/str.h"
 
 namespace {
 
@@ -67,19 +66,14 @@ using namespace mongo;
 class OpObserverMock : public OpObserverNoop {
 public:
     void onDropDatabase(OperationContext* opCtx, const std::string& dbName) override;
-
-    using OpObserver::onDropCollection;
     repl::OpTime onDropCollection(OperationContext* opCtx,
                                   const NamespaceString& collectionName,
-                                  OptionalCollectionUUID uuid,
-                                  std::uint64_t numRecords,
-                                  CollectionDropType dropType) override;
+                                  OptionalCollectionUUID uuid) override;
 
     std::set<std::string> droppedDatabaseNames;
     std::set<NamespaceString> droppedCollectionNames;
     Database* db = nullptr;
     bool onDropCollectionThrowsException = false;
-    const repl::OpTime dropOpTime = {Timestamp(Seconds(100), 1U), 1LL};
 };
 
 void OpObserverMock::onDropDatabase(OperationContext* opCtx, const std::string& dbName) {
@@ -91,13 +85,9 @@ void OpObserverMock::onDropDatabase(OperationContext* opCtx, const std::string&
 
 repl::OpTime OpObserverMock::onDropCollection(OperationContext* opCtx,
                                               const NamespaceString& collectionName,
-                                              OptionalCollectionUUID uuid,
-                                              std::uint64_t numRecords,
-                                              const CollectionDropType dropType) {
+                                              OptionalCollectionUUID uuid) {
     ASSERT_TRUE(opCtx->lockState()->inAWriteUnitOfWork());
-    auto opTime =
-        OpObserverNoop::onDropCollection(opCtx, collectionName, uuid, numRecords, dropType);
-    invariant(opTime.isNull());
+    auto opTime = OpObserverNoop::onDropCollection(opCtx, collectionName, uuid);
     // Do not update 'droppedCollectionNames' if OpObserverNoop::onDropCollection() throws.
     droppedCollectionNames.insert(collectionName);
 
@@ -109,8 +99,7 @@ repl::OpTime OpObserverMock::onDropCollection(OperationContext* opCtx,
     uassert(
         ErrorCodes::OperationFailed, "onDropCollection() failed", !onDropCollectionThrowsException);
 
-    OpObserver::Times::get(opCtx).reservedOpTimes.push_back(dropOpTime);
-    return {};
+    return opTime;
 }
 
 class DropDatabaseTest : public ServiceContextMongoDTest {
@@ -140,26 +129,25 @@ void DropDatabaseTest::setUp() {
     auto service = getServiceContext();
     _opCtx = cc().makeOperationContext();
 
-    repl::StorageInterface::set(service, std::make_unique<repl::StorageInterfaceMock>());
+    repl::StorageInterface::set(service, stdx::make_unique<repl::StorageInterfaceMock>());
     repl::DropPendingCollectionReaper::set(
         service,
-        std::make_unique<repl::DropPendingCollectionReaper>(repl::StorageInterface::get(service)));
+        stdx::make_unique<repl::DropPendingCollectionReaper>(repl::StorageInterface::get(service)));
 
     // Set up ReplicationCoordinator and create oplog.
-    auto replCoord = std::make_unique<repl::ReplicationCoordinatorMock>(service);
+    auto replCoord = stdx::make_unique<repl::ReplicationCoordinatorMock>(service);
     _replCoord = replCoord.get();
     repl::ReplicationCoordinator::set(service, std::move(replCoord));
+    repl::setOplogCollectionName();
     repl::createOplog(_opCtx.get());
 
     // Ensure that we are primary.
     ASSERT_OK(_replCoord->setFollowerMode(repl::MemberState::RS_PRIMARY));
 
     // Use OpObserverMock to track notifications for collection and database drops.
-    OpObserverRegistry* opObserverRegistry =
-        dynamic_cast<OpObserverRegistry*>(service->getOpObserver());
-    auto mockObserver = std::make_unique<OpObserverMock>();
-    _opObserver = mockObserver.get();
-    opObserverRegistry->addObserver(std::move(mockObserver));
+    auto opObserver = stdx::make_unique<OpObserverMock>();
+    _opObserver = opObserver.get();
+    service->setOpObserver(std::move(opObserver));
 
     _nss = NamespaceString("test.foo");
 }
@@ -182,12 +170,12 @@ void DropDatabaseTest::tearDown() {
  */
 void _createCollection(OperationContext* opCtx, const NamespaceString& nss) {
     writeConflictRetry(opCtx, "testDropCollection", nss.ns(), [=] {
-        AutoGetDb autoDb(opCtx, nss.db(), MODE_X);
-        auto db = autoDb.ensureDbExists();
+        AutoGetOrCreateDb autoDb(opCtx, nss.db(), MODE_X);
+        auto db = autoDb.getDb();
         ASSERT_TRUE(db);
 
         WriteUnitOfWork wuow(opCtx);
-        ASSERT_TRUE(db->createCollection(opCtx, nss));
+        ASSERT_TRUE(db->createCollection(opCtx, nss.ns()));
         wuow.commit();
     });
 
@@ -198,29 +186,24 @@ void _createCollection(OperationContext* opCtx, const NamespaceString& nss) {
  * Removes database from catalog, bypassing dropDatabase().
  */
 void _removeDatabaseFromCatalog(OperationContext* opCtx, StringData dbName) {
+    Lock::GlobalWrite lk(opCtx);
     AutoGetDb autoDB(opCtx, dbName, MODE_X);
     auto db = autoDB.getDb();
-    // dropDatabase can call awaitReplication more than once, so do not attempt to drop the database
-    // twice.
-    if (db) {
-        auto databaseHolder = DatabaseHolder::get(opCtx);
-        databaseHolder->dropDb(opCtx, db);
-    }
+    ASSERT_TRUE(db);
+    Database::dropDatabase(opCtx, db);
 }
 
 TEST_F(DropDatabaseTest, DropDatabaseReturnsNamespaceNotFoundIfDatabaseDoesNotExist) {
     ASSERT_FALSE(AutoGetDb(_opCtx.get(), _nss.db(), MODE_X).getDb());
-    ASSERT_EQUALS(ErrorCodes::NamespaceNotFound,
-                  dropDatabaseForApplyOps(_opCtx.get(), _nss.db().toString()));
+    ASSERT_EQUALS(ErrorCodes::NamespaceNotFound, dropDatabase(_opCtx.get(), _nss.db().toString()));
 }
 
-TEST_F(DropDatabaseTest, DropDatabaseReturnsNotWritablePrimaryIfNotPrimary) {
+TEST_F(DropDatabaseTest, DropDatabaseReturnsNotMasterIfNotPrimary) {
     _createCollection(_opCtx.get(), _nss);
     ASSERT_OK(_replCoord->setFollowerMode(repl::MemberState::RS_SECONDARY));
     ASSERT_TRUE(_opCtx->writesAreReplicated());
     ASSERT_FALSE(_replCoord->canAcceptWritesForDatabase(_opCtx.get(), _nss.db()));
-    ASSERT_EQUALS(ErrorCodes::NotWritablePrimary,
-                  dropDatabaseForApplyOps(_opCtx.get(), _nss.db().toString()));
+    ASSERT_EQUALS(ErrorCodes::NotMaster, dropDatabase(_opCtx.get(), _nss.db().toString()));
 }
 
 /**
@@ -241,7 +224,7 @@ void _testDropDatabase(OperationContext* opCtx,
     ASSERT_TRUE(db);
     opObserver->db = db;
 
-    ASSERT_OK(dropDatabaseForApplyOps(opCtx, nss.db().toString()));
+    ASSERT_OK(dropDatabase(opCtx, nss.db().toString()));
     ASSERT_FALSE(AutoGetDb(opCtx, nss.db(), MODE_X).getDb());
     opObserver->db = nullptr;
 
@@ -270,7 +253,7 @@ TEST_F(DropDatabaseTest, DropDatabaseWaitsForDropPendingCollectionOpTimeIfNoColl
 
     // Update ReplicationCoordinatorMock so that we record the optime passed to awaitReplication().
     _replCoord->setAwaitReplicationReturnValueFunction(
-        [&clientLastOpTime, this](OperationContext*, const repl::OpTime& opTime) {
+        [&clientLastOpTime, this](const repl::OpTime& opTime) {
             clientLastOpTime = opTime;
             ASSERT_GREATER_THAN(clientLastOpTime, repl::OpTime());
             return repl::ReplicationCoordinator::StatusAndDuration(Status::OK(), Milliseconds(0));
@@ -285,19 +268,27 @@ TEST_F(DropDatabaseTest, DropDatabaseWaitsForDropPendingCollectionOpTimeIfNoColl
 
 TEST_F(DropDatabaseTest, DropDatabasePassedThroughAwaitReplicationErrorForDropPendingCollection) {
     // Update ReplicationCoordinatorMock so that we record the optime passed to awaitReplication().
-    _replCoord->setAwaitReplicationReturnValueFunction(
-        [this](OperationContext*, const repl::OpTime& opTime) {
-            ASSERT_GREATER_THAN(opTime, repl::OpTime());
-            return repl::ReplicationCoordinator::StatusAndDuration(
-                Status(ErrorCodes::WriteConcernFailed, ""), Milliseconds(0));
-        });
+    _replCoord->setAwaitReplicationReturnValueFunction([this](const repl::OpTime& opTime) {
+        ASSERT_GREATER_THAN(opTime, repl::OpTime());
+        return repl::ReplicationCoordinator::StatusAndDuration(
+            Status(ErrorCodes::WriteConcernFailed, ""), Milliseconds(0));
+    });
 
     repl::OpTime dropOpTime(Timestamp(Seconds(100), 0), 1LL);
     auto dpns = _nss.makeDropPendingNamespace(dropOpTime);
     _createCollection(_opCtx.get(), dpns);
 
-    ASSERT_EQUALS(ErrorCodes::WriteConcernFailed,
-                  dropDatabaseForApplyOps(_opCtx.get(), _nss.db().toString()));
+    ASSERT_EQUALS(ErrorCodes::WriteConcernFailed, dropDatabase(_opCtx.get(), _nss.db().toString()));
+}
+
+TEST_F(DropDatabaseTest, DropDatabaseSkipsSystemDotIndexesCollectionWhenDroppingCollections) {
+    NamespaceString systemDotIndexesNss(_nss.getSystemIndexesCollection());
+    _testDropDatabase(_opCtx.get(), _opObserver, systemDotIndexesNss, false);
+}
+
+TEST_F(DropDatabaseTest, DropDatabaseSkipsSystemNamespacesCollectionWhenDroppingCollections) {
+    NamespaceString systemNamespacesNss(_nss.getSisterNS("system.namespaces"));
+    _testDropDatabase(_opCtx.get(), _opObserver, systemNamespacesNss, false);
 }
 
 TEST_F(DropDatabaseTest, DropDatabaseSkipsSystemProfileCollectionWhenDroppingCollections) {
@@ -316,7 +307,7 @@ TEST_F(DropDatabaseTest, DropDatabaseResetsDropPendingStateOnException) {
     auto db = autoDb.getDb();
     ASSERT_TRUE(db);
 
-    ASSERT_THROWS_CODE_AND_WHAT(dropDatabaseForApplyOps(_opCtx.get(), _nss.db().toString()),
+    ASSERT_THROWS_CODE_AND_WHAT(dropDatabase(_opCtx.get(), _nss.db().toString()).ignore(),
                                 AssertionException,
                                 ErrorCodes::OperationFailed,
                                 "onDropCollection() failed");
@@ -331,8 +322,7 @@ void _testDropDatabaseResetsDropPendingStateIfAwaitReplicationFails(OperationCon
 
     ASSERT_TRUE(AutoGetDb(opCtx, nss.db(), MODE_X).getDb());
 
-    ASSERT_EQUALS(ErrorCodes::WriteConcernFailed,
-                  dropDatabaseForApplyOps(opCtx, nss.db().toString()));
+    ASSERT_EQUALS(ErrorCodes::WriteConcernFailed, dropDatabase(opCtx, nss.db().toString()));
 
     AutoGetDb autoDb(opCtx, nss.db(), MODE_X);
     auto db = autoDb.getDb();
@@ -347,7 +337,7 @@ void _testDropDatabaseResetsDropPendingStateIfAwaitReplicationFails(OperationCon
 TEST_F(DropDatabaseTest,
        DropDatabaseResetsDropPendingStateIfAwaitReplicationFailsAndDatabaseIsPresent) {
     // Update ReplicationCoordinatorMock so that awaitReplication() fails.
-    _replCoord->setAwaitReplicationReturnValueFunction([](OperationContext*, const repl::OpTime&) {
+    _replCoord->setAwaitReplicationReturnValueFunction([](const repl::OpTime&) {
         return repl::ReplicationCoordinator::StatusAndDuration(
             Status(ErrorCodes::WriteConcernFailed, ""), Milliseconds(0));
     });
@@ -358,12 +348,11 @@ TEST_F(DropDatabaseTest,
 TEST_F(DropDatabaseTest,
        DropDatabaseResetsDropPendingStateIfAwaitReplicationFailsAndDatabaseIsMissing) {
     // Update ReplicationCoordinatorMock so that awaitReplication() fails.
-    _replCoord->setAwaitReplicationReturnValueFunction(
-        [this](OperationContext*, const repl::OpTime&) {
-            _removeDatabaseFromCatalog(_opCtx.get(), _nss.db());
-            return repl::ReplicationCoordinator::StatusAndDuration(
-                Status(ErrorCodes::WriteConcernFailed, ""), Milliseconds(0));
-        });
+    _replCoord->setAwaitReplicationReturnValueFunction([this](const repl::OpTime&) {
+        _removeDatabaseFromCatalog(_opCtx.get(), _nss.db());
+        return repl::ReplicationCoordinator::StatusAndDuration(
+            Status(ErrorCodes::WriteConcernFailed, ""), Milliseconds(0));
+    });
 
     _testDropDatabaseResetsDropPendingStateIfAwaitReplicationFails(_opCtx.get(), _nss, false);
 }
@@ -374,19 +363,18 @@ TEST_F(DropDatabaseTest,
     // dropDatabase() should detect this and release the global lock temporarily if it needs to call
     // ReplicationCoordinator::awaitReplication().
     bool isAwaitReplicationCalled = false;
-    _replCoord->setAwaitReplicationReturnValueFunction(
-        [&, this](OperationContext*, const repl::OpTime& opTime) {
-            isAwaitReplicationCalled = true;
-            // This test does not set the client's last optime.
-            ASSERT_EQUALS(opTime, repl::OpTime());
-            ASSERT_FALSE(_opCtx->lockState()->isW());
-            ASSERT_FALSE(_opCtx->lockState()->isDbLockedForMode(_nss.db(), MODE_X));
-            ASSERT_FALSE(_opCtx->lockState()->isLocked());
-            return repl::ReplicationCoordinator::StatusAndDuration(Status::OK(), Milliseconds(0));
-        });
+    _replCoord->setAwaitReplicationReturnValueFunction([&, this](const repl::OpTime& opTime) {
+        isAwaitReplicationCalled = true;
+        // This test does not set the client's last optime.
+        ASSERT_EQUALS(opTime, repl::OpTime());
+        ASSERT_FALSE(_opCtx->lockState()->isW());
+        ASSERT_FALSE(_opCtx->lockState()->isDbLockedForMode(_nss.db(), MODE_X));
+        ASSERT_FALSE(_opCtx->lockState()->isLocked());
+        return repl::ReplicationCoordinator::StatusAndDuration(Status::OK(), Milliseconds(0));
+    });
 
     {
-        Lock::DBLock lk(_opCtx.get(), _nss.db(), MODE_X);
+        Lock::GlobalWrite lk(_opCtx.get());
         _testDropDatabase(_opCtx.get(), _opObserver, _nss, true);
     }
 
@@ -399,23 +387,22 @@ TEST_F(DropDatabaseTest,
     // dropDatabase() should detect this and release the global lock temporarily if it needs to call
     // ReplicationCoordinator::awaitReplication().
     bool isAwaitReplicationCalled = false;
-    _replCoord->setAwaitReplicationReturnValueFunction(
-        [&, this](OperationContext*, const repl::OpTime& opTime) {
-            isAwaitReplicationCalled = true;
-            ASSERT_GREATER_THAN(opTime, repl::OpTime());
-            ASSERT_FALSE(_opCtx->lockState()->isW());
-            ASSERT_FALSE(_opCtx->lockState()->isDbLockedForMode(_nss.db(), MODE_X));
-            ASSERT_FALSE(_opCtx->lockState()->isLocked());
-            return repl::ReplicationCoordinator::StatusAndDuration(Status::OK(), Milliseconds(0));
-        });
+    _replCoord->setAwaitReplicationReturnValueFunction([&, this](const repl::OpTime& opTime) {
+        isAwaitReplicationCalled = true;
+        ASSERT_GREATER_THAN(opTime, repl::OpTime());
+        ASSERT_FALSE(_opCtx->lockState()->isW());
+        ASSERT_FALSE(_opCtx->lockState()->isDbLockedForMode(_nss.db(), MODE_X));
+        ASSERT_FALSE(_opCtx->lockState()->isLocked());
+        return repl::ReplicationCoordinator::StatusAndDuration(Status::OK(), Milliseconds(0));
+    });
 
     repl::OpTime dropOpTime(Timestamp(Seconds(100), 0), 1LL);
     auto dpns = _nss.makeDropPendingNamespace(dropOpTime);
     _createCollection(_opCtx.get(), dpns);
 
     {
-        Lock::DBLock lk(_opCtx.get(), _nss.db(), MODE_X);
-        ASSERT_OK(dropDatabaseForApplyOps(_opCtx.get(), _nss.db().toString()));
+        Lock::GlobalWrite lk(_opCtx.get());
+        ASSERT_OK(dropDatabase(_opCtx.get(), _nss.db().toString()));
     }
 
     ASSERT_TRUE(isAwaitReplicationCalled);
@@ -424,22 +411,20 @@ TEST_F(DropDatabaseTest,
 TEST_F(DropDatabaseTest,
        DropDatabaseReturnsNamespaceNotFoundIfDatabaseIsRemovedAfterCollectionsDropsAreReplicated) {
     // Update ReplicationCoordinatorMock so that awaitReplication() fails.
-    _replCoord->setAwaitReplicationReturnValueFunction(
-        [this](OperationContext*, const repl::OpTime&) {
-            _removeDatabaseFromCatalog(_opCtx.get(), _nss.db());
-            return repl::ReplicationCoordinator::StatusAndDuration(Status::OK(), Milliseconds(0));
-        });
+    _replCoord->setAwaitReplicationReturnValueFunction([this](const repl::OpTime&) {
+        _removeDatabaseFromCatalog(_opCtx.get(), _nss.db());
+        return repl::ReplicationCoordinator::StatusAndDuration(Status::OK(), Milliseconds(0));
+    });
 
     _createCollection(_opCtx.get(), _nss);
 
     ASSERT_TRUE(AutoGetDb(_opCtx.get(), _nss.db(), MODE_X).getDb());
 
-    auto status = dropDatabaseForApplyOps(_opCtx.get(), _nss.db().toString());
+    auto status = dropDatabase(_opCtx.get(), _nss.db().toString());
     ASSERT_EQUALS(ErrorCodes::NamespaceNotFound, status);
     ASSERT_EQUALS(status.reason(),
-                  std::string(str::stream()
-                              << "Could not drop database " << _nss.db()
-                              << " because it does not exist after dropping 1 collection(s)."));
+                  str::stream() << "Could not drop database " << _nss.db()
+                                << " because it does not exist after dropping 1 collection(s).");
 
     ASSERT_FALSE(AutoGetDb(_opCtx.get(), _nss.db(), MODE_X).getDb());
 }
@@ -447,24 +432,23 @@ TEST_F(DropDatabaseTest,
 TEST_F(DropDatabaseTest,
        DropDatabaseReturnsNotMasterIfNotPrimaryAfterCollectionsDropsAreReplicated) {
     // Transition from PRIMARY to SECONDARY while awaiting replication of collection drops.
-    _replCoord->setAwaitReplicationReturnValueFunction(
-        [this](OperationContext*, const repl::OpTime&) {
-            ASSERT_OK(_replCoord->setFollowerMode(repl::MemberState::RS_SECONDARY));
-            ASSERT_TRUE(_opCtx->writesAreReplicated());
-            ASSERT_FALSE(_replCoord->canAcceptWritesForDatabase(_opCtx.get(), _nss.db()));
-            return repl::ReplicationCoordinator::StatusAndDuration(Status::OK(), Milliseconds(0));
-        });
+    _replCoord->setAwaitReplicationReturnValueFunction([this](const repl::OpTime&) {
+        ASSERT_OK(_replCoord->setFollowerMode(repl::MemberState::RS_SECONDARY));
+        ASSERT_TRUE(_opCtx->writesAreReplicated());
+        ASSERT_FALSE(_replCoord->canAcceptWritesForDatabase(_opCtx.get(), _nss.db()));
+        return repl::ReplicationCoordinator::StatusAndDuration(Status::OK(), Milliseconds(0));
+    });
 
     _createCollection(_opCtx.get(), _nss);
 
     ASSERT_TRUE(AutoGetDb(_opCtx.get(), _nss.db(), MODE_X).getDb());
 
-    auto status = dropDatabaseForApplyOps(_opCtx.get(), _nss.db().toString());
+    auto status = dropDatabase(_opCtx.get(), _nss.db().toString());
     ASSERT_EQUALS(ErrorCodes::PrimarySteppedDown, status);
     ASSERT_EQUALS(status.reason(),
-                  std::string(str::stream() << "Could not drop database " << _nss.db()
-                                            << " because we transitioned from PRIMARY to SECONDARY"
-                                            << " while waiting for 1 pending collection drop(s)."));
+                  str::stream() << "Could not drop database " << _nss.db()
+                                << " because we transitioned from PRIMARY to SECONDARY"
+                                << " while waiting for 1 pending collection drop(s).");
 
     // Check drop-pending flag in Database after dropDatabase() fails.
     AutoGetDb autoDb(_opCtx.get(), _nss.db(), MODE_X);
@@ -476,7 +460,7 @@ TEST_F(DropDatabaseTest,
 TEST_F(DropDatabaseTest, DropDatabaseFailsToDropAdmin) {
     NamespaceString adminNSS(NamespaceString::kAdminDb, "foo");
     _createCollection(_opCtx.get(), adminNSS);
-    ASSERT_THROWS_CODE_AND_WHAT(dropDatabaseForApplyOps(_opCtx.get(), adminNSS.db().toString()),
+    ASSERT_THROWS_CODE_AND_WHAT(dropDatabase(_opCtx.get(), adminNSS.db().toString()).ignore(),
                                 AssertionException,
                                 ErrorCodes::IllegalOperation,
                                 "Dropping the 'admin' database is prohibited.");
