@@ -68,6 +68,7 @@ namespace mongo {
 namespace {
 
 MONGO_FP_DECLARE(rsStopGetMoreCmd);
+MONGO_FP_DECLARE(GetMoreHangBeforeReadLock);
 
 /**
  * A command for running getMore() against an existing cursor registered with a CursorManager.
@@ -206,6 +207,12 @@ public:
                                      dbProfilingLevel);
             }
         } else {
+            if (MONGO_FAIL_POINT(GetMoreHangBeforeReadLock)) {
+                log() << "GetMoreHangBeforeReadLock fail point enabled. Blocking until fail "
+                         "point is disabled.";
+                MONGO_FAIL_POINT_PAUSE_WHILE_SET(GetMoreHangBeforeReadLock);
+            }
+
             readLock.emplace(opCtx, request.nss);
             const int doNotChangeProfilingLevel = 0;
             statsTracker.emplace(opCtx,
@@ -215,6 +222,10 @@ public:
                                  readLock->getDb() ? readLock->getDb()->getProfilingLevel()
                                                    : doNotChangeProfilingLevel);
 
+            // Check whether we are allowed to read from this node after acquiring our locks.
+            uassertStatusOK(repl::ReplicationCoordinator::get(opCtx)->checkCanServeReadsFor(
+                opCtx, request.nss, true));
+
             Collection* collection = readLock->getCollection();
             if (!collection) {
                 return appendCommandStatus(result,
