@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -47,7 +48,6 @@
 #include "mongo/db/namespace_string.h"
 #include "mongo/db/query/explain.h"
 #include "mongo/db/query/plan_ranker.h"
-#include "mongo/util/hex.h"
 #include "mongo/util/log.h"
 
 namespace {
@@ -91,9 +91,9 @@ MONGO_INITIALIZER_WITH_PREREQUISITES(SetupPlanCacheCommands, MONGO_NO_PREREQUISI
     // PlanCacheCommand constructors refer to static ActionType instances.
     // Registering commands in a mongo static initializer ensures that
     // the ActionType construction will be completed first.
-    new PlanCacheListQueryShapesDeprecated();
+    new PlanCacheListQueryShapes();
     new PlanCacheClear();
-    new PlanCacheListPlansDeprecated();
+    new PlanCacheListPlans();
 
     return Status::OK();
 }
@@ -104,8 +104,8 @@ namespace mongo {
 
 using std::string;
 using std::stringstream;
-using std::unique_ptr;
 using std::vector;
+using std::unique_ptr;
 
 PlanCacheCommand::PlanCacheCommand(const string& name,
                                    const string& helpText,
@@ -116,10 +116,9 @@ bool PlanCacheCommand::run(OperationContext* opCtx,
                            const string& dbname,
                            const BSONObj& cmdObj,
                            BSONObjBuilder& result) {
-    const NamespaceString nss(CommandHelpers::parseNsCollectionRequired(dbname, cmdObj));
+    const NamespaceString nss(parseNsCollectionRequired(dbname, cmdObj));
     Status status = runPlanCacheCommand(opCtx, nss.ns(), cmdObj, &result);
-    uassertStatusOK(status);
-    return true;
+    return appendCommandStatus(result, status);
 }
 
 
@@ -127,17 +126,21 @@ bool PlanCacheCommand::supportsWriteConcern(const BSONObj& cmd) const {
     return false;
 }
 
-Command::AllowedOnSecondary PlanCacheCommand::secondaryAllowed(ServiceContext*) const {
-    return AllowedOnSecondary::kOptIn;
+bool PlanCacheCommand::slaveOk() const {
+    return false;
 }
 
-std::string PlanCacheCommand::help() const {
-    return helpText;
+bool PlanCacheCommand::slaveOverrideOk() const {
+    return true;
+}
+
+void PlanCacheCommand::help(stringstream& ss) const {
+    ss << helpText;
 }
 
 Status PlanCacheCommand::checkAuthForCommand(Client* client,
                                              const std::string& dbname,
-                                             const BSONObj& cmdObj) const {
+                                             const BSONObj& cmdObj) {
     AuthorizationSession* authzSession = AuthorizationSession::get(client);
     ResourcePattern pattern = parseResourcePattern(dbname, cmdObj);
 
@@ -220,21 +223,15 @@ StatusWith<unique_ptr<CanonicalQuery>> PlanCacheCommand::canonicalize(OperationC
     return std::move(statusWithCQ.getValue());
 }
 
-PlanCacheListQueryShapesDeprecated::PlanCacheListQueryShapesDeprecated()
+PlanCacheListQueryShapes::PlanCacheListQueryShapes()
     : PlanCacheCommand("planCacheListQueryShapes",
-                       "Deprecated. Prefer the $planCacheStats aggregation pipeline stage.",
+                       "Displays all query shapes in a collection.",
                        ActionType::planCacheRead) {}
 
-Status PlanCacheListQueryShapesDeprecated::runPlanCacheCommand(OperationContext* opCtx,
-                                                               const string& ns,
-                                                               const BSONObj& cmdObj,
-                                                               BSONObjBuilder* bob) {
-    if (_sampler.tick()) {
-        warning()
-            << "The planCacheListQueryShapes command is deprecated. Prefer the $planCacheStats "
-               "aggregation pipeline stage.";
-    }
-
+Status PlanCacheListQueryShapes::runPlanCacheCommand(OperationContext* opCtx,
+                                                     const string& ns,
+                                                     const BSONObj& cmdObj,
+                                                     BSONObjBuilder* bob) {
     // This is a read lock. The query cache is owned by the collection.
     AutoGetCollectionForReadCommand ctx(opCtx, NamespaceString(ns));
 
@@ -250,33 +247,28 @@ Status PlanCacheListQueryShapesDeprecated::runPlanCacheCommand(OperationContext*
 }
 
 // static
-Status PlanCacheListQueryShapesDeprecated::list(const PlanCache& planCache, BSONObjBuilder* bob) {
+Status PlanCacheListQueryShapes::list(const PlanCache& planCache, BSONObjBuilder* bob) {
     invariant(bob);
 
     // Fetch all cached solutions from plan cache.
-    auto entries = planCache.getAllEntries();
+    vector<PlanCacheEntry*> solutions = planCache.getAllEntries();
 
     BSONArrayBuilder arrayBuilder(bob->subarrayStart("shapes"));
-    for (auto&& entry : entries) {
+    for (vector<PlanCacheEntry*>::const_iterator i = solutions.begin(); i != solutions.end(); i++) {
+        PlanCacheEntry* entry = *i;
         invariant(entry);
 
         BSONObjBuilder shapeBuilder(arrayBuilder.subobjStart());
-
-        // Most details demonstrating the shape of the query must be omitted if the plan cache entry
-        // has had its debug info stripped. Debug info may be omitted from the plan cache entry in
-        // order to reduce the plan cache's memory footprint.
-        if (entry->debugInfo) {
-            const auto& createdFromQuery = entry->debugInfo->createdFromQuery;
-            shapeBuilder.append("query", createdFromQuery.filter);
-            shapeBuilder.append("sort", createdFromQuery.sort);
-            shapeBuilder.append("projection", createdFromQuery.projection);
-            if (!createdFromQuery.collation.isEmpty()) {
-                shapeBuilder.append("collation", createdFromQuery.collation);
-            }
+        shapeBuilder.append("query", entry->query);
+        shapeBuilder.append("sort", entry->sort);
+        shapeBuilder.append("projection", entry->projection);
+        if (!entry->collation.isEmpty()) {
+            shapeBuilder.append("collation", entry->collation);
         }
-
-        shapeBuilder.append("queryHash", unsignedIntToFixedLengthHex(entry->queryHash));
         shapeBuilder.doneFast();
+
+        // Release resources for cached solution after extracting query shape.
+        delete entry;
     }
     arrayBuilder.doneFast();
 
@@ -323,9 +315,8 @@ Status PlanCacheClear::clear(OperationContext* opCtx,
 
         unique_ptr<CanonicalQuery> cq = std::move(statusWithCQ.getValue());
 
-        Status result = planCache->remove(*cq);
-        if (!result.isOK()) {
-            invariant(result.code() == ErrorCodes::NoSuchKey);
+        if (!planCache->contains(*cq)) {
+            // Log if asked to clear non-existent query shape.
             LOG(1) << ns << ": query shape doesn't exist in PlanCache - "
                    << redact(cq->getQueryObj()) << "(sort: " << cq->getQueryRequest().getSort()
                    << "; projection: " << cq->getQueryRequest().getProj()
@@ -333,6 +324,11 @@ Status PlanCacheClear::clear(OperationContext* opCtx,
             return Status::OK();
         }
 
+        Status result = planCache->remove(*cq);
+        if (!result.isOK()) {
+            return result;
+        }
+
         LOG(1) << ns << ": removed plan cache entry - " << redact(cq->getQueryObj())
                << "(sort: " << cq->getQueryRequest().getSort()
                << "; projection: " << cq->getQueryRequest().getProj()
@@ -356,52 +352,59 @@ Status PlanCacheClear::clear(OperationContext* opCtx,
     return Status::OK();
 }
 
-PlanCacheListPlansDeprecated::PlanCacheListPlansDeprecated()
+PlanCacheListPlans::PlanCacheListPlans()
     : PlanCacheCommand("planCacheListPlans",
-                       "Deprecated. Prefer the $planCacheStats aggregation pipeline stage.",
+                       "Displays the cached plans for a query shape.",
                        ActionType::planCacheRead) {}
 
-Status PlanCacheListPlansDeprecated::runPlanCacheCommand(OperationContext* opCtx,
-                                                         const std::string& ns,
-                                                         const BSONObj& cmdObj,
-                                                         BSONObjBuilder* bob) {
-    if (_sampler.tick()) {
-        warning() << "The planCacheListPlans command is deprecated. Prefer the $planCacheStats "
-                     "aggregation pipeline stage.";
-    }
-
+Status PlanCacheListPlans::runPlanCacheCommand(OperationContext* opCtx,
+                                               const std::string& ns,
+                                               const BSONObj& cmdObj,
+                                               BSONObjBuilder* bob) {
     AutoGetCollectionForReadCommand ctx(opCtx, NamespaceString(ns));
 
     PlanCache* planCache;
-    uassertStatusOK(getPlanCache(opCtx, ctx.getCollection(), ns, &planCache));
+    Status status = getPlanCache(opCtx, ctx.getCollection(), ns, &planCache);
+    if (!status.isOK()) {
+        // No collection - return empty plans array.
+        BSONArrayBuilder plansBuilder(bob->subarrayStart("plans"));
+        plansBuilder.doneFast();
+        return Status::OK();
+    }
     return list(opCtx, *planCache, ns, cmdObj, bob);
 }
 
-namespace {
-Status listPlansOriginalFormat(std::unique_ptr<CanonicalQuery> cq,
-                               const PlanCache& planCache,
-                               BSONObjBuilder* bob) {
-    auto lookupResult = planCache.getEntry(*cq);
-    if (lookupResult == ErrorCodes::NoSuchKey) {
+// static
+Status PlanCacheListPlans::list(OperationContext* opCtx,
+                                const PlanCache& planCache,
+                                const std::string& ns,
+                                const BSONObj& cmdObj,
+                                BSONObjBuilder* bob) {
+    auto statusWithCQ = canonicalize(opCtx, ns, cmdObj);
+    if (!statusWithCQ.isOK()) {
+        return statusWithCQ.getStatus();
+    }
+    unique_ptr<CanonicalQuery> cq = std::move(statusWithCQ.getValue());
+
+    if (!planCache.contains(*cq)) {
         // Return empty plans in results if query shape does not
         // exist in plan cache.
         BSONArrayBuilder plansBuilder(bob->subarrayStart("plans"));
         plansBuilder.doneFast();
         return Status::OK();
-    } else if (!lookupResult.isOK()) {
-        return lookupResult.getStatus();
     }
 
-    auto entry = std::move(lookupResult.getValue());
+    PlanCacheEntry* entryRaw;
+    Status result = planCache.getEntry(*cq, &entryRaw);
+    if (!result.isOK()) {
+        return result;
+    }
+    unique_ptr<PlanCacheEntry> entry(entryRaw);
 
     BSONArrayBuilder plansBuilder(bob->subarrayStart("plans"));
-
     size_t numPlans = entry->plannerData.size();
-    if (const auto debugInfo = entry->debugInfo; debugInfo) {
-        invariant(numPlans == debugInfo->decision->stats.size());
-        invariant(numPlans == debugInfo->decision->scores.size());
-    }
-
+    invariant(numPlans == entry->decision->stats.size());
+    invariant(numPlans == entry->decision->scores.size());
     for (size_t i = 0; i < numPlans; ++i) {
         BSONObjBuilder planBob(plansBuilder.subobjStart());
 
@@ -411,32 +414,30 @@ Status listPlansOriginalFormat(std::unique_ptr<CanonicalQuery> cq,
         detailsBob.append("solution", entry->plannerData[i]->toString());
         detailsBob.doneFast();
 
-        // Some information for each candidate plan can only be provided if the plan cache entry
-        // contains debug info.
-        if (const auto debugInfo = entry->debugInfo; debugInfo) {
-            {
-                // 'reason' is comprised of score and initial stats provided by the multi-planner.
-                BSONObjBuilder reasonBob(planBob.subobjStart("reason"));
-                reasonBob.append("score", debugInfo->decision->scores[i]);
-                {
-                    BSONObjBuilder statsBob(reasonBob.subobjStart("stats"));
-                    if (auto* stats = debugInfo->decision->stats[i].get(); stats) {
-                        Explain::statsToBSON(*stats, &statsBob);
-                    }
-                }
-            }
-
-            // BSON object for 'feedback' field shows scores from historical executions of the plan.
-            BSONObjBuilder feedbackBob(planBob.subobjStart("feedback"));
-            if (i == 0U) {
-                feedbackBob.append("nfeedback", int(debugInfo->feedback.size()));
-                BSONArrayBuilder scoresBob(feedbackBob.subarrayStart("scores"));
-                for (auto score : debugInfo->feedback) {
-                    BSONObjBuilder scoreBob(scoresBob.subobjStart());
-                    scoreBob.append("score", score);
-                }
-            }
+        // reason is comprised of score and initial stats provided by
+        // multi plan runner.
+        BSONObjBuilder reasonBob(planBob.subobjStart("reason"));
+        reasonBob.append("score", entry->decision->scores[i]);
+        BSONObjBuilder statsBob(reasonBob.subobjStart("stats"));
+        PlanStageStats* stats = entry->decision->stats[i].get();
+        if (stats) {
+            Explain::statsToBSON(*stats, &statsBob);
         }
+        statsBob.doneFast();
+        reasonBob.doneFast();
+
+        // BSON object for 'feedback' field shows scores from historical executions of the plan.
+        BSONObjBuilder feedbackBob(planBob.subobjStart("feedback"));
+        if (i == 0U) {
+            feedbackBob.append("nfeedback", int(entry->feedback.size()));
+            BSONArrayBuilder scoresBob(feedbackBob.subarrayStart("scores"));
+            for (size_t i = 0; i < entry->feedback.size(); ++i) {
+                BSONObjBuilder scoreBob(scoresBob.subobjStart());
+                scoreBob.append("score", entry->feedback[i]->score);
+            }
+            scoresBob.doneFast();
+        }
+        feedbackBob.doneFast();
 
         planBob.append("filterSet", entry->plannerData[i]->indexFilterApplied);
     }
@@ -445,35 +446,7 @@ Status listPlansOriginalFormat(std::unique_ptr<CanonicalQuery> cq,
 
     // Append the time the entry was inserted into the plan cache.
     bob->append("timeOfCreation", entry->timeOfCreation);
-    bob->append("queryHash", unsignedIntToFixedLengthHex(entry->queryHash));
-    bob->append("planCacheKey", unsignedIntToFixedLengthHex(entry->planCacheKey));
-    // Append whether or not the entry is active.
-    bob->append("isActive", entry->isActive);
-    bob->append("works", static_cast<long long>(entry->works));
-    bob->append("estimatedSizeBytes", static_cast<long long>(entry->estimatedEntrySizeBytes));
-    return Status::OK();
-}
-}  // namespace
 
-// static
-Status PlanCacheListPlansDeprecated::list(OperationContext* opCtx,
-                                          const PlanCache& planCache,
-                                          const std::string& ns,
-                                          const BSONObj& cmdObj,
-                                          BSONObjBuilder* bob) {
-    auto statusWithCQ = canonicalize(opCtx, ns, cmdObj);
-    if (!statusWithCQ.isOK()) {
-        return statusWithCQ.getStatus();
-    }
-
-    if (!internalQueryCacheListPlansNewOutput.load())
-        return listPlansOriginalFormat(std::move(statusWithCQ.getValue()), planCache, bob);
-
-    unique_ptr<CanonicalQuery> cq = std::move(statusWithCQ.getValue());
-    auto entry = uassertStatusOK(planCache.getEntry(*cq));
-
-    // internalQueryCacheDisableInactiveEntries is True and we should use the new output format.
-    Explain::planCacheEntryToBSON(*entry, bob);
     return Status::OK();
 }
 
