@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -29,20 +30,23 @@
 
 #include "mongo/platform/basic.h"
 
-#include "mongo/client/dbclient_cursor.h"
+#include "mongo/client/dbclientcursor.h"
 #include "mongo/db/catalog/collection.h"
+#include "mongo/db/catalog/collection_catalog_entry.h"
 #include "mongo/db/catalog/database_holder.h"
 #include "mongo/db/catalog/index_catalog.h"
+#include "mongo/db/catalog/index_create.h"
 #include "mongo/db/catalog/rename_collection.h"
 #include "mongo/db/client.h"
 #include "mongo/db/commands.h"
 #include "mongo/db/commands/rename_collection.h"
 #include "mongo/db/db_raii.h"
 #include "mongo/db/index/index_descriptor.h"
+#include "mongo/db/index_builder.h"
 #include "mongo/db/namespace_string.h"
 #include "mongo/db/op_observer.h"
 #include "mongo/db/ops/insert.h"
-#include "mongo/db/repl/replication_coordinator.h"
+#include "mongo/db/repl/replication_coordinator_global.h"
 #include "mongo/db/service_context.h"
 #include "mongo/util/scopeguard.h"
 
@@ -60,23 +64,27 @@ public:
     virtual bool adminOnly() const {
         return true;
     }
-    AllowedOnSecondary secondaryAllowed(ServiceContext*) const override {
-        return AllowedOnSecondary::kNever;
+    virtual bool slaveOk() const {
+        return false;
     }
     virtual bool supportsWriteConcern(const BSONObj& cmd) const override {
         return true;
     }
     virtual Status checkAuthForCommand(Client* client,
                                        const std::string& dbname,
-                                       const BSONObj& cmdObj) const {
+                                       const BSONObj& cmdObj) {
         return rename_collection::checkAuthForRenameCollectionCommand(client, dbname, cmdObj);
     }
-    std::string help() const override {
-        return " example: { renameCollection: foo.a, to: bar.b }";
+    virtual void help(stringstream& help) const {
+        help << " example: { renameCollection: foo.a, to: bar.b }";
     }
 
-    std::string parseNs(const std::string& dbname, const BSONObj& cmdObj) const override {
-        return CommandHelpers::parseNsFullyQualified(cmdObj);
+    static void dropCollection(OperationContext* opCtx, Database* db, StringData collName) {
+        WriteUnitOfWork wunit(opCtx);
+        if (db->dropCollection(opCtx, collName).isOK()) {
+            // ignoring failure case
+            wunit.commit();
+        }
     }
 
     virtual bool errmsgRun(OperationContext* opCtx,
@@ -104,7 +112,7 @@ public:
                 str::stream() << "Invalid target namespace: " << target.ns(),
                 target.isValid());
 
-        if ((repl::ReplicationCoordinator::get(opCtx)->getReplicationMode() !=
+        if ((repl::getGlobalReplicationCoordinator()->getReplicationMode() !=
              repl::ReplicationCoordinator::modeNone)) {
             if (source.isOplog()) {
                 errmsg = "can't rename live oplog while replicating";
@@ -133,18 +141,22 @@ public:
             return false;
         }
 
-        if (source.isServerConfigurationCollection()) {
-            uasserted(ErrorCodes::IllegalOperation,
-                      "renaming the server configuration "
-                      "collection (admin.system.version) is not "
-                      "allowed");
+        if (source.isSystemDotIndexes() || target.isSystemDotIndexes()) {
+            errmsg = "renaming system.indexes is not allowed";
+            return false;
+        }
+
+        if (source.isAdminDotSystemDotVersion()) {
+            appendCommandStatus(result,
+                                Status(ErrorCodes::IllegalOperation,
+                                       "renaming admin.system.version is not allowed"));
+            return false;
         }
 
         RenameCollectionOptions options;
         options.dropTarget = cmdObj["dropTarget"].trueValue();
         options.stayTemp = cmdObj["stayTemp"].trueValue();
-        uassertStatusOK(renameCollection(opCtx, source, target, options));
-        return true;
+        return appendCommandStatus(result, renameCollection(opCtx, source, target, options));
     }
 
 } cmdrenamecollection;
