@@ -127,6 +127,7 @@
 #include "mongo/db/storage/encryption_hooks.h"
 #include "mongo/db/storage/mmap_v1/mmap_v1_options.h"
 #include "mongo/db/storage/storage_engine.h"
+#include "mongo/db/storage/storage_engine_lock_file.h"
 #include "mongo/db/storage/storage_options.h"
 #include "mongo/db/system_index.h"
 #include "mongo/db/ttl.h"
@@ -136,6 +137,7 @@
 #include "mongo/executor/network_interface_thread_pool.h"
 #include "mongo/executor/thread_pool_task_executor.h"
 #include "mongo/platform/process_id.h"
+#include "mongo/platform/random.h"
 #include "mongo/rpc/metadata/egress_metadata_hook_list.h"
 #include "mongo/s/catalog/sharding_catalog_manager.h"
 #include "mongo/s/client/shard_registry.h"
@@ -289,6 +291,8 @@ Status restoreMissingFeatureCompatibilityVersionDocument(OperationContext* opCtx
 const NamespaceString startupLogCollectionName("local.startup_log");
 const NamespaceString kSystemReplSetCollection("local.system.replset");
 
+MONGO_EXPORT_SERVER_PARAMETER(waitForStepDownOnNonCommandShutdown, bool, true);
+
 #ifdef _WIN32
 const ntservice::NtServiceDefaultStrings defaultServiceStrings = {
     L"MongoDB", L"MongoDB", L"MongoDB Server"};
@@ -1152,7 +1156,8 @@ void startupConfigActions(const std::vector<std::string>& args) {
         bool failed = false;
 
         std::string name =
-            (boost::filesystem::path(storageGlobalParams.dbpath) / "mongod.lock").string();
+            (boost::filesystem::path(storageGlobalParams.dbpath) / kLockFileBasename.toString())
+                .string();
         if (!boost::filesystem::exists(name) || boost::filesystem::file_size(name) == 0)
             failed = true;
 
@@ -1247,7 +1252,7 @@ MONGO_INITIALIZER_WITH_PREREQUISITES(CreateReplicationManager,
         stdx::make_unique<repl::TopologyCoordinator>(topoCoordOptions),
         replicationProcess,
         storageInterface,
-        static_cast<int64_t>(curTimeMillis64()));
+        SecureRandom::create()->nextInt64());
     repl::ReplicationCoordinator::set(serviceContext, std::move(replCoord));
     repl::setOplogCollectionName();
     return Status::OK();
@@ -1267,12 +1272,52 @@ MONGO_INITIALIZER_GENERAL(setSSLManagerType, MONGO_NO_PREREQUISITES, ("SSLManage
 
 // NOTE: This function may be called at any time after registerShutdownTask is called below. It
 // must not depend on the prior execution of mongo initializers or the existence of threads.
-void shutdownTask() {
-    Client::initThreadIfNotAlready();
+void shutdownTask(const ShutdownTaskArgs& shutdownArgs) {
+    // This client initiation pattern is only to be used here, with plans to eliminate this pattern
+    // down the line.
+    if (!haveClient())
+        Client::initThread(getThreadName());
 
     auto const client = Client::getCurrent();
     auto const serviceContext = client->getServiceContext();
 
+    // If we don't have shutdownArgs, we're shutting down from a signal, or other clean shutdown
+    // path.
+    //
+    // In that case, do a default step down, still shutting down if stepDown fails.
+    {
+        auto replCoord = repl::ReplicationCoordinator::get(serviceContext);
+        if (replCoord && !shutdownArgs.isUserInitiated) {
+            replCoord->enterTerminalShutdown();
+            ServiceContext::UniqueOperationContext uniqueOpCtx;
+            OperationContext* opCtx = client->getOperationContext();
+            if (!opCtx) {
+                uniqueOpCtx = client->makeOperationContext();
+                opCtx = uniqueOpCtx.get();
+            }
+
+            // If this is a single node replica set, then we don't have to wait
+            // for any secondaries. Ignore stepdown.
+            if (repl::ReplicationCoordinator::get(serviceContext)->getConfig().getNumMembers() !=
+                1) {
+                try {
+                    // For faster tests, we allow a short wait time with setParameter.
+                    auto waitTime = waitForStepDownOnNonCommandShutdown.load()
+                        ? Milliseconds(Seconds(10))
+                        : Milliseconds(100);
+
+                    uassertStatusOK(
+                        replCoord->stepDown(opCtx, false /* force */, waitTime, Seconds(120)));
+                } catch (const ExceptionFor<ErrorCodes::NotMaster>&) {
+                    // ignore not master errors
+                } catch (const DBException& e) {
+                    log() << "Failed to stepDown in non-command initiated shutdown path "
+                          << e.toString();
+                }
+            }
+        }
+    }
+
     // Terminate the balancer thread so it doesn't leak memory.
     if (auto balancer = Balancer::get(serviceContext)) {
         balancer->interruptBalancer();
