@@ -1,3 +1,6 @@
+// dbmessage.cpp
+
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -36,7 +39,7 @@
 
 namespace mongo {
 
-DbMessage::DbMessage(const Message& msg) : _msg(msg), _nsStart(nullptr), _mark(nullptr), _nsLen(0) {
+DbMessage::DbMessage(const Message& msg) : _msg(msg), _nsStart(NULL), _mark(NULL), _nsLen(0) {
     // for received messages, Message has only one buffer
     _theEnd = _msg.singleData().data() + _msg.singleData().dataLen();
     _nextjsobj = _msg.singleData().data();
@@ -61,10 +64,18 @@ DbMessage::DbMessage(const Message& msg) : _msg(msg), _nsStart(nullptr), _mark(n
 }
 
 const char* DbMessage::getns() const {
-    MONGO_verify(messageShouldHaveNs());
+    verify(messageShouldHaveNs());
     return _nsStart;
 }
 
+int DbMessage::getQueryNToReturn() const {
+    verify(messageShouldHaveNs());
+    const char* p = _nsStart + _nsLen + 1;
+    checkRead<int>(p, 2);
+
+    return ConstDataView(p).read<LittleEndian<int32_t>>(sizeof(int32_t));
+}
+
 int DbMessage::pullInt() {
     return readAndAdvance<int32_t>();
 }
@@ -81,31 +92,32 @@ const char* DbMessage::getArray(size_t count) const {
 BSONObj DbMessage::nextJsObj() {
     uassert(ErrorCodes::InvalidBSON,
             "Client Error: Remaining data too small for BSON object",
-            _nextjsobj != nullptr && _theEnd - _nextjsobj >= 5);
+            _nextjsobj != NULL && _theEnd - _nextjsobj >= 5);
 
     if (serverGlobalParams.objcheck) {
-        Status status = validateBSON(_nextjsobj, _theEnd - _nextjsobj);
+        Status status = validateBSON(
+            _nextjsobj, _theEnd - _nextjsobj, Validator<BSONObj>::enabledBSONVersion());
         uassert(ErrorCodes::InvalidBSON,
                 str::stream() << "Client Error: bad object in message: " << status.reason(),
                 status.isOK());
     }
 
     BSONObj js(_nextjsobj);
-    MONGO_verify(js.objsize() >= 5);
-    MONGO_verify(js.objsize() <= (_theEnd - _nextjsobj));
+    verify(js.objsize() >= 5);
+    verify(js.objsize() <= (_theEnd - _nextjsobj));
 
     _nextjsobj += js.objsize();
     if (_nextjsobj >= _theEnd)
-        _nextjsobj = nullptr;
+        _nextjsobj = NULL;
     return js;
 }
 
-void DbMessage::markReset(const char* toMark = nullptr) {
-    if (toMark == nullptr) {
+void DbMessage::markReset(const char* toMark = NULL) {
+    if (toMark == NULL) {
         toMark = _mark;
     }
 
-    MONGO_verify(toMark);
+    verify(toMark);
     _nextjsobj = toMark;
 }
 
@@ -130,17 +142,30 @@ T DbMessage::readAndAdvance() {
     return t;
 }
 
-Message makeUnsupportedOpInsertMessage(StringData ns,
-                                       const BSONObj* objs,
-                                       size_t count,
-                                       int flags) {
+namespace {
+template <typename Func>
+Message makeMessage(NetworkOp op, Func&& bodyBuilder) {
+    BufBuilder b;
+    b.skip(sizeof(MSGHEADER::Layout));
+
+    bodyBuilder(b);
+
+    const int size = b.len();
+    auto out = Message(b.release());
+    out.header().setOperation(op);
+    out.header().setLen(size);
+    return out;
+}
+}
+
+Message makeInsertMessage(StringData ns, const BSONObj* objs, size_t count, int flags) {
     return makeMessage(dbInsert, [&](BufBuilder& b) {
         int reservedFlags = 0;
         if (flags & InsertOption_ContinueOnError)
             reservedFlags |= InsertOption_ContinueOnError;
 
         b.appendNum(reservedFlags);
-        b.appendCStr(ns);
+        b.appendStr(ns);
 
         for (size_t i = 0; i < count; i++) {
             objs[i].appendSelfToBufBuilder(b);
@@ -148,28 +173,72 @@ Message makeUnsupportedOpInsertMessage(StringData ns,
     });
 }
 
-DbResponse makeErrorResponseToUnsupportedOpQuery(StringData errorMsg) {
-    BSONObjBuilder err;
-    err.append("$err",
-               str::stream() << errorMsg
-                             << ". The client driver may require an upgrade. For more details see "
-                                "https://dochub.mongodb.org/core/legacy-opcode-removal");
-    err.append("code", 5739101);
-    err.append("ok", 0.0);
-    BSONObj errObj = err.done();
+Message makeUpdateMessage(StringData ns, BSONObj query, BSONObj update, int flags) {
+    return makeMessage(dbUpdate, [&](BufBuilder& b) {
+        const int reservedFlags = 0;
+        b.appendNum(reservedFlags);
+        b.appendStr(ns);
+        b.appendNum(flags);
 
-    BufBuilder buffer(sizeof(QueryResult::Value) + errObj.objsize());
-    buffer.skip(sizeof(QueryResult::Value));
-    buffer.appendBuf(errObj.objdata(), errObj.objsize());
+        query.appendSelfToBufBuilder(b);
+        update.appendSelfToBufBuilder(b);
+    });
+}
 
-    QueryResult::View qr = buffer.buf();
-    qr.msgdata().setLen(buffer.len());
+Message makeRemoveMessage(StringData ns, BSONObj query, int flags) {
+    return makeMessage(dbDelete, [&](BufBuilder& b) {
+        const int reservedFlags = 0;
+        b.appendNum(reservedFlags);
+        b.appendStr(ns);
+        b.appendNum(flags);
+
+        query.appendSelfToBufBuilder(b);
+    });
+}
+
+Message makeKillCursorsMessage(long long cursorId) {
+    return makeMessage(dbKillCursors, [&](BufBuilder& b) {
+        b.appendNum((int)0);  // reserved
+        b.appendNum((int)1);  // number
+        b.appendNum(cursorId);
+    });
+}
+
+Message makeGetMoreMessage(StringData ns, long long cursorId, int nToReturn, int flags) {
+    return makeMessage(dbGetMore, [&](BufBuilder& b) {
+        b.appendNum(flags);
+        b.appendStr(ns);
+        b.appendNum(nToReturn);
+        b.appendNum(cursorId);
+    });
+}
+
+OpQueryReplyBuilder::OpQueryReplyBuilder() : _buffer(32768) {
+    _buffer.skip(sizeof(QueryResult::Value));
+}
+
+Message OpQueryReplyBuilder::toQueryReply(int queryResultFlags,
+                                          int nReturned,
+                                          int startingFrom,
+                                          long long cursorId) {
+    QueryResult::View qr = _buffer.buf();
+    qr.setResultFlags(queryResultFlags);
+    qr.msgdata().setLen(_buffer.len());
     qr.msgdata().setOperation(opReply);
-    qr.setResultFlags(ResultFlag_ErrSet);
-    qr.setCursorId(0);
-    qr.setStartingFrom(0);
-    qr.setNReturned(1);
+    qr.setCursorId(cursorId);
+    qr.setStartingFrom(startingFrom);
+    qr.setNReturned(nReturned);
+    return Message(_buffer.release());
+}
 
-    return DbResponse{Message(buffer.release())};
+DbResponse replyToQuery(int queryResultFlags,
+                        const void* data,
+                        int size,
+                        int nReturned,
+                        int startingFrom,
+                        long long cursorId) {
+    OpQueryReplyBuilder reply;
+    reply.bufBuilderForResults().appendBuf(data, size);
+    return DbResponse{reply.toQueryReply(queryResultFlags, nReturned, startingFrom, cursorId)};
+}
 }
-}  // namespace mongo
