@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -41,7 +42,7 @@
 #include "mongo/db/exec/write_stage_common.h"
 #include "mongo/db/op_observer.h"
 #include "mongo/db/query/canonical_query.h"
-#include "mongo/db/repl/replication_coordinator.h"
+#include "mongo/db/repl/replication_coordinator_global.h"
 #include "mongo/db/service_context.h"
 #include "mongo/stdx/memory.h"
 #include "mongo/util/log.h"
@@ -59,12 +60,12 @@ namespace {
  * Returns true if we should throw a WriteConflictException in order to retry the operation in
  * the case of a conflict. Returns false if we should skip the document and keep going.
  */
-bool shouldRestartDeleteIfNoLongerMatches(const DeleteStageParams* params) {
+bool shouldRestartDeleteIfNoLongerMatches(const DeleteStageParams& params) {
     // When we're doing a findAndModify with a sort, the sort will have a limit of 1, so it will not
     // produce any more results even if there is another matching document. Throw a WCE here so that
     // these operations get another chance to find a matching document. The findAndModify command
     // should automatically retry if it gets a WCE.
-    return params->returnDeleted && !params->sort.isEmpty();
+    return params.returnDeleted && !params.sort.isEmpty();
 };
 
 }  // namespace
@@ -73,20 +74,24 @@ bool shouldRestartDeleteIfNoLongerMatches(const DeleteStageParams* params) {
 const char* DeleteStage::kStageType = "DELETE";
 
 DeleteStage::DeleteStage(OperationContext* opCtx,
-                         std::unique_ptr<DeleteStageParams> params,
+                         const DeleteStageParams& params,
                          WorkingSet* ws,
                          Collection* collection,
                          PlanStage* child)
-    : RequiresMutableCollectionStage(kStageType, opCtx, collection),
-      _params(std::move(params)),
+    : PlanStage(kStageType, opCtx),
+      _params(params),
       _ws(ws),
+      _collection(collection),
       _idRetrying(WorkingSet::INVALID_ID),
       _idReturning(WorkingSet::INVALID_ID) {
     _children.emplace_back(child);
 }
 
 bool DeleteStage::isEOF() {
-    if (!_params->isMulti && _specificStats.docsDeleted > 0) {
+    if (!_collection) {
+        return true;
+    }
+    if (!_params.isMulti && _specificStats.docsDeleted > 0) {
         return true;
     }
     return _idRetrying == WorkingSet::INVALID_ID && _idReturning == WorkingSet::INVALID_ID &&
@@ -97,12 +102,13 @@ PlanStage::StageState DeleteStage::doWork(WorkingSetID* out) {
     if (isEOF()) {
         return PlanStage::IS_EOF;
     }
+    invariant(_collection);  // If isEOF() returns false, we must have a collection.
 
     // It is possible that after a delete was executed, a WriteConflictException occurred
     // and prevented us from returning ADVANCED with the old version of the document.
     if (_idReturning != WorkingSet::INVALID_ID) {
         // We should only get here if we were trying to return something before.
-        invariant(_params->returnDeleted);
+        invariant(_params.returnDeleted);
 
         WorkingSetMember* member = _ws->get(_idReturning);
         invariant(member->getState() == WorkingSetMember::OWNED_OBJ);
@@ -125,6 +131,7 @@ PlanStage::StageState DeleteStage::doWork(WorkingSetID* out) {
                 break;
 
             case PlanStage::FAILURE:
+            case PlanStage::DEAD:
                 // The stage which produces a failure is responsible for allocating a working set
                 // member with error details.
                 invariant(WorkingSet::INVALID_ID != id);
@@ -150,9 +157,13 @@ PlanStage::StageState DeleteStage::doWork(WorkingSetID* out) {
     WorkingSetMember* member = _ws->get(id);
 
     // We want to free this member when we return, unless we need to retry deleting or returning it.
-    auto memberFreer = makeGuard([&] { _ws->free(id); });
+    ScopeGuard memberFreer = MakeGuard(&WorkingSet::free, _ws, id);
 
-    invariant(member->hasRecordId());
+    if (!member->hasRecordId()) {
+        // We expect to be here because of an invalidation causing a force-fetch.
+        ++_specificStats.nInvalidateSkips;
+        return PlanStage::NEED_TIME;
+    }
     RecordId recordId = member->recordId;
     // Deletes can't have projections. This means that covering analysis will always add
     // a fetch. We should always get fetched data, and never just key data.
@@ -162,17 +173,17 @@ PlanStage::StageState DeleteStage::doWork(WorkingSetID* out) {
     bool docStillMatches;
     try {
         docStillMatches = write_stage_common::ensureStillMatches(
-            collection(), getOpCtx(), _ws, id, _params->canonicalQuery);
+            _collection, getOpCtx(), _ws, id, _params.canonicalQuery);
     } catch (const WriteConflictException&) {
         // There was a problem trying to detect if the document still exists, so retry.
-        memberFreer.dismiss();
+        memberFreer.Dismiss();
         return prepareToRetryWSM(id, out);
     }
 
     if (!docStillMatches) {
         // Either the document has already been deleted, or it has been updated such that it no
         // longer matches the predicate.
-        if (shouldRestartDeleteIfNoLongerMatches(_params.get())) {
+        if (shouldRestartDeleteIfNoLongerMatches(_params)) {
             throw WriteConflictException();
         }
         return PlanStage::NEED_TIME;
@@ -180,17 +191,13 @@ PlanStage::StageState DeleteStage::doWork(WorkingSetID* out) {
 
     // Ensure that the BSONObj underlying the WorkingSetMember is owned because saveState() is
     // allowed to free the memory.
-    if (_params->returnDeleted) {
+    if (_params.returnDeleted) {
         // Save a copy of the document that is about to get deleted, but keep it in the RID_AND_OBJ
         // state in case we need to retry deleting it.
         BSONObj deletedDoc = member->obj.value();
         member->obj.setValue(deletedDoc.getOwned());
     }
 
-    if (_params->removeSaver) {
-        uassertStatusOK(_params->removeSaver->goingToDelete(member->obj.value()));
-    }
-
     // TODO: Do we want to buffer docs and delete them in a group rather than saving/restoring state
     // repeatedly?
 
@@ -202,26 +209,26 @@ PlanStage::StageState DeleteStage::doWork(WorkingSetID* out) {
     }
 
     // Do the write, unless this is an explain.
-    if (!_params->isExplain) {
+    if (!_params.isExplain) {
         try {
             WriteUnitOfWork wunit(getOpCtx());
-            collection()->deleteDocument(getOpCtx(),
-                                         _params->stmtId,
-                                         recordId,
-                                         _params->opDebug,
-                                         _params->fromMigrate,
-                                         false,
-                                         _params->returnDeleted ? Collection::StoreDeletedDoc::On
-                                                                : Collection::StoreDeletedDoc::Off);
+            _collection->deleteDocument(getOpCtx(),
+                                        _params.stmtId,
+                                        recordId,
+                                        _params.opDebug,
+                                        _params.fromMigrate,
+                                        false,
+                                        _params.returnDeleted ? Collection::StoreDeletedDoc::On
+                                                              : Collection::StoreDeletedDoc::Off);
             wunit.commit();
         } catch (const WriteConflictException&) {
-            memberFreer.dismiss();  // Keep this member around so we can retry deleting it.
+            memberFreer.Dismiss();  // Keep this member around so we can retry deleting it.
             return prepareToRetryWSM(id, out);
         }
     }
     ++_specificStats.docsDeleted;
 
-    if (_params->returnDeleted) {
+    if (_params.returnDeleted) {
         // After deleting the document, the RecordId associated with this member is invalid.
         // Remove the 'recordId' from the WorkingSetMember before returning it.
         member->recordId = RecordId();
@@ -236,23 +243,23 @@ PlanStage::StageState DeleteStage::doWork(WorkingSetID* out) {
     } catch (const WriteConflictException&) {
         // Note we don't need to retry anything in this case since the delete already was committed.
         // However, we still need to return the deleted document (if it was requested).
-        if (_params->returnDeleted) {
+        if (_params.returnDeleted) {
             // member->obj should refer to the deleted document.
             invariant(member->getState() == WorkingSetMember::OWNED_OBJ);
 
             _idReturning = id;
             // Keep this member around so that we can return it on the next work() call.
-            memberFreer.dismiss();
+            memberFreer.Dismiss();
         }
         *out = WorkingSet::INVALID_ID;
         return NEED_YIELD;
     }
 
-    if (_params->returnDeleted) {
+    if (_params.returnDeleted) {
         // member->obj should refer to the deleted document.
         invariant(member->getState() == WorkingSetMember::OWNED_OBJ);
 
-        memberFreer.dismiss();  // Keep this member around so we can return it.
+        memberFreer.Dismiss();  // Keep this member around so we can return it.
         *out = id;
         return PlanStage::ADVANCED;
     }
@@ -260,12 +267,13 @@ PlanStage::StageState DeleteStage::doWork(WorkingSetID* out) {
     return PlanStage::NEED_TIME;
 }
 
-void DeleteStage::doRestoreStateRequiresCollection() {
-    const NamespaceString& ns = collection()->ns();
+void DeleteStage::doRestoreState() {
+    invariant(_collection);
+    const NamespaceString& ns(_collection->ns());
     uassert(ErrorCodes::PrimarySteppedDown,
             str::stream() << "Demoted from primary while removing from " << ns.ns(),
             !getOpCtx()->writesAreReplicated() ||
-                repl::ReplicationCoordinator::get(getOpCtx())->canAcceptWritesFor(getOpCtx(), ns));
+                repl::getGlobalReplicationCoordinator()->canAcceptWritesFor(getOpCtx(), ns));
 }
 
 unique_ptr<PlanStageStats> DeleteStage::getStats() {
@@ -283,31 +291,11 @@ const SpecificStats* DeleteStage::getSpecificStats() const {
 // static
 long long DeleteStage::getNumDeleted(const PlanExecutor& exec) {
     invariant(exec.getRootStage()->isEOF());
-
-    // If we're deleting from a non-existent collection, then the delete plan may have an EOF as the
-    // root stage.
-    if (exec.getRootStage()->stageType() == STAGE_EOF) {
-        return 0LL;
-    }
-
-    // If the collection exists, the delete plan may either have a delete stage at the root, or (for
-    // findAndModify) a projection stage wrapping a delete stage.
-    switch (exec.getRootStage()->stageType()) {
-        case StageType::STAGE_PROJECTION_DEFAULT:
-        case StageType::STAGE_PROJECTION_COVERED:
-        case StageType::STAGE_PROJECTION_SIMPLE: {
-            invariant(exec.getRootStage()->getChildren().size() == 1U);
-            invariant(StageType::STAGE_DELETE == exec.getRootStage()->child()->stageType());
-            const SpecificStats* stats = exec.getRootStage()->child()->getSpecificStats();
-            return static_cast<const DeleteStats*>(stats)->docsDeleted;
-        }
-        default: {
-            invariant(StageType::STAGE_DELETE == exec.getRootStage()->stageType());
-            const auto* deleteStats =
-                static_cast<const DeleteStats*>(exec.getRootStage()->getSpecificStats());
-            return deleteStats->docsDeleted;
-        }
-    }
+    invariant(exec.getRootStage()->stageType() == STAGE_DELETE);
+    DeleteStage* deleteStage = static_cast<DeleteStage*>(exec.getRootStage());
+    const DeleteStats* deleteStats =
+        static_cast<const DeleteStats*>(deleteStage->getSpecificStats());
+    return deleteStats->docsDeleted;
 }
 
 PlanStage::StageState DeleteStage::prepareToRetryWSM(WorkingSetID idToRetry, WorkingSetID* out) {
