@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -27,7 +28,7 @@
  *    it in the license file.
  */
 
-#define MONGO_LOGV2_DEFAULT_COMPONENT ::mongo::logv2::LogComponent::kQuery
+#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kQuery
 
 #include "mongo/platform/basic.h"
 
@@ -36,10 +37,10 @@
 #include <memory>
 #include <vector>
 
+#include "mongo/client/dbclientinterface.h"
 #include "mongo/db/exec/multi_plan.h"
 #include "mongo/db/exec/scoped_timer.h"
 #include "mongo/db/matcher/extensions_callback_real.h"
-#include "mongo/db/query/collection_query_info.h"
 #include "mongo/db/query/get_executor.h"
 #include "mongo/db/query/plan_executor.h"
 #include "mongo/db/query/planner_access.h"
@@ -47,7 +48,8 @@
 #include "mongo/db/query/query_planner.h"
 #include "mongo/db/query/query_planner_common.h"
 #include "mongo/db/query/stage_builder.h"
-#include "mongo/logv2/log.h"
+#include "mongo/stdx/memory.h"
+#include "mongo/util/log.h"
 #include "mongo/util/scopeguard.h"
 #include "mongo/util/transitional_tools_do_not_use/vector_spooling.h"
 
@@ -56,24 +58,45 @@ namespace mongo {
 using std::endl;
 using std::unique_ptr;
 using std::vector;
+using stdx::make_unique;
 
 const char* SubplanStage::kStageType = "SUBPLAN";
 
-SubplanStage::SubplanStage(ExpressionContext* expCtx,
-                           const Collection* collection,
+SubplanStage::SubplanStage(OperationContext* opCtx,
+                           Collection* collection,
                            WorkingSet* ws,
                            const QueryPlannerParams& params,
                            CanonicalQuery* cq)
-    : RequiresAllIndicesStage(kStageType, expCtx, collection),
+    : PlanStage(kStageType, opCtx),
+      _collection(collection),
       _ws(ws),
       _plannerParams(params),
       _query(cq) {
-    invariant(cq);
-    invariant(_query->root()->matchType() == MatchExpression::OR);
-    invariant(_query->root()->numChildren(),
-              "Cannot use a SUBPLAN stage for an $or with no children");
+    invariant(_collection);
 }
 
+namespace {
+
+/**
+ * Returns true if 'expr' is an AND that contains a single OR child.
+ */
+bool isContainedOr(const MatchExpression* expr) {
+    if (MatchExpression::AND != expr->matchType()) {
+        return false;
+    }
+
+    size_t numOrs = 0;
+    for (size_t i = 0; i < expr->numChildren(); ++i) {
+        if (MatchExpression::OR == expr->getChild(i)->matchType()) {
+            ++numOrs;
+        }
+    }
+
+    return (numOrs == 1U);
+}
+
+}  // namespace
+
 bool SubplanStage::canUseSubplanning(const CanonicalQuery& query) {
     const QueryRequest& qr = query.getQueryRequest();
     const MatchExpression* expr = query.root();
@@ -100,32 +123,77 @@ bool SubplanStage::canUseSubplanning(const CanonicalQuery& query) {
         return false;
     }
 
-    // We can only subplan rooted $or queries, and only if they have at least one clause.
-    return MatchExpression::OR == expr->matchType() && expr->numChildren() > 0;
+    // Snapshot is really a hint.
+    if (query.getQueryRequest().isSnapshot()) {
+        return false;
+    }
+
+    // TODO: For now we only allow rooted OR. We should consider also allowing contained OR that
+    // does not have a TEXT or GEO_NEAR node.
+    return MatchExpression::OR == expr->matchType();
+}
+
+std::unique_ptr<MatchExpression> SubplanStage::rewriteToRootedOr(
+    std::unique_ptr<MatchExpression> root) {
+    dassert(isContainedOr(root.get()));
+
+    // Detach the OR from the root.
+    std::vector<MatchExpression*>& rootChildren = *root->getChildVector();
+    std::unique_ptr<MatchExpression> orChild;
+    for (size_t i = 0; i < rootChildren.size(); ++i) {
+        if (MatchExpression::OR == rootChildren[i]->matchType()) {
+            orChild.reset(rootChildren[i]);
+            rootChildren.erase(rootChildren.begin() + i);
+            break;
+        }
+    }
+
+    // We should have found an OR, and the OR should have at least 2 children.
+    invariant(orChild);
+    invariant(orChild->getChildVector());
+    invariant(orChild->getChildVector()->size() > 1U);
+
+    // AND the existing root with each OR child.
+    std::vector<MatchExpression*>& orChildren = *orChild->getChildVector();
+    for (size_t i = 0; i < orChildren.size(); ++i) {
+        std::unique_ptr<AndMatchExpression> ama = stdx::make_unique<AndMatchExpression>();
+        ama->add(orChildren[i]);
+        ama->add(root->shallowClone().release());
+        orChildren[i] = ama.release();
+    }
+
+    // Normalize and sort the resulting match expression.
+    orChild = MatchExpression::optimize(std::move(orChild));
+    CanonicalQuery::sortTree(orChild.get());
+
+    return orChild;
 }
 
 Status SubplanStage::planSubqueries() {
     _orExpression = _query->root()->shallowClone();
+    if (isContainedOr(_orExpression.get())) {
+        _orExpression = rewriteToRootedOr(std::move(_orExpression));
+        invariant(CanonicalQuery::isValid(_orExpression.get(), _query->getQueryRequest()).isOK());
+    }
+
     for (size_t i = 0; i < _plannerParams.indices.size(); ++i) {
         const IndexEntry& ie = _plannerParams.indices[i];
-        const auto insertionRes = _indexMap.insert(std::make_pair(ie.identifier, i));
-        // Be sure the key was not already in the map.
-        invariant(insertionRes.second);
-        LOGV2_DEBUG(20598, 5, "Subplanner: index {i} is {ie}", "i"_attr = i, "ie"_attr = ie);
+        _indexMap[ie.name] = i;
+        LOG(5) << "Subplanner: index " << i << " is " << ie;
     }
 
     for (size_t i = 0; i < _orExpression->numChildren(); ++i) {
         // We need a place to shove the results from planning this branch.
-        _branchResults.push_back(std::make_unique<BranchPlanningResult>());
+        _branchResults.push_back(stdx::make_unique<BranchPlanningResult>());
         BranchPlanningResult* branchResult = _branchResults.back().get();
 
         MatchExpression* orChild = _orExpression->getChild(i);
 
         // Turn the i-th child into its own query.
-        auto statusWithCQ = CanonicalQuery::canonicalize(opCtx(), *_query, orChild);
+        auto statusWithCQ = CanonicalQuery::canonicalize(getOpCtx(), *_query, orChild);
         if (!statusWithCQ.isOK()) {
-            str::stream ss;
-            ss << "Can't canonicalize subchild " << orChild->debugString() << " "
+            mongoutils::str::stream ss;
+            ss << "Can't canonicalize subchild " << orChild->toString() << " "
                << statusWithCQ.getStatus().reason();
             return Status(ErrorCodes::BadValue, ss);
         }
@@ -134,48 +202,43 @@ Status SubplanStage::planSubqueries() {
 
         // Plan the i-th child. We might be able to find a plan for the i-th child in the plan
         // cache. If there's no cached plan, then we generate and rank plans using the MPS.
-        const auto* planCache = CollectionQueryInfo::get(collection()).getPlanCache();
+        CachedSolution* rawCS;
+        if (PlanCache::shouldCacheQuery(*branchResult->canonicalQuery) &&
+            _collection->infoCache()
+                ->getPlanCache()
+                ->get(*branchResult->canonicalQuery, &rawCS)
+                .isOK()) {
+            // We have a CachedSolution. Store it for later.
+            LOG(5) << "Subplanner: cached plan found for child " << i << " of "
+                   << _orExpression->numChildren();
 
-        // Populate branchResult->cachedSolution if an active cachedSolution entry exists.
-        if (planCache->shouldCacheQuery(*branchResult->canonicalQuery)) {
-            auto planCacheKey = planCache->computeKey(*branchResult->canonicalQuery);
-            if (auto cachedSol = planCache->getCacheEntryIfActive(planCacheKey)) {
-                // We have a CachedSolution. Store it for later.
-                LOGV2_DEBUG(
-                    20599,
-                    5,
-                    "Subplanner: cached plan found for child {i} of {orExpression_numChildren}",
-                    "i"_attr = i,
-                    "orExpression_numChildren"_attr = _orExpression->numChildren());
-
-                branchResult->cachedSolution = std::move(cachedSol);
-            }
-        }
-
-        if (!branchResult->cachedSolution) {
+            branchResult->cachedSolution.reset(rawCS);
+        } else {
             // No CachedSolution found. We'll have to plan from scratch.
-            LOGV2_DEBUG(20600,
-                        5,
-                        "Subplanner: planning child {i} of {orExpression_numChildren}",
-                        "i"_attr = i,
-                        "orExpression_numChildren"_attr = _orExpression->numChildren());
+            LOG(5) << "Subplanner: planning child " << i << " of " << _orExpression->numChildren();
 
             // We don't set NO_TABLE_SCAN because peeking at the cache data will keep us from
             // considering any plan that's a collscan.
             invariant(branchResult->solutions.empty());
-            auto solutions = QueryPlanner::plan(*branchResult->canonicalQuery, _plannerParams);
-            if (!solutions.isOK()) {
-                str::stream ss;
+            std::vector<QuerySolution*> rawSolutions;
+            Status status =
+                QueryPlanner::plan(*branchResult->canonicalQuery, _plannerParams, &rawSolutions);
+            branchResult->solutions = transitional_tools_do_not_use::spool_vector(rawSolutions);
+
+            if (!status.isOK()) {
+                mongoutils::str::stream ss;
                 ss << "Can't plan for subchild " << branchResult->canonicalQuery->toString() << " "
-                   << solutions.getStatus().reason();
+                   << status.reason();
                 return Status(ErrorCodes::BadValue, ss);
             }
-            branchResult->solutions = std::move(solutions.getValue());
+            LOG(5) << "Subplanner: got " << branchResult->solutions.size() << " solutions";
 
-            LOGV2_DEBUG(20601,
-                        5,
-                        "Subplanner: got {branchResult_solutions_size} solutions",
-                        "branchResult_solutions_size"_attr = branchResult->solutions.size());
+            if (0 == branchResult->solutions.size()) {
+                // If one child doesn't have an indexed solution, bail out.
+                mongoutils::str::stream ss;
+                ss << "No solutions for subchild " << branchResult->canonicalQuery->toString();
+                return Status(ErrorCodes::BadValue, ss);
+            }
         }
     }
 
@@ -191,21 +254,21 @@ namespace {
 Status tagOrChildAccordingToCache(PlanCacheIndexTree* compositeCacheData,
                                   SolutionCacheData* branchCacheData,
                                   MatchExpression* orChild,
-                                  const std::map<IndexEntry::Identifier, size_t>& indexMap) {
+                                  const std::map<StringData, size_t>& indexMap) {
     invariant(compositeCacheData);
 
     // We want a well-formed *indexed* solution.
-    if (nullptr == branchCacheData) {
+    if (NULL == branchCacheData) {
         // For example, we don't cache things for 2d indices.
-        str::stream ss;
-        ss << "No cache data for subchild " << orChild->debugString();
-        return Status(ErrorCodes::NoQueryExecutionPlans, ss);
+        mongoutils::str::stream ss;
+        ss << "No cache data for subchild " << orChild->toString();
+        return Status(ErrorCodes::BadValue, ss);
     }
 
     if (SolutionCacheData::USE_INDEX_TAGS_SOLN != branchCacheData->solnType) {
-        str::stream ss;
-        ss << "No indexed cache data for subchild " << orChild->debugString();
-        return Status(ErrorCodes::NoQueryExecutionPlans, ss);
+        mongoutils::str::stream ss;
+        ss << "No indexed cache data for subchild " << orChild->toString();
+        return Status(ErrorCodes::BadValue, ss);
     }
 
     // Add the index assignments to our original query.
@@ -213,9 +276,9 @@ Status tagOrChildAccordingToCache(PlanCacheIndexTree* compositeCacheData,
         QueryPlanner::tagAccordingToCache(orChild, branchCacheData->tree.get(), indexMap);
 
     if (!tagStatus.isOK()) {
-        str::stream ss;
-        ss << "Failed to extract indices from subchild " << orChild->debugString();
-        return tagStatus.withContext(ss);
+        mongoutils::str::stream ss;
+        ss << "Failed to extract indices from subchild " << orChild->toString();
+        return Status(ErrorCodes::BadValue, ss);
     }
 
     // Add the child's cache data to the cache data we're creating for the main query.
@@ -236,11 +299,8 @@ Status SubplanStage::choosePlanForSubqueries(PlanYieldPolicy* yieldPolicy) {
 
         if (branchResult->cachedSolution.get()) {
             // We can get the index tags we need out of the cache.
-            Status tagStatus =
-                tagOrChildAccordingToCache(cacheData.get(),
-                                           branchResult->cachedSolution->plannerData.get(),
-                                           orChild,
-                                           _indexMap);
+            Status tagStatus = tagOrChildAccordingToCache(
+                cacheData.get(), branchResult->cachedSolution->plannerData[0], orChild, _indexMap);
             if (!tagStatus.isOK()) {
                 return tagStatus;
             }
@@ -261,15 +321,15 @@ Status SubplanStage::choosePlanForSubqueries(PlanYieldPolicy* yieldPolicy) {
 
             // We pass the SometimesCache option to the MPS because the SubplanStage currently does
             // not use the CachedPlanStage's eviction mechanism. We therefore are more conservative
-            // about putting a potentially bad plan into the cache in the subplan path.  We
-            // temporarily add the MPS to _children to ensure that we pass down all save/restore
-            // messages that can be generated if pickBestPlan yields.
+            // about putting a potentially bad plan into the cache in the subplan path.
+            // We temporarily add the MPS to _children to ensure that we pass down all
+            // save/restore/invalidate messages that can be generated if pickBestPlan yields.
             invariant(_children.empty());
             _children.emplace_back(
-                std::make_unique<MultiPlanStage>(expCtx(),
-                                                 collection(),
-                                                 branchResult->canonicalQuery.get(),
-                                                 MultiPlanStage::CachingMode::SometimesCache));
+                stdx::make_unique<MultiPlanStage>(getOpCtx(),
+                                                  _collection,
+                                                  branchResult->canonicalQuery.get(),
+                                                  MultiPlanStage::CachingMode::SometimesCache));
             ON_BLOCK_EXIT([&] {
                 invariant(_children.size() == 1);  // Make sure nothing else was added to _children.
                 _children.pop_back();
@@ -278,14 +338,16 @@ Status SubplanStage::choosePlanForSubqueries(PlanYieldPolicy* yieldPolicy) {
 
             // Dump all the solutions into the MPS.
             for (size_t ix = 0; ix < branchResult->solutions.size(); ++ix) {
-                auto nextPlanRoot = StageBuilder::build(opCtx(),
-                                                        collection(),
-                                                        *branchResult->canonicalQuery,
-                                                        *branchResult->solutions[ix],
-                                                        _ws);
+                PlanStage* nextPlanRoot;
+                invariant(StageBuilder::build(getOpCtx(),
+                                              _collection,
+                                              *branchResult->canonicalQuery,
+                                              *branchResult->solutions[ix],
+                                              _ws,
+                                              &nextPlanRoot));
 
-                multiPlanStage->addPlan(
-                    std::move(branchResult->solutions[ix]), std::move(nextPlanRoot), _ws);
+                // Takes ownership of solution with index 'ix' and 'nextPlanRoot'.
+                multiPlanStage->addPlan(branchResult->solutions[ix].release(), nextPlanRoot, _ws);
             }
 
             Status planSelectStat = multiPlanStage->pickBestPlan(yieldPolicy);
@@ -294,26 +356,26 @@ Status SubplanStage::choosePlanForSubqueries(PlanYieldPolicy* yieldPolicy) {
             }
 
             if (!multiPlanStage->bestPlanChosen()) {
-                str::stream ss;
+                mongoutils::str::stream ss;
                 ss << "Failed to pick best plan for subchild "
                    << branchResult->canonicalQuery->toString();
-                return Status(ErrorCodes::NoQueryExecutionPlans, ss);
+                return Status(ErrorCodes::BadValue, ss);
             }
 
             QuerySolution* bestSoln = multiPlanStage->bestSolution();
 
             // Check that we have good cache data. For example, we don't cache things
             // for 2d indices.
-            if (nullptr == bestSoln->cacheData.get()) {
-                str::stream ss;
-                ss << "No cache data for subchild " << orChild->debugString();
-                return Status(ErrorCodes::NoQueryExecutionPlans, ss);
+            if (NULL == bestSoln->cacheData.get()) {
+                mongoutils::str::stream ss;
+                ss << "No cache data for subchild " << orChild->toString();
+                return Status(ErrorCodes::BadValue, ss);
             }
 
             if (SolutionCacheData::USE_INDEX_TAGS_SOLN != bestSoln->cacheData->solnType) {
-                str::stream ss;
-                ss << "No indexed cache data for subchild " << orChild->debugString();
-                return Status(ErrorCodes::NoQueryExecutionPlans, ss);
+                mongoutils::str::stream ss;
+                ss << "No indexed cache data for subchild " << orChild->toString();
+                return Status(ErrorCodes::BadValue, ss);
             }
 
             // Add the index assignments to our original query.
@@ -321,9 +383,9 @@ Status SubplanStage::choosePlanForSubqueries(PlanYieldPolicy* yieldPolicy) {
                 orChild, bestSoln->cacheData->tree.get(), _indexMap);
 
             if (!tagStatus.isOK()) {
-                str::stream ss;
-                ss << "Failed to extract indices from subchild " << orChild->debugString();
-                return tagStatus.withContext(ss);
+                mongoutils::str::stream ss;
+                ss << "Failed to extract indices from subchild " << orChild->toString();
+                return Status(ErrorCodes::BadValue, ss);
             }
 
             cacheData->children.push_back(bestSoln->cacheData->tree->clone());
@@ -338,36 +400,33 @@ Status SubplanStage::choosePlanForSubqueries(PlanYieldPolicy* yieldPolicy) {
         *_query, std::move(_orExpression), _plannerParams.indices, _plannerParams));
 
     if (!solnRoot) {
-        str::stream ss;
+        mongoutils::str::stream ss;
         ss << "Failed to build indexed data path for subplanned query\n";
-        return Status(ErrorCodes::NoQueryExecutionPlans, ss);
+        return Status(ErrorCodes::BadValue, ss);
     }
 
-    LOGV2_DEBUG(20602,
-                5,
-                "Subplanner: fully tagged tree is {solnRoot}",
-                "solnRoot"_attr = redact(solnRoot->toString()));
+    LOG(5) << "Subplanner: fully tagged tree is " << redact(solnRoot->toString());
 
-    _compositeSolution =
-        QueryPlannerAnalysis::analyzeDataAccess(*_query, _plannerParams, std::move(solnRoot));
+    // Takes ownership of 'solnRoot'
+    _compositeSolution.reset(
+        QueryPlannerAnalysis::analyzeDataAccess(*_query, _plannerParams, std::move(solnRoot)));
 
-    if (nullptr == _compositeSolution.get()) {
-        str::stream ss;
+    if (NULL == _compositeSolution.get()) {
+        mongoutils::str::stream ss;
         ss << "Failed to analyze subplanned query";
-        return Status(ErrorCodes::NoQueryExecutionPlans, ss);
+        return Status(ErrorCodes::BadValue, ss);
     }
 
-    LOGV2_DEBUG(20603,
-                5,
-                "Subplanner: Composite solution is {compositeSolution}",
-                "compositeSolution"_attr = redact(_compositeSolution->toString()));
+    LOG(5) << "Subplanner: Composite solution is " << redact(_compositeSolution->toString());
 
     // Use the index tags from planning each branch to construct the composite solution,
     // and set that solution as our child stage.
     _ws->clear();
-    auto root = StageBuilder::build(opCtx(), collection(), *_query, *_compositeSolution.get(), _ws);
+    PlanStage* root;
+    invariant(StageBuilder::build(
+        getOpCtx(), _collection, *_query, *_compositeSolution.get(), _ws, &root));
     invariant(_children.empty());
-    _children.emplace_back(std::move(root));
+    _children.emplace_back(root);
 
     return Status::OK();
 }
@@ -377,19 +436,30 @@ Status SubplanStage::choosePlanWholeQuery(PlanYieldPolicy* yieldPolicy) {
     _ws->clear();
 
     // Use the query planning module to plan the whole query.
-    auto statusWithSolutions = QueryPlanner::plan(*_query, _plannerParams);
-    if (!statusWithSolutions.isOK()) {
-        return statusWithSolutions.getStatus().withContext(
-            str::stream() << "error processing query: " << _query->toString()
-                          << " planner returned error");
+    std::vector<QuerySolution*> rawSolutions;
+    Status status = QueryPlanner::plan(*_query, _plannerParams, &rawSolutions);
+    std::vector<std::unique_ptr<QuerySolution>> solutions =
+        transitional_tools_do_not_use::spool_vector(rawSolutions);
+    if (!status.isOK()) {
+        return Status(ErrorCodes::BadValue,
+                      "error processing query: " + _query->toString() +
+                          " planner returned error: " + status.reason());
+    }
+
+    // We cannot figure out how to answer the query.  Perhaps it requires an index
+    // we do not have?
+    if (0 == solutions.size()) {
+        return Status(ErrorCodes::BadValue,
+                      str::stream() << "error processing query: " << _query->toString()
+                                    << " No query solutions");
     }
-    auto solutions = std::move(statusWithSolutions.getValue());
 
     if (1 == solutions.size()) {
+        PlanStage* root;
         // Only one possible plan.  Run it.  Build the stages from the solution.
-        auto root = StageBuilder::build(opCtx(), collection(), *_query, *solutions[0], _ws);
+        verify(StageBuilder::build(getOpCtx(), _collection, *_query, *solutions[0], _ws, &root));
         invariant(_children.empty());
-        _children.emplace_back(std::move(root));
+        _children.emplace_back(root);
 
         // This SubplanStage takes ownership of the query solution.
         _compositeSolution = std::move(solutions.back());
@@ -400,7 +470,7 @@ Status SubplanStage::choosePlanWholeQuery(PlanYieldPolicy* yieldPolicy) {
         // Many solutions. Create a MultiPlanStage to pick the best, update the cache,
         // and so on. The working set will be shared by all candidate plans.
         invariant(_children.empty());
-        _children.emplace_back(new MultiPlanStage(expCtx(), collection(), _query));
+        _children.emplace_back(new MultiPlanStage(getOpCtx(), _collection, _query));
         MultiPlanStage* multiPlanStage = static_cast<MultiPlanStage*>(child().get());
 
         for (size_t ix = 0; ix < solutions.size(); ++ix) {
@@ -408,10 +478,13 @@ Status SubplanStage::choosePlanWholeQuery(PlanYieldPolicy* yieldPolicy) {
                 solutions[ix]->cacheData->indexFilterApplied = _plannerParams.indexFiltersApplied;
             }
 
-            auto nextPlanRoot =
-                StageBuilder::build(opCtx(), collection(), *_query, *solutions[ix], _ws);
+            // version of StageBuild::build when WorkingSet is shared
+            PlanStage* nextPlanRoot;
+            verify(StageBuilder::build(
+                getOpCtx(), _collection, *_query, *solutions[ix], _ws, &nextPlanRoot));
 
-            multiPlanStage->addPlan(std::move(solutions[ix]), std::move(nextPlanRoot), _ws);
+            // Takes ownership of 'solutions[ix]' and 'nextPlanRoot'.
+            multiPlanStage->addPlan(solutions[ix].release(), nextPlanRoot, _ws);
         }
 
         // Delegate the the MultiPlanStage's plan selection facility.
@@ -429,17 +502,16 @@ Status SubplanStage::pickBestPlan(PlanYieldPolicy* yieldPolicy) {
     // work that happens here, so this is needed for the time accounting to make sense.
     ScopedTimer timer(getClock(), &_commonStats.executionTimeMillis);
 
-    // During plan selection, the list of indices we are using to plan must remain stable, so the
-    // query will die during yield recovery if any index has been dropped. However, once plan
-    // selection completes successfully, we no longer need all indices to stick around. The selected
-    // plan should safely die on yield recovery if it is using the dropped index.
-    //
-    // Dismiss the requirement that no indices can be dropped when this method returns.
-    ON_BLOCK_EXIT([this] { releaseAllIndicesRequirement(); });
-
     // Plan each branch of the $or.
     Status subplanningStatus = planSubqueries();
     if (!subplanningStatus.isOK()) {
+        if (subplanningStatus == ErrorCodes::QueryPlanKilled ||
+            subplanningStatus == ErrorCodes::ExceededTimeLimit) {
+            // Query planning cannot continue if the plan for one of the subqueries was killed
+            // because the collection or a candidate index may have been dropped, or if we've
+            // exceeded the operation's time limit.
+            return subplanningStatus;
+        }
         return choosePlanWholeQuery(yieldPolicy);
     }
 
@@ -447,10 +519,11 @@ Status SubplanStage::pickBestPlan(PlanYieldPolicy* yieldPolicy) {
     // the overall winning plan from the resulting index tags.
     Status subplanSelectStat = choosePlanForSubqueries(yieldPolicy);
     if (!subplanSelectStat.isOK()) {
-        if (subplanSelectStat != ErrorCodes::NoQueryExecutionPlans) {
-            // Query planning can continue if we failed to find a solution for one of the
-            // children. Otherwise, it cannot, as it may no longer be safe to access the collection
-            // (and index may have been dropped, we may have exceeded the time limit, etc).
+        if (subplanSelectStat == ErrorCodes::QueryPlanKilled ||
+            subplanSelectStat == ErrorCodes::ExceededTimeLimit) {
+            // Query planning cannot continue if the plan for one of the subqueries was killed
+            // because the collection or a candidate index may have been dropped, or if we've
+            // exceeded the operation's time limit.
             return subplanSelectStat;
         }
         return choosePlanWholeQuery(yieldPolicy);
@@ -476,17 +549,17 @@ PlanStage::StageState SubplanStage::doWork(WorkingSetID* out) {
 
 unique_ptr<PlanStageStats> SubplanStage::getStats() {
     _commonStats.isEOF = isEOF();
-    unique_ptr<PlanStageStats> ret = std::make_unique<PlanStageStats>(_commonStats, STAGE_SUBPLAN);
+    unique_ptr<PlanStageStats> ret = make_unique<PlanStageStats>(_commonStats, STAGE_SUBPLAN);
     ret->children.emplace_back(child()->getStats());
     return ret;
 }
 
 bool SubplanStage::branchPlannedFromCache(size_t i) const {
-    return nullptr != _branchResults[i]->cachedSolution.get();
+    return NULL != _branchResults[i]->cachedSolution.get();
 }
 
 const SpecificStats* SubplanStage::getSpecificStats() const {
-    return nullptr;
+    return NULL;
 }
 
 }  // namespace mongo
