@@ -45,8 +45,10 @@
 #include "mongo/db/op_observer.h"
 #include "mongo/db/ops/update_lifecycle.h"
 #include "mongo/db/query/explain.h"
-#include "mongo/db/repl/replication_coordinator.h"
+#include "mongo/db/repl/replication_coordinator_global.h"
+#include "mongo/db/s/collection_metadata.h"
 #include "mongo/db/s/collection_sharding_state.h"
+#include "mongo/db/s/metadata_manager.h"
 #include "mongo/db/service_context.h"
 #include "mongo/db/update/storage_validation.h"
 #include "mongo/stdx/memory.h"
@@ -135,8 +137,8 @@ bool shouldRestartUpdateIfNoLongerMatches(const UpdateStageParams& params) {
 
 const std::vector<std::unique_ptr<FieldRef>>* getImmutableFields(OperationContext* opCtx,
                                                                  const NamespaceString& ns) {
-    auto metadata = CollectionShardingState::get(opCtx, ns)->getCurrentMetadata();
-    if (metadata->isSharded()) {
+    auto metadata = CollectionShardingState::get(opCtx, ns)->getMetadata();
+    if (metadata) {
         const std::vector<std::unique_ptr<FieldRef>>& fields = metadata->getKeyPatternFields();
         // Return shard-keys as immutable for the update system.
         return &fields;
@@ -176,14 +178,6 @@ UpdateStage::UpdateStage(OperationContext* opCtx,
       _doc(params.driver->getDocument()) {
     _children.emplace_back(child);
 
-    // Should the modifiers validate their embedded docs via storage_validation::storageValid()?
-    // Only user updates should be checked. Any system or replication stuff should pass through.
-    // Config db docs also do not get checked.
-    const auto request = _params.request;
-    _enforceOkForStorage =
-        !(request->isFromOplogApplication() || request->getNamespaceString().isConfigDB() ||
-          request->isFromMigration());
-
     // Before we even start executing, we know whether or not this is a replacement
     // style or $mod style update.
     _specificStats.isDocReplacement = params.driver->isDocReplacement();
@@ -214,7 +208,8 @@ BSONObj UpdateStage::transformAndUpdate(const Snapshotted<BSONObj>& oldObj, Reco
     bool docWasModified = false;
 
     Status status = Status::OK();
-    const bool validateForStorage = getOpCtx()->writesAreReplicated() && _enforceOkForStorage;
+    const bool validateForStorage = getOpCtx()->writesAreReplicated() &&
+        !request->isFromMigration() && driver->modOptions().enforceOkForStorage;
     FieldRefSet immutablePaths;
     if (getOpCtx()->writesAreReplicated() && !request->isFromMigration()) {
         if (lifecycle) {
@@ -229,8 +224,13 @@ BSONObj UpdateStage::transformAndUpdate(const Snapshotted<BSONObj>& oldObj, Reco
     }
     if (!driver->needMatchDetails()) {
         // If we don't need match details, avoid doing the rematch
-        status = driver->update(
-            StringData(), &_doc, validateForStorage, immutablePaths, &logObj, &docWasModified);
+        status = driver->update(StringData(),
+                                oldObj.value(),
+                                &_doc,
+                                validateForStorage,
+                                immutablePaths,
+                                &logObj,
+                                &docWasModified);
     } else {
         // If there was a matched field, obtain it.
         MatchDetails matchDetails;
@@ -243,8 +243,13 @@ BSONObj UpdateStage::transformAndUpdate(const Snapshotted<BSONObj>& oldObj, Reco
         if (matchDetails.hasElemMatchKey())
             matchedField = matchDetails.elemMatchKey();
 
-        status = driver->update(
-            matchedField, &_doc, validateForStorage, immutablePaths, &logObj, &docWasModified);
+        status = driver->update(matchedField,
+                                oldObj.value(),
+                                &_doc,
+                                validateForStorage,
+                                immutablePaths,
+                                &logObj,
+                                &docWasModified);
     }
 
     if (!status.isOK()) {
@@ -281,19 +286,20 @@ BSONObj UpdateStage::transformAndUpdate(const Snapshotted<BSONObj>& oldObj, Reco
     }
 
     if (docWasModified) {
+
         // Prepare to write back the modified document
         WriteUnitOfWork wunit(getOpCtx());
 
         RecordId newRecordId;
         OplogUpdateEntryArgs args;
         if (!request->isExplain()) {
-            auto* const css = CollectionShardingState::get(getOpCtx(), _collection->ns());
+            invariant(_collection);
+            auto* css = CollectionShardingState::get(getOpCtx(), _collection->ns());
             args.nss = _collection->ns();
             args.uuid = _collection->uuid();
             args.stmtId = request->getStmtId();
             args.update = logObj;
-            auto metadata = css->getCurrentMetadata();
-            args.criteria = metadata->extractDocumentKey(newObj);
+            args.criteria = css->getMetadata().extractDocumentKey(newObj);
             uassert(16980,
                     "Multi-update operations require all documents to have an '_id' field",
                     !request->isMulti() || args.criteria.hasField("_id"_sd));
@@ -371,7 +377,6 @@ BSONObj UpdateStage::applyUpdateOpsForInsert(OperationContext* opCtx,
                                              mutablebson::Document* doc,
                                              bool isInternalRequest,
                                              const NamespaceString& ns,
-                                             bool enforceOkForStorage,
                                              UpdateStats* stats) {
     // Since this is an insert (no docs found and upsert:true), we will be logging it
     // as an insert in the oplog. We don't need the driver's help to build the
@@ -390,13 +395,18 @@ BSONObj UpdateStage::applyUpdateOpsForInsert(OperationContext* opCtx,
     }
     immutablePaths.keepShortest(&idFieldRef);
 
+    // The original document we compare changes to - immutable paths must not change
+    BSONObj original;
+
     if (cq) {
         uassertStatusOK(driver->populateDocumentWithQueryFields(*cq, immutablePaths, *doc));
         if (driver->isDocReplacement())
             stats->fastmodinsert = true;
+        original = doc->getObject();
     } else {
         fassert(17354, CanonicalQuery::isSimpleIdQuery(query));
         BSONElement idElt = query[idFieldName];
+        original = idElt.wrap();
         fassert(17352, doc->root().appendElement(idElt));
     }
 
@@ -406,7 +416,8 @@ BSONObj UpdateStage::applyUpdateOpsForInsert(OperationContext* opCtx,
     if (isInternalRequest) {
         immutablePaths.clear();
     }
-    Status updateStatus = driver->update(StringData(), doc, validateForStorage, immutablePaths);
+    Status updateStatus =
+        driver->update(StringData(), original, doc, validateForStorage, immutablePaths);
     if (!updateStatus.isOK()) {
         uasserted(16836, updateStatus.reason());
     }
@@ -423,7 +434,7 @@ BSONObj UpdateStage::applyUpdateOpsForInsert(OperationContext* opCtx,
     // that contains all the immutable keys and can be stored if it isn't coming
     // from a migration or via replication.
     if (!isInternalRequest) {
-        if (enforceOkForStorage) {
+        if (driver->modOptions().enforceOkForStorage) {
             storage_validation::storageValid(*doc);
         }
         checkImmutablePathsPresent(*doc, immutablePaths);
@@ -454,7 +465,6 @@ void UpdateStage::doInsert() {
                                              &_doc,
                                              isInternalRequest,
                                              request->getNamespaceString(),
-                                             _enforceOkForStorage,
                                              &_specificStats);
 
     _specificStats.objInserted = newObj;
@@ -715,7 +725,7 @@ void UpdateStage::doRestoreState() {
 
     // We may have stepped down during the yield.
     bool userInitiatedWritesAndNotPrimary = getOpCtx()->writesAreReplicated() &&
-        !repl::ReplicationCoordinator::get(getOpCtx())->canAcceptWritesFor(getOpCtx(), nsString);
+        !repl::getGlobalReplicationCoordinator()->canAcceptWritesFor(getOpCtx(), nsString);
 
     if (userInitiatedWritesAndNotPrimary) {
         uasserted(ErrorCodes::PrimarySteppedDown,
@@ -756,8 +766,8 @@ const UpdateStats* UpdateStage::getUpdateStats(const PlanExecutor* exec) {
 
 void UpdateStage::recordUpdateStatsInOpDebug(const UpdateStats* updateStats, OpDebug* opDebug) {
     invariant(opDebug);
-    opDebug->additiveMetrics.nMatched = updateStats->nMatched;
-    opDebug->additiveMetrics.nModified = updateStats->nModified;
+    opDebug->nMatched = updateStats->nMatched;
+    opDebug->nModified = updateStats->nModified;
     opDebug->upsert = updateStats->inserted;
     opDebug->fastmodinsert = updateStats->fastmodinsert;
 }
