@@ -58,7 +58,7 @@ public:
         _debugAddSpace(debug, level);
 
         BSONObjBuilder builder;
-        serialize(&builder, true);
+        serialize(&builder);
         debug << builder.obj().toString();
     }
 
@@ -94,6 +94,13 @@ public:
         return _expressions[i].get();
     }
 
+    /**
+     * Takes ownership of the MatchExpressions in 'expressions'.
+     */
+    void init(std::array<std::unique_ptr<MatchExpression>, nargs> expressions) {
+        _expressions = std::move(expressions);
+    }
+
     /**
      * The name of this MatchExpression.
      */
@@ -102,11 +109,11 @@ public:
     /**
      * Serializes each subexpression sequentially in a BSONArray.
      */
-    void serialize(BSONObjBuilder* builder, bool includePath) const final {
+    void serialize(BSONObjBuilder* builder) const final {
         BSONArrayBuilder exprArray(builder->subarrayStart(name()));
         for (const auto& expr : _expressions) {
             BSONObjBuilder exprBuilder(exprArray.subobjStart());
-            expr->serialize(&exprBuilder, includePath);
+            expr->serialize(&exprBuilder);
             exprBuilder.doneFast();
         }
         exprArray.doneFast();
@@ -116,6 +123,7 @@ public:
      * Clones this MatchExpression by recursively cloning each sub-expression.
      */
     std::unique_ptr<MatchExpression> shallowClone() const final {
+        std::unique_ptr<T> clone = stdx::make_unique<T>();
         std::array<std::unique_ptr<MatchExpression>, nargs> clonedExpressions;
         std::transform(_expressions.begin(),
                        _expressions.end(),
@@ -124,7 +132,7 @@ public:
                            return orig ? orig->shallowClone()
                                        : std::unique_ptr<MatchExpression>(nullptr);
                        });
-        std::unique_ptr<T> clone = stdx::make_unique<T>(std::move(clonedExpressions));
+        clone->_expressions = std::move(clonedExpressions);
 
         if (getTag()) {
             clone->setTag(getTag()->clone());
@@ -134,12 +142,7 @@ public:
     }
 
 protected:
-    /**
-     * Takes ownership of the MatchExpressions in 'expressions'.
-     */
-    explicit FixedArityMatchExpression(
-        MatchType type, std::array<std::unique_ptr<MatchExpression>, nargs> expressions)
-        : MatchExpression(type), _expressions(std::move(expressions)) {}
+    explicit FixedArityMatchExpression(MatchType type) : MatchExpression(type) {}
 
     const auto& expressions() const {
         return _expressions;
