@@ -36,8 +36,6 @@
 #include "mongo/bson/bsonobj.h"
 #include "mongo/bson/bsonobjbuilder.h"
 #include "mongo/db/matcher/expression_always_boolean.h"
-#include "mongo/db/matcher/expression_path.h"
-#include "mongo/db/matcher/expression_text_base.h"
 
 namespace mongo {
 
@@ -59,10 +57,10 @@ void ListOfMatchExpression::_debugList(StringBuilder& debug, int level) const {
         _expressions[i]->debugString(debug, level + 1);
 }
 
-void ListOfMatchExpression::_listToBSON(BSONArrayBuilder* out, bool includePath) const {
+void ListOfMatchExpression::_listToBSON(BSONArrayBuilder* out) const {
     for (unsigned i = 0; i < _expressions.size(); i++) {
         BSONObjBuilder childBob(out->subobjStart());
-        _expressions[i]->serialize(&childBob, includePath);
+        _expressions[i]->serialize(&childBob);
     }
     out->doneFast();
 }
@@ -117,32 +115,6 @@ MatchExpression::ExpressionOptimizerFunc ListOfMatchExpression::getOptimizer() c
             children.insert(children.end(), absorbedExpressions.begin(), absorbedExpressions.end());
         }
 
-        // Remove all children of AND that are $alwaysTrue and all children of OR that are
-        // $alwaysFalse.
-        if (matchType == AND || matchType == OR) {
-            for (MatchExpression*& childExpression : children) {
-                if ((childExpression->isTriviallyTrue() && matchType == MatchExpression::AND) ||
-                    (childExpression->isTriviallyFalse() && matchType == MatchExpression::OR)) {
-                    std::unique_ptr<MatchExpression> childPtr(childExpression);
-                    childExpression = nullptr;
-                }
-            }
-
-            // We replaced each destroyed child expression with nullptr. Now we remove those
-            // nullptrs from the vector.
-            children.erase(std::remove(children.begin(), children.end(), nullptr), children.end());
-        }
-
-        // Check if the above optimizations eliminated all children. An OR with no children is
-        // always false.
-        // TODO SERVER-34759 It is correct to replace this empty AND with an $alwaysTrue, but we
-        // need to make enhancements to the planner to make it understand an $alwaysTrue and an
-        // empty AND as the same thing. The planner can create inferior plans for $alwaysTrue which
-        // it would not produce for an AND with no children.
-        if (children.empty() && matchType == MatchExpression::OR) {
-            return stdx::make_unique<AlwaysFalseMatchExpression>();
-        }
-
         if (children.size() == 1) {
             if ((matchType == AND || matchType == OR || matchType == INTERNAL_SCHEMA_XOR)) {
                 // Simplify AND/OR/XOR with exactly one operand to an expression consisting of just
@@ -152,28 +124,13 @@ MatchExpression::ExpressionOptimizerFunc ListOfMatchExpression::getOptimizer() c
                 return std::unique_ptr<MatchExpression>(simplifiedExpression);
             } else if (matchType == NOR) {
                 // Simplify NOR of exactly one operand to NOT of that operand.
-                auto simplifiedExpression = stdx::make_unique<NotMatchExpression>(children.front());
+                auto simplifiedExpression = stdx::make_unique<NotMatchExpression>();
+                invariantOK(simplifiedExpression->init(children.front()));
                 children.clear();
                 return std::move(simplifiedExpression);
             }
         }
 
-        if (matchType == MatchExpression::AND || matchType == MatchExpression::OR) {
-            for (auto& childExpression : children) {
-                // An AND containing an expression that always evaluates to false can be
-                // optimized to a single $alwaysFalse expression.
-                if (childExpression->isTriviallyFalse() && matchType == MatchExpression::AND) {
-                    return stdx::make_unique<AlwaysFalseMatchExpression>();
-                }
-
-                // Likewise, an OR containing an expression that always evaluates to true can be
-                // optimized to a single $alwaysTrue expression.
-                if (childExpression->isTriviallyTrue() && matchType == MatchExpression::OR) {
-                    return stdx::make_unique<AlwaysTrueMatchExpression>();
-                }
-            }
-        }
-
         return expression;
     };
 }
@@ -224,7 +181,7 @@ void AndMatchExpression::debugString(StringBuilder& debug, int level) const {
     _debugList(debug, level);
 }
 
-void AndMatchExpression::serialize(BSONObjBuilder* out, bool includePath) const {
+void AndMatchExpression::serialize(BSONObjBuilder* out) const {
     if (!numChildren()) {
         // It is possible for an AndMatchExpression to have no children, resulting in the serialized
         // expression {$and: []}, which is not a valid query object.
@@ -232,14 +189,10 @@ void AndMatchExpression::serialize(BSONObjBuilder* out, bool includePath) const
     }
 
     BSONArrayBuilder arrBob(out->subarrayStart("$and"));
-    _listToBSON(&arrBob, includePath);
+    _listToBSON(&arrBob);
     arrBob.doneFast();
 }
 
-bool AndMatchExpression::isTriviallyTrue() const {
-    return numChildren() == 0;
-}
-
 // -----
 
 bool OrMatchExpression::matches(const MatchableDocument* doc, MatchDetails* details) const {
@@ -267,20 +220,13 @@ void OrMatchExpression::debugString(StringBuilder& debug, int level) const {
     _debugList(debug, level);
 }
 
-void OrMatchExpression::serialize(BSONObjBuilder* out, bool includePath) const {
+void OrMatchExpression::serialize(BSONObjBuilder* out) const {
     if (!numChildren()) {
-        // It is possible for an OrMatchExpression to have no children, resulting in the serialized
-        // expression {$or: []}, which is not a valid query object. An empty $or is logically
-        // equivalent to {$alwaysFalse: 1}.
         out->append(AlwaysFalseMatchExpression::kName, 1);
         return;
     }
     BSONArrayBuilder arrBob(out->subarrayStart("$or"));
-    _listToBSON(&arrBob, includePath);
-}
-
-bool OrMatchExpression::isTriviallyFalse() const {
-    return numChildren() == 0;
+    _listToBSON(&arrBob);
 }
 
 // ----
@@ -309,9 +255,9 @@ void NorMatchExpression::debugString(StringBuilder& debug, int level) const {
     _debugList(debug, level);
 }
 
-void NorMatchExpression::serialize(BSONObjBuilder* out, bool includePath) const {
+void NorMatchExpression::serialize(BSONObjBuilder* out) const {
     BSONArrayBuilder arrBob(out->subarrayStart("$nor"));
-    _listToBSON(&arrBob, includePath);
+    _listToBSON(&arrBob);
 }
 
 // -------
@@ -322,63 +268,19 @@ void NotMatchExpression::debugString(StringBuilder& debug, int level) const {
     _exp->debugString(debug, level + 1);
 }
 
-void NotMatchExpression::serializeNotExpressionToNor(MatchExpression* exp,
-                                                     BSONObjBuilder* out,
-                                                     bool includePath) {
+void NotMatchExpression::serialize(BSONObjBuilder* out) const {
     BSONObjBuilder childBob;
-    exp->serialize(&childBob, includePath);
+    _exp->serialize(&childBob);
+
     BSONObj tempObj = childBob.obj();
 
+    // We don't know what the inner object is, and thus whether serializing to $not will result in a
+    // parseable MatchExpression. As a fix, we change it to $nor, which is always parseable.
     BSONArrayBuilder tBob(out->subarrayStart("$nor"));
     tBob.append(tempObj);
     tBob.doneFast();
 }
 
-void NotMatchExpression::serialize(BSONObjBuilder* out, bool includePath) const {
-    if (_exp->matchType() == MatchType::AND && _exp->numChildren() == 0) {
-        out->append("$alwaysFalse", 1);
-        return;
-    }
-
-    if (!includePath) {
-        BSONObjBuilder notBob(out->subobjStart("$not"));
-        // Our parser does not accept a $and directly within a $not, instead expecting the direct
-        // notation like {x: {$not: {$gt: 5, $lt: 0}}}. We represent such an expression with an AND
-        // internally, so we un-nest it here to be able to re-parse it.
-        if (_exp->matchType() == MatchType::AND) {
-            for (size_t x = 0; x < _exp->numChildren(); ++x) {
-                _exp->getChild(x)->serialize(&notBob, includePath);
-            }
-        } else {
-            _exp->serialize(&notBob, includePath);
-        }
-        return;
-    }
-
-    auto expressionToNegate = _exp.get();
-    if (_exp->matchType() == MatchType::AND && _exp->numChildren() == 1) {
-        expressionToNegate = _exp->getChild(0);
-    }
-
-    // It is generally easier to be correct if we just always serialize to a $nor, since this will
-    // delegate the path serialization to lower in the tree where we have the information on-hand.
-    // However, for legibility we preserve a $not with a single path-accepting child as a $not.
-    //
-    // One exception: while TextMatchExpressionBase derives from PathMatchExpression, text match
-    // expressions cannot be serialized in the same manner as other PathMatchExpression derivatives.
-    // This is because the path for a TextMatchExpression is embedded within the $text object,
-    // whereas for other PathMatchExpressions it is on the left-hand-side, for example {x: {$eq:
-    // 1}}.
-    auto pathMatch = dynamic_cast<PathMatchExpression*>(expressionToNegate);
-    if (pathMatch && !dynamic_cast<TextMatchExpressionBase*>(expressionToNegate)) {
-        const auto path = pathMatch->path();
-        BSONObjBuilder pathBob(out->subobjStart(path));
-        pathBob.append("$not", pathMatch->getSerializedRightHandSide());
-        return;
-    }
-    return serializeNotExpressionToNor(expressionToNegate, out, includePath);
-}
-
 bool NotMatchExpression::equivalent(const MatchExpression* other) const {
     if (matchType() != other->matchType())
         return false;
@@ -395,4 +297,4 @@ MatchExpression::ExpressionOptimizerFunc NotMatchExpression::getOptimizer() cons
         return expression;
     };
 }
-}  // namespace mongo
+}
