@@ -1,23 +1,25 @@
+
 /**
- *    Copyright (C) 2013 10gen Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects for
+ *    must comply with the Server Side Public License in all respects for
  *    all of the code used other than as permitted herein. If you modify file(s)
  *    with this exception, you may extend this exception to your version of the
  *    file(s), but you are not obligated to do so. If you do not wish to do so,
@@ -36,7 +38,8 @@
 #include "mongo/bson/mutable/mutable_bson_test_utils.h"
 #include "mongo/db/jsobj.h"
 #include "mongo/db/json.h"
-#include "mongo/db/ops/log_builder.h"
+#include "mongo/db/pipeline/expression_context_for_test.h"
+#include "mongo/db/update/log_builder.h"
 #include "mongo/platform/decimal128.h"
 #include "mongo/unittest/unittest.h"
 
@@ -44,6 +47,7 @@ namespace {
 
 using mongo::BSONObj;
 using mongo::Decimal128;
+using mongo::ExpressionContextForTest;
 using mongo::LogBuilder;
 using mongo::ModifierBit;
 using mongo::ModifierInterface;
@@ -61,7 +65,7 @@ public:
 
     explicit Mod(BSONObj modObj) : _modObj(modObj), _mod() {
         ASSERT_OK(_mod.init(_modObj["$bit"].embeddedObject().firstElement(),
-                            ModifierInterface::Options::normal()));
+                            ModifierInterface::Options::normal(new ExpressionContextForTest())));
     }
 
     Status prepare(Element root, StringData matchedField, ModifierInterface::ExecInfo* execInfo) {
@@ -89,47 +93,51 @@ private:
 TEST(Init, FailToInitWithInvalidValue) {
     BSONObj modObj;
     ModifierBit mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
+
+    // Double is an invalid $bit argument
+    modObj = fromjson("{ $bit : { a : 0 } }");
+    ASSERT_NOT_OK(mod.init(modObj["$bit"].embeddedObject().firstElement(),
+                           ModifierInterface::Options::normal(expCtx)));
 
     // String is an invalid $bit argument
     modObj = fromjson("{ $bit : { a : '' } }");
     ASSERT_NOT_OK(mod.init(modObj["$bit"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 
     // Array is an invalid $bit argument
     modObj = fromjson("{ $bit : { a : [] } }");
     ASSERT_NOT_OK(mod.init(modObj["$bit"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 
     // An empty document is an invalid $bit argument.
     modObj = fromjson("{$bit: {a: {}}}");
     ASSERT_NOT_OK(mod.init(modObj["$bit"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 
     // An object with value not in ('and', 'or') is an invalid $bit argument
     modObj = fromjson("{ $bit : { a : { foo : 4 } } }");
     ASSERT_NOT_OK(mod.init(modObj["$bit"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 
     // The argument to the sub-operator must be numeric
     modObj = fromjson("{ $bit : { a : { or : [] } } }");
     ASSERT_NOT_OK(mod.init(modObj["$bit"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 
     modObj = fromjson("{ $bit : { a : { or : 'foo' } } }");
     ASSERT_NOT_OK(mod.init(modObj["$bit"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 
     // The argument to the sub-operator must be integral
     modObj = fromjson("{ $bit : { a : { or : 1.0 } } }");
     ASSERT_NOT_OK(mod.init(modObj["$bit"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 
-    if (mongo::Decimal128::enabled) {
-        // The argument to the sub-operator must be integral
-        modObj = fromjson("{ $bit : { a : { or : NumberDecimal(\"1.0\") } } }");
-        ASSERT_NOT_OK(mod.init(modObj["$bit"].embeddedObject().firstElement(),
-                               ModifierInterface::Options::normal()));
-    }
+    // The argument to the sub-operator must be integral
+    modObj = fromjson("{ $bit : { a : { or : NumberDecimal(\"1.0\") } } }");
+    ASSERT_NOT_OK(mod.init(modObj["$bit"].embeddedObject().firstElement(),
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, ParsesAndInt) {
@@ -181,7 +189,7 @@ TEST(SimpleMod, PrepareOKTargetFound) {
     ASSERT_EQUALS(fromjson("{ $set : { a : 1 } }"), logDoc);
 }
 
-TEST(SimpleMod, PrepareSimpleNonNumericObject) {
+TEST(SimpleMod, PrepareWithObjectShouldFail) {
     Document doc(fromjson("{ a : {} }"));
     Mod mod(fromjson("{ $bit : { a : { or : 1 } } }"));
 
@@ -189,7 +197,7 @@ TEST(SimpleMod, PrepareSimpleNonNumericObject) {
     ASSERT_NOT_OK(mod.prepare(doc.root(), "", &execInfo));
 }
 
-TEST(SimpleMod, PrepareSimpleNonNumericArray) {
+TEST(SimpleMod, PrepareWithArrayShouldFail) {
     Document doc(fromjson("{ a : [] }"));
     Mod mod(fromjson("{ $bit : { a : { and : 1 } } }"));
 
@@ -197,7 +205,7 @@ TEST(SimpleMod, PrepareSimpleNonNumericArray) {
     ASSERT_NOT_OK(mod.prepare(doc.root(), "", &execInfo));
 }
 
-TEST(SimpleMod, PrepareSimpleNonNumericString) {
+TEST(SimpleMod, PrepareWithStringShouldFail) {
     Document doc(fromjson("{ a : '' }"));
     Mod mod(fromjson("{ $bit : { a : { or : 1 } } }"));
 
@@ -205,6 +213,14 @@ TEST(SimpleMod, PrepareSimpleNonNumericString) {
     ASSERT_NOT_OK(mod.prepare(doc.root(), "", &execInfo));
 }
 
+TEST(SimpleMod, PrepareWithDoubleShouldFail) {
+    Document doc(fromjson("{ a : 1.1 }"));
+    Mod mod(fromjson("{ $bit : { a : { or : 1 } } }"));
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_NOT_OK(mod.prepare(doc.root(), "", &execInfo));
+}
+
 TEST(SimpleMod, ApplyAndLogEmptyDocumentAnd) {
     Document doc(fromjson("{}"));
     Mod mod(fromjson("{ $bit : { a : { and : 1 } } }"));
