@@ -1,23 +1,25 @@
+
 /**
- *    Copyright (C) 2013 10gen Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects for
+ *    must comply with the Server Side Public License in all respects for
  *    all of the code used other than as permitted herein. If you modify file(s)
  *    with this exception, you may extend this exception to your version of the
  *    file(s), but you are not obligated to do so. If you do not wish to do so,
@@ -35,13 +37,16 @@
 
 #include "mongo/base/status.h"
 #include "mongo/base/string_data.h"
-#include "mongo/bson/ordering.h"
 #include "mongo/bson/mutable/algorithm.h"
 #include "mongo/bson/mutable/document.h"
 #include "mongo/bson/mutable/mutable_bson_test_utils.h"
+#include "mongo/bson/ordering.h"
+#include "mongo/db/bson/dotted_path_support.h"
 #include "mongo/db/jsobj.h"
 #include "mongo/db/json.h"
-#include "mongo/db/ops/log_builder.h"
+#include "mongo/db/pipeline/expression_context_for_test.h"
+#include "mongo/db/query/collation/collator_interface_mock.h"
+#include "mongo/db/update/log_builder.h"
 #include "mongo/unittest/unittest.h"
 #include "mongo/util/mongoutils/str.h"
 
@@ -50,6 +55,8 @@ namespace {
 using mongo::BSONObj;
 using mongo::BSONObjBuilder;
 using mongo::BSONArrayBuilder;
+using mongo::CollatorInterfaceMock;
+using mongo::ExpressionContextForTest;
 using mongo::fromjson;
 using mongo::LogBuilder;
 using mongo::ModifierInterface;
@@ -65,6 +72,8 @@ using mongo::mutablebson::Element;
 using std::sort;
 using std::vector;
 
+namespace dps = ::mongo::dotted_path_support;
+
 void combineVec(const vector<int>& origVec,
                 const vector<int>& modVec,
                 int32_t slice,
@@ -113,8 +122,8 @@ struct ProjectKeyCmp {
         if (useWholeValue) {
             ret = left.woCompare(right, Ordering::make(sortPattern), false);
         } else {
-            BSONObj lhsKey = left.extractFields(sortPattern, true);
-            BSONObj rhsKey = right.extractFields(sortPattern, true);
+            BSONObj lhsKey = dps::extractElementsBasedOnTemplate(left, sortPattern, true);
+            BSONObj rhsKey = dps::extractElementsBasedOnTemplate(right, sortPattern, true);
             ret = lhsKey.woCompare(rhsKey, sortPattern);
         }
         return ret < 0;
@@ -160,8 +169,9 @@ void combineAndSortVec(const vector<BSONObj>& origVec,
 TEST(Init, SimplePush) {
     BSONObj modObj = fromjson("{$push: {x: 0}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 //
@@ -171,46 +181,52 @@ TEST(Init, SimplePush) {
 TEST(Init, PushEachNormal) {
     BSONObj modObj = fromjson("{$push: {x: {$each: [1, 2]}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachMixed) {
     BSONObj modObj = fromjson("{$push: {x: {$each: [1, {a: 2}]}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachObject) {
     // $each must be an array
     BSONObj modObj = fromjson("{$push: {x: {$each: {'0': 1}}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachSimpleType) {
     // $each must be an array.
     BSONObj modObj = fromjson("{$push: {x: {$each: 1}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachEmpty) {
     BSONObj modObj = fromjson("{$push: {x: {$each: []}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachInvalidType) {
     // $each must be an array.
     BSONObj modObj = fromjson("{$push: {x: {$each: {b: 1}}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 //
@@ -220,50 +236,57 @@ TEST(Init, PushEachInvalidType) {
 TEST(Init, PushEachWithSliceBottom) {
     BSONObj modObj = fromjson("{$push: {x: {$each: [1, 2], $slice: -3}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithSliceTop) {
     BSONObj modObj = fromjson("{$push: {x: {$each: [1, 2], $slice: 3}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithInvalidSliceObject) {
     BSONObj modObj = fromjson("{$push: {x: {$each: [1, 2], $slice: {a: 1}}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithInvalidSliceDouble) {
     BSONObj modObj = fromjson("{$push: {x: {$each: [1, 2], $slice: -2.1}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithValidSliceDouble) {
     BSONObj modObj = fromjson("{$push: {x: {$each: [1, 2], $slice: -2.0}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithUnsupportedFullSlice) {
     BSONObj modObj = fromjson("{$push: {x: {$each: [1, 2], $slice: [1,2]}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithWrongTypeSlice) {
     BSONObj modObj = fromjson("{$push: {x: {$each: [1, 2], $slice: '-1'}}}");
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 //
@@ -274,134 +297,99 @@ TEST(Init, PushEachWithObjectSort) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort: {a:1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithNumbericSort) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort:1 }}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithInvalidSortType) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort: [{a:1}]}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachDuplicateSortPattern) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort: [{a:1,a:1}]}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithInvalidSortValue) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort: {a:100}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithEmptySortField) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort: {'':1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithEmptyDottedSortField) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort: {'.':1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithMissingSortFieldSuffix) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort: {'a.':1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithMissingSortFieldPreffix) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort: {'.b':1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithMissingSortFieldMiddle) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort: {'a..b':1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithEmptySort) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort:{} }}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
-}
-
-//
-// If in $pushAll semantics, do we check the array and that nothing else is there?
-//
-
-TEST(Init, PushAllSimple) {
-    BSONObj modObj = fromjson("{$pushAll: {x: [0]}}");
-    ModifierPush mod(ModifierPush::PUSH_ALL);
-    ASSERT_OK(mod.init(modObj["$pushAll"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
-}
-
-TEST(Init, PushAllMultiple) {
-    BSONObj modObj = fromjson("{$pushAll: {x: [1,2,3]}}");
-    ModifierPush mod(ModifierPush::PUSH_ALL);
-    ASSERT_OK(mod.init(modObj["$pushAll"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
-}
-
-TEST(Init, PushAllObject) {
-    BSONObj modObj = fromjson("{$pushAll: {x: [{a:1},{a:2}]}}");
-    ModifierPush mod(ModifierPush::PUSH_ALL);
-    ASSERT_OK(mod.init(modObj["$pushAll"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
-}
-
-TEST(Init, PushAllMixed) {
-    BSONObj modObj = fromjson("{$pushAll: {x: [1,{a:2}]}}");
-    ModifierPush mod(ModifierPush::PUSH_ALL);
-    ASSERT_OK(mod.init(modObj["$pushAll"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
-}
-
-TEST(Init, PushAllWrongType) {
-    BSONObj modObj = fromjson("{$pushAll: {x: 1}}");
-    ModifierPush mod(ModifierPush::PUSH_ALL);
-    ASSERT_NOT_OK(mod.init(modObj["$pushAll"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
-}
-
-TEST(Init, PushAllNotArray) {
-    BSONObj modObj = fromjson("{$pushAll: {x: {a:1}}}");
-    ModifierPush mod(ModifierPush::PUSH_ALL);
-    ASSERT_NOT_OK(mod.init(modObj["$pushAll"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 //
@@ -412,83 +400,90 @@ TEST(Init, PushEachWithSortMissingSlice) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $sort:{a:1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachInvalidClause) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $xxx: -1, $sort:{a:1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachExtraField) {
     const char* c = "{$push: {x: {$each: [{a:1},{a:2}], $slice: -2.0, $sort: {a:1}, b: 1}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachDuplicateSortClause) {
     const char* c = "{$push: {x:{$each:[{a:1},{a:2}], $slice:-2.0, $sort:{a:1}, $sort:{a:1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachDuplicateSliceClause) {
     const char* c = "{$push: {x: {$each:[{a:1},{a:2}], $slice:-2.0, $slice:-2, $sort:{a:1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachDuplicateEachClause) {
     const char* c = "{$push: {x: {$each:[{a:1}], $each:[{a:2}], $slice:-3, $sort:{a:1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_NOT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                           ModifierInterface::Options::normal()));
+                           ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithSliceFirst) {
     const char* c = "{$push: {x: {$slice: -2.0, $each: [{a:1},{a:2}], $sort: {a:1}}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 TEST(Init, PushEachWithSortFirst) {
     const char* c = "{$push: {x: {$sort: {a:1}, $slice: -2.0, $each: [{a:1},{a:2}]}}}";
     BSONObj modObj = fromjson(c);
     ModifierPush mod;
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     ASSERT_OK(mod.init(modObj["$push"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
+                       ModifierInterface::Options::normal(expCtx)));
 }
 
 //
 // Simple mod
 //
 
-/** Helper to build and manipulate a $push or a $pushAll mod. */
+/** Helper to build and manipulate a $push mod. */
 class Mod {
 public:
     Mod() : _mod() {}
 
-    explicit Mod(BSONObj modObj)
-        : _mod(mongoutils::str::equals(modObj.firstElement().fieldName(), "$pushAll")
-                   ? ModifierPush::PUSH_ALL
-                   : ModifierPush::PUSH_NORMAL) {
+    explicit Mod(BSONObj modObj,
+                 ModifierInterface::Options options =
+                     ModifierInterface::Options::normal(new ExpressionContextForTest()))
+        : _mod() {
         _modObj = modObj;
         StringData modName = modObj.firstElement().fieldName();
-        ASSERT_OK(_mod.init(_modObj[modName].embeddedObject().firstElement(),
-                            ModifierInterface::Options::normal()));
+        ASSERT_OK(_mod.init(_modObj[modName].embeddedObject().firstElement(), options));
     }
 
     Status prepare(Element root, StringData matchedField, ModifierInterface::ExecInfo* execInfo) {
@@ -659,13 +654,13 @@ TEST(SimpleObjMod, PrepareApplyNormal) {
 }
 
 TEST(SimpleObjMod, PrepareApplyDotted) {
-    Document doc(fromjson(
-        "{ _id : 1 , "
-        "  question : 'a', "
-        "  choices : { "
-        "            first : { choice : 'b' }, "
-        "            second : { choice : 'c' } }"
-        "}"));
+    Document doc(
+        fromjson("{ _id : 1 , "
+                 "  question : 'a', "
+                 "  choices : { "
+                 "            first : { choice : 'b' }, "
+                 "            second : { choice : 'c' } }"
+                 "}"));
     Mod pushMod(fromjson("{$push: {'choices.first.votes': 1}}"));
 
     ModifierInterface::ExecInfo execInfo;
@@ -676,13 +671,12 @@ TEST(SimpleObjMod, PrepareApplyDotted) {
 
     ASSERT_OK(pushMod.apply());
     ASSERT_FALSE(doc.isInPlaceModeEnabled());
-    ASSERT_EQUALS(fromjson(
-                      "{ _id : 1 , "
-                      "  question : 'a', "
-                      "  choices : { "
-                      "            first : { choice : 'b', votes: [1]}, "
-                      "            second : { choice : 'c' } }"
-                      "}"),
+    ASSERT_EQUALS(fromjson("{ _id : 1 , "
+                           "  question : 'a', "
+                           "  choices : { "
+                           "            first : { choice : 'b', votes: [1]}, "
+                           "            second : { choice : 'c' } }"
+                           "}"),
                   doc);
 
     Document logDoc;
@@ -693,73 +687,6 @@ TEST(SimpleObjMod, PrepareApplyDotted) {
 }
 
 
-//
-// $pushAll Variation
-//
-
-TEST(PushAll, PrepareApplyEmpty) {
-    Document doc(fromjson("{a: []}"));
-    Mod pushMod(fromjson("{$pushAll: {a: [1]}}"));
-
-    ModifierInterface::ExecInfo execInfo;
-    ASSERT_OK(pushMod.prepare(doc.root(), "", &execInfo));
-
-    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a");
-    ASSERT_FALSE(execInfo.noOp);
-
-    ASSERT_OK(pushMod.apply());
-    ASSERT_FALSE(doc.isInPlaceModeEnabled());
-    ASSERT_EQUALS(doc, fromjson("{a: [1]}"));
-
-    Document logDoc;
-    LogBuilder logBuilder(logDoc.root());
-    ASSERT_OK(pushMod.log(&logBuilder));
-    ASSERT_EQUALS(countChildren(logDoc.root()), 1u);
-    ASSERT_EQUALS(logDoc, fromjson("{$set: {a: [1]}}"));
-}
-
-TEST(PushAll, PrepareApplyInexistent) {
-    Document doc(fromjson("{}"));
-    Mod pushMod(fromjson("{$pushAll: {a: [1]}}"));
-
-    ModifierInterface::ExecInfo execInfo;
-    ASSERT_OK(pushMod.prepare(doc.root(), "", &execInfo));
-
-    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a");
-    ASSERT_FALSE(execInfo.noOp);
-
-    ASSERT_OK(pushMod.apply());
-    ASSERT_FALSE(doc.isInPlaceModeEnabled());
-    ASSERT_EQUALS(doc, fromjson("{a: [1]}"));
-
-    Document logDoc;
-    LogBuilder logBuilder(logDoc.root());
-    ASSERT_OK(pushMod.log(&logBuilder));
-    ASSERT_EQUALS(countChildren(logDoc.root()), 1u);
-    ASSERT_EQUALS(logDoc, fromjson("{$set: {a: [1]}}"));
-}
-
-TEST(PushAll, PrepareApplyNormal) {
-    Document doc(fromjson("{a: [0]}"));
-    Mod pushMod(fromjson("{$pushAll: {a: [1,2]}}"));
-
-    ModifierInterface::ExecInfo execInfo;
-    ASSERT_OK(pushMod.prepare(doc.root(), "", &execInfo));
-
-    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a");
-    ASSERT_FALSE(execInfo.noOp);
-
-    ASSERT_OK(pushMod.apply());
-    ASSERT_FALSE(doc.isInPlaceModeEnabled());
-    ASSERT_EQUALS(doc, fromjson("{a: [0,1,2]}"));
-
-    Document logDoc;
-    LogBuilder logBuilder(logDoc.root());
-    ASSERT_OK(pushMod.log(&logBuilder));
-    ASSERT_EQUALS(countChildren(logDoc.root()), 1u);
-    ASSERT_EQUALS(logDoc, fromjson("{$set: {'a.1': 1, 'a.2':2}}"));
-}
-
 //
 // Simple $each mod
 //
@@ -1012,6 +939,38 @@ TEST(SortPushEach, MixedSortEmbeddedField) {
     ASSERT_EQUALS(BSON("$set" << expectedObj), logDoc);
 }
 
+TEST(SortPushEach, SortRespectsCollationFromOptions) {
+    Document doc(fromjson("{a: ['dd', 'fc', 'gb'] }"));
+    CollatorInterfaceMock collator(CollatorInterfaceMock::MockType::kReverseString);
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
+    expCtx->setCollator(&collator);
+    Mod pushMod(fromjson("{$push: {a: {$each: ['ha'], $sort: 1}}}"),
+                ModifierInterface::Options::normal(expCtx));
+    const BSONObj expectedObj = fromjson("{a: ['ha', 'gb', 'fc', 'dd']}");
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(pushMod.prepare(doc.root(), "", &execInfo));
+    ASSERT_FALSE(execInfo.noOp);
+
+    ASSERT_OK(pushMod.apply());
+    ASSERT_EQUALS(expectedObj, doc);
+}
+
+TEST(SortPushEach, SortRespectsCollationFromSetCollator) {
+    Document doc(fromjson("{a: ['dd', 'fc', 'gb'] }"));
+    CollatorInterfaceMock collator(CollatorInterfaceMock::MockType::kReverseString);
+    Mod pushMod(fromjson("{$push: {a: {$each: ['ha'], $sort: 1}}}"));
+    pushMod.mod().setCollator(&collator);
+    const BSONObj expectedObj = fromjson("{a: ['ha', 'gb', 'fc', 'dd']}");
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(pushMod.prepare(doc.root(), "", &execInfo));
+    ASSERT_FALSE(execInfo.noOp);
+
+    ASSERT_OK(pushMod.apply());
+    ASSERT_EQUALS(expectedObj, doc);
+}
+
 /**
  * This fixture supports building $push mods with parameterized $each arrays and $slices.
  * It always assume that the array being operated on is called 'a'. To build a mod, one
@@ -1048,8 +1007,9 @@ public:
         _modObj =
             BSON("$push" << BSON("a" << BSON("$each" << arrBuilder.arr() << "$slice" << slice)));
 
+        boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
         ASSERT_OK(_mod.init(_modObj["$push"].embeddedObject().firstElement(),
-                            ModifierInterface::Options::normal()));
+                            ModifierInterface::Options::normal(expCtx)));
     }
 
     /** Sets up the mod to be {$push: {a: {$each:[<Obj>,...], $slice:<slice>, $sort:<Obj>}}} */
@@ -1059,11 +1019,13 @@ public:
             arrBuilder.append(*it);
         }
 
-        _modObj = BSON("$push" << BSON("a" << BSON("$each" << arrBuilder.arr() << "$slice" << slice
-                                                           << "$sort" << sort)));
+        _modObj = BSON(
+            "$push" << BSON(
+                "a" << BSON("$each" << arrBuilder.arr() << "$slice" << slice << "$sort" << sort)));
 
+        boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
         ASSERT_OK(_mod.init(_modObj["$push"].embeddedObject().firstElement(),
-                            ModifierInterface::Options::normal()));
+                            ModifierInterface::Options::normal(expCtx)));
     }
 
     /** Returns an object {a: [<'vec's content>]} */
@@ -1270,8 +1232,9 @@ TEST_F(SlicedMod, ObjectArrayFromExisting) {
 // Push to position tests
 
 TEST(ToPosition, BadInputs) {
+    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
+
     const char* const bad[] = {
-        "{$push: {a: { $each: [1], $position:-1}}}",
         "{$push: {a: { $each: [1], $position:'s'}}}",
         "{$push: {a: { $each: [1], $position:{}}}}",
         "{$push: {a: { $each: [1], $position:[0]}}}",
@@ -1279,17 +1242,18 @@ TEST(ToPosition, BadInputs) {
         "{$push: {a: { $each: [1], $position:3.000000000001}}}",
         "{$push: {a: { $each: [1], $position:1.2}}}",
         "{$push: {a: { $each: [1], $position:-1.2}}}",
-        "{$push: {a: { $each: [1], $position:9.0e19}}}",
-        "{$push: {a: { $each: [1], $position:-9.0e19}}}",
+        "{$push: {a: { $each: [1], $position:2147483648}}}",
+        "{$push: {a: { $each: [1], $position:-2147483649}}}",
+        "{$push: {a: { $each: [1], $position:NaN}}}",
         NULL,
     };
 
     int i = 0;
     while (bad[i] != NULL) {
-        ModifierPush pushMod(ModifierPush::PUSH_NORMAL);
+        ModifierPush pushMod;
         BSONObj modObj = fromjson(bad[i]);
         ASSERT_NOT_OK(pushMod.init(modObj.firstElement().embeddedObject().firstElement(),
-                                   ModifierInterface::Options::normal()));
+                                   ModifierInterface::Options::normal(expCtx)));
         i++;
     }
 }
@@ -1437,6 +1401,111 @@ TEST(ToPosition, Back) {
     ASSERT_EQUALS(fromjson("{$set: {'a.1':1}}"), logDoc);
 }
 
+TEST(ToPosition, NegativePositionEmptyArray) {
+    Document doc(fromjson("{a: []}"));
+    Mod pushMod(fromjson("{$push: {a: {$each: [1], $position: -1}}}"));
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(pushMod.prepare(doc.root(), "", &execInfo));
+
+    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a");
+    ASSERT_FALSE(execInfo.noOp);
+
+    ASSERT_OK(pushMod.apply());
+    ASSERT_FALSE(doc.isInPlaceModeEnabled());
+    ASSERT_EQUALS(fromjson("{a: [1]}"), doc);
+
+    Document logDoc;
+    LogBuilder logBuilder(logDoc.root());
+    ASSERT_OK(pushMod.log(&logBuilder));
+    ASSERT_EQUALS(countChildren(logDoc.root()), 1u);
+    ASSERT_EQUALS(fromjson("{$set: {'a': [1]}}"), logDoc);
+}
+
+TEST(ToPosition, NegativePositionOneElementArray) {
+    Document doc(fromjson("{a: [0]}"));
+    Mod pushMod(fromjson("{$push: {a: {$each: [1], $position: -1}}}"));
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(pushMod.prepare(doc.root(), "", &execInfo));
+
+    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a");
+    ASSERT_FALSE(execInfo.noOp);
+
+    ASSERT_OK(pushMod.apply());
+    ASSERT_FALSE(doc.isInPlaceModeEnabled());
+    ASSERT_EQUALS(fromjson("{a: [1, 0]}"), doc);
+
+    Document logDoc;
+    LogBuilder logBuilder(logDoc.root());
+    ASSERT_OK(pushMod.log(&logBuilder));
+    ASSERT_EQUALS(countChildren(logDoc.root()), 1u);
+    ASSERT_EQUALS(fromjson("{$set: {'a': [1, 0]}}"), logDoc);
+}
+
+TEST(ToPosition, NegativePositionMultiElementArray) {
+    Document doc(fromjson("{a: [0, 1, 2, 3, 4]}"));
+    Mod pushMod(fromjson("{$push: {a: {$each: [5], $position: -2}}}"));
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(pushMod.prepare(doc.root(), "", &execInfo));
+
+    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a");
+    ASSERT_FALSE(execInfo.noOp);
+
+    ASSERT_OK(pushMod.apply());
+    ASSERT_FALSE(doc.isInPlaceModeEnabled());
+    ASSERT_EQUALS(fromjson("{a: [0, 1, 2, 5, 3, 4]}"), doc);
+
+    Document logDoc;
+    LogBuilder logBuilder(logDoc.root());
+    ASSERT_OK(pushMod.log(&logBuilder));
+    ASSERT_EQUALS(countChildren(logDoc.root()), 1u);
+    ASSERT_EQUALS(fromjson("{$set: {'a': [0, 1, 2, 5, 3, 4]}}"), logDoc);
+}
+
+TEST(ToPosition, NegativePositionOutOfBoundsDefaultsToBeginning) {
+    Document doc(fromjson("{a: [0]}"));
+    Mod pushMod(fromjson("{$push: {a: {$each: [1], $position: -2}}}"));
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(pushMod.prepare(doc.root(), "", &execInfo));
+
+    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a");
+    ASSERT_FALSE(execInfo.noOp);
+
+    ASSERT_OK(pushMod.apply());
+    ASSERT_FALSE(doc.isInPlaceModeEnabled());
+    ASSERT_EQUALS(fromjson("{a: [1, 0]}"), doc);
+
+    Document logDoc;
+    LogBuilder logBuilder(logDoc.root());
+    ASSERT_OK(pushMod.log(&logBuilder));
+    ASSERT_EQUALS(countChildren(logDoc.root()), 1u);
+    ASSERT_EQUALS(fromjson("{$set: {'a': [1, 0]}}"), logDoc);
+}
+
+TEST(ToPosition, NegativePositionPushMultipleElements) {
+    Document doc(fromjson("{a: [0, 1, 2, 3, 4]}"));
+    Mod pushMod(fromjson("{$push: {a: {$each: [5, 6, 7], $position: -2}}}"));
+
+    ModifierInterface::ExecInfo execInfo;
+    ASSERT_OK(pushMod.prepare(doc.root(), "", &execInfo));
+
+    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a");
+    ASSERT_FALSE(execInfo.noOp);
+
+    ASSERT_OK(pushMod.apply());
+    ASSERT_FALSE(doc.isInPlaceModeEnabled());
+    ASSERT_EQUALS(fromjson("{a: [0, 1, 2, 5, 6, 7, 3, 4]}"), doc);
+
+    Document logDoc;
+    LogBuilder logBuilder(logDoc.root());
+    ASSERT_OK(pushMod.log(&logBuilder));
+    ASSERT_EQUALS(countChildren(logDoc.root()), 1u);
+    ASSERT_EQUALS(fromjson("{$set: {'a': [0, 1, 2, 5, 6, 7, 3, 4]}}"), logDoc);
+}
+
 TEST(IndexedMod, PrepareReportCreatedArrayElement) {
     Document doc(fromjson("{a: [{b: 0}]}"));
     Mod mod(fromjson("{$push: {'a.1.c': 2}}"));
@@ -1450,22 +1519,6 @@ TEST(IndexedMod, PrepareReportCreatedArrayElement) {
     ASSERT_FALSE(execInfo.noOp);
 }
 
-TEST(IndexedMod, PrepareReportCreatedArrayElementPushAll) {
-    Document doc(fromjson("{a: [{b: 0}]}"));
-    auto modObj = fromjson("{$pushAll: {'a.1.c': [2]}}");
-    ModifierPush mod(ModifierPush::PUSH_ALL);
-    ASSERT_OK(mod.init(modObj["$pushAll"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
-
-    ModifierInterface::ExecInfo execInfo;
-    ASSERT_OK(mod.prepare(doc.root(), "", &execInfo));
-
-    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a.1.c");
-    ASSERT_TRUE(execInfo.indexOfArrayWithNewElement[0]);
-    ASSERT_EQUALS(*execInfo.indexOfArrayWithNewElement[0], 0u);
-    ASSERT_FALSE(execInfo.noOp);
-}
-
 TEST(IndexedMod, PrepareDoNotReportModifiedArrayElement) {
     Document doc(fromjson("{a: [{b: 0}]}"));
     Mod mod(fromjson("{$push: {'a.0.c': 2}}"));
@@ -1478,21 +1531,6 @@ TEST(IndexedMod, PrepareDoNotReportModifiedArrayElement) {
     ASSERT_FALSE(execInfo.noOp);
 }
 
-TEST(IndexedMod, PrepareDoNotReportModifiedArrayElementPushAll) {
-    Document doc(fromjson("{a: [{b: 0}]}"));
-    auto modObj = fromjson("{$pushAll: {'a.0.c': [2]}}");
-    ModifierPush mod(ModifierPush::PUSH_ALL);
-    ASSERT_OK(mod.init(modObj["$pushAll"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
-
-    ModifierInterface::ExecInfo execInfo;
-    ASSERT_OK(mod.prepare(doc.root(), "", &execInfo));
-
-    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a.0.c");
-    ASSERT_FALSE(execInfo.indexOfArrayWithNewElement[0]);
-    ASSERT_FALSE(execInfo.noOp);
-}
-
 TEST(IndexedMod, PrepareDoNotReportCreatedNumericObjectField) {
     Document doc(fromjson("{a: {'0': {b: 0}}}"));
     Mod mod(fromjson("{$push: {'a.1.c': 2}}"));
@@ -1505,19 +1543,4 @@ TEST(IndexedMod, PrepareDoNotReportCreatedNumericObjectField) {
     ASSERT_FALSE(execInfo.noOp);
 }
 
-TEST(IndexedMod, PrepareDoNotReportCreatedNumericObjectFieldPushAll) {
-    Document doc(fromjson("{a: {'0': {b: 0}}}"));
-    auto modObj = fromjson("{$pushAll: {'a.1.c': [2]}}");
-    ModifierPush mod(ModifierPush::PUSH_ALL);
-    ASSERT_OK(mod.init(modObj["$pushAll"].embeddedObject().firstElement(),
-                       ModifierInterface::Options::normal()));
-
-    ModifierInterface::ExecInfo execInfo;
-    ASSERT_OK(mod.prepare(doc.root(), "", &execInfo));
-
-    ASSERT_EQUALS(execInfo.fieldRef[0]->dottedField(), "a.1.c");
-    ASSERT_FALSE(execInfo.indexOfArrayWithNewElement[0]);
-    ASSERT_FALSE(execInfo.noOp);
-}
-
 }  // unnamed namespace
