@@ -462,10 +462,10 @@ StatusWith<Value> DocumentSourceSort::extractKeyPart(const Document& doc,
         plainKey = key.getValue();
     } else {
         invariant(patternPart.expression);
-        plainKey = patternPart.expression->evaluate(doc);
+        plainKey = patternPart.expression->evaluate(doc, &pExpCtx->variables);
     }
 
-    return getCollationComparisonKey(plainKey);
+    return plainKey.missing() ? Value{BSONNULL} : getCollationComparisonKey(plainKey);
 }
 
 StatusWith<Value> DocumentSourceSort::extractKeyFast(const Document& doc) const {
