@@ -46,7 +46,6 @@
 #include "mongo/db/pipeline/value.h"
 #include "mongo/db/pipeline/variables.h"
 #include "mongo/db/query/datetime/date_time_support.h"
-#include "mongo/db/server_options.h"
 #include "mongo/stdx/functional.h"
 #include "mongo/util/intrusive_counter.h"
 #include "mongo/util/mongoutils/str.h"
@@ -59,31 +58,14 @@ class BSONObjBuilder;
 class DocumentSource;
 
 /**
- * Registers a Parser so it can be called from parseExpression and friends.
+ * Registers an Parser so it can be called from parseExpression and friends.
  *
  * As an example, if your expression looks like {"$foo": [1,2,3]} you would add this line:
  * REGISTER_EXPRESSION(foo, ExpressionFoo::parse);
- *
- * An expression registered this way can be used in any featureCompatibilityVersion.
  */
 #define REGISTER_EXPRESSION(key, parser)                                     \
     MONGO_INITIALIZER(addToExpressionParserMap_##key)(InitializerContext*) { \
-        Expression::registerExpression("$" #key, (parser), boost::none);     \
-        return Status::OK();                                                 \
-    }
-
-/**
- * Registers a Parser so it can be called from parseExpression and friends. Use this version if your
- * expression can only be persisted to a catalog data structure in a feature compatibility version
- * >= X.
- *
- * As an example, if your expression looks like {"$foo": [1,2,3]}, and can only be used in a feature
- * compatibility version >= X, you would add this line:
- * REGISTER_EXPRESSION_WITH_MIN_VERSION(foo, ExpressionFoo::parse, X);
- */
-#define REGISTER_EXPRESSION_WITH_MIN_VERSION(key, parser, minVersion)        \
-    MONGO_INITIALIZER(addToExpressionParserMap_##key)(InitializerContext*) { \
-        Expression::registerExpression("$" #key, (parser), (minVersion));    \
+        Expression::registerExpression("$" #key, (parser));                  \
         return Status::OK();                                                 \
     }
 
@@ -144,9 +126,12 @@ public:
     virtual Value serialize(bool explain) const = 0;
 
     /**
-     * Evaluate expression with respect to the Document given by 'root', and return the result.
+     * Evaluate the expression with respect to the Document given by 'root' and the Variables given
+     * by 'variables'. It is an error to supply a Variables argument whose built-in variables (like
+     * $$NOW) are not set. This method is thread-safe, so long as the 'variables' passed in here is
+     * not shared between threads.
      */
-    virtual Value evaluate(const Document& root) const = 0;
+    virtual Value evaluate(const Document& root, Variables* variables) const = 0;
 
     /**
      * Returns information about the paths computed by this expression. This only needs to be
@@ -228,10 +213,11 @@ public:
      * DO NOT call this method directly. Instead, use the REGISTER_EXPRESSION macro defined in this
      * file.
      */
-    static void registerExpression(
-        std::string key,
-        Parser parser,
-        boost::optional<ServerGlobalParams::FeatureCompatibility::Version> requiredMinVersion);
+    static void registerExpression(std::string key, Parser parser);
+
+    const boost::intrusive_ptr<ExpressionContext>& getExpressionContext() const {
+        return _expCtx;
+    }
 
 protected:
     Expression(const boost::intrusive_ptr<ExpressionContext>& expCtx) : _expCtx(expCtx) {
@@ -243,10 +229,6 @@ protected:
 
     typedef std::vector<boost::intrusive_ptr<Expression>> ExpressionVector;
 
-    const boost::intrusive_ptr<ExpressionContext>& getExpressionContext() const {
-        return _expCtx;
-    }
-
     virtual void _doAddDependencies(DepsTracker* deps) const = 0;
 
 private:
@@ -385,13 +367,13 @@ public:
     explicit ExpressionFromAccumulator(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionVariadic<ExpressionFromAccumulator<Accumulator>>(expCtx) {}
 
-    Value evaluate(const Document& root) const final {
+    Value evaluate(const Document& root, Variables* variables) const final {
         Accumulator accum(this->getExpressionContext());
         const size_t n = this->vpOperand.size();
         // If a single array arg is given, loop through it passing each member to the accumulator.
         // If a single, non-array arg is given, pass it directly to the accumulator.
         if (n == 1) {
-            Value singleVal = this->vpOperand[0]->evaluate(root);
+            Value singleVal = this->vpOperand[0]->evaluate(root, variables);
             if (singleVal.getType() == Array) {
                 for (const Value& val : singleVal.getArray()) {
                     accum.process(val, false);
@@ -402,7 +384,7 @@ public:
         } else {
             // If multiple arguments are given, pass all arguments to the accumulator.
             for (auto&& argument : this->vpOperand) {
-                accum.process(argument->evaluate(root), false);
+                accum.process(argument->evaluate(root, variables), false);
             }
         }
         return accum.getValue(false);
@@ -437,8 +419,8 @@ public:
 
     virtual ~ExpressionSingleNumericArg() {}
 
-    Value evaluate(const Document& root) const final {
-        Value arg = this->vpOperand[0]->evaluate(root);
+    Value evaluate(const Document& root, Variables* variables) const final {
+        Value arg = this->vpOperand[0]->evaluate(root, variables);
         if (arg.nullish())
             return Value(BSONNULL);
 
@@ -459,7 +441,7 @@ public:
 class ExpressionConstant final : public Expression {
 public:
     boost::intrusive_ptr<Expression> optimize() final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     Value serialize(bool explain) const final;
 
     const char* getOpName() const;
@@ -519,8 +501,8 @@ class DateExpressionAcceptingTimeZone : public Expression {
 public:
     virtual ~DateExpressionAcceptingTimeZone() {}
 
-    Value evaluate(const Document& root) const final {
-        auto dateVal = _date->evaluate(root);
+    Value evaluate(const Document& root, Variables* variables) const final {
+        auto dateVal = _date->evaluate(root, variables);
         if (dateVal.nullish()) {
             return Value(BSONNULL);
         }
@@ -529,7 +511,7 @@ public:
         if (!_timeZone) {
             return evaluateDate(date, TimeZoneDatabase::utcZone());
         }
-        auto timeZoneId = _timeZone->evaluate(root);
+        auto timeZoneId = _timeZone->evaluate(root, variables);
         if (timeZoneId.nullish()) {
             return Value(BSONNULL);
         }
@@ -567,7 +549,8 @@ public:
         }
         if (ExpressionConstant::allNullOrConstant({_date, _timeZone})) {
             // Everything is a constant, so we can turn into a constant.
-            return ExpressionConstant::create(getExpressionContext(), evaluate(Document{}));
+            return ExpressionConstant::create(
+                getExpressionContext(), evaluate(Document{}, &(getExpressionContext()->variables)));
         }
         return this;
     }
@@ -671,7 +654,7 @@ public:
     explicit ExpressionAdd(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionVariadic<ExpressionAdd>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 
     bool isAssociative() const final {
@@ -689,7 +672,7 @@ public:
     explicit ExpressionAllElementsTrue(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionAllElementsTrue, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -700,7 +683,7 @@ public:
         : ExpressionVariadic<ExpressionAnd>(expCtx) {}
 
     boost::intrusive_ptr<Expression> optimize() final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 
     bool isAssociative() const final {
@@ -718,7 +701,7 @@ public:
     explicit ExpressionAnyElementTrue(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionAnyElementTrue, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -728,9 +711,8 @@ public:
     explicit ExpressionArray(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionVariadic<ExpressionArray>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     Value serialize(bool explain) const final;
-    boost::intrusive_ptr<Expression> optimize() final;
     const char* getOpName() const final;
 };
 
@@ -740,7 +722,7 @@ public:
     explicit ExpressionArrayElemAt(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionArrayElemAt, 2>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -749,7 +731,7 @@ public:
     explicit ExpressionObjectToArray(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionObjectToArray, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -758,7 +740,7 @@ public:
     explicit ExpressionArrayToObject(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionArrayToObject, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -775,7 +757,7 @@ public:
 class ExpressionCoerceToBool final : public Expression {
 public:
     boost::intrusive_ptr<Expression> optimize() final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     Value serialize(bool explain) const final;
 
     static boost::intrusive_ptr<ExpressionCoerceToBool> create(
@@ -812,7 +794,7 @@ public:
     ExpressionCompare(const boost::intrusive_ptr<ExpressionContext>& expCtx, CmpOp cmpOp)
         : ExpressionFixedArity<ExpressionCompare, 2>(expCtx), cmpOp(cmpOp) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 
     CmpOp getOp() const {
@@ -841,7 +823,7 @@ public:
     explicit ExpressionConcat(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionVariadic<ExpressionConcat>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 
     bool isAssociative() const final {
@@ -855,7 +837,7 @@ public:
     explicit ExpressionConcatArrays(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionVariadic<ExpressionConcatArrays>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 
     bool isAssociative() const final {
@@ -868,7 +850,7 @@ class ExpressionCond final : public ExpressionFixedArity<ExpressionCond, 3> {
 public:
     explicit ExpressionCond(const boost::intrusive_ptr<ExpressionContext>& expCtx) : Base(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 
     static boost::intrusive_ptr<Expression> parse(
@@ -884,7 +866,7 @@ class ExpressionDateFromString final : public Expression {
 public:
     boost::intrusive_ptr<Expression> optimize() final;
     Value serialize(bool explain) const final;
-    Value evaluate(const Document&) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
 
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -897,23 +879,17 @@ protected:
 private:
     ExpressionDateFromString(const boost::intrusive_ptr<ExpressionContext>& expCtx,
                              boost::intrusive_ptr<Expression> dateString,
-                             boost::intrusive_ptr<Expression> timeZone,
-                             boost::intrusive_ptr<Expression> format,
-                             boost::intrusive_ptr<Expression> onNull,
-                             boost::intrusive_ptr<Expression> onError);
+                             boost::intrusive_ptr<Expression> timeZone);
 
     boost::intrusive_ptr<Expression> _dateString;
     boost::intrusive_ptr<Expression> _timeZone;
-    boost::intrusive_ptr<Expression> _format;
-    boost::intrusive_ptr<Expression> _onNull;
-    boost::intrusive_ptr<Expression> _onError;
 };
 
 class ExpressionDateFromParts final : public Expression {
 public:
     boost::intrusive_ptr<Expression> optimize() final;
     Value serialize(bool explain) const final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
 
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -938,22 +914,17 @@ private:
                             boost::intrusive_ptr<Expression> timeZone);
 
     /**
-     * This function checks whether a field is a number.
-     *
-     * If 'field' is null, the default value is returned trough the 'returnValue' out
-     * parameter and the function returns true.
-     *
-     * If 'field' is not null:
-     * - if the value is "nullish", the function returns false.
-     * - if the value can not be coerced to an integral value, a UserException is thrown.
-     * - otherwise, the coerced integral value is returned through the 'returnValue'
-     *   out parameter, and the function returns true.
+     * Evaluates the value in field as number, and makes sure it fits in the minValue..maxValue
+     * range. If the field is missing or empty, the function returns the defaultValue.
      */
-    bool evaluateNumberWithDefault(const Document& root,
-                                   boost::intrusive_ptr<Expression> field,
+    bool evaluateNumberWithinRange(const Document& root,
+                                   const Expression* field,
                                    StringData fieldName,
-                                   long long defaultValue,
-                                   long long* returnValue) const;
+                                   int defaultValue,
+                                   int minValue,
+                                   int maxValue,
+                                   int* returnValue,
+                                   Variables* variables) const;
 
     boost::intrusive_ptr<Expression> _year;
     boost::intrusive_ptr<Expression> _month;
@@ -972,7 +943,7 @@ class ExpressionDateToParts final : public Expression {
 public:
     boost::intrusive_ptr<Expression> optimize() final;
     Value serialize(bool explain) const final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
 
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -991,7 +962,7 @@ private:
                           boost::intrusive_ptr<Expression> timeZone,
                           boost::intrusive_ptr<Expression> iso8601);
 
-    boost::optional<int> evaluateIso8601Flag(const Document& root) const;
+    boost::optional<int> evaluateIso8601Flag(const Document& root, Variables* variables) const;
 
     boost::intrusive_ptr<Expression> _date;
     boost::intrusive_ptr<Expression> _timeZone;
@@ -1002,7 +973,7 @@ class ExpressionDateToString final : public Expression {
 public:
     boost::intrusive_ptr<Expression> optimize() final;
     Value serialize(bool explain) const final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
 
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -1014,15 +985,13 @@ protected:
 
 private:
     ExpressionDateToString(const boost::intrusive_ptr<ExpressionContext>& expCtx,
-                           boost::intrusive_ptr<Expression> format,
-                           boost::intrusive_ptr<Expression> date,
-                           boost::intrusive_ptr<Expression> timeZone,
-                           boost::intrusive_ptr<Expression> onNull);
+                           const std::string& format,                   // The format string.
+                           boost::intrusive_ptr<Expression> date,       // The date to format.
+                           boost::intrusive_ptr<Expression> timeZone);  // The optional timezone.
 
-    boost::intrusive_ptr<Expression> _format;
+    const std::string _format;
     boost::intrusive_ptr<Expression> _date;
     boost::intrusive_ptr<Expression> _timeZone;
-    boost::intrusive_ptr<Expression> _onNull;
 };
 
 class ExpressionDayOfMonth final : public DateExpressionAcceptingTimeZone<ExpressionDayOfMonth> {
@@ -1063,7 +1032,7 @@ public:
     explicit ExpressionDivide(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionDivide, 2>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1085,7 +1054,7 @@ public:
     }
 
     boost::intrusive_ptr<Expression> optimize() final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     Value serialize(bool explain) const final;
 
     /*
@@ -1152,7 +1121,7 @@ class ExpressionFilter final : public Expression {
 public:
     boost::intrusive_ptr<Expression> optimize() final;
     Value serialize(bool explain) const final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
 
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -1206,7 +1175,7 @@ public:
     explicit ExpressionIfNull(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionIfNull, 2>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1216,44 +1185,18 @@ public:
     explicit ExpressionIn(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionIn, 2>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
 
-class ExpressionIndexOfArray : public ExpressionRangedArity<ExpressionIndexOfArray, 2, 4> {
+class ExpressionIndexOfArray final : public ExpressionRangedArity<ExpressionIndexOfArray, 2, 4> {
 public:
     explicit ExpressionIndexOfArray(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionRangedArity<ExpressionIndexOfArray, 2, 4>(expCtx) {}
 
-
-    Value evaluate(const Document& root) const;
-    boost::intrusive_ptr<Expression> optimize() final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
-
-protected:
-    struct Arguments {
-        Arguments(Value targetOfSearch, int startIndex, int endIndex)
-            : targetOfSearch(targetOfSearch), startIndex(startIndex), endIndex(endIndex) {}
-
-        Value targetOfSearch;
-        int startIndex;
-        int endIndex;
-    };
-    /**
-     * When given 'operands' which correspond to the arguments to $indexOfArray, evaluates and
-     * validates the target value, starting index, and ending index arguments and returns their
-     * values as a Arguments struct. The starting index and ending index are optional, so as default
-     * 'startIndex' will be 0 and 'endIndex' will be the length of the input array. Throws a
-     * UserException if the values are found to be invalid in some way, e.g. if the indexes are not
-     * numbers.
-     */
-    Arguments evaluateAndValidateArguments(const Document& root,
-                                           const ExpressionVector& operands,
-                                           size_t arrayLength) const;
-
-private:
-    class Optimized;
 };
 
 
@@ -1262,7 +1205,7 @@ public:
     explicit ExpressionIndexOfBytes(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionRangedArity<ExpressionIndexOfBytes, 2, 4>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1275,7 +1218,7 @@ public:
     explicit ExpressionIndexOfCP(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionRangedArity<ExpressionIndexOfCP, 2, 4>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1284,7 +1227,7 @@ class ExpressionLet final : public Expression {
 public:
     boost::intrusive_ptr<Expression> optimize() final;
     Value serialize(bool explain) const final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
 
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -1328,7 +1271,7 @@ public:
     explicit ExpressionLog(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionLog, 2>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1345,7 +1288,7 @@ class ExpressionMap final : public Expression {
 public:
     boost::intrusive_ptr<Expression> optimize() final;
     Value serialize(bool explain) const final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
 
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -1375,7 +1318,7 @@ private:
 class ExpressionMeta final : public Expression {
 public:
     Value serialize(bool explain) const final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
 
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -1423,7 +1366,7 @@ public:
     explicit ExpressionMod(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionMod, 2>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1433,7 +1376,7 @@ public:
     explicit ExpressionMultiply(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionVariadic<ExpressionMultiply>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 
     bool isAssociative() const final {
@@ -1462,7 +1405,7 @@ public:
     explicit ExpressionNot(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionNot, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1478,7 +1421,7 @@ public:
 class ExpressionObject final : public Expression {
 public:
     boost::intrusive_ptr<Expression> optimize() final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     Value serialize(bool explain) const final;
 
     static boost::intrusive_ptr<ExpressionObject> create(
@@ -1524,7 +1467,7 @@ public:
         : ExpressionVariadic<ExpressionOr>(expCtx) {}
 
     boost::intrusive_ptr<Expression> optimize() final;
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 
     bool isAssociative() const final {
@@ -1545,7 +1488,7 @@ public:
         const boost::intrusive_ptr<ExpressionContext>& expCtx, Value base, Value exp);
 
 private:
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1555,7 +1498,7 @@ public:
     explicit ExpressionRange(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionRangedArity<ExpressionRange, 2, 3>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1565,7 +1508,7 @@ public:
     explicit ExpressionReduce(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : Expression(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     boost::intrusive_ptr<Expression> optimize() final;
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -1602,7 +1545,7 @@ public:
     explicit ExpressionSetDifference(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionSetDifference, 2>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1612,7 +1555,7 @@ public:
     explicit ExpressionSetEquals(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionVariadic<ExpressionSetEquals>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
     void validateArguments(const ExpressionVector& args) const final;
 };
@@ -1623,7 +1566,7 @@ public:
     explicit ExpressionSetIntersection(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionVariadic<ExpressionSetIntersection>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 
     bool isAssociative() const final {
@@ -1643,7 +1586,7 @@ public:
         : ExpressionFixedArity<ExpressionSetIsSubset, 2>(expCtx) {}
 
     boost::intrusive_ptr<Expression> optimize() override;
-    Value evaluate(const Document& root) const override;
+    Value evaluate(const Document& root, Variables* variables) const override;
     const char* getOpName() const final;
 
 private:
@@ -1656,7 +1599,7 @@ public:
     explicit ExpressionSetUnion(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionVariadic<ExpressionSetUnion>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 
     bool isAssociative() const final {
@@ -1674,7 +1617,7 @@ public:
     explicit ExpressionSize(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionSize, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1684,7 +1627,7 @@ public:
     explicit ExpressionReverseArray(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionReverseArray, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1694,7 +1637,7 @@ public:
     explicit ExpressionSlice(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionRangedArity<ExpressionSlice, 2, 3>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1704,17 +1647,16 @@ public:
     explicit ExpressionIsArray(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionIsArray, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
-
 class ExpressionSplit final : public ExpressionFixedArity<ExpressionSplit, 2> {
 public:
     explicit ExpressionSplit(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionSplit, 2>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1734,7 +1676,7 @@ public:
     explicit ExpressionStrcasecmp(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionStrcasecmp, 2>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1744,7 +1686,7 @@ public:
     explicit ExpressionSubstrBytes(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionSubstrBytes, 3>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const;
 };
 
@@ -1754,7 +1696,7 @@ public:
     explicit ExpressionSubstrCP(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionSubstrCP, 3>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1764,7 +1706,7 @@ public:
     explicit ExpressionStrLenBytes(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionStrLenBytes, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1774,7 +1716,7 @@ public:
     explicit ExpressionStrLenCP(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionStrLenCP, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1784,7 +1726,7 @@ public:
     explicit ExpressionSubtract(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionSubtract, 2>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1794,7 +1736,7 @@ public:
     explicit ExpressionSwitch(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : Expression(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     boost::intrusive_ptr<Expression> optimize() final;
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -1819,7 +1761,7 @@ public:
     explicit ExpressionToLower(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionToLower, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1829,79 +1771,10 @@ public:
     explicit ExpressionToUpper(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionToUpper, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
-
-/**
- * This class is used to implement all three trim expressions: $trim, $ltrim, and $rtrim.
- */
-class ExpressionTrim final : public Expression {
-private:
-    enum class TrimType {
-        kBoth,
-        kLeft,
-        kRight,
-    };
-
-public:
-    ExpressionTrim(const boost::intrusive_ptr<ExpressionContext>& expCtx,
-                   TrimType trimType,
-                   StringData name,
-                   const boost::intrusive_ptr<Expression>& input,
-                   const boost::intrusive_ptr<Expression>& charactersToTrim)
-        : Expression(expCtx),
-          _trimType(trimType),
-          _name(name.toString()),
-          _input(input),
-          _characters(charactersToTrim) {}
-
-    Value evaluate(const Document& root) const final;
-    boost::intrusive_ptr<Expression> optimize() final;
-    static boost::intrusive_ptr<Expression> parse(
-        const boost::intrusive_ptr<ExpressionContext>& expCtx,
-        BSONElement expr,
-        const VariablesParseState& vpsIn);
-    Value serialize(bool explain) const final;
-
-protected:
-    void _doAddDependencies(DepsTracker* deps) const final;
-
-private:
-    /**
-     * Returns true if the unicode character found at index 'indexIntoInput' of 'input' is equal to
-     * 'testCP'.
-     */
-    static bool codePointMatchesAtIndex(const StringData& input,
-                                        std::size_t indexIntoInput,
-                                        const StringData& testCP);
-
-    /**
-     * Given the input string and the code points to trim from that string, returns a substring of
-     * 'input' with any code point from 'trimCPs' trimmed from the left.
-     */
-    static StringData trimFromLeft(StringData input, const std::vector<StringData>& trimCPs);
-
-    /**
-     * Given the input string and the code points to trim from that string, returns a substring of
-     * 'input' with any code point from 'trimCPs' trimmed from the right.
-     */
-    static StringData trimFromRight(StringData input, const std::vector<StringData>& trimCPs);
-
-    /**
-     * Returns the trimmed version of 'input', with all code points in 'trimCPs' removed from the
-     * front, back, or both - depending on _trimType.
-     */
-    StringData doTrim(StringData input, const std::vector<StringData>& trimCPs) const;
-
-    TrimType _trimType;
-    std::string _name;  // "$trim", "$ltrim", or "$rtrim".
-    boost::intrusive_ptr<Expression> _input;
-    boost::intrusive_ptr<Expression> _characters;  // Optional, null if not specified.
-};
-
-
 class ExpressionTrunc final : public ExpressionSingleNumericArg<ExpressionTrunc> {
 public:
     explicit ExpressionTrunc(const boost::intrusive_ptr<ExpressionContext>& expCtx)
@@ -1917,7 +1790,7 @@ public:
     explicit ExpressionType(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : ExpressionFixedArity<ExpressionType, 1>(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     const char* getOpName() const final;
 };
 
@@ -1983,7 +1856,7 @@ public:
     explicit ExpressionZip(const boost::intrusive_ptr<ExpressionContext>& expCtx)
         : Expression(expCtx) {}
 
-    Value evaluate(const Document& root) const final;
+    Value evaluate(const Document& root, Variables* variables) const final;
     boost::intrusive_ptr<Expression> optimize() final;
     static boost::intrusive_ptr<Expression> parse(
         const boost::intrusive_ptr<ExpressionContext>& expCtx,
@@ -1999,42 +1872,4 @@ private:
     ExpressionVector _inputs;
     ExpressionVector _defaults;
 };
-
-class ExpressionConvert final : public Expression {
-public:
-    /**
-     * Creates a $convert expression converting from 'input' to the type given by 'toType'. Leaves
-     * 'onNull' and 'onError' unspecified.
-     */
-    static boost::intrusive_ptr<Expression> create(const boost::intrusive_ptr<ExpressionContext>&,
-                                                   const boost::intrusive_ptr<Expression>& input,
-                                                   BSONType toType);
-
-    static boost::intrusive_ptr<Expression> parse(
-        const boost::intrusive_ptr<ExpressionContext>& expCtx,
-        BSONElement expr,
-        const VariablesParseState& vpsIn);
-
-    explicit ExpressionConvert(const boost::intrusive_ptr<ExpressionContext>& expCtx)
-        : Expression(expCtx) {}
-    Value evaluate(const Document& root) const final;
-    boost::intrusive_ptr<Expression> optimize() final;
-    Value serialize(bool explain) const final;
-
-protected:
-    void _doAddDependencies(DepsTracker* deps) const final;
-
-private:
-    ExpressionConvert(const boost::intrusive_ptr<ExpressionContext>&,
-                      const boost::intrusive_ptr<Expression>& input,
-                      BSONType toType);
-
-    BSONType computeTargetType(Value typeName) const;
-    Value performConversion(BSONType targetType, Value inputValue) const;
-
-    boost::intrusive_ptr<Expression> _input;
-    boost::intrusive_ptr<Expression> _to;
-    boost::intrusive_ptr<Expression> _onError;
-    boost::intrusive_ptr<Expression> _onNull;
-};
 }
