@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -92,8 +93,8 @@ TEST(ParsedAddFieldsSpec, ThrowsOnCreationWithInvalidFieldPath) {
     ASSERT_THROWS(ParsedAddFields::create(expCtx, BSON(".a" << true)), AssertionException);
 }
 
-// Verify that ParsedAddFields rejects specifications that contain invalid expressions and accepts
-// empty specifications.
+// Verify that ParsedAddFields rejects specifications that contain empty objects or invalid
+// expressions.
 TEST(ParsedAddFieldsSpec, ThrowsOnCreationWithInvalidObjectsOrExpressions) {
     boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
     // Invalid expressions should be rejected.
@@ -108,8 +109,8 @@ TEST(ParsedAddFieldsSpec, ThrowsOnCreationWithInvalidObjectsOrExpressions) {
                       expCtx, BSON("a" << false << "b" << BSON("$unknown" << BSON_ARRAY(4 << 2)))),
                   AssertionException);
 
-    // Empty specifications are allowed.
-    ASSERT(ParsedAddFields::create(expCtx, BSONObj()));
+    // Empty specifications are not allowed.
+    ASSERT_THROWS(ParsedAddFields::create(expCtx, BSONObj()), AssertionException);
 
     // Empty nested objects are not allowed.
     ASSERT_THROWS(ParsedAddFields::create(expCtx, BSON("a" << BSONObj())), AssertionException);
@@ -170,17 +171,6 @@ TEST(ParsedAddFieldsDeps, AddsDependenciesForComputedFields) {
     ASSERT_EQ(deps.fields.count("b"), 1UL);    // Needed by the ExpressionFieldPath for a.
 }
 
-TEST(ParsedAddFieldsDeps, ShouldNotIncludeDependenciesForEmptySpec) {
-    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
-    ParsedAddFields addition(expCtx);
-    addition.parse(BSONObj{});
-
-    DepsTracker deps;
-    addition.addDependencies(&deps);
-
-    ASSERT_EQ(deps.fields.size(), 0UL);
-}
-
 // Verify that the serialization produces the correct output: converting numbers and literals to
 // their corresponding $const form.
 TEST(ParsedAddFieldsSerialize, SerializesToCorrectForm) {
@@ -192,24 +182,13 @@ TEST(ParsedAddFieldsSerialize, SerializesToCorrectForm) {
         fromjson("{a: {$add: [\"$a\", {$const: 2}]}, b: {d: {$const: 3}}, x: {y: {$const: 4}}}"));
 
     // Should be the same if we're serializing for explain or for internal use.
-    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeTransformation(boost::none));
+    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeStageOptions(boost::none));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kQueryPlanner));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kQueryPlanner));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kExecStats));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kExecStats));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kExecAllPlans));
-}
-
-TEST(ParsedAddFieldsSerialize, EmptySpecSerializesToCorrectForm) {
-    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
-    ParsedAddFields addition(expCtx);
-    addition.parse(fromjson("{}"));
-
-    auto expectedSerialization = Document();
-
-    // Should be the same if we're serializing for explain or for internal use.
-    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeTransformation(boost::none));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kExecAllPlans));
 }
 
 // Verify that serialize treats the _id field as any other field: including when explicity included.
@@ -222,13 +201,13 @@ TEST(ParsedAddFieldsSerialize, AddsIdToSerializeWhenExplicitlyIncluded) {
     auto expectedSerialization = Document(fromjson("{_id: {$const: false}}"));
 
     // Should be the same if we're serializing for explain or for internal use.
-    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeTransformation(boost::none));
+    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeStageOptions(boost::none));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kQueryPlanner));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kQueryPlanner));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kExecStats));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kExecStats));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kExecAllPlans));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kExecAllPlans));
 }
 
 // Verify that serialize treats the _id field as any other field: excluded when not explicitly
@@ -244,13 +223,13 @@ TEST(ParsedAddFieldsSerialize, OmitsIdFromSerializeWhenNotIncluded) {
     auto expectedSerialization = Document(fromjson("{a: {$const: true}}"));
 
     // Should be the same if we're serializing for explain or for internal use.
-    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeTransformation(boost::none));
+    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeStageOptions(boost::none));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kQueryPlanner));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kQueryPlanner));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kExecStats));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kExecStats));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kExecAllPlans));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kExecAllPlans));
 }
 
 // Verify that the $addFields stage optimizes expressions into simpler forms when possible.
@@ -262,13 +241,13 @@ TEST(ParsedAddFieldsOptimize, OptimizesTopLevelExpressions) {
     auto expectedSerialization = Document{{"a", Document{{"$const", 3}}}};
 
     // Should be the same if we're serializing for explain or for internal use.
-    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeTransformation(boost::none));
+    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeStageOptions(boost::none));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kQueryPlanner));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kQueryPlanner));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kExecStats));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kExecStats));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kExecAllPlans));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kExecAllPlans));
 }
 
 // Verify that the $addFields stage optimizes expressions even when they are nested.
@@ -280,13 +259,13 @@ TEST(ParsedAddFieldsOptimize, ShouldOptimizeNestedExpressions) {
     auto expectedSerialization = Document{{"a", Document{{"b", Document{{"$const", 3}}}}}};
 
     // Should be the same if we're serializing for explain or for internal use.
-    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeTransformation(boost::none));
+    ASSERT_DOCUMENT_EQ(expectedSerialization, addition.serializeStageOptions(boost::none));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kQueryPlanner));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kQueryPlanner));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kExecStats));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kExecStats));
     ASSERT_DOCUMENT_EQ(expectedSerialization,
-                       addition.serializeTransformation(ExplainOptions::Verbosity::kExecAllPlans));
+                       addition.serializeStageOptions(ExplainOptions::Verbosity::kExecAllPlans));
 }
 
 //
@@ -310,21 +289,6 @@ TEST(ParsedAddFieldsExecutionTest, AddsNewFieldToEndOfDocument) {
     ASSERT_DOCUMENT_EQ(result, expectedResult);
 }
 
-TEST(ParsedAddFieldsExecutionTest, AddingEmptySpecResultsInNoOp) {
-    boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
-    ParsedAddFields addition(expCtx);
-
-    // There are no fields in the document.
-    auto result = addition.applyProjection(Document{});
-    auto expectedResult = Document{{}};
-    ASSERT_DOCUMENT_EQ(result, expectedResult);
-
-    // There are fields in the document but none of them are the added field.
-    result = addition.applyProjection(Document{{"a", 1}, {"b", 2}});
-    expectedResult = Document{{"a", 1}, {"b", 2}};
-    ASSERT_DOCUMENT_EQ(result, expectedResult);
-}
-
 // Verify that an existing field is replaced and stays in the same order in the document.
 TEST(ParsedAddFieldsExecutionTest, ReplacesFieldThatAlreadyExistsInDocument) {
     boost::intrusive_ptr<ExpressionContextForTest> expCtx(new ExpressionContextForTest());
