@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -27,7 +28,7 @@
  *    it in the license file.
  */
 
-#define MONGO_LOGV2_DEFAULT_COMPONENT ::mongo::logv2::LogComponent::kQuery
+#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kQuery
 
 #include "mongo/platform/basic.h"
 
@@ -37,11 +38,10 @@
 #include "mongo/db/matcher/expression_array.h"
 #include "mongo/db/namespace_string.h"
 #include "mongo/db/operation_context.h"
-#include "mongo/db/query/canonical_query_encoder.h"
 #include "mongo/db/query/collation/collator_factory_interface.h"
 #include "mongo/db/query/indexability.h"
-#include "mongo/db/query/projection_parser.h"
 #include "mongo/db/query/query_planner_common.h"
+#include "mongo/util/log.h"
 
 namespace mongo {
 namespace {
@@ -132,8 +132,7 @@ StatusWith<std::unique_ptr<CanonicalQuery>> CanonicalQuery::canonicalize(
     std::unique_ptr<QueryRequest> qr,
     const boost::intrusive_ptr<ExpressionContext>& expCtx,
     const ExtensionsCallback& extensionsCallback,
-    MatchExpressionParser::AllowedFeatureSet allowedFeatures,
-    const ProjectionPolicies& projectionPolicies) {
+    MatchExpressionParser::AllowedFeatureSet allowedFeatures) {
     auto qrStatus = qr->validate();
     if (!qrStatus.isOK()) {
         return qrStatus;
@@ -152,23 +151,16 @@ StatusWith<std::unique_ptr<CanonicalQuery>> CanonicalQuery::canonicalize(
     // Make MatchExpression.
     boost::intrusive_ptr<ExpressionContext> newExpCtx;
     if (!expCtx.get()) {
-        newExpCtx = make_intrusive<ExpressionContext>(
-            opCtx, std::move(collator), qr->nss(), qr->getRuntimeConstants());
+        newExpCtx.reset(new ExpressionContext(opCtx, collator.get()));
     } else {
         newExpCtx = expCtx;
         invariant(CollatorInterface::collatorsMatch(collator.get(), expCtx->getCollator()));
     }
-
     StatusWithMatchExpression statusWithMatcher = MatchExpressionParser::parse(
         qr->getFilter(), newExpCtx, extensionsCallback, allowedFeatures);
     if (!statusWithMatcher.isOK()) {
         return statusWithMatcher.getStatus();
     }
-
-    // Stop counting expressions after they have been parsed to exclude expressions created
-    // during optimization and other processing steps.
-    newExpCtx->stopExpressionCounters();
-
     std::unique_ptr<MatchExpression> me = std::move(statusWithMatcher.getValue());
 
     // Make the CQ we'll hopefully return.
@@ -176,11 +168,10 @@ StatusWith<std::unique_ptr<CanonicalQuery>> CanonicalQuery::canonicalize(
 
     Status initStatus =
         cq->init(opCtx,
-                 std::move(newExpCtx),
                  std::move(qr),
                  parsingCanProduceNoopMatchNodes(extensionsCallback, allowedFeatures),
                  std::move(me),
-                 projectionPolicies);
+                 std::move(collator));
 
     if (!initStatus.isOK()) {
         return initStatus;
@@ -191,10 +182,10 @@ StatusWith<std::unique_ptr<CanonicalQuery>> CanonicalQuery::canonicalize(
 // static
 StatusWith<std::unique_ptr<CanonicalQuery>> CanonicalQuery::canonicalize(
     OperationContext* opCtx, const CanonicalQuery& baseQuery, MatchExpression* root) {
-    auto qr = std::make_unique<QueryRequest>(baseQuery.nss());
-    BSONObjBuilder builder;
-    root->serialize(&builder, true);
-    qr->setFilter(builder.obj());
+    // TODO: we should be passing the filter corresponding to 'root' to the QR rather than the base
+    // query's filter, baseQuery.getQueryRequest().getFilter().
+    auto qr = stdx::make_unique<QueryRequest>(baseQuery.nss());
+    qr->setFilter(baseQuery.getQueryRequest().getFilter());
     qr->setProj(baseQuery.getQueryRequest().getProj());
     qr->setSort(baseQuery.getQueryRequest().getSort());
     qr->setCollation(baseQuery.getQueryRequest().getCollation());
@@ -204,14 +195,18 @@ StatusWith<std::unique_ptr<CanonicalQuery>> CanonicalQuery::canonicalize(
         return qrStatus;
     }
 
+    std::unique_ptr<CollatorInterface> collator;
+    if (baseQuery.getCollator()) {
+        collator = baseQuery.getCollator()->clone();
+    }
+
     // Make the CQ we'll hopefully return.
     std::unique_ptr<CanonicalQuery> cq(new CanonicalQuery());
     Status initStatus = cq->init(opCtx,
-                                 baseQuery.getExpCtx(),
                                  std::move(qr),
                                  baseQuery.canHaveNoopMatchNodes(),
                                  root->shallowClone(),
-                                 ProjectionPolicies::findProjectionPolicies());
+                                 std::move(collator));
 
     if (!initStatus.isOK()) {
         return initStatus;
@@ -220,99 +215,54 @@ StatusWith<std::unique_ptr<CanonicalQuery>> CanonicalQuery::canonicalize(
 }
 
 Status CanonicalQuery::init(OperationContext* opCtx,
-                            boost::intrusive_ptr<ExpressionContext> expCtx,
                             std::unique_ptr<QueryRequest> qr,
                             bool canHaveNoopMatchNodes,
                             std::unique_ptr<MatchExpression> root,
-                            const ProjectionPolicies& projectionPolicies) {
-    _expCtx = expCtx;
+                            std::unique_ptr<CollatorInterface> collator) {
     _qr = std::move(qr);
+    _collator = std::move(collator);
 
     _canHaveNoopMatchNodes = canHaveNoopMatchNodes;
-
-    // Validate, normalize, and sort tree.
-    auto validStatus = isValid(root.get(), *_qr);
-    if (!validStatus.isOK()) {
-        return validStatus.getStatus();
+    _isIsolated = QueryRequest::isQueryIsolated(_qr->getFilter());
+    if (_isIsolated) {
+        RARELY {
+            warning() << "The $isolated/$atomic option is deprecated. See "
+                         "http://dochub.mongodb.org/core/isolated-deprecation";
+        }
     }
-    auto unavailableMetadata = validStatus.getValue();
+
+    // Normalize, sort and validate tree.
     _root = MatchExpression::optimize(std::move(root));
     sortTree(_root.get());
-    // The tree must always be valid after normalization.
-    dassert(isValid(_root.get(), *_qr).isOK());
-    if (auto status = isValidNormalized(_root.get()); !status.isOK()) {
-        return status;
+    Status validStatus = isValid(_root.get(), *_qr);
+    if (!validStatus.isOK()) {
+        return validStatus;
     }
 
     // Validate the projection if there is one.
     if (!_qr->getProj().isEmpty()) {
-        try {
-            _proj.emplace(projection_ast::parse(
-                expCtx, _qr->getProj(), _root.get(), _qr->getFilter(), projectionPolicies));
-
-            // Fail if any of the projection's dependencies are unavailable.
-            DepsTracker{unavailableMetadata}.requestMetadata(_proj->metadataDeps());
-        } catch (const DBException& e) {
-            return e.toStatus();
+        ParsedProjection* pp;
+        Status projStatus = ParsedProjection::make(opCtx, _qr->getProj(), _root.get(), &pp);
+        if (!projStatus.isOK()) {
+            return projStatus;
         }
-
-        _metadataDeps = _proj->metadataDeps();
+        _proj.reset(pp);
     }
 
-    if (_proj && _proj->metadataDeps()[DocumentMetadataFields::kSortKey] &&
-        _qr->getSort().isEmpty()) {
+    if (_proj && _proj->wantSortKey() && _qr->getSort().isEmpty()) {
         return Status(ErrorCodes::BadValue, "cannot use sortKey $meta projection without a sort");
     }
 
-    // If there is a sort, parse it and add any metadata dependencies it induces.
-    try {
-        initSortPattern(unavailableMetadata);
-    } catch (const DBException& ex) {
-        return ex.toStatus();
-    }
-
-    // If the 'returnKey' option is set, then the plan should produce index key metadata.
-    if (_qr->returnKey()) {
-        _metadataDeps.set(DocumentMetadataFields::kIndexKey);
-    }
-
     return Status::OK();
 }
 
-void CanonicalQuery::initSortPattern(QueryMetadataBitSet unavailableMetadata) {
-    if (_qr->getSort().isEmpty()) {
-        return;
-    }
-
-    // A $natural sort is really a hint, and should be handled as such. Furthermore, the downstream
-    // sort handling code may not expect a $natural sort.
-    //
-    // We have already validated that if there is a $natural sort and a hint, that the hint
-    // also specifies $natural with the same direction. Therefore, it is safe to clear the $natural
-    // sort and rewrite it as a $natural hint.
-    if (_qr->getSort()[QueryRequest::kNaturalSortField]) {
-        _qr->setHint(_qr->getSort());
-        _qr->setSort(BSONObj{});
-    }
-
-    _sortPattern = SortPattern{_qr->getSort(), _expCtx};
-    _metadataDeps |= _sortPattern->metadataDeps(unavailableMetadata);
-
-    // If the results of this query might have to be merged on a remote node, then that node might
-    // need the sort key metadata. Request that the plan generates this metadata.
-    if (_expCtx->needsMerge) {
-        _metadataDeps.set(DocumentMetadataFields::kSortKey);
-    }
-}
-
 void CanonicalQuery::setCollator(std::unique_ptr<CollatorInterface> collator) {
-    auto collatorRaw = collator.get();
-    // We must give the ExpressionContext the same collator.
-    _expCtx->setCollator(std::move(collator));
+    _collator = std::move(collator);
 
     // The collator associated with the match expression tree is now invalid, since we have reset
-    // the collator owned by the ExpressionContext.
-    _root->setCollator(collatorRaw);
+    // the object owned by '_collator'. We must associate the match expression tree with the new
+    // value of '_collator'.
+    _root->setCollator(_collator.get());
 }
 
 // static
@@ -322,7 +272,7 @@ bool CanonicalQuery::isSimpleIdQuery(const BSONObj& query) {
     BSONObjIterator it(query);
     while (it.more()) {
         BSONElement elt = it.next();
-        if (elt.fieldNameStringData() == "_id") {
+        if (str::equals("_id", elt.fieldName())) {
             // Verify that the query on _id is a simple equality.
             hasID = true;
 
@@ -337,7 +287,11 @@ bool CanonicalQuery::isSimpleIdQuery(const BSONObj& query) {
                 // But it can be BinData.
                 return false;
             }
+        } else if (elt.fieldName()[0] == '$' && (str::equals("$isolated", elt.fieldName()) ||
+                                                 str::equals("$atomic", elt.fieldName()))) {
+            // ok, passthrough
         } else {
+            // If the field is not _id, it must be $isolated/$atomic.
             return false;
         }
     }
@@ -350,8 +304,9 @@ void CanonicalQuery::sortTree(MatchExpression* tree) {
     for (size_t i = 0; i < tree->numChildren(); ++i) {
         sortTree(tree->getChild(i));
     }
-    if (auto&& children = tree->getChildVector()) {
-        std::stable_sort(children->begin(), children->end(), matchExpressionLessThan);
+    std::vector<MatchExpression*>* children = tree->getChildVector();
+    if (NULL != children) {
+        std::sort(children->begin(), children->end(), matchExpressionLessThan);
     }
 }
 
@@ -370,7 +325,7 @@ size_t CanonicalQuery::countNodes(const MatchExpression* root, MatchExpression::
 /**
  * Does 'root' have a subtree of type 'subtreeType' with a node of type 'childType' inside?
  */
-bool hasNodeInSubtree(const MatchExpression* root,
+bool hasNodeInSubtree(MatchExpression* root,
                       MatchExpression::MatchType childType,
                       MatchExpression::MatchType subtreeType) {
     if (subtreeType == root->matchType()) {
@@ -384,9 +339,9 @@ bool hasNodeInSubtree(const MatchExpression* root,
     return false;
 }
 
-StatusWith<QueryMetadataBitSet> CanonicalQuery::isValid(const MatchExpression* root,
-                                                        const QueryRequest& request) {
-    QueryMetadataBitSet unavailableMetadata{};
+// static
+Status CanonicalQuery::isValid(MatchExpression* root, const QueryRequest& parsed) {
+    // Analysis below should be done after squashing the tree to make it clearer.
 
     // There can only be one TEXT.  If there is a TEXT, it cannot appear inside a NOR.
     //
@@ -399,9 +354,6 @@ StatusWith<QueryMetadataBitSet> CanonicalQuery::isValid(const MatchExpression* r
         if (hasNodeInSubtree(root, MatchExpression::TEXT, MatchExpression::NOR)) {
             return Status(ErrorCodes::BadValue, "text expression not allowed in nor");
         }
-    } else {
-        // Text metadata is not available.
-        unavailableMetadata.set(DocumentMetadataFields::kTextScore);
     }
 
     // There can only be one NEAR.  If there is a NEAR, it must be either the root or the root
@@ -410,28 +362,27 @@ StatusWith<QueryMetadataBitSet> CanonicalQuery::isValid(const MatchExpression* r
     if (numGeoNear > 1) {
         return Status(ErrorCodes::BadValue, "Too many geoNear expressions");
     } else if (1 == numGeoNear) {
-        // Do nothing, we will perform extra checks in CanonicalQuery::isValidNormalized.
-    } else {
-        // Geo distance and geo point metadata are unavailable.
-        unavailableMetadata |= DepsTracker::kAllGeoNearData;
-    }
-
-    const BSONObj& sortObj = request.getSort();
-    BSONElement sortNaturalElt = sortObj["$natural"];
-    const BSONObj& hintObj = request.getHint();
-    BSONElement hintNaturalElt = hintObj["$natural"];
-
-    if (sortNaturalElt && sortObj.nFields() != 1) {
-        return Status(ErrorCodes::BadValue,
-                      str::stream() << "Cannot include '$natural' in compound sort: " << sortObj);
-    }
-
-    if (hintNaturalElt && hintObj.nFields() != 1) {
-        return Status(ErrorCodes::BadValue,
-                      str::stream() << "Cannot include '$natural' in compound hint: " << hintObj);
+        bool topLevel = false;
+        if (MatchExpression::GEO_NEAR == root->matchType()) {
+            topLevel = true;
+        } else if (MatchExpression::AND == root->matchType()) {
+            for (size_t i = 0; i < root->numChildren(); ++i) {
+                if (MatchExpression::GEO_NEAR == root->getChild(i)->matchType()) {
+                    topLevel = true;
+                    break;
+                }
+            }
+        }
+        if (!topLevel) {
+            return Status(ErrorCodes::BadValue, "geoNear must be top-level expr");
+        }
     }
 
     // NEAR cannot have a $natural sort or $natural hint.
+    const BSONObj& sortObj = parsed.getSort();
+    BSONElement sortNaturalElt = sortObj["$natural"];
+    const BSONObj& hintObj = parsed.getHint();
+    BSONElement hintNaturalElt = hintObj["$natural"];
     if (numGeoNear > 0) {
         if (sortNaturalElt) {
             return Status(ErrorCodes::BadValue,
@@ -459,15 +410,14 @@ StatusWith<QueryMetadataBitSet> CanonicalQuery::isValid(const MatchExpression* r
         return Status(ErrorCodes::BadValue, "text and hint not allowed in same query");
     }
 
-    // TEXT and tailable are incompatible.
-    if (numText > 0 && request.isTailable()) {
-        return Status(ErrorCodes::BadValue, "text and tailable cursor not allowed in same query");
+    // TEXT and snapshot cannot both be in the query.
+    if (numText > 0 && parsed.isSnapshot()) {
+        return Status(ErrorCodes::BadValue, "text and snapshot not allowed in same query");
     }
 
-    // NEAR and tailable are incompatible.
-    if (numGeoNear > 0 && request.isTailable()) {
-        return Status(ErrorCodes::BadValue,
-                      "Tailable cursors and geo $near cannot be used together");
+    // TEXT and tailable are incompatible.
+    if (numText > 0 && parsed.isTailable()) {
+        return Status(ErrorCodes::BadValue, "text and tailable cursor not allowed in same query");
     }
 
     // $natural sort order must agree with hint.
@@ -483,30 +433,6 @@ StatusWith<QueryMetadataBitSet> CanonicalQuery::isValid(const MatchExpression* r
         }
     }
 
-    return unavailableMetadata;
-}
-
-Status CanonicalQuery::isValidNormalized(const MatchExpression* root) {
-    if (auto numGeoNear = countNodes(root, MatchExpression::GEO_NEAR); numGeoNear > 0) {
-        invariant(numGeoNear == 1);
-
-        auto topLevel = false;
-        if (MatchExpression::GEO_NEAR == root->matchType()) {
-            topLevel = true;
-        } else if (MatchExpression::AND == root->matchType()) {
-            for (size_t i = 0; i < root->numChildren(); ++i) {
-                if (MatchExpression::GEO_NEAR == root->getChild(i)->matchType()) {
-                    topLevel = true;
-                    break;
-                }
-            }
-        }
-
-        if (!topLevel) {
-            return Status(ErrorCodes::BadValue, "geoNear must be top-level expr");
-        }
-    }
-
     return Status::OK();
 }
 
@@ -531,7 +457,7 @@ std::string CanonicalQuery::toString() const {
     }
 
     // The expression tree puts an endl on for us.
-    ss << "Tree: " << _root->debugString();
+    ss << "Tree: " << _root->toString();
     ss << "Sort: " << _qr->getSort().toString() << '\n';
     ss << "Proj: " << _qr->getProj().toString() << '\n';
     if (!_qr->getCollation().isEmpty()) {
@@ -542,8 +468,8 @@ std::string CanonicalQuery::toString() const {
 
 std::string CanonicalQuery::toStringShort() const {
     str::stream ss;
-    ss << "ns: " << _qr->nss().ns() << " query: " << _qr->getFilter().toString()
-       << " sort: " << _qr->getSort().toString() << " projection: " << _qr->getProj().toString();
+    ss << "query: " << _qr->getFilter().toString() << " sort: " << _qr->getSort().toString()
+       << " projection: " << _qr->getProj().toString();
 
     if (!_qr->getCollation().isEmpty()) {
         ss << " collation: " << _qr->getCollation().toString();
@@ -568,8 +494,4 @@ std::string CanonicalQuery::toStringShort() const {
     return ss;
 }
 
-CanonicalQuery::QueryShapeString CanonicalQuery::encodeKey() const {
-    return canonical_query_encoder::encode(*this);
-}
-
 }  // namespace mongo
