@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -31,9 +32,6 @@
 
 #include "mongo/db/query/cursor_response.h"
 
-#include "mongo/rpc/op_msg_rpc_impls.h"
-
-#include "mongo/db/pipeline/resume_token.h"
 #include "mongo/unittest/unittest.h"
 
 namespace mongo {
@@ -41,11 +39,13 @@ namespace mongo {
 namespace {
 
 TEST(CursorResponseTest, parseFromBSONFirstBatch) {
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "db.coll"
-                              << "firstBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                 << "ok" << 1));
+    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(
+        BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                   << "db.coll"
+                                   << "firstBatch"
+                                   << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
+                      << "ok"
+                      << 1));
     ASSERT_OK(result.getStatus());
 
     CursorResponse response = std::move(result.getValue());
@@ -54,14 +54,17 @@ TEST(CursorResponseTest, parseFromBSONFirstBatch) {
     ASSERT_EQ(response.getBatch().size(), 2U);
     ASSERT_BSONOBJ_EQ(response.getBatch()[0], BSON("_id" << 1));
     ASSERT_BSONOBJ_EQ(response.getBatch()[1], BSON("_id" << 2));
+    ASSERT_FALSE(response.getLastOplogTimestamp());
 }
 
 TEST(CursorResponseTest, parseFromBSONNextBatch) {
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "db.coll"
-                              << "nextBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                 << "ok" << 1));
+    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(
+        BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                   << "db.coll"
+                                   << "nextBatch"
+                                   << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
+                      << "ok"
+                      << 1));
     ASSERT_OK(result.getStatus());
 
     CursorResponse response = std::move(result.getValue());
@@ -70,14 +73,17 @@ TEST(CursorResponseTest, parseFromBSONNextBatch) {
     ASSERT_EQ(response.getBatch().size(), 2U);
     ASSERT_BSONOBJ_EQ(response.getBatch()[0], BSON("_id" << 1));
     ASSERT_BSONOBJ_EQ(response.getBatch()[1], BSON("_id" << 2));
+    ASSERT_FALSE(response.getLastOplogTimestamp());
 }
 
 TEST(CursorResponseTest, parseFromBSONCursorIdZero) {
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(BSON(
-        "cursor" << BSON("id" << CursorId(0) << "ns"
-                              << "db.coll"
-                              << "nextBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                 << "ok" << 1));
+    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(
+        BSON("cursor" << BSON("id" << CursorId(0) << "ns"
+                                   << "db.coll"
+                                   << "nextBatch"
+                                   << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
+                      << "ok"
+                      << 1));
     ASSERT_OK(result.getStatus());
 
     CursorResponse response = std::move(result.getValue());
@@ -89,11 +95,13 @@ TEST(CursorResponseTest, parseFromBSONCursorIdZero) {
 }
 
 TEST(CursorResponseTest, parseFromBSONEmptyBatch) {
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(
-        BSON("cursor" << BSON("id" << CursorId(123) << "ns"
-                                   << "db.coll"
-                                   << "nextBatch" << BSONArrayBuilder().arr())
-                      << "ok" << 1));
+    StatusWith<CursorResponse> result =
+        CursorResponse::parseFromBSON(BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                                                 << "db.coll"
+                                                                 << "nextBatch"
+                                                                 << BSONArrayBuilder().arr())
+                                                    << "ok"
+                                                    << 1));
     ASSERT_OK(result.getStatus());
 
     CursorResponse response = std::move(result.getValue());
@@ -102,6 +110,25 @@ TEST(CursorResponseTest, parseFromBSONEmptyBatch) {
     ASSERT_EQ(response.getBatch().size(), 0U);
 }
 
+TEST(CursorResponseTest, parseFromBSONLatestOplogEntry) {
+    StatusWith<CursorResponse> result =
+        CursorResponse::parseFromBSON(BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                                                 << "db.coll"
+                                                                 << "nextBatch"
+                                                                 << BSONArrayBuilder().arr())
+                                                    << "$_internalLatestOplogTimestamp"
+                                                    << Timestamp(1, 2)
+                                                    << "ok"
+                                                    << 1));
+    ASSERT_OK(result.getStatus());
+
+    CursorResponse response = std::move(result.getValue());
+    ASSERT_EQ(response.getCursorId(), CursorId(123));
+    ASSERT_EQ(response.getNSS().ns(), "db.coll");
+    ASSERT_EQ(response.getBatch().size(), 0U);
+    ASSERT_EQ(*response.getLastOplogTimestamp(), Timestamp(1, 2));
+}
+
 TEST(CursorResponseTest, parseFromBSONMissingCursorField) {
     StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(BSON("ok" << 1));
     ASSERT_NOT_OK(result.getStatus());
@@ -117,7 +144,8 @@ TEST(CursorResponseTest, parseFromBSONNsFieldMissing) {
     StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(
         BSON("cursor" << BSON("id" << CursorId(123) << "firstBatch"
                                    << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                      << "ok" << 1));
+                      << "ok"
+                      << 1));
     ASSERT_NOT_OK(result.getStatus());
 }
 
@@ -125,7 +153,8 @@ TEST(CursorResponseTest, parseFromBSONNsFieldWrongType) {
     StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(
         BSON("cursor" << BSON("id" << CursorId(123) << "ns" << 456 << "firstBatch"
                                    << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                      << "ok" << 1));
+                      << "ok"
+                      << 1));
     ASSERT_NOT_OK(result.getStatus());
 }
 
@@ -133,8 +162,10 @@ TEST(CursorResponseTest, parseFromBSONIdFieldMissing) {
     StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(
         BSON("cursor" << BSON("ns"
                               << "db.coll"
-                              << "nextBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                      << "ok" << 1));
+                              << "nextBatch"
+                              << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
+                      << "ok"
+                      << 1));
     ASSERT_NOT_OK(result.getStatus());
 }
 
@@ -144,8 +175,10 @@ TEST(CursorResponseTest, parseFromBSONIdFieldWrongType) {
                               << "123"
                               << "ns"
                               << "db.coll"
-                              << "nextBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                      << "ok" << 1));
+                              << "nextBatch"
+                              << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
+                      << "ok"
+                      << 1));
     ASSERT_NOT_OK(result.getStatus());
 }
 
@@ -153,16 +186,19 @@ TEST(CursorResponseTest, parseFromBSONBatchFieldMissing) {
     StatusWith<CursorResponse> result =
         CursorResponse::parseFromBSON(BSON("cursor" << BSON("id" << CursorId(123) << "ns"
                                                                  << "db.coll")
-                                                    << "ok" << 1));
+                                                    << "ok"
+                                                    << 1));
     ASSERT_NOT_OK(result.getStatus());
 }
 
 TEST(CursorResponseTest, parseFromBSONFirstBatchFieldWrongType) {
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(
-        BSON("cursor" << BSON("id" << CursorId(123) << "ns"
-                                   << "db.coll"
-                                   << "firstBatch" << BSON("_id" << 1))
-                      << "ok" << 1));
+    StatusWith<CursorResponse> result =
+        CursorResponse::parseFromBSON(BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                                                 << "db.coll"
+                                                                 << "firstBatch"
+                                                                 << BSON("_id" << 1))
+                                                    << "ok"
+                                                    << 1));
     ASSERT_NOT_OK(result.getStatus());
 }
 
@@ -170,142 +206,35 @@ TEST(CursorResponseTest, parseFromBSONNextBatchFieldWrongType) {
     StatusWith<CursorResponse> result =
         CursorResponse::parseFromBSON(BSON("cursor" << BSON("id" << CursorId(123) << "ns"
                                                                  << "db.coll"
-                                                                 << "nextBatch" << BSON("_id" << 1))
-                                                    << "ok" << 1));
+                                                                 << "nextBatch"
+                                                                 << BSON("_id" << 1))
+                                                    << "ok"
+                                                    << 1));
+    ASSERT_NOT_OK(result.getStatus());
+}
+
+TEST(CursorResponseTest, parseFromBSONLatestOplogEntryWrongType) {
+    StatusWith<CursorResponse> result =
+        CursorResponse::parseFromBSON(BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                                                 << "db.coll"
+                                                                 << "nextBatch"
+                                                                 << BSON_ARRAY(BSON("_id" << 1)))
+                                                    << "$_internalLatestOplogTimestamp"
+                                                    << 1
+                                                    << "ok"
+                                                    << 1));
     ASSERT_NOT_OK(result.getStatus());
 }
 
 TEST(CursorResponseTest, parseFromBSONOkFieldMissing) {
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "db.coll"
-                              << "nextBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))));
+    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(
+        BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                   << "db.coll"
+                                   << "nextBatch"
+                                   << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))));
     ASSERT_NOT_OK(result.getStatus());
 }
 
-TEST(CursorResponseTest, parseFromBSONPartialResultsReturnedField) {
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "db.coll"
-                              << "firstBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2))
-                              << "partialResultsReturned" << true)
-                 << "ok" << 1));
-    ASSERT_OK(result.getStatus());
-
-    CursorResponse response = std::move(result.getValue());
-    ASSERT_EQ(response.getCursorId(), CursorId(123));
-    ASSERT_EQ(response.getNSS().ns(), "db.coll");
-    ASSERT_EQ(response.getBatch().size(), 2U);
-    ASSERT_BSONOBJ_EQ(response.getBatch()[0], BSON("_id" << 1));
-    ASSERT_BSONOBJ_EQ(response.getBatch()[1], BSON("_id" << 2));
-    ASSERT_EQ(response.getPartialResultsReturned(), true);
-}
-
-TEST(CursorResponseTest, parseFromBSONPartialResultsReturnedFieldWrongType) {
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "db.coll"
-                              << "firstBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2))
-                              << "partialResultsReturned" << 1)
-                 << "ok" << 1));
-    ASSERT_NOT_OK(result.getStatus());
-}
-
-TEST(CursorResponseTest, parseFromBSONVarsFieldCorrect) {
-    BSONObj varsContents = BSON("randomVar" << 7);
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "db.coll"
-                              << "firstBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                 << "vars" << varsContents << "ok" << 1));
-    ASSERT_OK(result.getStatus());
-
-    CursorResponse response = std::move(result.getValue());
-    ASSERT_EQ(response.getCursorId(), CursorId(123));
-    ASSERT_EQ(response.getNSS().ns(), "db.coll");
-    ASSERT_EQ(response.getBatch().size(), 2U);
-    ASSERT_BSONOBJ_EQ(response.getBatch()[0], BSON("_id" << 1));
-    ASSERT_BSONOBJ_EQ(response.getBatch()[1], BSON("_id" << 2));
-    ASSERT_TRUE(response.getVarsField());
-    ASSERT_BSONOBJ_EQ(response.getVarsField().get(), varsContents);
-}
-
-TEST(CursorResponseTest, parseFromBSONVarsFieldWrongType) {
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "db.coll"
-                              << "firstBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                 << "vars" << 2 << "ok" << 1));
-    ASSERT_NOT_OK(result.getStatus());
-}
-
-TEST(CursorResponseTest, parseFromBSONMultipleVars) {
-    BSONObj varsContents = BSON("randomVar" << 7 << "otherVar" << BSON("nested" << 2));
-    StatusWith<CursorResponse> result = CursorResponse::parseFromBSON(BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "db.coll"
-                              << "firstBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                 << "vars" << varsContents << "ok" << 1));
-    ASSERT_OK(result.getStatus());
-
-    CursorResponse response = std::move(result.getValue());
-    ASSERT_EQ(response.getCursorId(), CursorId(123));
-    ASSERT_EQ(response.getNSS().ns(), "db.coll");
-    ASSERT_EQ(response.getBatch().size(), 2U);
-    ASSERT_BSONOBJ_EQ(response.getBatch()[0], BSON("_id" << 1));
-    ASSERT_BSONOBJ_EQ(response.getBatch()[1], BSON("_id" << 2));
-    ASSERT_TRUE(response.getVarsField());
-    ASSERT_BSONOBJ_EQ(response.getVarsField().get(), varsContents);
-}
-
-TEST(CursorResponseTest, roundTripThroughCursorResponseBuilderWithPartialResultsReturned) {
-    CursorResponseBuilder::Options options;
-    options.isInitialResponse = true;
-    rpc::OpMsgReplyBuilder builder;
-    BSONObj okStatus = BSON("ok" << 1);
-    BSONObj testDoc = BSON("_id" << 1);
-    BSONObj expectedBody =
-        BSON("cursor" << BSON("firstBatch" << BSON_ARRAY(testDoc) << "partialResultsReturned"
-                                           << true << "id" << CursorId(123) << "ns"
-                                           << "db.coll"));
-
-    // Use CursorResponseBuilder to serialize the cursor response to OpMsgReplyBuilder.
-    CursorResponseBuilder crb(&builder, options);
-    crb.append(testDoc);
-    crb.setPartialResultsReturned(true);
-    crb.done(CursorId(123), "db.coll");
-
-    // Confirm that the resulting BSONObj response matches the expected body.
-    auto msg = builder.done();
-    auto opMsg = OpMsg::parse(msg);
-    ASSERT_BSONOBJ_EQ(expectedBody, opMsg.body);
-
-    // Append {"ok": 1} to the opMsg body so that it can be parsed by CursorResponse.
-    auto swCursorResponse = CursorResponse::parseFromBSON(opMsg.body.addField(okStatus["ok"]));
-    ASSERT_OK(swCursorResponse.getStatus());
-
-    // Confirm the CursorReponse parsed from CursorResponseBuilder output has the correct content.
-    CursorResponse response = std::move(swCursorResponse.getValue());
-    ASSERT_EQ(response.getCursorId(), CursorId(123));
-    ASSERT_EQ(response.getNSS().ns(), "db.coll");
-    ASSERT_EQ(response.getBatch().size(), 1U);
-    ASSERT_BSONOBJ_EQ(response.getBatch()[0], testDoc);
-    ASSERT_EQ(response.getPartialResultsReturned(), true);
-
-    // Re-serialize a BSONObj response from the CursorResponse.
-    auto cursorResBSON = response.toBSONAsInitialResponse();
-
-    // Confirm that the BSON serialized by the CursorResponse is the same as that serialized by the
-    // CursorResponseBuilder. Field ordering differs between the two, so compare per-element.
-    BSONObjIteratorSorted cursorResIt(cursorResBSON["cursor"].Obj());
-    BSONObjIteratorSorted cursorBuilderIt(opMsg.body["cursor"].Obj());
-    while (cursorResIt.more()) {
-        ASSERT(cursorBuilderIt.more());
-        ASSERT_EQ(cursorResIt.next().woCompare(cursorBuilderIt.next()), 0);
-    }
-    ASSERT(!cursorBuilderIt.more());
-}
-
 TEST(CursorResponseTest, parseFromBSONHandleErrorResponse) {
     StatusWith<CursorResponse> result =
         CursorResponse::parseFromBSON(BSON("ok" << 0 << "code" << 123 << "errmsg"
@@ -319,11 +248,13 @@ TEST(CursorResponseTest, toBSONInitialResponse) {
     std::vector<BSONObj> batch = {BSON("_id" << 1), BSON("_id" << 2)};
     CursorResponse response(NamespaceString("testdb.testcoll"), CursorId(123), batch);
     BSONObj responseObj = response.toBSON(CursorResponse::ResponseType::InitialResponse);
-    BSONObj expectedResponse = BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "testdb.testcoll"
-                              << "firstBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                 << "ok" << 1.0);
+    BSONObj expectedResponse =
+        BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                   << "testdb.testcoll"
+                                   << "firstBatch"
+                                   << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
+                      << "ok"
+                      << 1.0);
     ASSERT_BSONOBJ_EQ(responseObj, expectedResponse);
 }
 
@@ -331,31 +262,13 @@ TEST(CursorResponseTest, toBSONSubsequentResponse) {
     std::vector<BSONObj> batch = {BSON("_id" << 1), BSON("_id" << 2)};
     CursorResponse response(NamespaceString("testdb.testcoll"), CursorId(123), batch);
     BSONObj responseObj = response.toBSON(CursorResponse::ResponseType::SubsequentResponse);
-    BSONObj expectedResponse = BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "testdb.testcoll"
-                              << "nextBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                 << "ok" << 1.0);
-    ASSERT_BSONOBJ_EQ(responseObj, expectedResponse);
-}
-
-TEST(CursorResponseTest, toBSONPartialResultsReturned) {
-    std::vector<BSONObj> batch = {BSON("_id" << 1), BSON("_id" << 2)};
-    CursorResponse response(NamespaceString("testdb.testcoll"),
-                            CursorId(123),
-                            batch,
-                            boost::none,
-                            boost::none,
-                            boost::none,
-                            boost::none,
-                            true);
-    BSONObj responseObj = response.toBSON(CursorResponse::ResponseType::InitialResponse);
-    BSONObj expectedResponse = BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "testdb.testcoll"
-                              << "firstBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2))
-                              << "partialResultsReturned" << true)
-                 << "ok" << 1.0);
+    BSONObj expectedResponse =
+        BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                   << "testdb.testcoll"
+                                   << "nextBatch"
+                                   << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
+                      << "ok"
+                      << 1.0);
     ASSERT_BSONOBJ_EQ(responseObj, expectedResponse);
 }
 
@@ -367,11 +280,13 @@ TEST(CursorResponseTest, addToBSONInitialResponse) {
     response.addToBSON(CursorResponse::ResponseType::InitialResponse, &builder);
     BSONObj responseObj = builder.obj();
 
-    BSONObj expectedResponse = BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "testdb.testcoll"
-                              << "firstBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                 << "ok" << 1.0);
+    BSONObj expectedResponse =
+        BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                   << "testdb.testcoll"
+                                   << "firstBatch"
+                                   << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
+                      << "ok"
+                      << 1.0);
     ASSERT_BSONOBJ_EQ(responseObj, expectedResponse);
 }
 
@@ -383,61 +298,38 @@ TEST(CursorResponseTest, addToBSONSubsequentResponse) {
     response.addToBSON(CursorResponse::ResponseType::SubsequentResponse, &builder);
     BSONObj responseObj = builder.obj();
 
-    BSONObj expectedResponse = BSON(
-        "cursor" << BSON("id" << CursorId(123) << "ns"
-                              << "testdb.testcoll"
-                              << "nextBatch" << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
-                 << "ok" << 1.0);
+    BSONObj expectedResponse =
+        BSON("cursor" << BSON("id" << CursorId(123) << "ns"
+                                   << "testdb.testcoll"
+                                   << "nextBatch"
+                                   << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
+                      << "ok"
+                      << 1.0);
     ASSERT_BSONOBJ_EQ(responseObj, expectedResponse);
 }
 
-TEST(CursorResponseTest, serializePostBatchResumeToken) {
+TEST(CursorResponseTest, serializeLatestOplogEntry) {
     std::vector<BSONObj> batch = {BSON("_id" << 1), BSON("_id" << 2)};
-    auto postBatchResumeToken =
-        ResumeToken::makeHighWaterMarkToken(Timestamp(1, 2)).toDocument().toBson();
     CursorResponse response(
-        NamespaceString("db.coll"), CursorId(123), batch, boost::none, postBatchResumeToken);
+        NamespaceString("db.coll"), CursorId(123), batch, boost::none, Timestamp(1, 2));
     auto serialized = response.toBSON(CursorResponse::ResponseType::SubsequentResponse);
     ASSERT_BSONOBJ_EQ(serialized,
-                      BSON("cursor" << BSON("id" << CursorId(123) << "ns"
-                                                 << "db.coll"
-                                                 << "nextBatch"
-                                                 << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2))
-                                                 << "postBatchResumeToken" << postBatchResumeToken)
-                                    << "ok" << 1));
+                      BSON("cursor"
+                           << BSON("id" << CursorId(123) << "ns"
+                                        << "db.coll"
+                                        << "nextBatch"
+                                        << BSON_ARRAY(BSON("_id" << 1) << BSON("_id" << 2)))
+                           << "$_internalLatestOplogTimestamp"
+                           << Timestamp(1, 2)
+                           << "ok"
+                           << 1));
     auto reparsed = CursorResponse::parseFromBSON(serialized);
     ASSERT_OK(reparsed.getStatus());
     CursorResponse reparsedResponse = std::move(reparsed.getValue());
     ASSERT_EQ(reparsedResponse.getCursorId(), CursorId(123));
     ASSERT_EQ(reparsedResponse.getNSS().ns(), "db.coll");
     ASSERT_EQ(reparsedResponse.getBatch().size(), 2U);
-    ASSERT_BSONOBJ_EQ(*reparsedResponse.getPostBatchResumeToken(), postBatchResumeToken);
-}
-
-TEST(CursorResponseTest, cursorReturnDocumentSequences) {
-    CursorResponseBuilder::Options options;
-    options.isInitialResponse = true;
-    options.useDocumentSequences = true;
-    rpc::OpMsgReplyBuilder builder;
-    BSONObj expectedDoc = BSON("_id" << 1 << "test"
-                                     << "123");
-    BSONObj expectedBody = BSON("cursor" << BSON("id" << CursorId(123) << "ns"
-                                                      << "db.coll"));
-
-    CursorResponseBuilder crb(&builder, options);
-    crb.append(expectedDoc);
-    ASSERT_EQ(crb.numDocs(), 1U);
-    crb.done(CursorId(123), "db.coll");
-
-    auto msg = builder.done();
-    auto opMsg = OpMsg::parse(msg);
-    const auto& docSeqs = opMsg.sequences;
-    ASSERT_EQ(docSeqs.size(), 1U);
-    const auto& documentSequence = docSeqs[0];
-    ASSERT_EQ(documentSequence.name, "cursor.firstBatch");
-    ASSERT_EQ(documentSequence.objs.size(), 1U);
-    ASSERT_BSONOBJ_EQ(documentSequence.objs[0], expectedDoc);
-    ASSERT_BSONOBJ_EQ(opMsg.body, expectedBody);
+    ASSERT_EQ(*reparsedResponse.getLastOplogTimestamp(), Timestamp(1, 2));
 }
 
 }  // namespace
