@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -34,8 +35,8 @@
 
 namespace mongo {
 
-using std::string;
 using std::unique_ptr;
+using std::string;
 
 /**
  * Parses the projection 'spec' and checks its validity with respect to the query 'query'.
@@ -78,7 +79,7 @@ Status ParsedProjection::make(OperationContext* opCtx,
             }
 
             BSONElement e2 = obj.firstElement();
-            if (e2.fieldNameStringData() == "$slice") {
+            if (mongoutils::str::equals(e2.fieldName(), "$slice")) {
                 if (e2.isNumber()) {
                     // This is A-OK.
                 } else if (e2.type() == Array) {
@@ -90,7 +91,7 @@ Status ParsedProjection::make(OperationContext* opCtx,
                     BSONObjIterator it(arr);
                     // Skip over 'skip'.
                     it.next();
-                    int limit = it.next().safeNumberInt();
+                    int limit = it.next().numberInt();
                     if (limit <= 0) {
                         return Status(ErrorCodes::BadValue, "$slice limit must be positive");
                     }
@@ -102,7 +103,7 @@ Status ParsedProjection::make(OperationContext* opCtx,
                 // Projections with $slice aren't covered.
                 requiresDocument = true;
                 pp->_arrayFields.push_back(elem.fieldNameStringData());
-            } else if (e2.fieldNameStringData() == "$elemMatch") {
+            } else if (mongoutils::str::equals(e2.fieldName(), "$elemMatch")) {
                 // Validate $elemMatch arguments and dependencies.
                 if (Object != e2.type()) {
                     return Status(ErrorCodes::BadValue,
@@ -114,7 +115,7 @@ Status ParsedProjection::make(OperationContext* opCtx,
                                   "Cannot specify positional operator and $elemMatch.");
                 }
 
-                if (str::contains(elem.fieldName(), '.')) {
+                if (mongoutils::str::contains(elem.fieldName(), '.')) {
                     return Status(ErrorCodes::BadValue,
                                   "Cannot use $elemMatch projection on a nested field.");
                 }
@@ -147,9 +148,9 @@ Status ParsedProjection::make(OperationContext* opCtx,
                 // Projections with $elemMatch aren't covered.
                 requiresDocument = true;
                 pp->_arrayFields.push_back(elem.fieldNameStringData());
-            } else if (e2.fieldNameStringData() == "$meta") {
+            } else if (mongoutils::str::equals(e2.fieldName(), "$meta")) {
                 // Field for meta must be top level.  We can relax this at some point.
-                if (str::contains(elem.fieldName(), '.')) {
+                if (mongoutils::str::contains(elem.fieldName(), '.')) {
                     return Status(ErrorCodes::BadValue, "field for $meta cannot be nested");
                 }
 
@@ -190,7 +191,7 @@ Status ParsedProjection::make(OperationContext* opCtx,
                 return Status(ErrorCodes::BadValue,
                               string("Unsupported projection option: ") + elem.toString());
             }
-        } else if ((elem.fieldNameStringData() == "_id") && !elem.trueValue()) {
+        } else if (mongoutils::str::equals(elem.fieldName(), "_id") && !elem.trueValue()) {
             pp->_hasId = false;
         } else {
             pp->_hasDottedFieldPath = pp->_hasDottedFieldPath ||
@@ -231,17 +232,17 @@ Status ParsedProjection::make(OperationContext* opCtx,
                               "Cannot specify positional operator and $elemMatch.");
             }
 
-            StringData after = str::after(elem.fieldNameStringData(), ".$");
-            if (after.find(".$"_sd) != std::string::npos) {
-                str::stream ss;
+            std::string after = mongoutils::str::after(elem.fieldName(), ".$");
+            if (mongoutils::str::contains(after, ".$")) {
+                mongoutils::str::stream ss;
                 ss << "Positional projection '" << elem.fieldName() << "' contains "
                    << "the positional operator more than once.";
                 return Status(ErrorCodes::BadValue, ss);
             }
 
-            StringData matchfield = str::before(elem.fieldNameStringData(), '.');
-            if (query && !_hasPositionalOperatorMatch(query, matchfield)) {
-                str::stream ss;
+            std::string matchfield = mongoutils::str::before(elem.fieldName(), '.');
+            if (!_hasPositionalOperatorMatch(query, matchfield)) {
+                mongoutils::str::stream ss;
                 ss << "Positional projection '" << elem.fieldName() << "' does not "
                    << "match the query document.";
                 return Status(ErrorCodes::BadValue, ss);
@@ -291,15 +292,15 @@ Status ParsedProjection::make(OperationContext* opCtx,
         while (srcIt.more()) {
             BSONElement elt = srcIt.next();
             // We've already handled the _id field before entering this loop.
-            if (pp->_hasId && (elt.fieldNameStringData() == "_id")) {
+            if (pp->_hasId && mongoutils::str::equals(elt.fieldName(), "_id")) {
                 continue;
             }
             // $meta sortKey should not be checked as a part of _requiredFields, since it can
             // potentially produce a covered projection as long as the sort key is covered.
             if (BSONType::Object == elt.type()) {
-                dassert(SimpleBSONObjComparator::kInstance.evaluate(elt.Obj() ==
-                                                                    BSON("$meta"
-                                                                         << "sortKey")));
+                dassert(
+                    SimpleBSONObjComparator::kInstance.evaluate(elt.Obj() == BSON("$meta"
+                                                                                  << "sortKey")));
                 continue;
             }
             if (elt.trueValue()) {
@@ -382,13 +383,15 @@ bool ParsedProjection::isFieldRetainedExactly(StringData path) const {
 
 // static
 bool ParsedProjection::_isPositionalOperator(const char* fieldName) {
-    return str::contains(fieldName, ".$") && !str::contains(fieldName, ".$ref") &&
-        !str::contains(fieldName, ".$id") && !str::contains(fieldName, ".$db");
+    return mongoutils::str::contains(fieldName, ".$") &&
+        !mongoutils::str::contains(fieldName, ".$ref") &&
+        !mongoutils::str::contains(fieldName, ".$id") &&
+        !mongoutils::str::contains(fieldName, ".$db");
 }
 
 // static
 bool ParsedProjection::_hasPositionalOperatorMatch(const MatchExpression* const query,
-                                                   StringData matchfield) {
+                                                   const std::string& matchfield) {
     if (query->getCategory() == MatchExpression::MatchCategory::kLogical) {
         for (unsigned int i = 0; i < query->numChildren(); ++i) {
             if (_hasPositionalOperatorMatch(query->getChild(i), matchfield)) {
@@ -397,13 +400,14 @@ bool ParsedProjection::_hasPositionalOperatorMatch(const MatchExpression* const
         }
     } else {
         StringData queryPath = query->path();
+        const char* pathRawData = queryPath.rawData();
         // We have to make a distinction between match expressions that are
         // initialized with an empty field/path name "" and match expressions
         // for which the path is not meaningful (eg. $where).
-        if (!queryPath.rawData()) {
+        if (!pathRawData) {
             return false;
         }
-        StringData pathPrefix = str::before(queryPath, '.');
+        std::string pathPrefix = mongoutils::str::before(pathRawData, '.');
         return pathPrefix == matchfield;
     }
     return false;
