@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -31,12 +32,13 @@
 
 #include <vector>
 
+#include "mongo/base/disallow_copying.h"
 #include "mongo/base/status.h"
 #include "mongo/db/query/canonical_query.h"
 #include "mongo/db/query/index_entry.h"
 #include "mongo/db/query/index_tag.h"
-#include "mongo/db/query/query_knobs_gen.h"
-#include "mongo/stdx/unordered_map.h"
+#include "mongo/db/query/query_knobs.h"
+#include "mongo/platform/unordered_map.h"
 
 namespace mongo {
 
@@ -72,8 +74,7 @@ struct PlanEnumeratorParams {
  * predicate information to make better decisions about what indices are best.
  */
 class PlanEnumerator {
-    PlanEnumerator(const PlanEnumerator&) = delete;
-    PlanEnumerator& operator=(const PlanEnumerator&) = delete;
+    MONGO_DISALLOW_COPYING(PlanEnumerator);
 
 public:
     /**
@@ -158,12 +159,12 @@ private:
     };
 
     struct PrepMemoContext {
-        PrepMemoContext() : elemMatchExpr(nullptr) {}
+        PrepMemoContext() : elemMatchExpr(NULL) {}
         MatchExpression* elemMatchExpr;
 
         // Maps from indexable predicates that can be pushed into the current node to the route
         // through ORs that they have taken to get to this node.
-        stdx::unordered_map<MatchExpression*, OutsidePredRoute> outsidePreds;
+        unordered_map<MatchExpression*, OutsidePredRoute> outsidePreds;
     };
 
     /**
@@ -405,7 +406,7 @@ private:
      */
     void assignMultikeySafePredicates(
         const std::vector<MatchExpression*>& couldAssign,
-        const stdx::unordered_map<MatchExpression*, OutsidePredRoute>& outsidePreds,
+        const unordered_map<MatchExpression*, OutsidePredRoute>& outsidePreds,
         OneIndexAssignment* indexAssignment);
 
     /**
@@ -429,16 +430,10 @@ private:
      */
     bool alreadyCompounded(const std::set<MatchExpression*>& ixisectAssigned,
                            const AndAssignment* andAssignment);
-
-    struct CmpByIndexID {
-        bool operator()(IndexID a, IndexID b) const {
-            return a < b;
-        }
-    };
     /**
-     * Maps from index id to the list of predicates assigned to that index.
+     * Output index intersection assignments inside of an AND node.
      */
-    typedef std::map<IndexID, std::vector<MatchExpression*>, CmpByIndexID> IndexToPredMap;
+    typedef unordered_map<IndexID, std::vector<MatchExpression*>> IndexToPredMap;
 
     /**
      * Generate index intersection assignments given the predicate/index structure in idxToFirst
@@ -455,12 +450,11 @@ private:
      * and idxToNotFirst (and the sub-trees in 'subnodes').  Outputs the assignments into
      * 'andAssignment'. The predicates in 'outsidePreds' are considered for OrPushdownTags.
      */
-    void enumerateOneIndex(
-        IndexToPredMap idxToFirst,
-        IndexToPredMap idxToNotFirst,
-        const std::vector<MemoID>& subnodes,
-        const stdx::unordered_map<MatchExpression*, OutsidePredRoute>& outsidePreds,
-        AndAssignment* andAssignment);
+    void enumerateOneIndex(IndexToPredMap idxToFirst,
+                           IndexToPredMap idxToNotFirst,
+                           const std::vector<MemoID>& subnodes,
+                           const unordered_map<MatchExpression*, OutsidePredRoute>& outsidePreds,
+                           AndAssignment* andAssignment);
 
     /**
      * Generate single-index assignments for queries which contain mandatory
@@ -509,11 +503,10 @@ private:
      * 'outsidePreds'. 'pred' must be able to use the index and be multikey-safe to add to
      * 'indexAssignment'.
      */
-    void assignPredicate(
-        const stdx::unordered_map<MatchExpression*, OutsidePredRoute>& outsidePreds,
-        MatchExpression* pred,
-        size_t position,
-        OneIndexAssignment* indexAssignment);
+    void assignPredicate(const unordered_map<MatchExpression*, OutsidePredRoute>& outsidePreds,
+                         MatchExpression* pred,
+                         size_t position,
+                         OneIndexAssignment* indexAssignment);
 
     /**
      * Sets a flag on all outside pred routes that descend through an $elemMatch object node.
@@ -529,10 +522,10 @@ private:
     std::string dumpMemo();
 
     // Map from expression to its MemoID.
-    stdx::unordered_map<MatchExpression*, MemoID> _nodeToId;
+    unordered_map<MatchExpression*, MemoID> _nodeToId;
 
     // Map from MemoID to its precomputed solution info.
-    stdx::unordered_map<MemoID, NodeAssignment*> _memo;
+    unordered_map<MemoID, NodeAssignment*> _memo;
 
     // If true, there are no further enumeration states, and getNext should return false.
     // We could be _done immediately after init if we're unable to output an indexed plan.
