@@ -63,20 +63,13 @@ extern AtomicBool internalQueryPlannerEnableHashIntersection;
 // plan cache
 //
 
-// The maximum number of entries allowed in a given collection's plan cache.
+// How many entries in the cache?
 extern AtomicInt32 internalQueryCacheSize;
 
 // How many feedback entries do we collect before possibly evicting from the cache based on bad
 // performance?
 extern AtomicInt32 internalQueryCacheFeedbacksStored;
 
-// Limits the amount of debug info stored across all plan caches in the system. Once the estimate of
-// the number of bytes used across all plan caches exceeds this threshold, then debug info is not
-// stored alongside new cache entries, in order to limit plan cache memory consumption. If plan
-// cache entries are freed and the estimate once again dips below this threshold, then new cache
-// entries will once again have debug info associated with them.
-extern AtomicInt64 internalQueryCacheMaxSizeBytesBeforeStripDebugInfo;
-
 // How many times more works must we perform in order to justify plan cache eviction
 // and replanning?
 extern AtomicDouble internalQueryCacheEvictionRatio;
@@ -88,21 +81,6 @@ extern AtomicDouble internalQueryCacheEvictionRatio;
 // How many indexed solutions will QueryPlanner::plan output?
 extern AtomicInt32 internalQueryPlannerMaxIndexedSolutions;
 
-// If set to true, instructs the plan enumerator to enumerate contained $ors in a special order. $or
-// enumeration can generate an exponential number of plans, and is therefore limited at some
-// arbitrary cutoff controlled by a parameter. When this limit is hit, the order of enumeration is
-// important. For example, a query like the following has a 'contained $or' (within an $and): {a: 1,
-// $or: [{b: 1, c: 1}, {b: 2, c: 2}]} For this query if there are indexes a_b={a: 1, b: 1} and
-// a_c={a: 1, c: 1}, the normal enumeration order would output assignments [a_b, a_b], [a_c, a_b],
-// [a_b, a_c], then [a_c, a_c]. This flag will instruct the enumerator to instead prefer a different
-// order. It's hard to summarize, but perhaps the phrases 'lockstep enumeration', 'simultaneous
-// advancement', or 'parallel iteration' will help the reader. The effect is to give earlier
-// enumeration to plans which use the same choice across all branches. In this order, we would get
-// assignments [a_b, a_b], [a_c, a_c], [a_c, a_b], then [a_b, a_c]. This is thought to be helpful in
-// general, but particularly in cases where all children of the $or use the same fields and have the
-// same indexes available, as in this example.
-extern AtomicBool internalQueryEnumerationPreferLockstepOrEnumeration;
-
 // How many solutions will the enumerator consider at each OR?
 extern AtomicInt32 internalQueryEnumerationMaxOrSolutions;
 
@@ -140,9 +118,6 @@ const int64_t insertVectorMaxBytes = 256 * 1024;
 // The number of bytes to buffer at once during a $facet stage.
 extern AtomicInt32 internalQueryFacetBufferSizeBytes;
 
-// The maximum size in bytes of the $facet stage's output document.
-extern AtomicInt64 internalQueryFacetMaxOutputDocSizeBytes;
-
 extern AtomicInt64 internalLookupStageIntermediateDocumentMaxSizeBytes;
 
 extern AtomicInt32 internalInsertMaxBatchSize;
@@ -156,9 +131,4 @@ extern AtomicBool internalQueryProhibitBlockingMergeOnMongoS;
 extern AtomicInt32 internalQueryMaxPushBytes;
 
 extern AtomicInt32 internalQueryMaxAddToSetBytes;
-
-extern AtomicInt32 internalQueryMaxRangeBytes;
-
-// The number of bytes after which explain should start truncating portions of its output.
-extern AtomicInt32 internalQueryExplainSizeThresholdBytes;
 }  // namespace mongo
