@@ -40,11 +40,11 @@
 #include "mongo/db/repl/repl_set_heartbeat_response.h"
 #include "mongo/executor/network_interface_mock.h"
 #include "mongo/executor/thread_pool_task_executor_test_fixture.h"
+#include "mongo/platform/unordered_set.h"
 #include "mongo/rpc/metadata/repl_set_metadata.h"
 #include "mongo/stdx/functional.h"
 #include "mongo/stdx/memory.h"
 #include "mongo/stdx/thread.h"
-#include "mongo/stdx/unordered_set.h"
 #include "mongo/unittest/unittest.h"
 #include "mongo/util/net/hostandport.h"
 
@@ -99,7 +99,7 @@ void CheckQuorumTest::startQuorumCheck(const ReplSetConfig& config, int myIndex)
     ASSERT_FALSE(_quorumCheckThread);
     _isQuorumCheckDone = false;
     _quorumCheckThread.reset(
-        new stdx::thread([this, config, myIndex] { _runQuorumCheck(config, myIndex); }));
+        new stdx::thread(stdx::bind(&CheckQuorumTest::_runQuorumCheck, this, config, myIndex)));
 }
 
 Status CheckQuorumTest::waitForQuorumCheck() {
@@ -145,8 +145,6 @@ TEST_F(CheckQuorumForInitiate, ValidSingleNodeSet) {
                                                    << "rs0"
                                                    << "version"
                                                    << 1
-                                                   << "protocolVersion"
-                                                   << 1
                                                    << "members"
                                                    << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                                             << "h1"))));
@@ -160,8 +158,6 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckCanceledByShutdown) {
                                                    << "rs0"
                                                    << "version"
                                                    << 1
-                                                   << "protocolVersion"
-                                                   << 1
                                                    << "members"
                                                    << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                                             << "h1"))));
@@ -177,8 +173,6 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToSeveralDownNodes) {
                                                    << "rs0"
                                                    << "version"
                                                    << 1
-                                                   << "protocolVersion"
-                                                   << 1
                                                    << "members"
                                                    << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                                             << "h1:1")
@@ -216,7 +210,6 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToSeveralDownNodes) {
 const BSONObj makeHeartbeatRequest(const ReplSetConfig& rsConfig, int myConfigIndex) {
     const MemberConfig& myConfig = rsConfig.getMemberAt(myConfigIndex);
     ReplSetHeartbeatArgsV1 hbArgs;
-    hbArgs.setHeartbeatVersion(1);
     hbArgs.setSetName(rsConfig.getReplSetName());
     hbArgs.setConfigVersion(rsConfig.getConfigVersion());
     if (rsConfig.getConfigVersion() == 1) {
@@ -237,8 +230,6 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckSuccessForFiveNodes) {
                                 << "rs0"
                                 << "version"
                                 << 1
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -256,7 +247,7 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckSuccessForFiveNodes) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
@@ -286,8 +277,6 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToOneDownNode) {
                                 << "rs0"
                                 << "version"
                                 << 1
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -311,7 +300,7 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToOneDownNode) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
@@ -354,8 +343,6 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToSetNameMismatch) {
                                 << "rs0"
                                 << "version"
                                 << 1
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -373,7 +360,7 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToSetNameMismatch) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
@@ -418,8 +405,6 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToSetIdMismatch) {
                                 << "rs0"
                                 << "version"
                                 << 1
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -439,7 +424,7 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToSetIdMismatch) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     HostAndPort incompatibleHost("h4", 1);
     OID unexpectedId = OID::gen();
@@ -501,8 +486,6 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToInitializedNode) {
                                 << "rs0"
                                 << "version"
                                 << 1
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -520,7 +503,7 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToInitializedNode) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
@@ -569,8 +552,6 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToInitializedNodeOnlyOneRespo
                                 << "rs0"
                                 << "version"
                                 << 1
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -588,7 +569,7 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToInitializedNodeOnlyOneRespo
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
@@ -632,8 +613,6 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToNodeWithData) {
                                 << "rs0"
                                 << "version"
                                 << 1
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -651,7 +630,7 @@ TEST_F(CheckQuorumForInitiate, QuorumCheckFailedDueToNodeWithData) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
@@ -692,8 +671,6 @@ TEST_F(CheckQuorumForReconfig, QuorumCheckVetoedDueToHigherConfigVersion) {
                                 << "rs0"
                                 << "version"
                                 << 2
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -707,7 +684,7 @@ TEST_F(CheckQuorumForReconfig, QuorumCheckVetoedDueToHigherConfigVersion) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
@@ -749,8 +726,6 @@ TEST_F(CheckQuorumForReconfig, QuorumCheckVetoedDueToIncompatibleSetName) {
                                 << "rs0"
                                 << "version"
                                 << 2
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -764,7 +739,7 @@ TEST_F(CheckQuorumForReconfig, QuorumCheckVetoedDueToIncompatibleSetName) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
@@ -805,8 +780,6 @@ TEST_F(CheckQuorumForReconfig, QuorumCheckFailsDueToInsufficientVoters) {
                                 << "rs0"
                                 << "version"
                                 << 2
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -832,7 +805,7 @@ TEST_F(CheckQuorumForReconfig, QuorumCheckFailsDueToInsufficientVoters) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
@@ -872,8 +845,6 @@ TEST_F(CheckQuorumForReconfig, QuorumCheckFailsDueToNoElectableNodeResponding) {
                                 << "rs0"
                                 << "version"
                                 << 2
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -895,7 +866,7 @@ TEST_F(CheckQuorumForReconfig, QuorumCheckFailsDueToNoElectableNodeResponding) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
@@ -931,8 +902,6 @@ TEST_F(CheckQuorumForReconfig, QuorumCheckSucceedsWithAsSoonAsPossible) {
                                 << "rs0"
                                 << "version"
                                 << 2
-                                << "protocolVersion"
-                                << 1
                                 << "members"
                                 << BSON_ARRAY(BSON("_id" << 1 << "host"
                                                          << "h1:1")
@@ -958,7 +927,7 @@ TEST_F(CheckQuorumForReconfig, QuorumCheckSucceedsWithAsSoonAsPossible) {
     startQuorumCheck(rsConfig, myConfigIndex);
     const Date_t startDate = getNet()->now();
     const int numCommandsExpected = rsConfig.getNumMembers() - 1;
-    stdx::unordered_set<HostAndPort> seenHosts;
+    unordered_set<HostAndPort> seenHosts;
     getNet()->enterNetwork();
     for (int i = 0; i < numCommandsExpected; ++i) {
         const NetworkInterfaceMock::NetworkOperationIterator noi = getNet()->getNextReadyRequest();
