@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -27,7 +28,7 @@
  *    it in the license file.
  */
 
-#define MONGO_LOGV2_DEFAULT_COMPONENT ::mongo::logv2::LogComponent::kReplication
+#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kReplication
 
 #include "mongo/platform/basic.h"
 
@@ -37,7 +38,7 @@
 #include "mongo/bson/oid.h"
 #include "mongo/bson/util/bson_extract.h"
 #include "mongo/db/jsobj.h"
-#include "mongo/util/str.h"
+#include "mongo/util/mongoutils/str.h"
 
 namespace mongo {
 namespace repl {
@@ -47,7 +48,6 @@ const std::string kIsMasterFieldName = "ismaster";
 const std::string kSecondaryFieldName = "secondary";
 const std::string kSetNameFieldName = "setName";
 const std::string kSetVersionFieldName = "setVersion";
-const std::string kTopologyVersionFieldName = "topologyVersion";
 const std::string kHostsFieldName = "hosts";
 const std::string kPassivesFieldName = "passives";
 const std::string kArbitersFieldName = "arbiters";
@@ -103,11 +103,6 @@ IsMasterResponse::IsMasterResponse()
       _shutdownInProgress(false) {}
 
 void IsMasterResponse::addToBSON(BSONObjBuilder* builder) const {
-    if (_topologyVersion) {
-        BSONObjBuilder topologyVersionBuilder(builder->subobjStart(kTopologyVersionFieldName));
-        _topologyVersion->serialize(&topologyVersionBuilder);
-    }
-
     if (_hostsSet) {
         std::vector<std::string> hosts;
         for (size_t i = 0; i < _hosts.size(); ++i) {
@@ -169,7 +164,7 @@ void IsMasterResponse::addToBSON(BSONObjBuilder* builder) const {
         builder->appendIntOrLL(kSlaveDelayFieldName, durationCount<Seconds>(_slaveDelay));
     if (_tagsSet) {
         BSONObjBuilder tags(builder->subobjStart(kTagsFieldName));
-        for (stdx::unordered_map<std::string, std::string>::const_iterator it = _tags.begin();
+        for (unordered_map<std::string, std::string>::const_iterator it = _tags.begin();
              it != _tags.end();
              ++it) {
             tags.append(it->first, it->second);
@@ -226,7 +221,8 @@ Status IsMasterResponse::initialize(const BSONObj& doc) {
                           str::stream() << "Found \"" << kIsReplicaSetFieldName
                                         << "\" field which should indicate that no valid config "
                                            "is loaded, but we didn't also have an \""
-                                        << kInfoFieldName << "\" field as we expected");
+                                        << kInfoFieldName
+                                        << "\" field as we expected");
         }
     }
 
@@ -253,7 +249,8 @@ Status IsMasterResponse::initialize(const BSONObj& doc) {
                 return Status(ErrorCodes::TypeMismatch,
                               str::stream() << "Elements in \"" << kHostsFieldName
                                             << "\" array of isMaster response must be of type "
-                                            << typeName(String) << " but found type "
+                                            << typeName(String)
+                                            << " but found type "
                                             << typeName(hostElement.type()));
             }
             _hosts.push_back(HostAndPort(hostElement.String()));
@@ -273,7 +270,8 @@ Status IsMasterResponse::initialize(const BSONObj& doc) {
                 return Status(ErrorCodes::TypeMismatch,
                               str::stream() << "Elements in \"" << kPassivesFieldName
                                             << "\" array of isMaster response must be of type "
-                                            << typeName(String) << " but found type "
+                                            << typeName(String)
+                                            << " but found type "
                                             << typeName(passiveElement.type()));
             }
             _passives.push_back(HostAndPort(passiveElement.String()));
@@ -293,7 +291,8 @@ Status IsMasterResponse::initialize(const BSONObj& doc) {
                 return Status(ErrorCodes::TypeMismatch,
                               str::stream() << "Elements in \"" << kArbitersFieldName
                                             << "\" array of isMaster response must be of type "
-                                            << typeName(String) << " but found type "
+                                            << typeName(String)
+                                            << " but found type "
                                             << typeName(arbiterElement.type()));
             }
             _arbiters.push_back(HostAndPort(arbiterElement.String()));
@@ -366,7 +365,8 @@ Status IsMasterResponse::initialize(const BSONObj& doc) {
                               str::stream() << "Elements in \"" << kTagsFieldName
                                             << "\" obj "
                                                "of isMaster response must be of type "
-                                            << typeName(String) << " but found type "
+                                            << typeName(String)
+                                            << " but found type "
                                             << typeName(tagsElement.type()));
             }
             _tags[tagElement.fieldNameStringData().toString()] = tagElement.String();
@@ -398,7 +398,8 @@ Status IsMasterResponse::initialize(const BSONObj& doc) {
                               str::stream() << "Elements in \"" << kLastWriteOpTimeFieldName
                                             << "\" obj "
                                                "of isMaster response must be of type "
-                                            << typeName(Object) << " but found type "
+                                            << typeName(Object)
+                                            << " but found type "
                                             << typeName(lastWriteOpTimeElement.type()));
             }
             auto lastWriteOpTime = OpTime::parseFromOplogEntry(lastWriteOpTimeElement.Obj());
@@ -418,7 +419,8 @@ Status IsMasterResponse::initialize(const BSONObj& doc) {
                               str::stream() << "Elements in \"" << kLastWriteDateFieldName
                                             << "\" obj "
                                                "of isMaster response must be of type "
-                                            << typeName(Date) << " but found type "
+                                            << typeName(Date)
+                                            << " but found type "
                                             << typeName(lastWriteDateElement.type()));
             }
             if (_lastWrite) {
@@ -438,7 +440,8 @@ Status IsMasterResponse::initialize(const BSONObj& doc) {
                               str::stream() << "Elements in \"" << kLastMajorityWriteOpTimeFieldName
                                             << "\" obj "
                                                "of isMaster response must be of type "
-                                            << typeName(Object) << " but found type "
+                                            << typeName(Object)
+                                            << " but found type "
                                             << typeName(lastMajorityWriteOpTimeElement.type()));
             }
             auto lastMajorityWriteOpTime =
@@ -459,7 +462,8 @@ Status IsMasterResponse::initialize(const BSONObj& doc) {
                               str::stream() << "Elements in \"" << kLastMajorityWriteDateFieldName
                                             << "\" obj "
                                                "of isMaster response must be of type "
-                                            << typeName(Date) << " but found type "
+                                            << typeName(Date)
+                                            << " but found type "
                                             << typeName(lastMajorityWriteDateElement.type()));
             }
             if (_lastMajorityWrite) {
@@ -544,10 +548,6 @@ void IsMasterResponse::setShouldBuildIndexes(bool buildIndexes) {
     _buildIndexes = buildIndexes;
 }
 
-void IsMasterResponse::setTopologyVersion(TopologyVersion topologyVersion) {
-    _topologyVersion = topologyVersion;
-}
-
 void IsMasterResponse::setSlaveDelay(Seconds slaveDelay) {
     _slaveDelaySet = true;
     _slaveDelay = slaveDelay;
