@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -35,7 +36,6 @@
 
 #include "mongo/db/namespace_string.h"
 #include "mongo/util/log.h"
-#include "mongo/util/time_support.h"
 
 namespace mongo {
 namespace repl {
@@ -64,24 +64,14 @@ OplogEntry::CommandType parseCommandType(const BSONObj& objectField) {
         return OplogEntry::CommandType::kConvertToCapped;
     } else if (commandString == "createIndexes") {
         return OplogEntry::CommandType::kCreateIndexes;
-    } else if (commandString == "startIndexBuild") {
-        return OplogEntry::CommandType::kStartIndexBuild;
-    } else if (commandString == "commitIndexBuild") {
-        return OplogEntry::CommandType::kCommitIndexBuild;
-    } else if (commandString == "abortIndexBuild") {
-        return OplogEntry::CommandType::kAbortIndexBuild;
     } else if (commandString == "dropIndexes") {
         return OplogEntry::CommandType::kDropIndexes;
     } else if (commandString == "deleteIndexes") {
         return OplogEntry::CommandType::kDropIndexes;
-    } else if (commandString == "commitTransaction") {
-        return OplogEntry::CommandType::kCommitTransaction;
-    } else if (commandString == "abortTransaction") {
-        return OplogEntry::CommandType::kAbortTransaction;
     } else {
-        uasserted(ErrorCodes::BadValue,
-                  str::stream() << "Unknown oplog entry command type: " << commandString
-                                << " Object field: " << redact(objectField));
+        severe() << "Unknown oplog entry command type: " << commandString
+                 << " Object field: " << redact(objectField);
+        fassertFailedNoTrace(40444);
     }
     MONGO_UNREACHABLE;
 }
@@ -90,7 +80,7 @@ OplogEntry::CommandType parseCommandType(const BSONObj& objectField) {
  * Returns a document representing an oplog entry with the given fields.
  */
 BSONObj makeOplogEntryDoc(OpTime opTime,
-                          const boost::optional<long long> hash,
+                          long long hash,
                           OpTypeEnum opType,
                           const NamespaceString& nss,
                           const boost::optional<UUID>& uuid,
@@ -104,18 +94,15 @@ BSONObj makeOplogEntryDoc(OpTime opTime,
                           const boost::optional<StmtId>& statementId,
                           const boost::optional<OpTime>& prevWriteOpTimeInTransaction,
                           const boost::optional<OpTime>& preImageOpTime,
-                          const boost::optional<OpTime>& postImageOpTime,
-                          const boost::optional<repl::RetryImageEnum>& needsRetryImage) {
+                          const boost::optional<OpTime>& postImageOpTime) {
     BSONObjBuilder builder;
     sessionInfo.serialize(&builder);
     builder.append(OplogEntryBase::kTimestampFieldName, opTime.getTimestamp());
     builder.append(OplogEntryBase::kTermFieldName, opTime.getTerm());
+    builder.append(OplogEntryBase::kHashFieldName, hash);
     builder.append(OplogEntryBase::kVersionFieldName, version);
     builder.append(OplogEntryBase::kOpTypeFieldName, OpType_serializer(opType));
-    builder.append(OplogEntryBase::kNssFieldName, nss.toString());
-    if (hash) {
-        builder.append(OplogEntryBase::kHashFieldName, hash.get());
-    }
+    builder.append(OplogEntryBase::kNamespaceFieldName, nss.toString());
     if (uuid) {
         uuid->appendToBuilder(&builder, OplogEntryBase::kUuidFieldName);
     }
@@ -148,10 +135,6 @@ BSONObj makeOplogEntryDoc(OpTime opTime,
         const BSONObj localObject = postImageOpTime.get().toBSON();
         builder.append(OplogEntryBase::kPostImageOpTimeFieldName, localObject);
     }
-    if (needsRetryImage) {
-        builder.append(OplogEntryBase::kNeedsRetryImageFieldName,
-                       RetryImage_serializer(needsRetryImage.get()));
-    }
     return builder.obj();
 }
 
@@ -160,46 +143,6 @@ BSONObj makeOplogEntryDoc(OpTime opTime,
 const int OplogEntry::kOplogVersion = 2;
 
 // Static
-ReplOperation OplogEntry::makeInsertOperation(const NamespaceString& nss,
-                                              boost::optional<UUID> uuid,
-                                              const BSONObj& docToInsert) {
-    ReplOperation op;
-    op.setOpType(OpTypeEnum::kInsert);
-    op.setNss(nss);
-    op.setUuid(uuid);
-    op.setObject(docToInsert.getOwned());
-    return op;
-}
-
-ReplOperation OplogEntry::makeUpdateOperation(const NamespaceString nss,
-                                              boost::optional<UUID> uuid,
-                                              const BSONObj& update,
-                                              const BSONObj& criteria) {
-    ReplOperation op;
-    op.setOpType(OpTypeEnum::kUpdate);
-    op.setNss(nss);
-    op.setUuid(uuid);
-    op.setObject(update.getOwned());
-    op.setObject2(criteria.getOwned());
-    return op;
-}
-
-ReplOperation OplogEntry::makeDeleteOperation(const NamespaceString& nss,
-                                              boost::optional<UUID> uuid,
-                                              const BSONObj& docToDelete) {
-    ReplOperation op;
-    op.setOpType(OpTypeEnum::kDelete);
-    op.setNss(nss);
-    op.setUuid(uuid);
-    op.setObject(docToDelete.getOwned());
-    return op;
-}
-
-size_t OplogEntry::getDurableReplOperationSize(const DurableReplOperation& op) {
-    return sizeof(op) + op.getNss().size() + op.getObject().objsize() +
-        (op.getObject2() ? op.getObject2()->objsize() : 0);
-}
-
 StatusWith<OplogEntry> OplogEntry::parse(const BSONObj& object) {
     try {
         return OplogEntry(object);
@@ -209,10 +152,11 @@ StatusWith<OplogEntry> OplogEntry::parse(const BSONObj& object) {
     MONGO_UNREACHABLE;
 }
 
-OplogEntry::OplogEntry(BSONObj rawInput) : _raw(std::move(rawInput)) {
-    _raw = _raw.getOwned();
+OplogEntry::OplogEntry(BSONObj rawInput)
+    : raw(std::move(rawInput)), _commandType(OplogEntry::CommandType::kNotCommand) {
+    raw = raw.getOwned();
 
-    parseProtected(IDLParserErrorContext("OplogEntryBase"), _raw);
+    parseProtected(IDLParserErrorContext("OplogEntryBase"), raw);
 
     // Parse command type from 'o' and 'o2' fields.
     if (isCommand()) {
@@ -221,7 +165,7 @@ OplogEntry::OplogEntry(BSONObj rawInput) : _raw(std::move(rawInput)) {
 }
 
 OplogEntry::OplogEntry(OpTime opTime,
-                       const boost::optional<long long> hash,
+                       long long hash,
                        OpTypeEnum opType,
                        const NamespaceString& nss,
                        const boost::optional<UUID>& uuid,
@@ -235,8 +179,7 @@ OplogEntry::OplogEntry(OpTime opTime,
                        const boost::optional<StmtId>& statementId,
                        const boost::optional<OpTime>& prevWriteOpTimeInTransaction,
                        const boost::optional<OpTime>& preImageOpTime,
-                       const boost::optional<OpTime>& postImageOpTime,
-                       const boost::optional<repl::RetryImageEnum>& needsRetryImage)
+                       const boost::optional<OpTime>& postImageOpTime)
     : OplogEntry(makeOplogEntryDoc(opTime,
                                    hash,
                                    opType,
@@ -252,38 +195,18 @@ OplogEntry::OplogEntry(OpTime opTime,
                                    statementId,
                                    prevWriteOpTimeInTransaction,
                                    preImageOpTime,
-                                   postImageOpTime,
-                                   needsRetryImage)) {}
+                                   postImageOpTime)) {}
 
 bool OplogEntry::isCommand() const {
     return getOpType() == OpTypeEnum::kCommand;
 }
 
-// static
-bool OplogEntry::isCrudOpType(OpTypeEnum opType) {
-    switch (opType) {
-        case OpTypeEnum::kInsert:
-        case OpTypeEnum::kDelete:
-        case OpTypeEnum::kUpdate:
-            return true;
-        case OpTypeEnum::kCommand:
-        case OpTypeEnum::kNoop:
-            return false;
-    }
-    MONGO_UNREACHABLE;
-}
-
 bool OplogEntry::isCrudOpType() const {
-    return isCrudOpType(getOpType());
-}
-
-bool OplogEntry::isUpdateOrDelete() const {
-    auto opType = getOpType();
-    switch (opType) {
+    switch (getOpType()) {
+        case OpTypeEnum::kInsert:
         case OpTypeEnum::kDelete:
         case OpTypeEnum::kUpdate:
             return true;
-        case OpTypeEnum::kInsert:
         case OpTypeEnum::kCommand:
         case OpTypeEnum::kNoop:
             return false;
@@ -291,45 +214,21 @@ bool OplogEntry::isUpdateOrDelete() const {
     MONGO_UNREACHABLE;
 }
 
-bool OplogEntry::shouldPrepare() const {
-    return getCommandType() == CommandType::kApplyOps &&
-        getObject()[ApplyOpsCommandInfoBase::kPrepareFieldName].booleanSafe();
-}
-
 BSONElement OplogEntry::getIdElement() const {
     invariant(isCrudOpType());
     if (getOpType() == OpTypeEnum::kUpdate) {
-        // We cannot use getObjectContainingDocumentKey() here because the BSONObj will go out
-        // of scope after we return the BSONElement.
-        fassert(31080, getObject2() != boost::none);
         return getObject2()->getField("_id");
     } else {
         return getObject()["_id"];
     }
 }
 
-BSONObj OplogEntry::getOperationToApply() const {
-    return getObject();
-}
-
-BSONObj OplogEntry::getObjectContainingDocumentKey() const {
-    invariant(isCrudOpType());
-    if (getOpType() == OpTypeEnum::kUpdate) {
-        fassert(31081, getObject2() != boost::none);
-        return *getObject2();
-    } else {
-        return getObject();
-    }
-}
-
 OplogEntry::CommandType OplogEntry::getCommandType() const {
+    invariant(isCommand());
+    invariant(_commandType != OplogEntry::CommandType::kNotCommand);
     return _commandType;
 }
 
-int OplogEntry::getRawObjSizeBytes() const {
-    return _raw.objsize();
-}
-
 OpTime OplogEntry::getOpTime() const {
     long long term = OpTime::kUninitializedTerm;
     if (getTerm()) {
@@ -339,16 +238,12 @@ OpTime OplogEntry::getOpTime() const {
 }
 
 std::string OplogEntry::toString() const {
-    return _raw.toString();
+    return raw.toString();
 }
 
 std::ostream& operator<<(std::ostream& s, const OplogEntry& o) {
     return s << o.toString();
 }
 
-std::ostream& operator<<(std::ostream& s, const ReplOperation& o) {
-    return s << o.toBSON().toString();
-}
-
 }  // namespace repl
 }  // namespace mongo
