@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -39,11 +40,9 @@
 #include "mongo/bson/util/bson_extract.h"
 #include "mongo/db/jsobj.h"
 #include "mongo/db/repl/bson_extract_optime.h"
-#include "mongo/db/server_options.h"
-#include "mongo/rpc/get_status_from_command_result.h"
 #include "mongo/util/assert_util.h"
 #include "mongo/util/log.h"
-#include "mongo/util/str.h"
+#include "mongo/util/mongoutils/str.h"
 
 namespace mongo {
 namespace repl {
@@ -52,23 +51,38 @@ namespace {
 const std::string kConfigFieldName = "config";
 const std::string kConfigVersionFieldName = "v";
 const std::string kElectionTimeFieldName = "electionTime";
+const std::string kErrMsgFieldName = "errmsg";
+const std::string kErrorCodeFieldName = "code";
+const std::string kHasDataFieldName = "hasData";
+const std::string kHasStateDisagreementFieldName = "stateDisagreement";
+const std::string kHbMessageFieldName = "hbmsg";
+const std::string kIsElectableFieldName = "e";
+const std::string kIsReplSetFieldName = "rs";
 const std::string kMemberStateFieldName = "state";
+const std::string kMismatchFieldName = "mismatch";
 const std::string kOkFieldName = "ok";
 const std::string kDurableOpTimeFieldName = "durableOpTime";
-const std::string kDurableWallTimeFieldName = "durableWallTime";
 const std::string kAppliedOpTimeFieldName = "opTime";
-const std::string kAppliedWallTimeFieldName = "wallTime";
 const std::string kPrimaryIdFieldName = "primaryId";
 const std::string kReplSetFieldName = "set";
 const std::string kSyncSourceFieldName = "syncingTo";
 const std::string kTermFieldName = "term";
+const std::string kTimeFieldName = "time";
 const std::string kTimestampFieldName = "ts";
-const std::string kIsElectableFieldName = "electable";
 
 }  // namespace
 
-void ReplSetHeartbeatResponse::addToBSON(BSONObjBuilder* builder) const {
+void ReplSetHeartbeatResponse::addToBSON(BSONObjBuilder* builder, bool isProtocolVersionV1) const {
+    if (_mismatch) {
+        *builder << kOkFieldName << 0.0;
+        *builder << kMismatchFieldName << _mismatch;
+        return;
+    }
+
     builder->append(kOkFieldName, 1.0);
+    if (_timeSet) {
+        *builder << kTimeFieldName << durationCount<Seconds>(_time);
+    }
     if (_electionTimeSet) {
         builder->appendDate(kElectionTimeFieldName,
                             Date_t::fromMillisSinceEpoch(_electionTime.asLL()));
@@ -76,18 +90,31 @@ void ReplSetHeartbeatResponse::addToBSON(BSONObjBuilder* builder) const {
     if (_configSet) {
         *builder << kConfigFieldName << _config.toBSON();
     }
+    if (_electableSet) {
+        *builder << kIsElectableFieldName << _electable;
+    }
+    if (_isReplSet) {
+        *builder << "rs" << _isReplSet;
+    }
+    if (_stateDisagreement) {
+        *builder << kHasStateDisagreementFieldName << _stateDisagreement;
+    }
     if (_stateSet) {
         builder->appendIntOrLL(kMemberStateFieldName, _state.s);
     }
     if (_configVersion != -1) {
         *builder << kConfigVersionFieldName << _configVersion;
     }
+    *builder << kHbMessageFieldName << _hbmsg;
     if (!_setName.empty()) {
         *builder << kReplSetFieldName << _setName;
     }
     if (!_syncingTo.empty()) {
         *builder << kSyncSourceFieldName << _syncingTo.toString();
     }
+    if (_hasDataSet) {
+        builder->append(kHasDataFieldName, _hasData);
+    }
     if (_term != -1) {
         builder->append(kTermFieldName, _term);
     }
@@ -96,31 +123,30 @@ void ReplSetHeartbeatResponse::addToBSON(BSONObjBuilder* builder) const {
     }
     if (_durableOpTimeSet) {
         _durableOpTime.append(builder, kDurableOpTimeFieldName);
-        builder->appendDate(kDurableWallTimeFieldName, _durableWallTime);
     }
     if (_appliedOpTimeSet) {
-        _appliedOpTime.append(builder, kAppliedOpTimeFieldName);
-        builder->appendDate(kAppliedWallTimeFieldName, _appliedWallTime);
-    }
-    if (_electableSet) {
-        *builder << kIsElectableFieldName << _electable;
+        if (isProtocolVersionV1) {
+            _appliedOpTime.append(builder, kAppliedOpTimeFieldName);
+        } else {
+            builder->appendDate(kAppliedOpTimeFieldName,
+                                Date_t::fromMillisSinceEpoch(_appliedOpTime.getTimestamp().asLL()));
+        }
     }
 }
 
-BSONObj ReplSetHeartbeatResponse::toBSON() const {
+BSONObj ReplSetHeartbeatResponse::toBSON(bool isProtocolVersionV1) const {
     BSONObjBuilder builder;
-    addToBSON(&builder);
+    addToBSON(&builder, isProtocolVersionV1);
     return builder.obj();
 }
 
-Status ReplSetHeartbeatResponse::initialize(const BSONObj& doc,
-                                            long long term,
-                                            bool requireWallTime) {
-    auto status = getStatusFromCommandResult(doc);
-    if (!status.isOK()) {
-        return status;
-    }
+Status ReplSetHeartbeatResponse::initialize(const BSONObj& doc, long long term) {
+    // Old versions set this even though they returned not "ok"
+    _mismatch = doc[kMismatchFieldName].trueValue();
+    if (_mismatch)
+        return Status(ErrorCodes::InconsistentReplicaSetNames, "replica set name doesn't match.");
 
+    // Old versions sometimes set the replica set name ("set") but ok:0
     const BSONElement replSetNameElement = doc[kReplSetFieldName];
     if (replSetNameElement.eoo()) {
         _setName.clear();
@@ -134,9 +160,30 @@ Status ReplSetHeartbeatResponse::initialize(const BSONObj& doc,
         _setName = replSetNameElement.String();
     }
 
+    if (_setName.empty() && !doc[kOkFieldName].trueValue()) {
+        std::string errMsg = doc[kErrMsgFieldName].str();
+
+        BSONElement errCodeElem = doc[kErrorCodeFieldName];
+        if (errCodeElem.ok()) {
+            if (!errCodeElem.isNumber())
+                return Status(ErrorCodes::BadValue, "Error code is not a number!");
+
+            int errorCode = errCodeElem.numberInt();
+            return Status(ErrorCodes::Error(errorCode), errMsg);
+        }
+        return Status(ErrorCodes::UnknownError, errMsg);
+    }
+
+    const BSONElement hasDataElement = doc[kHasDataFieldName];
+    _hasDataSet = !hasDataElement.eoo();
+    _hasData = hasDataElement.trueValue();
+
     const BSONElement electionTimeElement = doc[kElectionTimeFieldName];
     if (electionTimeElement.eoo()) {
         _electionTimeSet = false;
+    } else if (electionTimeElement.type() == bsonTimestamp) {
+        _electionTimeSet = true;
+        _electionTime = electionTimeElement.timestamp();
     } else if (electionTimeElement.type() == Date) {
         _electionTimeSet = true;
         _electionTime = Timestamp(electionTimeElement.date());
@@ -144,78 +191,90 @@ Status ReplSetHeartbeatResponse::initialize(const BSONObj& doc,
         return Status(ErrorCodes::TypeMismatch,
                       str::stream() << "Expected \"" << kElectionTimeFieldName
                                     << "\" field in response to replSetHeartbeat "
-                                       "command to have type Date, but found type "
+                                       "command to have type Date or Timestamp, but found type "
                                     << typeName(electionTimeElement.type()));
     }
 
+    const BSONElement timeElement = doc[kTimeFieldName];
+    if (timeElement.eoo()) {
+        _timeSet = false;
+    } else if (timeElement.isNumber()) {
+        _timeSet = true;
+        _time = Seconds(timeElement.numberLong());
+    } else {
+        return Status(ErrorCodes::TypeMismatch,
+                      str::stream() << "Expected \"" << kTimeFieldName
+                                    << "\" field in response to replSetHeartbeat "
+                                       "command to have a numeric type, but found type "
+                                    << typeName(timeElement.type()));
+    }
+
+    _isReplSet = doc[kIsReplSetFieldName].trueValue();
+
     Status termStatus = bsonExtractIntegerField(doc, kTermFieldName, &_term);
     if (!termStatus.isOK() && termStatus != ErrorCodes::NoSuchKey) {
         return termStatus;
     }
 
-    status = bsonExtractOpTimeField(doc, kDurableOpTimeFieldName, &_durableOpTime);
+    Status status = bsonExtractOpTimeField(doc, kDurableOpTimeFieldName, &_durableOpTime);
     if (!status.isOK()) {
-        return status;
+        if (status != ErrorCodes::NoSuchKey) {
+            return status;
+        }
+    } else {
+        _durableOpTimeSet = true;
     }
 
-    BSONElement durableWallTimeElement;
-    _durableWallTime = Date_t();
-    status = bsonExtractTypedField(
-        doc, kDurableWallTimeFieldName, BSONType::Date, &durableWallTimeElement);
-    if (!status.isOK() && (status != ErrorCodes::NoSuchKey || requireWallTime)) {
-        // We ignore NoSuchKey errors if the FeatureCompatibilityVersion is less than 4.2, since
-        // older version nodes may not report wall clock times.
-        return status;
-    }
-    if (status.isOK()) {
-        _durableWallTime = durableWallTimeElement.Date();
-    }
-    _durableOpTimeSet = true;
-
-
-    // In V1, heartbeats OpTime is type Object and we construct an OpTime out of its nested fields.
-    status = bsonExtractOpTimeField(doc, kAppliedOpTimeFieldName, &_appliedOpTime);
-    if (!status.isOK()) {
-        return status;
+    // In order to support both the 3.0(V0) and 3.2(V1) heartbeats we must parse the OpTime
+    // field based on its type. If it is a Date, we parse it as the timestamp and use
+    // initialize's term argument to complete the OpTime type. If it is an Object, then it's
+    // V1 and we construct an OpTime out of its nested fields.
+    const BSONElement appliedOpTimeElement = doc[kAppliedOpTimeFieldName];
+    if (appliedOpTimeElement.eoo()) {
+        _appliedOpTimeSet = false;
+    } else if (appliedOpTimeElement.type() == bsonTimestamp) {
+        _appliedOpTimeSet = true;
+        _appliedOpTime = OpTime(appliedOpTimeElement.timestamp(), term);
+    } else if (appliedOpTimeElement.type() == Date) {
+        _appliedOpTimeSet = true;
+        _appliedOpTime = OpTime(Timestamp(appliedOpTimeElement.date()), term);
+    } else if (appliedOpTimeElement.type() == Object) {
+        Status status = bsonExtractOpTimeField(doc, kAppliedOpTimeFieldName, &_appliedOpTime);
+        _appliedOpTimeSet = true;
+        // since a v1 OpTime was in the response, the member must be part of a replset
+        _isReplSet = true;
+    } else {
+        return Status(ErrorCodes::TypeMismatch,
+                      str::stream() << "Expected \"" << kAppliedOpTimeFieldName
+                                    << "\" field in response to replSetHeartbeat "
+                                       "command to have type Date or Timestamp, but found type "
+                                    << typeName(appliedOpTimeElement.type()));
     }
 
-    BSONElement appliedWallTimeElement;
-    _appliedWallTime = Date_t();
-    status = bsonExtractTypedField(
-        doc, kAppliedWallTimeFieldName, BSONType::Date, &appliedWallTimeElement);
-    if (!status.isOK() && (status != ErrorCodes::NoSuchKey || requireWallTime)) {
-        // We ignore NoSuchKey errors if the FeatureCompatibilityVersion is less than 4.2, since
-        // older version nodes may not report wall clock times.
-        return status;
-    }
-    if (status.isOK()) {
-        _appliedWallTime = appliedWallTimeElement.Date();
-    }
-    _appliedOpTimeSet = true;
-
-    status = bsonExtractBooleanField(doc, kIsElectableFieldName, &_electable);
-    if (!status.isOK()) {
+    const BSONElement electableElement = doc[kIsElectableFieldName];
+    if (electableElement.eoo()) {
         _electableSet = false;
     } else {
         _electableSet = true;
+        _electable = electableElement.trueValue();
     }
 
     const BSONElement memberStateElement = doc[kMemberStateFieldName];
     if (memberStateElement.eoo()) {
         _stateSet = false;
     } else if (memberStateElement.type() != NumberInt && memberStateElement.type() != NumberLong) {
-        return Status(ErrorCodes::TypeMismatch,
-                      str::stream()
-                          << "Expected \"" << kMemberStateFieldName
+        return Status(
+            ErrorCodes::TypeMismatch,
+            str::stream() << "Expected \"" << kMemberStateFieldName
                           << "\" field in response to replSetHeartbeat "
                              "command to have type NumberInt or NumberLong, but found type "
                           << typeName(memberStateElement.type()));
     } else {
         long long stateInt = memberStateElement.numberLong();
         if (stateInt < 0 || stateInt > MemberState::RS_MAX) {
-            return Status(ErrorCodes::BadValue,
-                          str::stream()
-                              << "Value for \"" << kMemberStateFieldName
+            return Status(
+                ErrorCodes::BadValue,
+                str::stream() << "Value for \"" << kMemberStateFieldName
                               << "\" in response to replSetHeartbeat is "
                                  "out of range; legal values are non-negative and no more than "
                               << MemberState::RS_MAX);
@@ -224,13 +283,22 @@ Status ReplSetHeartbeatResponse::initialize(const BSONObj& doc,
         _state = MemberState(static_cast<int>(stateInt));
     }
 
+    _stateDisagreement = doc[kHasStateDisagreementFieldName].trueValue();
+
+
+    // Not required for the case of uninitialized members -- they have no config
     const BSONElement configVersionElement = doc[kConfigVersionFieldName];
-    if (configVersionElement.eoo()) {
+
+    // If we have an optime then we must have a configVersion
+    if (_appliedOpTimeSet && configVersionElement.eoo()) {
         return Status(ErrorCodes::NoSuchKey,
                       str::stream() << "Response to replSetHeartbeat missing required \""
-                                    << kConfigVersionFieldName << "\" field");
+                                    << kConfigVersionFieldName
+                                    << "\" field even though initialized");
     }
-    if (configVersionElement.type() != NumberInt) {
+
+    // If there is a "v" (config version) then it must be an int.
+    if (!configVersionElement.eoo() && configVersionElement.type() != NumberInt) {
         return Status(ErrorCodes::TypeMismatch,
                       str::stream() << "Expected \"" << kConfigVersionFieldName
                                     << "\" field in response to replSetHeartbeat to have "
@@ -239,6 +307,19 @@ Status ReplSetHeartbeatResponse::initialize(const BSONObj& doc,
     }
     _configVersion = configVersionElement.numberInt();
 
+    const BSONElement hbMsgElement = doc[kHbMessageFieldName];
+    if (hbMsgElement.eoo()) {
+        _hbmsg.clear();
+    } else if (hbMsgElement.type() != String) {
+        return Status(ErrorCodes::TypeMismatch,
+                      str::stream() << "Expected \"" << kHbMessageFieldName
+                                    << "\" field in response to replSetHeartbeat to have "
+                                       "type String, but found "
+                                    << typeName(hbMsgElement.type()));
+    } else {
+        _hbmsg = hbMsgElement.String();
+    }
+
     const BSONElement syncingToElement = doc[kSyncSourceFieldName];
     if (syncingToElement.eoo()) {
         _syncingTo = HostAndPort();
@@ -279,6 +360,16 @@ Timestamp ReplSetHeartbeatResponse::getElectionTime() const {
     return _electionTime;
 }
 
+bool ReplSetHeartbeatResponse::isElectable() const {
+    invariant(_electableSet);
+    return _electable;
+}
+
+Seconds ReplSetHeartbeatResponse::getTime() const {
+    invariant(_timeSet);
+    return _time;
+}
+
 const ReplSetConfig& ReplSetHeartbeatResponse::getConfig() const {
     invariant(_configSet);
     return _config;
@@ -294,25 +385,10 @@ OpTime ReplSetHeartbeatResponse::getAppliedOpTime() const {
     return _appliedOpTime;
 }
 
-OpTimeAndWallTime ReplSetHeartbeatResponse::getAppliedOpTimeAndWallTime() const {
-    invariant(_appliedOpTimeSet);
-    return {_appliedOpTime, _appliedWallTime};
-}
-
 OpTime ReplSetHeartbeatResponse::getDurableOpTime() const {
     invariant(_durableOpTimeSet);
     return _durableOpTime;
 }
 
-OpTimeAndWallTime ReplSetHeartbeatResponse::getDurableOpTimeAndWallTime() const {
-    invariant(_durableOpTimeSet);
-    return {_durableOpTime, _durableWallTime};
-}
-
-bool ReplSetHeartbeatResponse::isElectable() const {
-    invariant(_electableSet);
-    return _electable;
-}
-
 }  // namespace repl
 }  // namespace mongo
