@@ -27,30 +27,26 @@
  *    it in the license file.
  */
 
+#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kReplication
+
+#include "mongo/platform/basic.h"
+
 #include "mongo/db/repl/split_horizon.h"
 
-#include <algorithm>
-#include <iterator>
-#include <mutex>
 #include <utility>
-#include <vector>
 
-#include <absl/container/flat_hash_map.h>
-#include <boost/move/utility_core.hpp>
-#include <boost/optional/optional.hpp>
-
-#include "mongo/bson/bsontypes.h"
+#include "mongo/bson/util/bson_extract.h"
 #include "mongo/db/client.h"
-#include "mongo/util/decorable.h"
+#include "mongo/util/log.h"
 
-#define MONGO_LOGV2_DEFAULT_COMPONENT ::mongo::logv2::LogComponent::kReplication
+using namespace std::literals::string_literals;
+
+using std::begin;
+using std::end;
 
 namespace mongo {
 namespace repl {
 namespace {
-
-using namespace std::literals::string_literals;
-
 const auto getSplitHorizonParameters = Client::declareDecoration<SplitHorizon::Parameters>();
 
 using AllMappings = SplitHorizon::AllMappings;
@@ -91,17 +87,29 @@ AllMappings computeReverseMappings(SplitHorizon::ForwardMapping forwardMapping)
     }
 
 
-    return {std::move(forwardMapping), std::move(reverseHostMapping)};
+    return AllMappings{std::move(forwardMapping), std::move(reverseHostMapping)};
 }
 
 SplitHorizon::ForwardMapping computeForwardMappings(
-    const HostAndPort& host, const boost::optional<BSONObj>& horizonsObject) {
+    const HostAndPort& host, const boost::optional<BSONElement>& horizonsElement) {
     SplitHorizon::ForwardMapping forwardMapping;
 
-    if (horizonsObject) {
+    if (horizonsElement) {
         using MapMember = std::pair<std::string, HostAndPort>;
 
-        if (horizonsObject->isEmpty()) {
+        if (horizonsElement->eoo()) {
+            uasserted(ErrorCodes::BadValue,
+                      str::stream() << "The horizons field cannot be empty, if present.");
+        }
+
+        if (horizonsElement->type() != Object) {
+            uasserted(ErrorCodes::TypeMismatch,
+                      str::stream() << "The horizons field must be an object");
+        }
+
+        const auto& horizonsObject = horizonsElement->Obj();
+
+        if (horizonsObject.isEmpty()) {
             uasserted(ErrorCodes::BadValue,
                       str::stream() << "The horizons field cannot be empty, if present.");
         }
@@ -128,10 +136,8 @@ SplitHorizon::ForwardMapping computeForwardMappings(
 
         const auto horizonEntries = [&] {
             std::vector<MapMember> rv;
-            std::transform(std::begin(*horizonsObject),
-                           std::end(*horizonsObject),
-                           inserter(rv, end(rv)),
-                           convert);
+            std::transform(
+                begin(horizonsObject), end(horizonsObject), inserter(rv, end(rv)), convert);
             return rv;
         }();
 
@@ -178,6 +184,7 @@ SplitHorizon::ForwardMapping computeForwardMappings(
     return forwardMapping;
 }
 }  // namespace
+const std::string SplitHorizon::kDefaultHorizon = "__default";
 
 void SplitHorizon::setParameters(Client* const client, boost::optional<std::string> sniName) {
     stdx::lock_guard<Client> lk(*client);
@@ -188,8 +195,7 @@ auto SplitHorizon::getParameters(const Client* const client) -> Parameters {
     return getSplitHorizonParameters(*client);
 }
 
-std::string SplitHorizon::determineHorizon(
-    const SplitHorizon::Parameters& horizonParameters) const {
+StringData SplitHorizon::determineHorizon(const SplitHorizon::Parameters& horizonParameters) const {
     if (horizonParameters.sniName) {
         const auto sniName = *horizonParameters.sniName;
         const auto found = _reverseHostMapping.find(sniName);
@@ -197,7 +203,7 @@ std::string SplitHorizon::determineHorizon(
             return found->second;
         }
     }
-    return kDefaultHorizon.toString();
+    return kDefaultHorizon;
 }
 
 void SplitHorizon::toBSON(BSONObjBuilder& configBuilder) const {
@@ -210,18 +216,12 @@ void SplitHorizon::toBSON(BSONObjBuilder& configBuilder) const {
     if (_forwardMapping.size() == 1)
         return;
 
-    // StringMaps are iterated in arbitrary order, so we sort before returning the horizons.
-    std::vector<std::pair<StringData, std::string>> sortedHorizons;
+    BSONObjBuilder horizonsBson(configBuilder.subobjStart("horizons"));
     for (const auto& horizon : _forwardMapping) {
         // The "__default" horizon should never be emitted in the horizon table.
         if (horizon.first == SplitHorizon::kDefaultHorizon)
             continue;
-        sortedHorizons.emplace_back(horizon.first, horizon.second.toString());
-    }
-    std::sort(sortedHorizons.begin(), sortedHorizons.end());
-    BSONObjBuilder horizonsBson(configBuilder.subobjStart("horizons"));
-    for (const auto& horizon : sortedHorizons) {
-        horizonsBson.append(horizon.first, horizon.second);
+        horizonsBson.append(horizon.first, horizon.second.toString());
     }
 }
 
@@ -233,8 +233,9 @@ SplitHorizon::SplitHorizon(ForwardMapping mapping)
 // A split horizon constructed from the BSON configuration and the host specifier for this member
 // needs to compute the forward mapping table.  In turn that will be used to compute the reverse
 // mapping table.
-SplitHorizon::SplitHorizon(const HostAndPort& host, const boost::optional<BSONObj>& horizonsObject)
-    : SplitHorizon(computeForwardMappings(host, horizonsObject)) {}
+SplitHorizon::SplitHorizon(const HostAndPort& host,
+                           const boost::optional<BSONElement>& horizonsElement)
+    : SplitHorizon(computeForwardMappings(host, horizonsElement)) {}
 
 }  // namespace repl
 }  // namespace mongo
