@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -30,11 +31,13 @@
 
 #pragma once
 
+#include "mongo/base/disallow_copying.h"
 #include "mongo/base/status.h"
 #include "mongo/base/status_with.h"
 #include "mongo/base/string_data.h"
 #include "mongo/bson/bsonobj.h"
 #include "mongo/bson/timestamp.h"
+#include "mongo/db/catalog/index_create.h"
 #include "mongo/db/namespace_string.h"
 #include "mongo/db/repl/storage_interface.h"
 
@@ -42,8 +45,7 @@ namespace mongo {
 namespace repl {
 
 class StorageInterfaceImpl : public StorageInterface {
-    StorageInterfaceImpl(const StorageInterfaceImpl&) = delete;
-    StorageInterfaceImpl& operator=(const StorageInterfaceImpl&) = delete;
+    MONGO_DISALLOW_COPYING(StorageInterfaceImpl);
 
 public:
     static const char kDefaultRollbackIdNamespace[];
@@ -66,18 +68,19 @@ public:
         const std::vector<BSONObj>& secondaryIndexSpecs) override;
 
     Status insertDocument(OperationContext* opCtx,
-                          const NamespaceStringOrUUID& nsOrUUID,
+                          const NamespaceString& nss,
                           const TimestampedBSONObj& doc,
                           long long term) override;
 
     Status insertDocuments(OperationContext* opCtx,
-                           const NamespaceStringOrUUID& nsOrUUID,
+                           const NamespaceString& nss,
                            const std::vector<InsertStatement>& docs) override;
 
     Status dropReplicatedDatabases(OperationContext* opCtx) override;
 
     Status createOplog(OperationContext* opCtx, const NamespaceString& nss) override;
-    StatusWith<size_t> getOplogMaxSize(OperationContext* opCtx) override;
+    StatusWith<size_t> getOplogMaxSize(OperationContext* opCtx,
+                                       const NamespaceString& nss) override;
 
     Status createCollection(OperationContext* opCtx,
                             const NamespaceString& nss,
@@ -92,14 +95,6 @@ public:
                             const NamespaceString& toNS,
                             bool stayTemp) override;
 
-    Status setIndexIsMultikey(OperationContext* opCtx,
-                              const NamespaceString& nss,
-                              const UUID& collectionUUID,
-                              const std::string& indexName,
-                              const KeyStringSet& multikeyMetadataKeys,
-                              const MultikeyPaths& paths,
-                              Timestamp ts) override;
-
     StatusWith<std::vector<BSONObj>> findDocuments(OperationContext* opCtx,
                                                    const NamespaceString& nss,
                                                    boost::optional<StringData> indexName,
@@ -120,23 +115,23 @@ public:
 
     Status putSingleton(OperationContext* opCtx,
                         const NamespaceString& nss,
-                        const TimestampedBSONObj& update) override;
+                        const BSONObj& update) override;
 
     Status updateSingleton(OperationContext* opCtx,
                            const NamespaceString& nss,
                            const BSONObj& query,
-                           const TimestampedBSONObj& update) override;
+                           const BSONObj& update) override;
 
     StatusWith<BSONObj> findById(OperationContext* opCtx,
-                                 const NamespaceStringOrUUID& nsOrUUID,
+                                 const NamespaceString& nss,
                                  const BSONElement& idKey) override;
 
     StatusWith<BSONObj> deleteById(OperationContext* opCtx,
-                                   const NamespaceStringOrUUID& nsOrUUID,
+                                   const NamespaceString& nss,
                                    const BSONElement& idKey) override;
 
     Status upsertById(OperationContext* opCtx,
-                      const NamespaceStringOrUUID& nsOrUUID,
+                      const NamespaceString& nss,
                       const BSONElement& idKey,
                       const BSONObj& update) override;
 
@@ -144,65 +139,33 @@ public:
                           const NamespaceString& nss,
                           const BSONObj& filter) override;
 
-    boost::optional<BSONObj> findOplogEntryLessThanOrEqualToTimestamp(
-        OperationContext* opCtx, Collection* oplog, const Timestamp& timestamp) override;
-
-    boost::optional<BSONObj> findOplogEntryLessThanOrEqualToTimestampRetryOnWCE(
-        OperationContext* opCtx, Collection* oplog, const Timestamp& timestamp) override;
-
-    Timestamp getLatestOplogTimestamp(OperationContext* opCtx) override;
-
     StatusWith<StorageInterface::CollectionSize> getCollectionSize(
         OperationContext* opCtx, const NamespaceString& nss) override;
 
     StatusWith<StorageInterface::CollectionCount> getCollectionCount(
-        OperationContext* opCtx, const NamespaceStringOrUUID& nsOrUUID) override;
-
-    Status setCollectionCount(OperationContext* opCtx,
-                              const NamespaceStringOrUUID& nsOrUUID,
-                              long long newCount) override;
+        OperationContext* opCtx, const NamespaceString& nss) override;
 
     StatusWith<OptionalCollectionUUID> getCollectionUUID(OperationContext* opCtx,
                                                          const NamespaceString& nss) override;
 
+    Status upgradeUUIDSchemaVersionNonReplicated(OperationContext* opCtx) override;
+
     void setStableTimestamp(ServiceContext* serviceCtx, Timestamp snapshotName) override;
 
     void setInitialDataTimestamp(ServiceContext* serviceCtx, Timestamp snapshotName) override;
 
-    Timestamp recoverToStableTimestamp(OperationContext* opCtx) override;
-
-    bool supportsRecoverToStableTimestamp(ServiceContext* serviceCtx) const override;
-
-    bool supportsRecoveryTimestamp(ServiceContext* serviceCtx) const override;
-
-    void initializeStorageControlsForReplication(ServiceContext* serviceCtx) const override;
-
-    boost::optional<Timestamp> getRecoveryTimestamp(ServiceContext* serviceCtx) const override;
+    Status recoverToStableTimestamp(ServiceContext* serviceCtx) override;
 
     bool supportsDocLocking(ServiceContext* serviceCtx) const override;
 
-    Timestamp getAllDurableTimestamp(ServiceContext* serviceCtx) const override;
-
-    Timestamp getOldestOpenReadTimestamp(ServiceContext* serviceCtx) const override;
+    Timestamp getAllCommittedTimestamp(ServiceContext* serviceCtx) const override;
 
     /**
      * Checks that the "admin" database contains a supported version of the auth data schema.
      */
     Status isAdminDbValid(OperationContext* opCtx) override;
 
-    void waitForAllEarlierOplogWritesToBeVisible(OperationContext* opCtx,
-                                                 bool primaryOnly) override;
-    void oplogDiskLocRegister(OperationContext* opCtx,
-                              const Timestamp& ts,
-                              bool orderedCommit) override;
-
-    boost::optional<Timestamp> getLastStableRecoveryTimestamp(
-        ServiceContext* serviceCtx) const override;
-
-    Timestamp getPointInTimeReadTimestamp(OperationContext* opCtx) const override;
-
-    void setPinnedOplogTimestamp(OperationContext* opCtx,
-                                 const Timestamp& pinnedTimestamp) const override;
+    void waitForAllEarlierOplogWritesToBeVisible(OperationContext* opCtx) override;
 
 private:
     const NamespaceString _rollbackIdNss;
