@@ -1,23 +1,25 @@
+
 /**
- *    Copyright (C) 2008 10gen Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects for
+ *    must comply with the Server Side Public License in all respects for
  *    all of the code used other than as permitted herein. If you modify file(s)
  *    with this exception, you may extend this exception to your version of the
  *    file(s), but you are not obligated to do so. If you do not wish to do so,
@@ -34,6 +36,7 @@
 #include "mongo/base/status.h"
 #include "mongo/bson/bsonobj.h"
 #include "mongo/db/repl/multiapplier.h"
+#include "mongo/db/repl/oplog.h"
 #include "mongo/db/repl/oplog_entry.h"
 #include "mongo/stdx/functional.h"
 #include "mongo/util/concurrency/old_thread_pool.h"
@@ -65,26 +68,37 @@ public:
      * Used for applying from an oplog.
      * 'db' is the database where the op will be applied.
      * 'opObj' is a BSONObj describing the op to be applied.
-     * 'inSteadyStateReplication' indicates to convert some updates to upserts for idempotency
-     * reasons.
+     * 'alwaysUpsert' indicates to convert updates to upserts for idempotency reasons.
+     * 'mode' indicates the oplog application mode.
      * 'opCounter' is used to update server status metrics.
      * Returns failure status if the op was an update that could not be applied.
      */
-    using ApplyOperationInLockFn = stdx::function<Status(OperationContext* txn,
-                                                         Database* db,
-                                                         const BSONObj& opObj,
-                                                         bool inSteadyStateReplication,
-                                                         IncrementOpsAppliedStatsFn opCounter)>;
+    using ApplyOperationInLockFn =
+        stdx::function<Status(OperationContext* opCtx,
+                              Database* db,
+                              const BSONObj& opObj,
+                              bool alwaysUpsert,
+                              OplogApplication::Mode oplogApplicationMode,
+                              IncrementOpsAppliedStatsFn opCounter)>;
 
     /**
      * Type of function that takes a command op and applies it locally.
      * Used for applying from an oplog.
-     * inSteadyStateReplication indicates whether we are in steady state replication, rather than
-     * initial sync.
+     * 'mode' indicates the oplog application mode.
      * Returns failure status if the op that could not be applied.
      */
-    using ApplyCommandInLockFn =
-        stdx::function<Status(OperationContext*, const BSONObj&, bool inSteadyStateReplication)>;
+    using ApplyCommandInLockFn = stdx::function<Status(
+        OperationContext*, const BSONObj&, OplogApplication::Mode oplogApplicationMode)>;
+
+    /**
+     * Maximum number of operations in each batch that can be applied using multiApply().
+     */
+    static AtomicInt32 replBatchLimitOperations;
+
+    /**
+     * Lower bound of batch limit size (in bytes) returned by calculateBatchLimitBytes().
+     */
+    static const unsigned int replBatchLimitBytes = 100 * 1024 * 1024;
 
     SyncTail(BackgroundSync* q, MultiSyncApplyFunc func);
     SyncTail(BackgroundSync* q, MultiSyncApplyFunc func, std::unique_ptr<OldThreadPool> writerPool);
@@ -100,22 +114,24 @@ public:
      * Functions for applying operations/commands and increment server status counters may
      * be overridden for testing.
      */
-    static Status syncApply(OperationContext* txn,
+    static Status syncApply(OperationContext* opCtx,
                             const BSONObj& o,
-                            bool inSteadyStateReplication,
+                            OplogApplication::Mode oplogApplicationMode,
                             ApplyOperationInLockFn applyOperationInLock,
                             ApplyCommandInLockFn applyCommandInLock,
                             IncrementOpsAppliedStatsFn incrementOpsAppliedStats);
 
-    static Status syncApply(OperationContext* txn, const BSONObj& o, bool inSteadyStateReplication);
+    static Status syncApply(OperationContext* opCtx,
+                            const BSONObj& o,
+                            OplogApplication::Mode oplogApplicationMode);
 
     void oplogApplication(ReplicationCoordinator* replCoord);
-    bool peek(OperationContext* txn, BSONObj* obj);
+    bool peek(OperationContext* opCtx, BSONObj* obj);
 
     class OpQueue {
     public:
         OpQueue() : _bytes(0) {
-            _batch.reserve(replBatchLimitOperations);
+            _batch.reserve(replBatchLimitOperations.load());
         }
 
         size_t getBytes() const {
@@ -178,9 +194,13 @@ public:
         bool _mustShutdown = false;
     };
 
+    /**
+     * Batch settings used when retrieving operations from an OplogBuffer.
+     * Set in SyncTail::OpQueueBatcher thread.
+     */
     struct BatchLimits {
-        size_t bytes = replBatchLimitBytes;
-        size_t ops = replBatchLimitOperations.load();
+        size_t bytes = 0;
+        size_t ops = 0;
 
         // If provided, the batch will not include any operations with timestamps after this point.
         // This is intended for implementing slaveDelay, so it should be some number of seconds
@@ -195,19 +215,19 @@ public:
      * If ops is empty on entry and nothing can be added yet, will wait up to a second before
      * returning true.
      */
-    bool tryPopAndWaitForMore(OperationContext* txn, OpQueue* ops, const BatchLimits& limits);
+    bool tryPopAndWaitForMore(OperationContext* opCtx, OpQueue* ops, const BatchLimits& limits);
 
     /**
      * Fetch a single document referenced in the operation from the sync source.
      */
-    virtual BSONObj getMissingDoc(OperationContext* txn, const BSONObj& o);
+    virtual BSONObj getMissingDoc(OperationContext* opCtx, const BSONObj& o);
 
     /**
      * If an update fails, fetches the missing document and inserts it into the local collection.
      *
      * Returns true if the document was fetched and inserted successfully.
      */
-    virtual bool fetchAndInsertMissingDocument(OperationContext* txn, const BSONObj& o);
+    virtual bool fetchAndInsertMissingDocument(OperationContext* opCtx, const BSONObj& o);
 
     void setHostname(const std::string& hostname);
 
@@ -217,15 +237,10 @@ public:
      */
     OldThreadPool* getWriterPool();
 
-    static std::atomic<int> replBatchLimitOperations;  // NOLINT (server param must use std::atomic)
-
 protected:
-    static const unsigned int replBatchLimitBytes = 100 * 1024 * 1024;
-    static const int replBatchLimitSeconds = 1;
-
     // Apply a batch of operations, using multiple threads.
     // Returns the last OpTime applied during the apply batch, ops.end["ts"] basically.
-    OpTime multiApply(OperationContext* txn, MultiApplier::Operations ops);
+    OpTime multiApply(OperationContext* opCtx, MultiApplier::Operations ops);
 
 private:
     class OpQueueBatcher;
@@ -252,7 +267,7 @@ private:
  *
  * Shared between here and MultiApplier.
  */
-StatusWith<OpTime> multiApply(OperationContext* txn,
+StatusWith<OpTime> multiApply(OperationContext* opCtx,
                               OldThreadPool* workerPool,
                               MultiApplier::Operations ops,
                               MultiApplier::ApplyOperationFn applyOperation);
@@ -276,9 +291,9 @@ Status multiInitialSyncApply(MultiApplier::OperationPtrs* ops,
  * Accepts an external operation context and a function with the same argument list as
  * SyncTail::syncApply.
  */
-using SyncApplyFn =
-    stdx::function<Status(OperationContext* txn, const BSONObj& o, bool inSteadyStateReplication)>;
-Status multiSyncApply_noAbort(OperationContext* txn,
+using SyncApplyFn = stdx::function<Status(
+    OperationContext* opCtx, const BSONObj& o, OplogApplication::Mode oplogApplicationMode)>;
+Status multiSyncApply_noAbort(OperationContext* opCtx,
                               MultiApplier::OperationPtrs* ops,
                               SyncApplyFn syncApply);
 
@@ -286,7 +301,7 @@ Status multiSyncApply_noAbort(OperationContext* txn,
  * Testing-only version of multiInitialSyncApply that accepts an external operation context and
  * returns an error instead of aborting.
  */
-Status multiInitialSyncApply_noAbort(OperationContext* txn,
+Status multiInitialSyncApply_noAbort(OperationContext* opCtx,
                                      MultiApplier::OperationPtrs* ops,
                                      SyncTail* st,
                                      AtomicUInt32* fetchCount);
