@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -27,21 +28,22 @@
  *    it in the license file.
  */
 
-#define MONGO_LOGV2_DEFAULT_COMPONENT ::mongo::logv2::LogComponent::kSharding
+#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kSharding
 
 #include "mongo/platform/basic.h"
 
 #include "mongo/db/auth/action_set.h"
 #include "mongo/db/auth/action_type.h"
+#include "mongo/db/auth/authorization_manager.h"
 #include "mongo/db/auth/authorization_session.h"
 #include "mongo/db/auth/privilege.h"
-#include "mongo/db/catalog_raii.h"
+#include "mongo/db/catalog/catalog_raii.h"
 #include "mongo/db/commands.h"
-#include "mongo/db/s/collection_sharding_runtime.h"
+#include "mongo/db/s/collection_sharding_state.h"
 #include "mongo/db/s/sharded_connection_info.h"
 #include "mongo/db/s/sharding_state.h"
-#include "mongo/s/grid.h"
-#include "mongo/util/str.h"
+#include "mongo/util/log.h"
+#include "mongo/util/stringutils.h"
 
 namespace mongo {
 namespace {
@@ -50,16 +52,16 @@ class GetShardVersion : public BasicCommand {
 public:
     GetShardVersion() : BasicCommand("getShardVersion") {}
 
-    std::string help() const override {
-        return " example: { getShardVersion : 'alleyinsider.foo'  } ";
+    void help(std::stringstream& help) const override {
+        help << " example: { getShardVersion : 'alleyinsider.foo'  } ";
     }
 
     bool supportsWriteConcern(const BSONObj& cmd) const override {
         return false;
     }
 
-    AllowedOnSecondary secondaryAllowed(ServiceContext*) const override {
-        return AllowedOnSecondary::kAlways;
+    bool slaveOk() const override {
+        return false;
     }
 
     bool adminOnly() const override {
@@ -68,7 +70,7 @@ public:
 
     Status checkAuthForCommand(Client* client,
                                const std::string& dbname,
-                               const BSONObj& cmdObj) const override {
+                               const BSONObj& cmdObj) override {
         if (!AuthorizationSession::get(client)->isAuthorizedForActionsOnResource(
                 ResourcePattern::forExactNamespace(NamespaceString(parseNs(dbname, cmdObj))),
                 ActionType::getShardVersion)) {
@@ -78,7 +80,7 @@ public:
     }
 
     std::string parseNs(const std::string& dbname, const BSONObj& cmdObj) const override {
-        return CommandHelpers::parseNsFullyQualified(cmdObj);
+        return parseNsFullyQualified(dbname, cmdObj);
     }
 
     bool run(OperationContext* opCtx,
@@ -89,52 +91,43 @@ public:
 
         ShardingState* const shardingState = ShardingState::get(opCtx);
         if (shardingState->enabled()) {
-            result.append(
-                "configServer",
-                Grid::get(opCtx)->shardRegistry()->getConfigServerConnectionString().toString());
+            result.append("configServer", shardingState->getConfigServer(opCtx).toString());
         } else {
             result.append("configServer", "");
         }
 
         ShardedConnectionInfo* const sci = ShardedConnectionInfo::get(opCtx->getClient(), false);
         result.appendBool("inShardedMode", sci != nullptr);
-
-        if (sci && sci->getVersion(nss.ns())) {
-            result.appendTimestamp("mine", sci->getVersion(nss.ns())->toLong());
+        if (sci) {
+            result.appendTimestamp("mine", sci->getVersion(nss.ns()).toLong());
         } else {
             result.appendTimestamp("mine", 0);
         }
 
-        AutoGetCollection autoColl(
-            opCtx, nss, MODE_IS, AutoGetCollection::ViewMode::kViewsPermitted);
-        auto* const css = CollectionShardingState::get(opCtx, nss);
+        AutoGetCollection autoColl(opCtx, nss, MODE_IS);
+        CollectionShardingState* const css = CollectionShardingState::get(opCtx, nss);
 
-        const auto optMetadata = css->getCurrentMetadataIfKnown();
-        if (!optMetadata) {
-            result.append("global", "UNKNOWN");
-
-            if (cmdObj["fullMetadata"].trueValue()) {
-                result.append("metadata", BSONObj());
-            }
-        } else {
-            const auto& metadata = *optMetadata;
+        const auto metadata = css->getMetadata();
+        if (metadata) {
             result.appendTimestamp("global", metadata->getShardVersion().toLong());
+        } else {
+            result.appendTimestamp("global", ChunkVersion(0, 0, OID()).toLong());
+        }
 
-            if (cmdObj["fullMetadata"].trueValue()) {
-                BSONObjBuilder metadataBuilder(result.subobjStart("metadata"));
-                if (metadata->isSharded()) {
-                    metadata->toBSONBasic(metadataBuilder);
+        if (cmdObj["fullMetadata"].trueValue()) {
+            BSONObjBuilder metadataBuilder(result.subobjStart("metadata"));
+            if (metadata) {
+                metadata->toBSONBasic(metadataBuilder);
 
-                    BSONArrayBuilder chunksArr(metadataBuilder.subarrayStart("chunks"));
-                    metadata->toBSONChunks(&chunksArr);
-                    chunksArr.doneFast();
+                BSONArrayBuilder chunksArr(metadataBuilder.subarrayStart("chunks"));
+                metadata->toBSONChunks(chunksArr);
+                chunksArr.doneFast();
 
-                    BSONArrayBuilder pendingArr(metadataBuilder.subarrayStart("pending"));
-                    css->toBSONPending(pendingArr);
-                    pendingArr.doneFast();
-                }
-                metadataBuilder.doneFast();
+                BSONArrayBuilder pendingArr(metadataBuilder.subarrayStart("pending"));
+                css->toBSONPending(pendingArr);
+                pendingArr.doneFast();
             }
+            metadataBuilder.doneFast();
         }
 
         return true;
