@@ -77,6 +77,13 @@ public:
      */
     size_t numberOfMetadataSnapshots() const;
 
+    /**
+     * Returns the number of metadata objects that have been set to boost::none in
+     * _retireExpiredMetadata(). The actual number may vary after it returns, so this is really only
+     * useful for unit tests.
+     */
+    int numberOfEmptyMetadataSnapshots() const;
+
     /**
      * Uses the contents of the specified metadata as a way to purge any pending chunks.
      */
@@ -165,7 +172,7 @@ private:
             invariant(!usageCounter);
         }
 
-        CollectionMetadata metadata;
+        boost::optional<CollectionMetadata> metadata;
 
         std::list<Deletion> orphans;
 
