@@ -34,10 +34,11 @@
 
 #include <boost/optional.hpp>
 
+#include "mongo/db/s/split_chunk.h"
+
 #include "mongo/client/remote_command_targeter_mock.h"
 #include "mongo/db/json.h"
-#include "mongo/db/s/sharding_initialization_mongod.h"
-#include "mongo/db/s/split_chunk.h"
+#include "mongo/db/s/sharding_state.h"
 #include "mongo/db/server_options.h"
 #include "mongo/executor/network_interface_mock.h"
 #include "mongo/executor/remote_command_request.h"
@@ -68,7 +69,6 @@ public:
     void setUp() override {
         ShardServerTestFixture::setUp();
 
-        ShardingState::get(operationContext())->setInitialized(_shardId, OID::gen());
         CatalogCacheLoader::get(getServiceContext()).initializeReplicaSetRole(true);
 
         // Instantiate names.
@@ -213,6 +213,7 @@ void SplitChunkTest::emptyResponse() {
 }
 
 TEST_F(SplitChunkTest, HashedKeyPatternNumberLongSplitKeys) {
+
     BSONObj keyPatternObj = BSON("foo"
                                  << "hashed");
     _coll.setKeyPattern(BSON("_id"
@@ -224,6 +225,9 @@ TEST_F(SplitChunkTest, HashedKeyPatternNumberLongSplitKeys) {
         validSplitKeys.push_back(BSON("foo" << i));
     }
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -255,10 +259,11 @@ TEST_F(SplitChunkTest, HashedKeyPatternNumberLongSplitKeys) {
     collResponse();
     chunkResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, HashedKeyPatternIntegerSplitKeys) {
+
     BSONObj keyPatternObj = BSON("foo"
                                  << "hashed");
     _coll.setKeyPattern(BSON("_id"
@@ -269,6 +274,9 @@ TEST_F(SplitChunkTest, HashedKeyPatternIntegerSplitKeys) {
     std::vector<BSONObj> invalidSplitKeys{
         BSON("foo" << -1), BSON("foo" << 0), BSON("foo" << 1), BSON("foo" << 42)};
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -293,10 +301,11 @@ TEST_F(SplitChunkTest, HashedKeyPatternIntegerSplitKeys) {
     chunkResponse();
     shardResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, HashedKeyPatternDoubleSplitKeys) {
+
     BSONObj keyPatternObj = BSON("foo"
                                  << "hashed");
     _coll.setKeyPattern(BSON("_id"
@@ -307,6 +316,9 @@ TEST_F(SplitChunkTest, HashedKeyPatternDoubleSplitKeys) {
     std::vector<BSONObj> invalidSplitKeys{
         BSON("foo" << 47.21230129), BSON("foo" << 1.0), BSON("foo" << 0.0), BSON("foo" << -0.001)};
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -331,10 +343,11 @@ TEST_F(SplitChunkTest, HashedKeyPatternDoubleSplitKeys) {
     chunkResponse();
     shardResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, HashedKeyPatternStringSplitKeys) {
+
     BSONObj keyPatternObj = BSON("foo"
                                  << "hashed");
     _coll.setKeyPattern(BSON("_id"
@@ -351,6 +364,9 @@ TEST_F(SplitChunkTest, HashedKeyPatternStringSplitKeys) {
                                           BSON("foo"
                                                << "")};
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -375,10 +391,11 @@ TEST_F(SplitChunkTest, HashedKeyPatternStringSplitKeys) {
     chunkResponse();
     shardResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, ValidRangeKeyPatternSplitKeys) {
+
     BSONObj keyPatternObj = BSON("foo" << 1);
 
     // Build a vector of valid split keys, which contains values that may not necessarily be able
@@ -392,6 +409,9 @@ TEST_F(SplitChunkTest, ValidRangeKeyPatternSplitKeys) {
                                              << ""),
                                         BSON("foo" << 3.1415926535)};
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -423,10 +443,11 @@ TEST_F(SplitChunkTest, ValidRangeKeyPatternSplitKeys) {
     collResponse();
     chunkResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, SplitChunkWithNoErrors) {
+
     BSONObj keyPatternObj = BSON("foo" << 1);
 
     // Build a vector of split keys. Note that we start at {"foo" : 256} and end at {"foo" : 768},
@@ -436,6 +457,9 @@ TEST_F(SplitChunkTest, SplitChunkWithNoErrors) {
         splitKeys.push_back(BSON("foo" << i));
     }
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -484,10 +508,11 @@ TEST_F(SplitChunkTest, SplitChunkWithNoErrors) {
     collResponse();
     chunkResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, AttemptSplitWithConfigsvrError) {
+
     BSONObj keyPatternObj = BSON("foo" << 1);
 
     // Build a vector of split keys. Note that we start at {"foo" : 0} and end at {"foo" : 1024},
@@ -497,6 +522,9 @@ TEST_F(SplitChunkTest, AttemptSplitWithConfigsvrError) {
         splitKeys.push_back(BSON("foo" << i));
     }
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -528,10 +556,11 @@ TEST_F(SplitChunkTest, AttemptSplitWithConfigsvrError) {
     collResponse();
     chunkResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, AttemptSplitOnNoDatabases) {
+
     BSONObj keyPatternObj = BSON("foo" << 1);
 
     // Build a vector of split keys. Note that we start at {"foo" : 256} and end at {"foo" : 768},
@@ -541,6 +570,9 @@ TEST_F(SplitChunkTest, AttemptSplitOnNoDatabases) {
         splitKeys.push_back(BSON("foo" << i));
     }
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -562,10 +594,11 @@ TEST_F(SplitChunkTest, AttemptSplitOnNoDatabases) {
     emptyResponse();
     emptyResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, AttemptSplitOnNoCollections) {
+
     BSONObj keyPatternObj = BSON("foo" << 1);
 
     // Build a vector of split keys. Note that we start at {"foo" : 256} and end at {"foo" : 768},
@@ -575,6 +608,9 @@ TEST_F(SplitChunkTest, AttemptSplitOnNoCollections) {
         splitKeys.push_back(BSON("foo" << i));
     }
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -599,10 +635,11 @@ TEST_F(SplitChunkTest, AttemptSplitOnNoCollections) {
     emptyResponse();
     shardResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, AttemptSplitOnNoChunks) {
+
     BSONObj keyPatternObj = BSON("foo" << 1);
 
     // Build a vector of split keys. Note that we start at {"foo" : 256} and end at {"foo" : 768},
@@ -612,6 +649,9 @@ TEST_F(SplitChunkTest, AttemptSplitOnNoChunks) {
         splitKeys.push_back(BSON("foo" << i));
     }
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -642,10 +682,11 @@ TEST_F(SplitChunkTest, AttemptSplitOnNoChunks) {
     collResponse();
     emptyResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, NoCollectionAfterSplit) {
+
     BSONObj keyPatternObj = BSON("foo" << 1);
 
     // Build a vector of split keys. Note that we start at {"foo" : 256} and end at {"foo" : 768},
@@ -655,6 +696,9 @@ TEST_F(SplitChunkTest, NoCollectionAfterSplit) {
         splitKeys.push_back(BSON("foo" << i));
     }
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -686,10 +730,11 @@ TEST_F(SplitChunkTest, NoCollectionAfterSplit) {
     // Finally, give an empty response to a request regarding a find on the original collection.
     emptyResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(SplitChunkTest, NoChunksAfterSplit) {
+
     BSONObj keyPatternObj = BSON("foo" << 1);
 
     // Build a vector of split keys. Note that we start at {"foo" : 256} and end at {"foo" : 768},
@@ -699,6 +744,9 @@ TEST_F(SplitChunkTest, NoChunksAfterSplit) {
         splitKeys.push_back(BSON("foo" << i));
     }
 
+    // Force-set the sharding state to enabled with the _shardId, for testing purposes.
+    ShardingState::get(operationContext())->setEnabledForTest(_shardId.toString());
+
     expectLock();
 
     // Call the splitChunk function asynchronously on a different thread, so that we do not block,
@@ -736,7 +784,7 @@ TEST_F(SplitChunkTest, NoChunksAfterSplit) {
     collResponse();
     emptyResponse();
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 }  // namespace
