@@ -31,10 +31,6 @@ Copyright (C) 2018-present Percona and/or its affiliates. All rights reserved.
 
 #pragma once
 
-namespace mongo {
-class DatabaseName;
-}
-
 namespace percona {
 
 /**
@@ -47,9 +43,9 @@ struct KeyDBAPI {
     /**
      * Returns whether the engine supports feature compatibility version 3.6
      */
-    virtual void keydbDropDatabase(const mongo::DatabaseName& dbName) {
+    virtual void keydbDropDatabase(const std::string& db) {
         // do nothing for engines which do not support KeyDB
     }
 };
 
-}  // namespace percona
+}  // end of percona namespace.
