@@ -1,3 +1,5 @@
+// record_store_v1_base.h
+
 
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
@@ -30,7 +32,7 @@
 
 #pragma once
 
-#include "mongo/stdx/unordered_set.h"
+#include "mongo/platform/unordered_set.h"
 #include "mongo/util/concurrency/spin_lock.h"
 
 #include "mongo/db/storage/mmap_v1/diskloc.h"
@@ -146,8 +148,7 @@ public:
 
 private:
     SpinLock _mutex;
-    typedef stdx::unordered_set<SavedCursor*>
-        SavedCursorSet;  // SavedCursor pointers not owned here
+    typedef unordered_set<SavedCursor*> SavedCursorSet;  // SavedCursor pointers not owned here
     SavedCursorSet _cursors;
 };
 
@@ -173,10 +174,6 @@ public:
 
     virtual ~RecordStoreV1Base();
 
-    const std::string& getIdent() const override {
-        MONGO_UNREACHABLE;
-    }
-
     virtual long long dataSize(OperationContext* opCtx) const {
         return _details->dataSize();
     }
@@ -264,7 +261,7 @@ public:
     virtual void updateStatsAfterRepair(OperationContext* opCtx,
                                         long long numRecords,
                                         long long dataSize) {
-        MONGO_UNREACHABLE;  // MMAPv1 has its own repair which doesn't call this.
+        invariant(false);  // MMAPv1 has its own repair which doesn't call this.
     }
 
 protected:
@@ -363,4 +360,4 @@ private:
     const RecordStoreV1Base* _rs;
     bool _forward;
 };
-}  // namespace mongo
+}
