@@ -1,32 +1,34 @@
 // record_store.h
 
+
 /**
-*    Copyright (C) 2013 10gen Inc.
-*
-*    This program is free software: you can redistribute it and/or  modify
-*    it under the terms of the GNU Affero General Public License, version 3,
-*    as published by the Free Software Foundation.
-*
-*    This program is distributed in the hope that it will be useful,
-*    but WITHOUT ANY WARRANTY; without even the implied warranty of
-*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*    GNU Affero General Public License for more details.
-*
-*    You should have received a copy of the GNU Affero General Public License
-*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*
-*    As a special exception, the copyright holders give permission to link the
-*    code of portions of this program with the OpenSSL library under certain
-*    conditions as described in each individual source file and distribute
-*    linked combinations including the program with the OpenSSL library. You
-*    must comply with the GNU Affero General Public License in all respects for
-*    all of the code used other than as permitted herein. If you modify file(s)
-*    with this exception, you may extend this exception to your version of the
-*    file(s), but you are not obligated to do so. If you do not wish to do so,
-*    delete this exception statement from your version. If you delete this
-*    exception statement from all source files in the program, then also delete
-*    it in the license file.
-*/
+ *    Copyright (C) 2018-present MongoDB, Inc.
+ *
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
+ *
+ *    This program is distributed in the hope that it will be useful,
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *    Server Side Public License for more details.
+ *
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
+ *
+ *    As a special exception, the copyright holders give permission to link the
+ *    code of portions of this program with the OpenSSL library under certain
+ *    conditions as described in each individual source file and distribute
+ *    linked combinations including the program with the OpenSSL library. You
+ *    must comply with the Server Side Public License in all respects for
+ *    all of the code used other than as permitted herein. If you modify file(s)
+ *    with this exception, you may extend this exception to your version of the
+ *    file(s), but you are not obligated to do so. If you do not wish to do so,
+ *    delete this exception statement from your version. If you delete this
+ *    exception statement from all source files in the program, then also delete
+ *    it in the license file.
+ */
 
 #pragma once
 
@@ -45,7 +47,6 @@ class CappedCallback;
 class Collection;
 struct CompactOptions;
 struct CompactStats;
-class DocWriter;
 class MAdvise;
 class NamespaceDetails;
 class OperationContext;
@@ -62,12 +63,15 @@ class ValidateAdaptor;
  */
 class DocWriter {
 public:
-    virtual ~DocWriter() {}
     virtual void writeDocument(char* buf) const = 0;
     virtual size_t documentSize() const = 0;
     virtual bool addPadding() const {
         return true;
     }
+
+protected:
+    // Can't delete through base pointer.
+    ~DocWriter() = default;
 };
 
 /**
@@ -76,11 +80,8 @@ public:
 class UpdateNotifier {
 public:
     virtual ~UpdateNotifier() {}
-    virtual Status recordStoreGoingToMove(OperationContext* txn,
-                                          const RecordId& oldLocation,
-                                          const char* oldBuffer,
-                                          size_t oldSize) = 0;
-    virtual Status recordStoreGoingToUpdateInPlace(OperationContext* txn, const RecordId& loc) = 0;
+    virtual Status recordStoreGoingToUpdateInPlace(OperationContext* opCtx,
+                                                   const RecordId& loc) = 0;
 };
 
 /**
@@ -96,6 +97,13 @@ struct BsonRecord {
     const BSONObj* docPtr;
 };
 
+enum ValidateCmdLevel : int {
+    kValidateIndex = 0x01,
+    kValidateRecordStore = 0x02,
+    kValidateFull = 0x03
+};
+
+
 /**
  * Retrieves Records from a RecordStore.
  *
@@ -194,12 +202,12 @@ public:
 
     /**
      * Inform the cursor that this id is being invalidated. Must be called between save and restore.
-     * The txn is that of the operation causing the invalidation, not the txn using the cursor.
+     * The opCtx is that of the operation causing the invalidation, not the opCtx using the cursor.
      *
      * WARNING: Storage engines other than MMAPv1 should use the default implementation,
      *          and not depend on this being called.
      */
-    virtual void invalidate(OperationContext* txn, const RecordId& id) {}
+    virtual void invalidate(OperationContext* opCtx, const RecordId& id) {}
 
     //
     // RecordFetchers
@@ -272,6 +280,10 @@ public:
  * Many methods take an OperationContext parameter. This contains the RecoveryUnit, with
  * all RecordStore specific transaction information, as well as the LockState. Methods that take
  * an OperationContext may throw a WriteConflictException.
+ *
+ * This class must be thread-safe for document-level locking storage engines. In addition, for
+ * storage engines implementing the KVEngine some methods must be thread safe, see KVCatalog. Only
+ * for MMAPv1 is this class not thread-safe.
  */
 class RecordStore {
     MONGO_DISALLOW_COPYING(RecordStore);
@@ -294,13 +306,13 @@ public:
      * The dataSize is an approximation of the sum of the sizes (in bytes) of the
      * documents or entries in the recordStore.
      */
-    virtual long long dataSize(OperationContext* txn) const = 0;
+    virtual long long dataSize(OperationContext* opCtx) const = 0;
 
     /**
      * Total number of record in the RecordStore. You may need to cache it, so this call
      * takes constant time, as it is called often.
      */
-    virtual long long numRecords(OperationContext* txn) const = 0;
+    virtual long long numRecords(OperationContext* opCtx) const = 0;
 
     virtual bool isCapped() const = 0;
 
@@ -313,7 +325,7 @@ public:
      * @param level - optional, level of debug info to put in (higher is more)
      * @return total estimate size (in bytes) on stable storage
      */
-    virtual int64_t storageSize(OperationContext* txn,
+    virtual int64_t storageSize(OperationContext* opCtx,
                                 BSONObjBuilder* extraInfo = NULL,
                                 int infoLevel = 0) const = 0;
 
@@ -328,9 +340,9 @@ public:
      * In general, prefer findRecord or RecordCursor::seekExact since they can tell you if a
      * record has been removed.
      */
-    virtual RecordData dataFor(OperationContext* txn, const RecordId& loc) const {
+    virtual RecordData dataFor(OperationContext* opCtx, const RecordId& loc) const {
         RecordData data;
-        invariant(findRecord(txn, loc, &data));
+        invariant(findRecord(opCtx, loc, &data));
         return data;
     }
 
@@ -348,8 +360,8 @@ public:
      * potentially deleted RecordIds to seek methods if they know that MMAPv1 is not the current
      * storage engine. All new storage engines must support detecting the existence of Records.
      */
-    virtual bool findRecord(OperationContext* txn, const RecordId& loc, RecordData* out) const {
-        auto cursor = getCursor(txn);
+    virtual bool findRecord(OperationContext* opCtx, const RecordId& loc, RecordData* out) const {
+        auto cursor = getCursor(opCtx);
         auto record = cursor->seekExact(loc);
         if (!record)
             return false;
@@ -359,33 +371,25 @@ public:
         return true;
     }
 
-    /**
-     * Relaxed version of findRecord which allows storage engines
-     * to skip a pessimistic locking strategy.
-     */
-    virtual bool findRecordRelaxed(OperationContext* txn,
-                                   const RecordId& loc,
-                                   RecordData* out) const {
-        return findRecord(txn, loc, out);
-    }
+    virtual void deleteRecord(OperationContext* opCtx, const RecordId& dl) = 0;
 
-    virtual void deleteRecord(OperationContext* txn, const RecordId& dl) = 0;
-
-    virtual StatusWith<RecordId> insertRecord(OperationContext* txn,
+    virtual StatusWith<RecordId> insertRecord(OperationContext* opCtx,
                                               const char* data,
                                               int len,
+                                              Timestamp timestamp,
                                               bool enforceQuota) = 0;
 
-    virtual StatusWith<RecordId> insertRecord(OperationContext* txn,
-                                              const DocWriter* doc,
-                                              bool enforceQuota) = 0;
-
-    virtual Status insertRecords(OperationContext* txn,
+    virtual Status insertRecords(OperationContext* opCtx,
                                  std::vector<Record>* records,
+                                 std::vector<Timestamp>* timestamps,
                                  bool enforceQuota) {
+        int index = 0;
         for (auto& record : *records) {
-            StatusWith<RecordId> res =
-                insertRecord(txn, record.data.data(), record.data.size(), enforceQuota);
+            StatusWith<RecordId> res = insertRecord(opCtx,
+                                                    record.data.data(),
+                                                    record.data.size(),
+                                                    (*timestamps)[index++],
+                                                    enforceQuota);
             if (!res.isOK())
                 return res.getStatus();
 
@@ -395,22 +399,51 @@ public:
     }
 
     /**
-     * @param notifier - Only used by record stores which do not support doc-locking.
-     *                   In the case of a document move, this is called after the document
-     *                   has been written to the new location, but before it is deleted from
-     *                   the old location.
-     *                   In the case of an in-place update, this is called just before the
-     *                   in-place write occurs.
-     * @return Status or RecordId, RecordId might be different
+     * Inserts nDocs documents into this RecordStore using the DocWriter interface.
+     *
+     * This allows the storage engine to reserve space for a record and have it built in-place
+     * rather than building the record then copying it into its destination.
+     *
+     * On success, if idsOut is non-null the RecordIds of the inserted records will be written into
+     * it. It must have space for nDocs RecordIds.
+     */
+    virtual Status insertRecordsWithDocWriter(OperationContext* opCtx,
+                                              const DocWriter* const* docs,
+                                              const Timestamp* timestamps,
+                                              size_t nDocs,
+                                              RecordId* idsOut = nullptr) = 0;
+
+    /**
+     * A thin wrapper around insertRecordsWithDocWriter() to simplify handling of single DocWriters.
+     */
+    StatusWith<RecordId> insertRecordWithDocWriter(OperationContext* opCtx,
+                                                   const DocWriter* doc,
+                                                   Timestamp timestamp) {
+        RecordId out;
+        Status status = insertRecordsWithDocWriter(opCtx, &doc, &timestamp, 1, &out);
+        if (!status.isOK())
+            return status;
+        return out;
+    }
+
+    /**
+     * @param notifier - Only used by record stores which do not support doc-locking. Called only
+     *                   in the case of an in-place update. Called just before the in-place write
+     *                   occurs.
+     * @return Status  - If a document move is required (MMAPv1 only) then a status of
+     *                   ErrorCodes::NeedsDocumentMove will be returned. On receipt of this status
+     *                   no update will be performed. It is the caller's responsibility to:
+     *                     1. Remove the existing document and associated index keys.
+     *                     2. Insert a new document and index keys.
      *
      * For capped record stores, the record size will never change.
      */
-    virtual StatusWith<RecordId> updateRecord(OperationContext* txn,
-                                              const RecordId& oldLocation,
-                                              const char* data,
-                                              int len,
-                                              bool enforceQuota,
-                                              UpdateNotifier* notifier) = 0;
+    virtual Status updateRecord(OperationContext* opCtx,
+                                const RecordId& oldLocation,
+                                const char* data,
+                                int len,
+                                bool enforceQuota,
+                                UpdateNotifier* notifier) = 0;
 
     /**
      * @return Returns 'false' if this record store does not implement
@@ -429,7 +462,7 @@ public:
      * @return the updated version of the record. If unowned data is returned, then it is valid
      * until the next modification of this Record or the lock on the collection has been released.
      */
-    virtual StatusWith<RecordData> updateWithDamages(OperationContext* txn,
+    virtual StatusWith<RecordData> updateWithDamages(OperationContext* opCtx,
                                                      const RecordId& loc,
                                                      const RecordData& oldRec,
                                                      const char* damageSource,
@@ -443,7 +476,7 @@ public:
      * are allowed to lazily seek to the first Record when next() is called rather than doing
      * it on construction.
      */
-    virtual std::unique_ptr<SeekableRecordCursor> getCursor(OperationContext* txn,
+    virtual std::unique_ptr<SeekableRecordCursor> getCursor(OperationContext* opCtx,
                                                             bool forward = true) const = 0;
 
     /**
@@ -451,7 +484,7 @@ public:
      * damaged records. The iterator might return every record in the store if all of them
      * are reachable and not corrupted.  Returns NULL if not supported.
      */
-    virtual std::unique_ptr<RecordCursor> getCursorForRepair(OperationContext* txn) const {
+    virtual std::unique_ptr<RecordCursor> getCursorForRepair(OperationContext* opCtx) const {
         return {};
     }
 
@@ -466,7 +499,7 @@ public:
      * the record store. Implementations should avoid obvious biases toward older, newer, larger
      * smaller or other specific classes of documents.
      */
-    virtual std::unique_ptr<RecordCursor> getRandomCursor(OperationContext* txn) const {
+    virtual std::unique_ptr<RecordCursor> getRandomCursor(OperationContext* opCtx) const {
         return {};
     }
 
@@ -474,9 +507,10 @@ public:
      * Returns many RecordCursors that partition the RecordStore into many disjoint sets.
      * Iterating all returned RecordCursors is equivalent to iterating the full store.
      */
-    virtual std::vector<std::unique_ptr<RecordCursor>> getManyCursors(OperationContext* txn) const {
+    virtual std::vector<std::unique_ptr<RecordCursor>> getManyCursors(
+        OperationContext* opCtx) const {
         std::vector<std::unique_ptr<RecordCursor>> out(1);
-        out[0] = getCursor(txn);
+        out[0] = getCursor(opCtx);
         return out;
     }
 
@@ -486,16 +520,15 @@ public:
     /**
      * removes all Records
      */
-    virtual Status truncate(OperationContext* txn) = 0;
+    virtual Status truncate(OperationContext* opCtx) = 0;
 
     /**
      * Truncate documents newer than the document at 'end' from the capped
      * collection.  The collection cannot be completely emptied using this
      * function.  An assertion will be thrown if that is attempted.
      * @param inclusive - Truncate 'end' as well iff true
-     * XXX: this will go away soon, just needed to move for now
      */
-    virtual void temp_cappedTruncateAfter(OperationContext* txn, RecordId end, bool inclusive) = 0;
+    virtual void cappedTruncateAfter(OperationContext* opCtx, RecordId end, bool inclusive) = 0;
 
     /**
      * does this RecordStore support the compact operation?
@@ -521,7 +554,7 @@ public:
      * Only called if compactSupported() returns true.
      * No RecordStoreCompactAdaptor will be passed if compactsInPlace() returns true.
      */
-    virtual Status compact(OperationContext* txn,
+    virtual Status compact(OperationContext* opCtx,
                            RecordStoreCompactAdaptor* adaptor,
                            const CompactOptions* options,
                            CompactStats* stats) {
@@ -529,15 +562,25 @@ public:
     }
 
     /**
-     * @param full - does more checks
-     * @param scanData - scans each document
+     * Does the RecordStore cursor retrieve its document in RecordId Order?
+     *
+     * If a subclass overrides the default value to true, the RecordStore cursor must retrieve
+     * its documents in RecordId order.
+     *
+     * This enables your storage engine to run collection validation in the
+     * background.
+     */
+    virtual bool isInRecordIdOrder() const {
+        return false;
+    }
+
+    /**
      * @return OK if the validate run successfully
      *         OK will be returned even if corruption is found
      *         deatils will be in result
      */
-    virtual Status validate(OperationContext* txn,
-                            bool full,
-                            bool scanData,
+    virtual Status validate(OperationContext* opCtx,
+                            ValidateCmdLevel level,
                             ValidateAdaptor* adaptor,
                             ValidateResults* results,
                             BSONObjBuilder* output) = 0;
@@ -546,7 +589,7 @@ public:
      * @param scaleSize - amount by which to scale size metrics
      * appends any custom stats from the RecordStore or other unique stats
      */
-    virtual void appendCustomStats(OperationContext* txn,
+    virtual void appendCustomStats(OperationContext* opCtx,
                                    BSONObjBuilder* result,
                                    double scale) const = 0;
 
@@ -559,7 +602,7 @@ public:
      *
      * @param output (optional) - where to put detailed stats
      */
-    virtual Status touch(OperationContext* txn, BSONObjBuilder* output) const {
+    virtual Status touch(OperationContext* opCtx, BSONObjBuilder* output) const {
         return Status(ErrorCodes::CommandNotSupported,
                       "this storage engine does not support touch");
     }
@@ -571,7 +614,7 @@ public:
      * If you don't implement the oplogStartHack, just use the default implementation which
      * returns boost::none.
      */
-    virtual boost::optional<RecordId> oplogStartHack(OperationContext* txn,
+    virtual boost::optional<RecordId> oplogStartHack(OperationContext* opCtx,
                                                      const RecordId& startingPosition) const {
         return boost::none;
     }
@@ -584,7 +627,7 @@ public:
      * Since this is called inside of a WriteUnitOfWork while holding a std::mutex, it is
      * illegal to acquire any LockManager locks inside of this function.
      */
-    virtual Status oplogDiskLocRegister(OperationContext* txn, const Timestamp& opTime) {
+    virtual Status oplogDiskLocRegister(OperationContext* opCtx, const Timestamp& opTime) {
         return Status::OK();
     }
 
@@ -595,15 +638,23 @@ public:
      * It is only legal to call this on an oplog. It is illegal to call this inside a
      * WriteUnitOfWork.
      */
-    virtual void waitForAllEarlierOplogWritesToBeVisible(OperationContext* txn) const = 0;
+    virtual void waitForAllEarlierOplogWritesToBeVisible(OperationContext* opCtx) const = 0;
 
     /**
      * Called after a repair operation is run with the recomputed numRecords and dataSize.
      */
-    virtual void updateStatsAfterRepair(OperationContext* txn,
+    virtual void updateStatsAfterRepair(OperationContext* opCtx,
                                         long long numRecords,
                                         long long dataSize) = 0;
 
+    /**
+     * used to support online change oplog size.
+     */
+    virtual Status updateCappedSize(OperationContext* opCtx, long long cappedSize) {
+        return Status(ErrorCodes::CommandNotSupported,
+                      "this storage engine does not support updateCappedSize");
+    }
+
 protected:
     std::string _ns;
 };
@@ -622,6 +673,9 @@ struct ValidateResults {
     }
     bool valid;
     std::vector<std::string> errors;
+    std::vector<std::string> warnings;
+    std::vector<BSONObj> extraIndexEntries;
+    std::vector<BSONObj> missingIndexEntries;
 };
 
 /**
@@ -633,6 +687,8 @@ class ValidateAdaptor {
 public:
     virtual ~ValidateAdaptor() {}
 
-    virtual Status validate(const RecordData& recordData, size_t* dataSize) = 0;
+    virtual Status validate(const RecordId& recordId,
+                            const RecordData& recordData,
+                            size_t* dataSize) = 0;
 };
 }
