@@ -37,6 +37,7 @@
 #include <rocksdb/options.h>
 #include <rocksdb/slice.h>
 
+#include "mongo/base/init.h"
 #include "mongo/db/concurrency/write_conflict_exception.h"
 #include "mongo/db/storage/record_store_test_harness.h"
 #include "mongo/unittest/unittest.h"
@@ -52,7 +53,7 @@ namespace mongo {
 
     using std::string;
 
-    class RocksRecordStoreHarnessHelper final : public HarnessHelper {
+    class RocksRecordStoreHarnessHelper final : public RecordStoreHarnessHelper {
     public:
         RocksRecordStoreHarnessHelper() : _tempDir(_testNamespace) {
             boost::filesystem::remove_all(_tempDir.path());
@@ -62,6 +63,7 @@ namespace mongo {
             auto s = rocksdb::DB::Open(options, _tempDir.path(), &db);
             ASSERT(s.ok());
             _db.reset(db);
+            _snapshotManager.reset(new RocksSnapshotManager(_db.get()));
             _counterManager.reset(new RocksCounterManager(_db.get(), true));
             _durabilityManager.reset(new RocksDurabilityManager(_db.get(), true));
             _compactionScheduler.reset(new RocksCompactionScheduler());
@@ -92,10 +94,10 @@ namespace mongo {
                                                        cappedMaxSize, cappedMaxDocs);
         }
 
-        RecoveryUnit* newRecoveryUnit() final {
-            return new RocksRecoveryUnit(&_transactionEngine, &_snapshotManager, _db.get(),
-                                         _counterManager.get(), nullptr, _durabilityManager.get(),
-                                         true);
+        std::unique_ptr<RecoveryUnit> newRecoveryUnit() final {
+            return stdx::make_unique<RocksRecoveryUnit>(&_transactionEngine, _snapshotManager.get(),
+                                                        _db.get(), _counterManager.get(), nullptr,
+                                                        _durabilityManager.get(), true);
         }
 
         bool supportsDocLocking() final {
@@ -107,18 +109,23 @@ namespace mongo {
         unittest::TempDir _tempDir;
         std::unique_ptr<rocksdb::DB> _db;
         RocksTransactionEngine _transactionEngine;
-        RocksSnapshotManager _snapshotManager;
+        std::unique_ptr<RocksSnapshotManager> _snapshotManager;
         std::unique_ptr<RocksDurabilityManager> _durabilityManager;
         std::unique_ptr<RocksCounterManager> _counterManager;
         std::unique_ptr<RocksCompactionScheduler> _compactionScheduler;
     };
 
-    std::unique_ptr<HarnessHelper> newHarnessHelper() {
+    std::unique_ptr<HarnessHelper> makeHarnessHelper() {
         return stdx::make_unique<RocksRecordStoreHarnessHelper>();
     }
 
+    MONGO_INITIALIZER(RegisterHarnessFactory)(InitializerContext* const) {
+        mongo::registerHarnessHelperFactory(makeHarnessHelper);
+        return Status::OK();
+    }
+
     TEST(RocksRecordStoreTest, Isolation1 ) {
-        std::unique_ptr<HarnessHelper> harnessHelper(newHarnessHelper());
+        auto harnessHelper = stdx::make_unique<RocksRecordStoreHarnessHelper>();
         std::unique_ptr<RecordStore> rs(harnessHelper->newNonCappedRecordStore());
 
         RecordId loc1;
@@ -129,11 +136,11 @@ namespace mongo {
             {
                 WriteUnitOfWork uow( opCtx.get() );
 
-                StatusWith<RecordId> res = rs->insertRecord( opCtx.get(), "a", 2, false );
+                StatusWith<RecordId> res = rs->insertRecord( opCtx.get(), "a", 2, Timestamp(), false );
                 ASSERT_OK( res.getStatus() );
                 loc1 = res.getValue();
 
-                res = rs->insertRecord( opCtx.get(), "a", 2, false );
+                res = rs->insertRecord( opCtx.get(), "a", 2, Timestamp(), false );
                 ASSERT_OK( res.getStatus() );
                 loc2 = res.getValue();
 
@@ -156,7 +163,7 @@ namespace mongo {
             ASSERT_OK( rs->updateRecord( t1.get(), loc2, "B", 2, false, NULL ) );
 
             // this should throw
-            ASSERT_THROWS(rs->updateRecord(t2.get(), loc1, "c", 2, false, NULL),
+            ASSERT_THROWS(rs->updateRecord(t2.get(), loc1, "c", 2, false, NULL).ignore(),
                           WriteConflictException);
 
             w1->commit(); // this should succeed
@@ -164,7 +171,7 @@ namespace mongo {
     }
 
     TEST(RocksRecordStoreTest, Isolation2 ) {
-        std::unique_ptr<HarnessHelper> harnessHelper( newHarnessHelper() );
+        auto harnessHelper = stdx::make_unique<RocksRecordStoreHarnessHelper>();
         std::unique_ptr<RecordStore> rs( harnessHelper->newNonCappedRecordStore() );
 
         RecordId loc1;
@@ -175,11 +182,11 @@ namespace mongo {
             {
                 WriteUnitOfWork uow( opCtx.get() );
 
-                StatusWith<RecordId> res = rs->insertRecord( opCtx.get(), "a", 2, false );
+                StatusWith<RecordId> res = rs->insertRecord( opCtx.get(), "a", 2, Timestamp(), false );
                 ASSERT_OK( res.getStatus() );
                 loc1 = res.getValue();
 
-                res = rs->insertRecord( opCtx.get(), "a", 2, false );
+                res = rs->insertRecord( opCtx.get(), "a", 2, Timestamp(), false );
                 ASSERT_OK( res.getStatus() );
                 loc2 = res.getValue();
 
@@ -206,7 +213,7 @@ namespace mongo {
                 WriteUnitOfWork w( t2.get() );
                 ASSERT_EQUALS(string("a"), rs->dataFor(t2.get(), loc1).data());
                 // this should fail as our version of loc1 is too old
-                ASSERT_THROWS(rs->updateRecord(t2.get(), loc1, "c", 2, false, NULL),
+                ASSERT_THROWS(rs->updateRecord(t2.get(), loc1, "c", 2, false, NULL).ignore(),
                               WriteConflictException);
             }
         }
@@ -225,6 +232,7 @@ namespace mongo {
         StatusWith<RecordId> res = rs->insertRecord(opCtx.get(),
                                                    obj.objdata(),
                                                    obj.objsize(),
+                                                   Timestamp(),
                                                    false);
         if (res.isOK())
             wuow.commit();
@@ -244,12 +252,12 @@ namespace mongo {
             {
                 BSONObj obj = BSON("not_ts" << Timestamp(2,1));
                 ASSERT_EQ(rs->insertRecord(opCtx.get(), obj.objdata(), obj.objsize(),
-                                           false ).getStatus(),
+                                           Timestamp(), false ).getStatus(),
                           ErrorCodes::BadValue);
 
                 obj = BSON( "ts" << "not an Timestamp" );
                 ASSERT_EQ(rs->insertRecord(opCtx.get(), obj.objdata(), obj.objsize(),
-                                           false ).getStatus(),
+                                           Timestamp(), false ).getStatus(),
                           ErrorCodes::BadValue);
             }
 
@@ -279,7 +287,7 @@ namespace mongo {
 
         {
             ServiceContext::UniqueOperationContext opCtx(harnessHelper.newOperationContext());
-            rs->temp_cappedTruncateAfter(opCtx.get(), RecordId(2,2),  false); // no-op
+            rs->cappedTruncateAfter(opCtx.get(), RecordId(2,2),  false); // no-op
         }
 
         {
@@ -289,7 +297,7 @@ namespace mongo {
 
         {
             ServiceContext::UniqueOperationContext opCtx(harnessHelper.newOperationContext());
-            rs->temp_cappedTruncateAfter(opCtx.get(), RecordId(1,2),  false); // deletes 2,2
+            rs->cappedTruncateAfter(opCtx.get(), RecordId(1,2),  false); // deletes 2,2
         }
 
         {
@@ -299,7 +307,7 @@ namespace mongo {
 
         {
             ServiceContext::UniqueOperationContext opCtx(harnessHelper.newOperationContext());
-            rs->temp_cappedTruncateAfter(opCtx.get(), RecordId(1,2),  true); // deletes 1,2
+            rs->cappedTruncateAfter(opCtx.get(), RecordId(1,2),  true); // deletes 1,2
         }
 
         {
@@ -380,7 +388,7 @@ namespace mongo {
         {
             WriteUnitOfWork wuow( opCtx.get() );
             ASSERT_OK(rs->insertRecord(opCtx.get(), obj.objdata(),
-                                       obj.objsize(), false ).getStatus());
+                                       obj.objsize(), Timestamp(), false ).getStatus());
             wuow.commit();
         }
         ASSERT_TRUE(rs->oplogStartHack(opCtx.get(), RecordId(0,1)) == boost::none);
@@ -397,7 +405,7 @@ namespace mongo {
             ServiceContext::UniqueOperationContext opCtx( harnessHelper->newOperationContext() );
             {
                 WriteUnitOfWork uow( opCtx.get() );
-                StatusWith<RecordId> res = rs->insertRecord( opCtx.get(), "a", 2, false );
+                StatusWith<RecordId> res = rs->insertRecord( opCtx.get(), "a", 2, Timestamp(), false );
                 ASSERT_OK( res.getStatus() );
                 loc1 = res.getValue();
                 uow.commit();
@@ -418,7 +426,7 @@ namespace mongo {
             // we make sure we can't find the 2nd until the first is commited
             ServiceContext::UniqueOperationContext t1( harnessHelper->newOperationContext() );
             std::unique_ptr<WriteUnitOfWork> w1( new WriteUnitOfWork( t1.get() ) );
-            rs->insertRecord( t1.get(), "b", 2, false );
+            ASSERT_OK(rs->insertRecord( t1.get(), "b", 2, Timestamp(), false ));
             // do not commit yet
 
             { // create 2nd doc
@@ -426,7 +434,7 @@ namespace mongo {
                 auto t2 = harnessHelper->newOperationContext(client2.get());
                 {
                     WriteUnitOfWork w2( t2.get() );
-                    rs->insertRecord( t2.get(), "c", 2, false );
+                    ASSERT_OK(rs->insertRecord( t2.get(), "c", 2, Timestamp(), false ));
                     w2.commit();
                 }
             }
@@ -456,15 +464,15 @@ namespace mongo {
         }
     }
 
-    RecordId _oplogOrderInsertOplog( OperationContext* txn,
+    RecordId _oplogOrderInsertOplog( OperationContext* opCtx,
                                     std::unique_ptr<RecordStore>& rs,
                                     int inc ) {
         Timestamp opTime = Timestamp(5,inc);
         RocksRecordStore* rrs = dynamic_cast<RocksRecordStore*>(rs.get());
-        Status status = rrs->oplogDiskLocRegister( txn, opTime );
+        Status status = rrs->oplogDiskLocRegister( opCtx, opTime );
         ASSERT_OK( status );
         BSONObj obj = BSON( "ts" << opTime );
-        StatusWith<RecordId> res = rs->insertRecord( txn, obj.objdata(), obj.objsize(), false );
+        StatusWith<RecordId> res = rs->insertRecord( opCtx, obj.objdata(), obj.objsize(), Timestamp(), false );
         ASSERT_OK( res.getStatus() );
         return res.getValue();
     }
@@ -555,8 +563,8 @@ namespace mongo {
         // Rollback the last two oplog entries, then insert entries with older optimes and ensure that
         // the visibility rules aren't violated. See SERVER-21645
         {
-            ServiceContext::UniqueOperationContext txn(harnessHelper->newOperationContext());
-            rs->temp_cappedTruncateAfter(txn.get(), loc1, /*inclusive*/ false);
+            ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
+            rs->cappedTruncateAfter(opCtx.get(), loc1, /*inclusive*/ false);
         }
 
         {
