@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -31,7 +32,6 @@
 
 #include "mongo/db/storage/sorted_data_interface_test_harness.h"
 
-#include <limits>
 #include <memory>
 
 #include "mongo/db/storage/sorted_data_interface.h"
@@ -45,8 +45,7 @@ namespace {
 // restorePosition() in succession.
 TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursor) {
     const auto harnessHelper(newSortedDataInterfaceHarnessHelper());
-    const std::unique_ptr<SortedDataInterface> sorted(
-        harnessHelper->newSortedDataInterface(/*unique=*/false, /*partial=*/false));
+    const std::unique_ptr<SortedDataInterface> sorted(harnessHelper->newSortedDataInterface(false));
 
     {
         const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
@@ -60,7 +59,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursor) {
             WriteUnitOfWork uow(opCtx.get());
             BSONObj key = BSON("" << i);
             RecordId loc(42, i * 2);
-            ASSERT_OK(sorted->insert(opCtx.get(), makeKeyString(sorted.get(), key, loc), true));
+            ASSERT_OK(sorted->insert(opCtx.get(), key, loc, true));
             uow.commit();
         }
     }
@@ -74,59 +73,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursor) {
         const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
         const std::unique_ptr<SortedDataInterface::Cursor> cursor(sorted->newCursor(opCtx.get()));
         int i = 0;
-        for (auto entry = cursor->seek(makeKeyStringForSeek(sorted.get(), BSONObj(), true, true));
-             entry;
-             i++, entry = cursor->next()) {
-            ASSERT_LT(i, nToInsert);
-            ASSERT_EQ(entry, IndexKeyEntry(BSON("" << i), RecordId(42, i * 2)));
-
-            cursor->save();
-            cursor->restore();
-        }
-        ASSERT(!cursor->next());
-        ASSERT_EQ(i, nToInsert);
-    }
-}
-
-// Insert multiple keys and try to iterate through all of them
-// using a forward cursor with set end position, while calling savePosition() and
-// restorePosition() in succession.
-TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorWithEndPosition) {
-    const auto harnessHelper(newSortedDataInterfaceHarnessHelper());
-    const std::unique_ptr<SortedDataInterface> sorted(
-        harnessHelper->newSortedDataInterface(/*unique=*/false, /*partial=*/false));
-
-    {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        ASSERT(sorted->isEmpty(opCtx.get()));
-    }
-
-    int nToInsert = 10;
-    for (int i = 0; i < nToInsert; i++) {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        {
-            WriteUnitOfWork uow(opCtx.get());
-            BSONObj key = BSON("" << i);
-            RecordId loc(42, i * 2);
-            ASSERT_OK(sorted->insert(opCtx.get(), makeKeyString(sorted.get(), key, loc), true));
-            uow.commit();
-        }
-    }
-
-    {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        ASSERT_EQUALS(nToInsert, sorted->numEntries(opCtx.get()));
-    }
-
-    {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        const std::unique_ptr<SortedDataInterface::Cursor> cursor(sorted->newCursor(opCtx.get()));
-        cursor->setEndPosition(BSON("" << std::numeric_limits<double>::infinity()), true);
-
-        int i = 0;
-        for (auto entry = cursor->seek(makeKeyStringForSeek(sorted.get(), BSONObj(), true, true));
-             entry;
-             i++, entry = cursor->next()) {
+        for (auto entry = cursor->seek(kMinBSONKey, true); entry; i++, entry = cursor->next()) {
             ASSERT_LT(i, nToInsert);
             ASSERT_EQ(entry, IndexKeyEntry(BSON("" << i), RecordId(42, i * 2)));
 
@@ -143,8 +90,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorWithEndPositio
 // restorePosition() in succession.
 TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorReversed) {
     const auto harnessHelper(newSortedDataInterfaceHarnessHelper());
-    const std::unique_ptr<SortedDataInterface> sorted(
-        harnessHelper->newSortedDataInterface(/*unique=*/false, /*partial=*/false));
+    const std::unique_ptr<SortedDataInterface> sorted(harnessHelper->newSortedDataInterface(false));
 
     {
         const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
@@ -158,7 +104,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorReversed) {
             WriteUnitOfWork uow(opCtx.get());
             BSONObj key = BSON("" << i);
             RecordId loc(42, i * 2);
-            ASSERT_OK(sorted->insert(opCtx.get(), makeKeyString(sorted.get(), key, loc), true));
+            ASSERT_OK(sorted->insert(opCtx.get(), key, loc, true));
             uow.commit();
         }
     }
@@ -173,108 +119,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorReversed) {
         const std::unique_ptr<SortedDataInterface::Cursor> cursor(
             sorted->newCursor(opCtx.get(), false));
         int i = nToInsert - 1;
-        for (auto entry =
-                 cursor->seek(makeKeyStringForSeek(sorted.get(), kMaxBSONKey, false, true));
-             entry;
-             i--, entry = cursor->next()) {
-            ASSERT_GTE(i, 0);
-            ASSERT_EQ(entry, IndexKeyEntry(BSON("" << i), RecordId(42, i * 2)));
-
-            cursor->save();
-            cursor->restore();
-        }
-        ASSERT(!cursor->next());
-        ASSERT_EQ(i, -1);
-    }
-}
-
-// Insert multiple keys on the _id index and try to iterate through all of them using a forward
-// cursor while calling save() and restore() in succession.
-TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorOnIdIndex) {
-    const auto harnessHelper(newSortedDataInterfaceHarnessHelper());
-    const std::unique_ptr<SortedDataInterface> sorted(
-        harnessHelper->newIdIndexSortedDataInterface());
-
-    {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        ASSERT(sorted->isEmpty(opCtx.get()));
-    }
-
-    int nToInsert = 10;
-    for (int i = 0; i < nToInsert; i++) {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        {
-            WriteUnitOfWork uow(opCtx.get());
-            BSONObj key = BSON("" << i);
-            RecordId loc(42, i * 2);
-            ASSERT_OK(sorted->insert(opCtx.get(), makeKeyString(sorted.get(), key, loc), false));
-            uow.commit();
-        }
-    }
-
-    {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        ASSERT_EQUALS(nToInsert, sorted->numEntries(opCtx.get()));
-    }
-
-    {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        const std::unique_ptr<SortedDataInterface::Cursor> cursor(
-            sorted->newCursor(opCtx.get(), false));
-        int i = nToInsert - 1;
-        for (auto entry =
-                 cursor->seek(makeKeyStringForSeek(sorted.get(), kMaxBSONKey, false, true));
-             entry;
-             i--, entry = cursor->next()) {
-            ASSERT_GTE(i, 0);
-            ASSERT_EQ(entry, IndexKeyEntry(BSON("" << i), RecordId(42, i * 2)));
-
-            cursor->save();
-            cursor->restore();
-        }
-        ASSERT(!cursor->next());
-        ASSERT_EQ(i, -1);
-    }
-}
-
-// Insert multiple keys on the _id index and try to iterate through all of them using a reverse
-// cursor while calling save() and restore() in succession.
-TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorReversedOnIdIndex) {
-    const auto harnessHelper(newSortedDataInterfaceHarnessHelper());
-    const std::unique_ptr<SortedDataInterface> sorted(
-        harnessHelper->newIdIndexSortedDataInterface());
-
-    {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        ASSERT(sorted->isEmpty(opCtx.get()));
-    }
-
-    int nToInsert = 10;
-    for (int i = 0; i < nToInsert; i++) {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        {
-            WriteUnitOfWork uow(opCtx.get());
-            BSONObj key = BSON("" << i);
-            RecordId loc(42, i * 2);
-            ASSERT_OK(sorted->insert(opCtx.get(), makeKeyString(sorted.get(), key, loc), false));
-            uow.commit();
-        }
-    }
-
-    {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        ASSERT_EQUALS(nToInsert, sorted->numEntries(opCtx.get()));
-    }
-
-    {
-        const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        const std::unique_ptr<SortedDataInterface::Cursor> cursor(
-            sorted->newCursor(opCtx.get(), false));
-        int i = nToInsert - 1;
-        for (auto entry =
-                 cursor->seek(makeKeyStringForSeek(sorted.get(), kMaxBSONKey, false, true));
-             entry;
-             i--, entry = cursor->next()) {
+        for (auto entry = cursor->seek(kMaxBSONKey, true); entry; i--, entry = cursor->next()) {
             ASSERT_GTE(i, 0);
             ASSERT_EQ(entry, IndexKeyEntry(BSON("" << i), RecordId(42, i * 2)));
 
@@ -292,8 +137,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorReversedOnIdIn
 // as part of the current position of the cursor.
 TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorWithDupKeys) {
     const auto harnessHelper(newSortedDataInterfaceHarnessHelper());
-    const std::unique_ptr<SortedDataInterface> sorted(
-        harnessHelper->newSortedDataInterface(/*unique=*/false, /*partial=*/false));
+    const std::unique_ptr<SortedDataInterface> sorted(harnessHelper->newSortedDataInterface(false));
 
     {
         const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
@@ -306,8 +150,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorWithDupKeys) {
         {
             WriteUnitOfWork uow(opCtx.get());
             RecordId loc(42, i * 2);
-            ASSERT_OK(sorted->insert(
-                opCtx.get(), makeKeyString(sorted.get(), key1, loc), true /* allow duplicates */));
+            ASSERT_OK(sorted->insert(opCtx.get(), key1, loc, true /* allow duplicates */));
             uow.commit();
         }
     }
@@ -321,9 +164,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorWithDupKeys) {
         const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
         const std::unique_ptr<SortedDataInterface::Cursor> cursor(sorted->newCursor(opCtx.get()));
         int i = 0;
-        for (auto entry = cursor->seek(makeKeyStringForSeek(sorted.get(), BSONObj(), true, true));
-             entry;
-             i++, entry = cursor->next()) {
+        for (auto entry = cursor->seek(kMinBSONKey, true); entry; i++, entry = cursor->next()) {
             ASSERT_LT(i, nToInsert);
             ASSERT_EQ(entry, IndexKeyEntry(key1, RecordId(42, i * 2)));
 
@@ -341,8 +182,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorWithDupKeys) {
 // as part of the current position of the cursor.
 TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorWithDupKeysReversed) {
     const auto harnessHelper(newSortedDataInterfaceHarnessHelper());
-    const std::unique_ptr<SortedDataInterface> sorted(
-        harnessHelper->newSortedDataInterface(/*unique=*/false, /*partial=*/false));
+    const std::unique_ptr<SortedDataInterface> sorted(harnessHelper->newSortedDataInterface(false));
 
     {
         const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
@@ -355,8 +195,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorWithDupKeysRev
         {
             WriteUnitOfWork uow(opCtx.get());
             RecordId loc(42, i * 2);
-            ASSERT_OK(sorted->insert(
-                opCtx.get(), makeKeyString(sorted.get(), key1, loc), true /* allow duplicates */));
+            ASSERT_OK(sorted->insert(opCtx.get(), key1, loc, true /* allow duplicates */));
             uow.commit();
         }
     }
@@ -371,10 +210,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorWithDupKeysRev
         const std::unique_ptr<SortedDataInterface::Cursor> cursor(
             sorted->newCursor(opCtx.get(), false));
         int i = nToInsert - 1;
-        for (auto entry =
-                 cursor->seek(makeKeyStringForSeek(sorted.get(), kMaxBSONKey, false, true));
-             entry;
-             i--, entry = cursor->next()) {
+        for (auto entry = cursor->seek(kMaxBSONKey, true); entry; i--, entry = cursor->next()) {
             ASSERT_GTE(i, 0);
             ASSERT_EQ(entry, IndexKeyEntry(key1, RecordId(42, i * 2)));
 
@@ -390,8 +226,7 @@ TEST(SortedDataInterface, SaveAndRestorePositionWhileIterateCursorWithDupKeysRev
 // May be useful to run this test under valgrind to verify there are no leaks.
 TEST(SortedDataInterface, SavePositionWithoutRestore) {
     const auto harnessHelper(newSortedDataInterfaceHarnessHelper());
-    const std::unique_ptr<SortedDataInterface> sorted(
-        harnessHelper->newSortedDataInterface(/*unique=*/true, /*partial=*/false));
+    const std::unique_ptr<SortedDataInterface> sorted(harnessHelper->newSortedDataInterface(true));
 
     {
         const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
@@ -402,7 +237,7 @@ TEST(SortedDataInterface, SavePositionWithoutRestore) {
         const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
         {
             WriteUnitOfWork uow(opCtx.get());
-            ASSERT_OK(sorted->insert(opCtx.get(), makeKeyString(sorted.get(), key1, loc1), false));
+            ASSERT_OK(sorted->insert(opCtx.get(), key1, loc1, false));
             uow.commit();
         }
     }
@@ -423,8 +258,7 @@ TEST(SortedDataInterface, SavePositionWithoutRestore) {
 // May be useful to run this test under valgrind to verify there are no leaks.
 TEST(SortedDataInterface, SavePositionWithoutRestoreReversed) {
     const auto harnessHelper(newSortedDataInterfaceHarnessHelper());
-    const std::unique_ptr<SortedDataInterface> sorted(
-        harnessHelper->newSortedDataInterface(/*unique=*/false, /*partial=*/false));
+    const std::unique_ptr<SortedDataInterface> sorted(harnessHelper->newSortedDataInterface(false));
 
     {
         const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
@@ -435,7 +269,7 @@ TEST(SortedDataInterface, SavePositionWithoutRestoreReversed) {
         const ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
         {
             WriteUnitOfWork uow(opCtx.get());
-            ASSERT_OK(sorted->insert(opCtx.get(), makeKeyString(sorted.get(), key1, loc1), true));
+            ASSERT_OK(sorted->insert(opCtx.get(), key1, loc1, true));
             uow.commit();
         }
     }
@@ -459,20 +293,17 @@ void testSaveAndRestorePositionSeesNewInserts(bool forward, bool unique) {
     const auto harnessHelper = newSortedDataInterfaceHarnessHelper();
     auto opCtx = harnessHelper->newOperationContext();
     auto sorted = harnessHelper->newSortedDataInterface(unique,
-                                                        /*partial=*/false,
                                                         {
-                                                            {key1, loc1},
-                                                            {key3, loc1},
+                                                            {key1, loc1}, {key3, loc1},
                                                         });
 
     auto cursor = sorted->newCursor(opCtx.get(), forward);
     const auto seekPoint = forward ? key1 : key3;
 
-    ASSERT_EQ(cursor->seek(makeKeyStringForSeek(sorted.get(), seekPoint, forward, true)),
-              IndexKeyEntry(seekPoint, loc1));
+    ASSERT_EQ(cursor->seek(seekPoint, true), IndexKeyEntry(seekPoint, loc1));
 
     cursor->save();
-    insertToIndex(opCtx.get(), sorted.get(), {{key2, loc1}});
+    insertToIndex(opCtx, sorted, {{key2, loc1}});
     cursor->restore();
 
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key2, loc1));
@@ -496,25 +327,22 @@ void testSaveAndRestorePositionSeesNewInsertsAfterRemove(bool forward, bool uniq
     const auto harnessHelper = newSortedDataInterfaceHarnessHelper();
     auto opCtx = harnessHelper->newOperationContext();
     auto sorted = harnessHelper->newSortedDataInterface(unique,
-                                                        /*partial=*/false,
                                                         {
-                                                            {key1, loc1},
-                                                            {key3, loc1},
+                                                            {key1, loc1}, {key3, loc1},
                                                         });
 
     auto cursor = sorted->newCursor(opCtx.get(), forward);
     const auto seekPoint = forward ? key1 : key3;
 
-    ASSERT_EQ(cursor->seek(makeKeyStringForSeek(sorted.get(), seekPoint, forward, true)),
-              IndexKeyEntry(seekPoint, loc1));
+    ASSERT_EQ(cursor->seek(seekPoint, true), IndexKeyEntry(seekPoint, loc1));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key1, loc1}});
+    removeFromIndex(opCtx, sorted, {{key1, loc1}});
     cursor->restore();
     // The restore may have seeked since it can't return to the saved position.
 
     cursor->save();  // Should still save originally saved key as "current position".
-    insertToIndex(opCtx.get(), sorted.get(), {{key2, loc1}});
+    insertToIndex(opCtx, sorted, {{key2, loc1}});
     cursor->restore();
 
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key2, loc1));
@@ -538,26 +366,24 @@ TEST(SortedDataInterface, SaveAndRestorePositionSeesNewInsertsAfterRemove_Revers
 void testSaveAndRestorePositionSeesNewInsertsAfterEOF(bool forward, bool unique) {
     const auto harnessHelper = newSortedDataInterfaceHarnessHelper();
     auto opCtx = harnessHelper->newOperationContext();
-    auto sorted = harnessHelper->newSortedDataInterface(/*unique=*/false,
-                                                        /*partial=*/false,
+    auto sorted = harnessHelper->newSortedDataInterface(false,
                                                         {
                                                             {key1, loc1},
                                                         });
 
     auto cursor = sorted->newCursor(opCtx.get(), forward);
 
-    ASSERT_EQ(cursor->seek(makeKeyStringForSeek(sorted.get(), key1, forward, true)),
-              IndexKeyEntry(key1, loc1));
+    ASSERT_EQ(cursor->seek(key1, true), IndexKeyEntry(key1, loc1));
     // next() would return EOF now.
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key1, loc1}});
+    removeFromIndex(opCtx, sorted, {{key1, loc1}});
     cursor->restore();
     // The restore may have seeked to EOF.
 
     auto insertPoint = forward ? key2 : key0;
     cursor->save();  // Should still save key1 as "current position".
-    insertToIndex(opCtx.get(), sorted.get(), {{insertPoint, loc1}});
+    insertToIndex(opCtx, sorted, {{insertPoint, loc1}});
     cursor->restore();
 
     ASSERT_EQ(cursor->next(), IndexKeyEntry(insertPoint, loc1));
@@ -580,39 +406,36 @@ TEST(SortedDataInterface, SaveAndRestorePositionSeesNewInsertsAfterEOF_Reverse_S
 TEST(SortedDataInterface, SaveAndRestorePositionStandardIndexConsidersRecordId_Forward) {
     const auto harnessHelper = newSortedDataInterfaceHarnessHelper();
     auto opCtx = harnessHelper->newOperationContext();
-    auto sorted = harnessHelper->newSortedDataInterface(/*unique*/ false,
-                                                        /*partial=*/false,
-                                                        {
-                                                            {key1, loc1},
-                                                            {key2, loc1},
-                                                            {key3, loc1},
-                                                        });
+    auto sorted =
+        harnessHelper->newSortedDataInterface(/*isUnique*/ false,
+                                              {
+                                                  {key1, loc1}, {key2, loc1}, {key3, loc1},
+                                              });
 
     auto cursor = sorted->newCursor(opCtx.get());
 
-    ASSERT_EQ(cursor->seek(makeKeyStringForSeek(sorted.get(), key1, true, true)),
-              IndexKeyEntry(key1, loc1));
+    ASSERT_EQ(cursor->seek(key1, true), IndexKeyEntry(key1, loc1));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key1, loc1}});
-    insertToIndex(opCtx.get(), sorted.get(), {{key1, loc2}});
+    removeFromIndex(opCtx, sorted, {{key1, loc1}});
+    insertToIndex(opCtx, sorted, {{key1, loc2}});
     cursor->restore();  // Lands on inserted key.
 
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key1, loc2));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key1, loc2}});
-    insertToIndex(opCtx.get(), sorted.get(), {{key1, loc1}});
+    removeFromIndex(opCtx, sorted, {{key1, loc2}});
+    insertToIndex(opCtx, sorted, {{key1, loc1}});
     cursor->restore();  // Lands after inserted.
 
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key2, loc1));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key2, loc1}});
+    removeFromIndex(opCtx, sorted, {{key2, loc1}});
     cursor->restore();
 
     cursor->save();
-    insertToIndex(opCtx.get(), sorted.get(), {{key2, loc1}});
+    insertToIndex(opCtx, sorted, {{key2, loc1}});
     cursor->restore();  // Lands at same point as initial save.
 
     // Advances from restore point since restore didn't move position.
@@ -624,26 +447,23 @@ TEST(SortedDataInterface, SaveAndRestorePositionUniqueIndexWontReturnDupKeys_For
     const auto harnessHelper = newSortedDataInterfaceHarnessHelper();
     auto opCtx = harnessHelper->newOperationContext();
     auto sorted = harnessHelper->newSortedDataInterface(
-        /*unique*/ true,
-        /*partial=*/false,
-        {{key1, loc1}, {key2, loc2}, {key3, loc2}, {key4, loc2}});
+        /*isUnique*/ true, {{key1, loc1}, {key2, loc2}, {key3, loc2}, {key4, loc2}});
 
     auto cursor = sorted->newCursor(opCtx.get());
 
-    ASSERT_EQ(cursor->seek(makeKeyStringForSeek(sorted.get(), key1, true, true)),
-              IndexKeyEntry(key1, loc1));
+    ASSERT_EQ(cursor->seek(key1, true), IndexKeyEntry(key1, loc1));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key1, loc1}});
-    insertToIndex(opCtx.get(), sorted.get(), {{key1, loc2}});
+    removeFromIndex(opCtx, sorted, {{key1, loc1}});
+    insertToIndex(opCtx, sorted, {{key1, loc2}});
     cursor->restore();
 
     // We should skip over (key1, loc2) since we already returned (key1, loc1).
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key2, loc2));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key2, loc2}});
-    insertToIndex(opCtx.get(), sorted.get(), {{key2, loc1}});
+    removeFromIndex(opCtx, sorted, {{key2, loc2}});
+    insertToIndex(opCtx, sorted, {{key2, loc1}});
     cursor->restore();
 
     // We should skip over (key2, loc1) since we already returned (key2, loc2).
@@ -651,13 +471,13 @@ TEST(SortedDataInterface, SaveAndRestorePositionUniqueIndexWontReturnDupKeys_For
 
     // If the key we just returned is removed, we should simply return the next key after restoring.
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key3, loc2}});
+    removeFromIndex(opCtx, sorted, {{key3, loc2}});
     cursor->restore();
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key4, loc2));
 
     // If a key is inserted just ahead of our position, we should return it after restoring.
     cursor->save();
-    insertToIndex(opCtx.get(), sorted.get(), {{key5, loc2}});
+    insertToIndex(opCtx, sorted, {{key5, loc2}});
     cursor->restore();
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key5, loc2));
 }
@@ -666,39 +486,36 @@ TEST(SortedDataInterface, SaveAndRestorePositionUniqueIndexWontReturnDupKeys_For
 TEST(SortedDataInterface, SaveAndRestorePositionStandardIndexConsidersRecordId_Reverse) {
     const auto harnessHelper = newSortedDataInterfaceHarnessHelper();
     auto opCtx = harnessHelper->newOperationContext();
-    auto sorted = harnessHelper->newSortedDataInterface(/*unique*/ false,
-                                                        /*partial=*/false,
-                                                        {
-                                                            {key0, loc1},
-                                                            {key1, loc1},
-                                                            {key2, loc2},
-                                                        });
+    auto sorted =
+        harnessHelper->newSortedDataInterface(/*isUnique*/ false,
+                                              {
+                                                  {key0, loc1}, {key1, loc1}, {key2, loc2},
+                                              });
 
     auto cursor = sorted->newCursor(opCtx.get(), false);
 
-    ASSERT_EQ(cursor->seek(makeKeyStringForSeek(sorted.get(), key2, false, true)),
-              IndexKeyEntry(key2, loc2));
+    ASSERT_EQ(cursor->seek(key2, true), IndexKeyEntry(key2, loc2));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key2, loc2}});
-    insertToIndex(opCtx.get(), sorted.get(), {{key2, loc1}});
+    removeFromIndex(opCtx, sorted, {{key2, loc2}});
+    insertToIndex(opCtx, sorted, {{key2, loc1}});
     cursor->restore();
 
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key2, loc1));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key2, loc1}});
-    insertToIndex(opCtx.get(), sorted.get(), {{key2, loc2}});
+    removeFromIndex(opCtx, sorted, {{key2, loc1}});
+    insertToIndex(opCtx, sorted, {{key2, loc2}});
     cursor->restore();
 
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key1, loc1));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key1, loc1}});
+    removeFromIndex(opCtx, sorted, {{key1, loc1}});
     cursor->restore();
 
     cursor->save();
-    insertToIndex(opCtx.get(), sorted.get(), {{key1, loc1}});
+    insertToIndex(opCtx, sorted, {{key1, loc1}});
     cursor->restore();  // Lands at same point as initial save.
 
     // Advances from restore point since restore didn't move position.
@@ -710,26 +527,23 @@ TEST(SortedDataInterface, SaveAndRestorePositionUniqueIndexWontReturnDupKeys_Rev
     const auto harnessHelper = newSortedDataInterfaceHarnessHelper();
     auto opCtx = harnessHelper->newOperationContext();
     auto sorted = harnessHelper->newSortedDataInterface(
-        /*unique*/ true,
-        /*partial=*/false,
-        {{key1, loc1}, {key2, loc1}, {key3, loc1}, {key4, loc2}});
+        /*isUnique*/ true, {{key1, loc1}, {key2, loc1}, {key3, loc1}, {key4, loc2}});
 
     auto cursor = sorted->newCursor(opCtx.get(), false);
 
-    ASSERT_EQ(cursor->seek(makeKeyStringForSeek(sorted.get(), key4, false, true)),
-              IndexKeyEntry(key4, loc2));
+    ASSERT_EQ(cursor->seek(key4, true), IndexKeyEntry(key4, loc2));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key4, loc2}});
-    insertToIndex(opCtx.get(), sorted.get(), {{key4, loc1}});
+    removeFromIndex(opCtx, sorted, {{key4, loc2}});
+    insertToIndex(opCtx, sorted, {{key4, loc1}});
     cursor->restore();
 
     // We should skip over (key4, loc1) since we already returned (key4, loc2).
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key3, loc1));
 
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key3, loc1}});
-    insertToIndex(opCtx.get(), sorted.get(), {{key3, loc2}});
+    removeFromIndex(opCtx, sorted, {{key3, loc1}});
+    insertToIndex(opCtx, sorted, {{key3, loc2}});
     cursor->restore();
 
     // We should skip over (key3, loc2) since we already returned (key3, loc1).
@@ -737,13 +551,13 @@ TEST(SortedDataInterface, SaveAndRestorePositionUniqueIndexWontReturnDupKeys_Rev
 
     // If the key we just returned is removed, we should simply return the next key after restoring.
     cursor->save();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key2, loc1}});
+    removeFromIndex(opCtx, sorted, {{key2, loc1}});
     cursor->restore();
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key1, loc1));
 
     // If a key is inserted just ahead of our position, we should return it after restoring.
     cursor->save();
-    insertToIndex(opCtx.get(), sorted.get(), {{key0, loc1}});
+    insertToIndex(opCtx, sorted, {{key0, loc1}});
     cursor->restore();
     ASSERT_EQ(cursor->next(), IndexKeyEntry(key0, loc1));
 }
@@ -752,31 +566,26 @@ TEST(SortedDataInterface, SaveAndRestorePositionUniqueIndexWontReturnDupKeys_Rev
 TEST(SortedDataInterface, SaveUnpositionedAndRestore) {
     const auto harnessHelper = newSortedDataInterfaceHarnessHelper();
     auto opCtx = harnessHelper->newOperationContext();
-    auto sorted = harnessHelper->newSortedDataInterface(/*unique=*/false,
-                                                        /*partial=*/false,
-                                                        {
-                                                            {key1, loc1},
-                                                            {key2, loc1},
-                                                            {key3, loc1},
-                                                        });
+    auto sorted =
+        harnessHelper->newSortedDataInterface(false,
+                                              {
+                                                  {key1, loc1}, {key2, loc1}, {key3, loc1},
+                                              });
 
     auto cursor = sorted->newCursor(opCtx.get());
 
-    ASSERT_EQ(cursor->seek(makeKeyStringForSeek(sorted.get(), key2, true, true)),
-              IndexKeyEntry(key2, loc1));
+    ASSERT_EQ(cursor->seek(key2, true), IndexKeyEntry(key2, loc1));
 
     cursor->saveUnpositioned();
-    removeFromIndex(opCtx.get(), sorted.get(), {{key2, loc1}});
+    removeFromIndex(opCtx, sorted, {{key2, loc1}});
     cursor->restore();
 
-    ASSERT_EQ(cursor->seek(makeKeyStringForSeek(sorted.get(), key1, true, true)),
-              IndexKeyEntry(key1, loc1));
+    ASSERT_EQ(cursor->seek(key1, true), IndexKeyEntry(key1, loc1));
 
     cursor->saveUnpositioned();
     cursor->restore();
 
-    ASSERT_EQ(cursor->seek(makeKeyStringForSeek(sorted.get(), key3, true, true)),
-              IndexKeyEntry(key3, loc1));
+    ASSERT_EQ(cursor->seek(key3, true), IndexKeyEntry(key3, loc1));
 }
 
 }  // namespace
