@@ -104,7 +104,8 @@ bool StorageEngineLockFile::createdByUncleanShutdown() const {
 Status StorageEngineLockFile::open() {
     try {
         if (!boost::filesystem::exists(_dbpath)) {
-            return Status(ErrorCodes::NonExistentPath, _getNonExistentPathMessage());
+            return Status(ErrorCodes::NonExistentPath,
+                          str::stream() << "Data directory " << _dbpath << " not found.");
         }
     } catch (const std::exception& ex) {
         return Status(ErrorCodes::UnknownError,
