@@ -29,6 +29,7 @@ Copyright (C) 2018-present Percona and/or its affiliates. All rights reserved.
     it in the license file.
 ======= */
 
+#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kStorage
 
 #include <boost/filesystem/path.hpp>
 
@@ -37,15 +38,12 @@ Copyright (C) 2018-present Percona and/or its affiliates. All rights reserved.
 #include <wiredtiger.h>
 
 #include "mongo/db/encryption/encryption_options.h"
-#include "mongo/db/storage/wiredtiger/encryption_keydb.h"
-#include "mongo/db/storage/wiredtiger/encryption_keydb_c_api.h"
 #include "mongo/db/storage/wiredtiger/wiredtiger_data_protector.h"
 #include "mongo/db/storage/wiredtiger/wiredtiger_encryption_hooks.h"
-#include "mongo/logv2/log.h"
-#include "mongo/util/database_name_util.h"
-
-#define MONGO_LOGV2_DEFAULT_COMPONENT ::mongo::logv2::LogComponent::kStorage
+#include "mongo/stdx/memory.h"
+#include "mongo/util/log.h"
 
+#include <third_party/wiredtiger/ext/encryptors/percona/encryption_keydb_c_api.h>
 
 namespace mongo {
 
@@ -86,7 +84,7 @@ namespace {
 
     // callback for ERR_print_errors_cb
     static int err_print_cb(const char *str, size_t len, void *param) {
-        LOGV2_ERROR(29029, "{str}", "str"_attr = str);
+        error() << str;
         return 1;
     }
 
@@ -98,10 +96,12 @@ namespace {
 }
 
 
-WiredTigerEncryptionHooks::WiredTigerEncryptionHooks(EncryptionKeyDB* encryptionKeyDB)
-    : _encryptionKeyDB(encryptionKeyDB) {}
+WiredTigerEncryptionHooks::WiredTigerEncryptionHooks() {
+    // get master key
+    get_key_by_id(nullptr, 0, _masterkey, nullptr);
+}
 
-WiredTigerEncryptionHooks::~WiredTigerEncryptionHooks() = default;
+WiredTigerEncryptionHooks::~WiredTigerEncryptionHooks() {}
 
 bool WiredTigerEncryptionHooks::enabled() const {
     return true;
@@ -111,44 +111,8 @@ bool WiredTigerEncryptionHooks::restartRequired() {
     return false;
 }
 
-StatusWith<std::deque<BackupBlock>> WiredTigerEncryptionHooks::beginNonBlockingBackup(
-    OperationContext* opCtx,
-    boost::optional<Timestamp> checkpointTimestamp,
-    const StorageEngine::BackupOptions& options) {
-    return _encryptionKeyDB->beginNonBlockingBackup(opCtx, checkpointTimestamp, options);
-}
 
-Status WiredTigerEncryptionHooks::endNonBlockingBackup(OperationContext* opCtx) {
-    return _encryptionKeyDB->endNonBlockingBackup(opCtx);
-}
-
-StatusWith<std::deque<std::string>> WiredTigerEncryptionHooks::extendBackupCursor(
-    OperationContext* opCtx) {
-    return _encryptionKeyDB->extendBackupCursor(opCtx);
-}
-
-const unsigned char* WiredTigerEncryptionHooks::dbKey(boost::optional<DatabaseName> dbName,
-                                                      unsigned char* buf) {
-    if (!dbName) {
-        // static local initialization is thread safe since C++11
-        static const struct TmpKey {
-            unsigned char _tmpkey[_key_len];
-            TmpKey() {
-                // generate temporary key valid only while current process is running
-                generate_secure_key(static_cast<unsigned char*>(_tmpkey));
-            }
-        } tmp_key_holder;
-        return static_cast<const unsigned char*>(tmp_key_holder._tmpkey);
-    }
-    std::string dbNameStr =
-        DatabaseNameUtil::serialize(*dbName, SerializationContext::stateDefault());
-    get_key_by_id(dbNameStr.c_str(), dbNameStr.length(), buf, nullptr);
-    return buf;
-}
-
-
-WiredTigerEncryptionHooksCBC::WiredTigerEncryptionHooksCBC(EncryptionKeyDB* encryptionKeyDB)
-    : WiredTigerEncryptionHooks(encryptionKeyDB) {
+WiredTigerEncryptionHooksCBC::WiredTigerEncryptionHooksCBC() {
     _cipher = EVP_aes_256_cbc();
     _iv_len = EVP_CIPHER_iv_length(_cipher);
     // get wiredTiger's crc32c function
@@ -157,12 +121,8 @@ WiredTigerEncryptionHooksCBC::WiredTigerEncryptionHooksCBC(EncryptionKeyDB* encr
 
 WiredTigerEncryptionHooksCBC::~WiredTigerEncryptionHooksCBC() {}
 
-Status WiredTigerEncryptionHooksCBC::protectTmpData(const uint8_t* in,
-                                                    size_t inLen,
-                                                    uint8_t* out,
-                                                    size_t outLen,
-                                                    size_t* resultLen,
-                                                    boost::optional<DatabaseName> dbName) {
+Status WiredTigerEncryptionHooksCBC::protectTmpData(
+    const uint8_t* in, size_t inLen, uint8_t* out, size_t outLen, size_t* resultLen) {
 
     if (outLen < _chksum_len + _iv_len + inLen + EVP_CIPHER_block_size(_cipher))
         return Status(ErrorCodes::InternalError,
@@ -178,10 +138,7 @@ Status WiredTigerEncryptionHooksCBC::protectTmpData(const uint8_t* in,
     store_pseudo_bytes(iv, _iv_len);
     *resultLen += _iv_len;
 
-    unsigned char db_key[_key_len];
-    if (1 !=
-        EVP_EncryptInit_ex(
-            ctx, _cipher, nullptr, dbKey(dbName, static_cast<unsigned char*>(db_key)), iv))
+    if (1 != EVP_EncryptInit_ex(ctx, _cipher, nullptr, _masterkey, iv))
         return handleCryptoErrors();
 
     int encrypted_len = 0;
@@ -196,12 +153,8 @@ Status WiredTigerEncryptionHooksCBC::protectTmpData(const uint8_t* in,
     return Status::OK();
 }
 
-Status WiredTigerEncryptionHooksCBC::unprotectTmpData(const uint8_t* in,
-                                                      size_t inLen,
-                                                      uint8_t* out,
-                                                      size_t outLen,
-                                                      size_t* resultLen,
-                                                      boost::optional<DatabaseName> dbName) {
+Status WiredTigerEncryptionHooksCBC::unprotectTmpData(
+    const uint8_t* in, size_t inLen, uint8_t* out, size_t outLen, size_t* resultLen) {
 
     *resultLen = 0;
     EVPCipherCtx ctx;
@@ -210,10 +163,7 @@ Status WiredTigerEncryptionHooksCBC::unprotectTmpData(const uint8_t* in,
     in += _chksum_len;
     inLen -= _chksum_len;
 
-    unsigned char db_key[_key_len];
-    if (1 !=
-        EVP_DecryptInit_ex(
-            ctx, _cipher, nullptr, dbKey(dbName, static_cast<unsigned char*>(db_key)), in))
+    if (1 != EVP_DecryptInit_ex(ctx, _cipher, nullptr, _masterkey, in))
         return handleCryptoErrors();
     in += _iv_len;
     inLen -= _iv_len;
@@ -242,7 +192,7 @@ size_t WiredTigerEncryptionHooksCBC::additionalBytesForProtectedBuffer() {
 }
 
 std::unique_ptr<DataProtector> WiredTigerEncryptionHooksCBC::getDataProtector() {
-    return std::make_unique<WiredTigerDataProtectorCBC>();
+    return stdx::make_unique<WiredTigerDataProtectorCBC>();
 }
 
 boost::filesystem::path WiredTigerEncryptionHooksCBC::getProtectedPathSuffix() {
@@ -250,20 +200,15 @@ boost::filesystem::path WiredTigerEncryptionHooksCBC::getProtectedPathSuffix() {
 }
 
 
-WiredTigerEncryptionHooksGCM::WiredTigerEncryptionHooksGCM(EncryptionKeyDB* encryptionKeyDB)
-    : WiredTigerEncryptionHooks(encryptionKeyDB) {
+WiredTigerEncryptionHooksGCM::WiredTigerEncryptionHooksGCM() {
     _cipher = EVP_aes_256_gcm();
     _iv_len = EVP_CIPHER_iv_length(_cipher);
 }
 
 WiredTigerEncryptionHooksGCM::~WiredTigerEncryptionHooksGCM() {}
 
-Status WiredTigerEncryptionHooksGCM::protectTmpData(const uint8_t* in,
-                                                    size_t inLen,
-                                                    uint8_t* out,
-                                                    size_t outLen,
-                                                    size_t* resultLen,
-                                                    boost::optional<DatabaseName> dbName) {
+Status WiredTigerEncryptionHooksGCM::protectTmpData(
+    const uint8_t* in, size_t inLen, uint8_t* out, size_t outLen, size_t* resultLen) {
 
     if (outLen < _iv_len + inLen + _gcm_tag_len)
         return Status(ErrorCodes::InternalError,
@@ -281,10 +226,7 @@ Status WiredTigerEncryptionHooksGCM::protectTmpData(const uint8_t* in,
                       "failed generating IV for GCM");
     *resultLen += _iv_len;
 
-    unsigned char db_key[_key_len];
-    if (1 !=
-        EVP_EncryptInit_ex(
-            ctx, _cipher, nullptr, dbKey(dbName, static_cast<unsigned char*>(db_key)), iv))
+    if (1 != EVP_EncryptInit_ex(ctx, _cipher, nullptr, _masterkey, iv))
         return handleCryptoErrors();
 
     // we don't provide any AAD data yet
@@ -306,12 +248,8 @@ Status WiredTigerEncryptionHooksGCM::protectTmpData(const uint8_t* in,
     return Status::OK();
 }
 
-Status WiredTigerEncryptionHooksGCM::unprotectTmpData(const uint8_t* in,
-                                                      size_t inLen,
-                                                      uint8_t* out,
-                                                      size_t outLen,
-                                                      size_t* resultLen,
-                                                      boost::optional<DatabaseName> dbName) {
+Status WiredTigerEncryptionHooksGCM::unprotectTmpData(
+    const uint8_t* in, size_t inLen, uint8_t* out, size_t outLen, size_t* resultLen) {
 
     *resultLen = 0;
     EVPCipherCtx ctx;
@@ -321,10 +259,7 @@ Status WiredTigerEncryptionHooksGCM::unprotectTmpData(const uint8_t* in,
     in += _gcm_tag_len;
     inLen -= _gcm_tag_len;
 
-    unsigned char db_key[_key_len];
-    if (1 !=
-        EVP_DecryptInit_ex(
-            ctx, _cipher, nullptr, dbKey(dbName, static_cast<unsigned char*>(db_key)), in))
+    if (1 != EVP_DecryptInit_ex(ctx, _cipher, nullptr, _masterkey, in))
         return handleCryptoErrors();
     in += _iv_len;
     inLen -= _iv_len;
@@ -354,7 +289,7 @@ size_t WiredTigerEncryptionHooksGCM::additionalBytesForProtectedBuffer() {
 }
 
 std::unique_ptr<DataProtector> WiredTigerEncryptionHooksGCM::getDataProtector() {
-    return std::make_unique<WiredTigerDataProtectorGCM>();
+    return stdx::make_unique<WiredTigerDataProtectorGCM>();
 }
 
 boost::filesystem::path WiredTigerEncryptionHooksGCM::getProtectedPathSuffix() {
