@@ -45,8 +45,20 @@
 
 #include <boost/filesystem.hpp>
 #include <boost/filesystem/operations.hpp>
+#include <libarchive/archive.h>
+#include <libarchive/archive_entry.h>
 #include <valgrind/valgrind.h>
 
+
+#include <aws/core/Aws.h>
+#include <aws/core/auth/AWSCredentialsProvider.h>
+#include <aws/core/utils/logging/AWSLogging.h>
+#include <aws/core/utils/logging/FormattedLogSystem.h>
+#include <aws/s3/S3Client.h>
+#include <aws/s3/model/CreateBucketRequest.h>
+#include <aws/s3/model/ListObjectsRequest.h>
+#include <aws/s3/model/PutObjectRequest.h>
+
 #include "mongo/base/error_codes.h"
 #include "mongo/bson/bsonobjbuilder.h"
 #include "mongo/db/bson/dotted_path_support.h"
@@ -74,7 +86,6 @@
 #include "mongo/db/storage/wiredtiger/wiredtiger_recovery_unit.h"
 #include "mongo/db/storage/wiredtiger/wiredtiger_session_cache.h"
 #include "mongo/db/storage/wiredtiger/wiredtiger_size_storer.h"
-#include "mongo/db/storage/wiredtiger/wiredtiger_util.h"
 #include "mongo/platform/atomic_word.h"
 #include "mongo/stdx/memory.h"
 #include "mongo/util/background.h"
@@ -438,12 +449,12 @@ WiredTigerKVEngine::WiredTigerKVEngine(const std::string& canonicalName,
                                        ClockSource* cs,
                                        const std::string& extraOpenOptions,
                                        size_t cacheSizeMB,
+                                       size_t maxCacheOverflowFileSizeMB,
                                        bool durable,
                                        bool ephemeral,
                                        bool repair,
                                        bool readOnly)
     : _keepDataHistory(serverGlobalParams.enableMajorityReadConcern),
-      _eventHandler(WiredTigerUtil::defaultEventHandlers()),
       _clockSource(cs),
       _oplogManager(stdx::make_unique<WiredTigerOplogManager>()),
       _canonicalName(canonicalName),
@@ -566,6 +577,7 @@ WiredTigerKVEngine::WiredTigerKVEngine(const std::string& canonicalName,
     std::stringstream ss;
     ss << "create,";
     ss << "cache_size=" << cacheSizeMB << "M,";
+    ss << "cache_overflow=(file_max=" << maxCacheOverflowFileSizeMB << "M),";
     ss << "session_max=20000,";
     ss << "eviction=(threads_min=4,threads_max=4),";
     ss << "config_base=false,";
@@ -606,7 +618,8 @@ WiredTigerKVEngine::WiredTigerKVEngine(const std::string& canonicalName,
             string config = ss.str();
             log() << "Detected WT journal files.  Running recovery from last checkpoint.";
             log() << "journal to nojournal transition config: " << config;
-            int ret = wiredtiger_open(path.c_str(), &_eventHandler, config.c_str(), &_conn);
+            int ret = wiredtiger_open(
+                path.c_str(), _eventHandler.getWtEventHandler(), config.c_str(), &_conn);
             if (ret == EINVAL) {
                 fassertFailedNoTrace(28717);
             } else if (ret != 0) {
@@ -628,7 +641,8 @@ WiredTigerKVEngine::WiredTigerKVEngine(const std::string& canonicalName,
     string config = ss.str();
     log() << "wiredtiger_open config: " << config;
     _wtOpenConfig = config;
-    int ret = wiredtiger_open(path.c_str(), &_eventHandler, config.c_str(), &_conn);
+    int ret =
+        wiredtiger_open(path.c_str(), _eventHandler.getWtEventHandler(), config.c_str(), &_conn);
     // Invalid argument (EINVAL) is usually caused by invalid configuration string.
     // We still fassert() but without a stack trace.
     if (ret == EINVAL) {
@@ -698,6 +712,8 @@ void WiredTigerKVEngine::appendGlobalStats(BSONObjBuilder& b) {
 
 void WiredTigerKVEngine::cleanShutdown() {
     log() << "WiredTigerKVEngine shutting down";
+    // Ensure that key db is destroyed on exit
+    ON_BLOCK_EXIT([&] { _encryptionKeyDB.reset(nullptr); });
     if (!_readOnly)
         syncSizeInfo(true);
     if (_conn) {
@@ -762,8 +778,8 @@ void WiredTigerKVEngine::cleanShutdown() {
             WT_CONNECTION* conn;
             std::stringstream openConfig;
             openConfig << _wtOpenConfig << ",log=(archive=false)";
-            invariantWTOK(
-                wiredtiger_open(_path.c_str(), &_eventHandler, openConfig.str().c_str(), &conn));
+            invariantWTOK(wiredtiger_open(
+                _path.c_str(), _eventHandler.getWtEventHandler(), openConfig.str().c_str(), &conn));
 
             WT_SESSION* session;
             conn->open_session(conn, nullptr, "", &session);
@@ -793,8 +809,7 @@ void WiredTigerKVEngine::cleanShutdown() {
             invariantWTOK(conn->reconfigure(conn, "compatibility=(release=2.9)"));
             invariantWTOK(conn->close(conn, closeConfig));
         }
-    }
-    _encryptionKeyDB.reset(nullptr);
+    }  // namespace mongo
 }
 
 Status WiredTigerKVEngine::okToRename(OperationContext* opCtx,
@@ -912,7 +927,7 @@ static void copy_file_size(const boost::filesystem::path& srcFile, const boost::
     }
 }
 
-Status WiredTigerKVEngine::hotBackup(OperationContext* opCtx, const std::string& path) {
+Status WiredTigerKVEngine::_hotBackupPopulateLists(OperationContext* opCtx, const std::string& path, std::vector<DBTuple>& dbList, std::vector<FileTuple>& filesList) {
     // Nothing to backup for non-durable engine.
     if (!_durable) {
         return EngineExtension::hotBackup(opCtx, path);
@@ -921,11 +936,6 @@ Status WiredTigerKVEngine::hotBackup(OperationContext* opCtx, const std::string&
     namespace fs = boost::filesystem;
     int ret;
 
-    // srcPath, destPath, session, cursor
-    typedef std::tuple<fs::path, fs::path, std::shared_ptr<WiredTigerSession>, WT_CURSOR*> DBTuple;
-    // list of DBs to backup
-    std::vector<DBTuple> dbList;
-
     const char* journalDir = "journal";
     fs::path destPath{path};
 
@@ -954,11 +964,6 @@ Status WiredTigerKVEngine::hotBackup(OperationContext* opCtx, const std::string&
 
     // Open backup cursor for keyDB
     if (_encryptionKeyDB) {
-        try {
-            fs::create_directory(destPath / keydbDir);
-        } catch (const fs::filesystem_error& ex) {
-            return Status(ErrorCodes::InvalidPath, str::stream() << ex.what());
-        }
         auto session = std::make_shared<WiredTigerSession>(_encryptionKeyDB->getConnection());
         WT_SESSION* s = session->getSession();
         ret = s->log_flush(s, "sync=off");
@@ -974,8 +979,6 @@ Status WiredTigerKVEngine::hotBackup(OperationContext* opCtx, const std::string&
     }
 
     // Populate list of files to copy
-    typedef std::tuple<fs::path, fs::path, boost::uintmax_t> FileTuple;  // srcPath, destPath, filename, size to copy
-    std::vector<FileTuple> filesList;
     for (auto&& db : dbList) {
         fs::path srcPath = std::get<0>(db);
         fs::path destPath = std::get<1>(db);
@@ -987,13 +990,13 @@ Status WiredTigerKVEngine::hotBackup(OperationContext* opCtx, const std::string&
             fs::path destFile{destPath / filename};
 
             if (fs::exists(srcFile)) {
-                filesList.emplace_back(srcFile, destFile, fs::file_size(srcFile));
+                filesList.emplace_back(srcFile, destFile, fs::file_size(srcFile), fs::last_write_time(srcFile));
             } else {
                 // WT-999: check journal folder.
                 srcFile = srcPath / journalDir / filename;
                 destFile = destPath / journalDir / filename;
                 if (fs::exists(srcFile)) {
-                    filesList.emplace_back(srcFile, destFile, fs::file_size(srcFile));
+                    filesList.emplace_back(srcFile, destFile, fs::file_size(srcFile), fs::last_write_time(srcFile));
                 } else {
                     return Status(ErrorCodes::InvalidPath,
                                   str::stream() << "Cannot find source file for backup :" << filename << ", source path: " << srcPath.string());
@@ -1005,20 +1008,191 @@ Status WiredTigerKVEngine::hotBackup(OperationContext* opCtx, const std::string&
         else
             return wtRCToStatus(ret);
     }
+    // We also need to backup storage engine metadata
+    {
+        const char* storageMetadata = "storage.bson";
+        fs::path srcFile{fs::path{_path} / storageMetadata};
+        fs::path destFile{destPath / storageMetadata};
+        filesList.emplace_back(srcFile, destFile, fs::file_size(srcFile), fs::last_write_time(srcFile));
+    }
 
     // Release global lock (if it was created)
     global.reset();
 
-    // We assume destination dir exists
-    std::set<fs::path> existDirs{destPath};
+    return wtRCToStatus(ret);
+}
 
-    // WT-999: Create journal folder.
-    try {
-        fs::create_directory(destPath / journalDir);
-        existDirs.insert(destPath / journalDir);
-    } catch (const fs::filesystem_error& ex) {
-        return Status(ErrorCodes::InvalidPath, str::stream() << ex.what());
+// Define log redirector for AWS SDK
+namespace {
+
+class MongoLogSystem : public Aws::Utils::Logging::FormattedLogSystem
+{
+public:
+
+    using Base = FormattedLogSystem;
+
+    MongoLogSystem() :
+        Base(Aws::Utils::Logging::LogLevel::Info)
+    {}
+
+    virtual ~MongoLogSystem() {}
+
+protected:
+
+    virtual void ProcessFormattedStatement(Aws::String&& statement) override {
+        log() << statement;
     }
+};
+
+}
+
+//TODO: (15) consider replacing s3params with BSONObj and moving parse code from backup_commands.cpp
+Status WiredTigerKVEngine::hotBackup(OperationContext* opCtx, const percona::S3BackupParameters& s3params) {
+    // list of DBs to backup
+    std::vector<DBTuple> dbList;
+    // list of files to backup
+    std::vector<FileTuple> filesList;
+
+    auto status = _hotBackupPopulateLists(opCtx, s3params.path, dbList, filesList);
+    if (!status.isOK()) {
+        return status;
+    }
+
+    // stream files to S3-compatible storage
+    Aws::SDKOptions options;
+    Aws::InitAPI(options);
+    ON_BLOCK_EXIT([&] { Aws::ShutdownAPI(options); });
+    Aws::Utils::Logging::InitializeAWSLogging(Aws::MakeShared<MongoLogSystem>("AWS"));
+    ON_BLOCK_EXIT([&] { Aws::Utils::Logging::ShutdownAWSLogging(); });
+
+    Aws::Client::ClientConfiguration config;
+    config.endpointOverride = s3params.endpoint; // for example "127.0.0.1:9000"
+    config.scheme = Aws::Http::SchemeMapper::FromString(s3params.scheme.c_str());
+    if (!s3params.region.empty())
+        config.region = s3params.region;
+
+    std::shared_ptr<Aws::Auth::AWSCredentialsProvider> credentialsProvider;
+    if (!s3params.accessKeyId.empty()) {
+        credentialsProvider = Aws::MakeShared<Aws::Auth::SimpleAWSCredentialsProvider>("AWS",
+                                                                                       s3params.accessKeyId,
+                                                                                       s3params.secretAccessKey);
+    } else {
+        // using ProfileConfigFileAWSCredentialsProvider to allow loading of non-default profile
+        credentialsProvider = s3params.profile.empty()
+            ? Aws::MakeShared<Aws::Auth::ProfileConfigFileAWSCredentialsProvider>("AWS", 1000 * 3600)
+            : Aws::MakeShared<Aws::Auth::ProfileConfigFileAWSCredentialsProvider>("AWS", s3params.profile.c_str(), 1000 * 3600);
+    }
+    Aws::S3::S3Client s3_client{credentialsProvider, config, Aws::Client::AWSAuthV4Signer::PayloadSigningPolicy::Never, s3params.useVirtualAddressing};
+
+    // check if bucket already exists and skip create if it does
+    bool bucketExists{false};
+    {
+        auto outcome = s3_client.ListBuckets();
+        if (!outcome.IsSuccess()) {
+            return Status(ErrorCodes::InternalError,
+                          str::stream() << "Cannot list buckets on storage server"
+                                        << " : " << outcome.GetError().GetExceptionName()
+                                        << " : " << outcome.GetError().GetMessage());
+        }
+        for (auto&& bucket : outcome.GetResult().GetBuckets()) {
+            if (bucket.GetName() == s3params.bucket) {
+                bucketExists = true;
+            }
+        }
+    }
+
+    // create bucket for the backup
+    if (!bucketExists) {
+        Aws::S3::Model::CreateBucketRequest request;
+        request.SetBucket(s3params.bucket);
+
+        auto outcome = s3_client.CreateBucket(request);
+        if (!outcome.IsSuccess()) {
+            return Status(ErrorCodes::InvalidPath,
+                          str::stream() << "Cannot create '" << s3params.bucket << "' bucket for the backup"
+                                        << " : " << outcome.GetError().GetExceptionName()
+                                        << " : " << outcome.GetError().GetMessage());
+        }
+        log() << "Successfully created bucket for backup: " << s3params.bucket;
+    }
+
+    // check if target location is empty, fail if not
+    if (bucketExists) {
+        Aws::S3::Model::ListObjectsRequest request;
+        request.SetBucket(s3params.bucket);
+        if (!s3params.path.empty())
+            request.SetPrefix(s3params.path);
+
+        auto outcome = s3_client.ListObjects(request);
+        if (!outcome.IsSuccess()) {
+            return Status(ErrorCodes::InvalidPath,
+                          str::stream() << "Cannot list objects in the target location"
+                                        << " : " << outcome.GetError().GetExceptionName()
+                                        << " : " << outcome.GetError().GetMessage());
+        }
+        const auto root = s3params.path + '/';
+        Aws::Vector<Aws::S3::Model::Object> object_list = outcome.GetResult().GetContents();
+        for (auto const &s3_object : object_list) {
+            if (s3_object.GetKey() != root) {
+                return Status(ErrorCodes::InvalidPath,
+                              str::stream() << "Target location is not empty"
+                                            << " : " << s3params.bucket << '/' << s3params.path);
+            }
+        }
+    }
+
+    // stream files to the bucket
+    for (auto&& file : filesList) {
+        boost::filesystem::path srcFile{std::get<0>(file)};
+        boost::filesystem::path destFile{std::get<1>(file)};
+        auto fsize{std::get<2>(file)};
+
+        LOG(2) << "uploading file: " << srcFile.string() << std::endl;
+        LOG(2) << "      key name: " << destFile.string() << std::endl;
+
+        Aws::S3::Model::PutObjectRequest request;
+        request.SetBucket(s3params.bucket);
+        request.SetKey(destFile.string());
+        request.SetContentLength(fsize);
+        request.SetContentType("application/octet-stream");
+
+        auto fileToUpload = Aws::MakeShared<Aws::FStream>("AWS", srcFile.string(), std::ios_base::in | std::ios_base::binary);
+        if (!fileToUpload) {
+            return Status(ErrorCodes::InvalidPath,
+                          str::stream() << "Cannot open file '" << srcFile.string() << "' for backup"
+                                        << " : " << strerror(errno));
+        }
+        request.SetBody(fileToUpload);
+
+        auto outcome = s3_client.PutObject(request);
+        if (!outcome.IsSuccess()) {
+            return Status(ErrorCodes::InternalError,
+                          str::stream() << "Cannot backup '" << srcFile.string() << "'"
+                                        << " : " << outcome.GetError().GetExceptionName()
+                                        << " : " << outcome.GetError().GetMessage());
+        }
+        LOG(2) << "Successfully uploaded file: " << destFile.string();
+    }
+
+    return Status::OK();
+}
+
+Status WiredTigerKVEngine::hotBackup(OperationContext* opCtx, const std::string& path) {
+    namespace fs = boost::filesystem;
+
+    // list of DBs to backup
+    std::vector<DBTuple> dbList;
+    // list of files to backup
+    std::vector<FileTuple> filesList;
+
+    auto status = _hotBackupPopulateLists(opCtx, path, dbList, filesList);
+    if (!status.isOK()) {
+        return status;
+    }
+
+    // We assume destination dir exists - it is created during command validation
+    fs::path destPath{path};
+    std::set<fs::path> existDirs{destPath};
 
     // Do copy files
     for (auto&& file : filesList) {
@@ -1045,7 +1219,73 @@ Status WiredTigerKVEngine::hotBackup(OperationContext* opCtx, const std::string&
 
     }
 
-    return wtRCToStatus(ret);
+    return Status::OK();
+}
+
+Status WiredTigerKVEngine::hotBackupTar(OperationContext* opCtx, const std::string& path) {
+    namespace fs = boost::filesystem;
+
+    // list of DBs to backup
+    std::vector<DBTuple> dbList;
+    // list of files to backup
+    std::vector<FileTuple> filesList;
+
+    auto status = _hotBackupPopulateLists(opCtx, "", dbList, filesList);
+    if (!status.isOK()) {
+        return status;
+    }
+
+    // Write tar archive
+    struct archive *a{archive_write_new()};
+    ON_BLOCK_EXIT([&] { archive_write_free(a);});
+    archive_write_set_format_pax_restricted(a);
+    archive_write_open_filename(a, path.c_str());
+
+    struct archive_entry *entry{archive_entry_new()};
+    ON_BLOCK_EXIT([&] { archive_entry_free(entry);});
+
+    constexpr int bufsize = 8 * 1024;
+    auto buf = stdx::make_unique<char[]>(bufsize);
+    auto bufptr = buf.get();
+
+    for (auto&& file : filesList) {
+        fs::path srcFile{std::get<0>(file)};
+        fs::path destFile{std::get<1>(file)};
+        auto fsize{std::get<2>(file)};
+        auto fmtime{std::get<3>(file)};
+
+        LOG(2) << "backup of file: " << srcFile.string() << std::endl;
+        LOG(2) << "    storing as: " << destFile.string() << std::endl;
+
+        archive_entry_clear(entry);
+        archive_entry_set_pathname(entry, destFile.string().c_str());
+        archive_entry_set_size(entry, fsize);
+        archive_entry_set_filetype(entry, AE_IFREG);
+        archive_entry_set_perm(entry, 0660);
+        archive_entry_set_mtime(entry, fmtime, 0);
+        archive_write_header(a, entry);
+
+        try {
+            std::ifstream src{};
+            src.exceptions(std::ios::failbit | std::ios::badbit);
+            src.open(srcFile.string(), std::ios::binary);
+
+            while (fsize > 0) {
+                boost::uintmax_t cnt = bufsize;
+                if (fsize < bufsize)
+                    cnt = fsize;
+                src.read(bufptr, cnt);
+                archive_write_data(a, bufptr, cnt);
+                fsize -= cnt;
+            }
+        } catch (const fs::filesystem_error& ex) {
+            return Status(ErrorCodes::InvalidPath, ex.what());
+        } catch (const std::exception& ex) {
+            return Status(ErrorCodes::InternalError, ex.what());
+        }
+    }
+
+    return Status::OK();
 }
 
 void WiredTigerKVEngine::syncSizeInfo(bool sync) const {
@@ -1327,8 +1567,9 @@ bool WiredTigerKVEngine::hasIdent(OperationContext* opCtx, StringData ident) con
 
 bool WiredTigerKVEngine::_hasUri(WT_SESSION* session, const std::string& uri) const {
     // can't use WiredTigerCursor since this is called from constructor.
-    WT_CURSOR* c = NULL;
-    int ret = session->open_cursor(session, "metadata:", NULL, NULL, &c);
+    WT_CURSOR* c = nullptr;
+    // No need for a metadata:create cursor, since it gathers extra information and is slower.
+    int ret = session->open_cursor(session, "metadata:", nullptr, nullptr, &c);
     if (ret == ENOENT)
         return false;
     invariantWTOK(ret);
@@ -1341,6 +1582,7 @@ bool WiredTigerKVEngine::_hasUri(WT_SESSION* session, const std::string& uri) co
 std::vector<std::string> WiredTigerKVEngine::getAllIdents(OperationContext* opCtx) const {
     std::vector<std::string> all;
     int ret;
+    // No need for a metadata:create cursor, since it gathers extra information and is slower.
     WiredTigerCursor cursor("metadata:", WiredTigerSession::kMetadataTableId, false, opCtx);
     WT_CURSOR* c = cursor.get();
     if (!c)
