@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -41,9 +42,6 @@
 #include "mongo/db/concurrency/write_conflict_exception.h"
 #include "mongo/db/json.h"
 #include "mongo/db/operation_context_noop.h"
-#include "mongo/db/repl/repl_settings.h"
-#include "mongo/db/repl/replication_coordinator_mock.h"
-#include "mongo/db/service_context.h"
 #include "mongo/db/storage/kv/kv_engine_test_harness.h"
 #include "mongo/db/storage/kv/kv_prefix.h"
 #include "mongo/db/storage/record_store_test_harness.h"
@@ -54,6 +52,7 @@
 #include "mongo/db/storage/wiredtiger/wiredtiger_session_cache.h"
 #include "mongo/db/storage/wiredtiger/wiredtiger_size_storer.h"
 #include "mongo/db/storage/wiredtiger/wiredtiger_util.h"
+#include "mongo/stdx/memory.h"
 #include "mongo/unittest/temp_dir.h"
 #include "mongo/unittest/unittest.h"
 #include "mongo/util/clock_source_mock.h"
@@ -69,7 +68,10 @@ using std::unique_ptr;
 
 class WiredTigerHarnessHelper final : public RecordStoreHarnessHelper {
 public:
-    WiredTigerHarnessHelper() : WiredTigerHarnessHelper(""_sd) {}
+    WiredTigerHarnessHelper()
+        : _dbpath("wt_test"),
+          _engine(
+              kWiredTigerEngineName, _dbpath.path(), &_cs, "", 1, 0, false, false, false, false) {}
 
     WiredTigerHarnessHelper(StringData extraStrings)
         : _dbpath("wt_test"),
@@ -82,12 +84,8 @@ public:
                   false,
                   false,
                   false,
-                  false) {
-        repl::ReplicationCoordinator::set(serviceContext(),
-                                          std::make_unique<repl::ReplicationCoordinatorMock>(
-                                              serviceContext(), repl::ReplSettings()));
-        _engine.notifyStartupComplete();
-    }
+                  false) {}
+
 
     ~WiredTigerHarnessHelper() {}
 
@@ -97,9 +95,9 @@ public:
 
     virtual std::unique_ptr<RecordStore> newNonCappedRecordStore(const std::string& ns) {
         WiredTigerRecoveryUnit* ru =
-            checked_cast<WiredTigerRecoveryUnit*>(_engine.newRecoveryUnit());
+            dynamic_cast<WiredTigerRecoveryUnit*>(_engine.newRecoveryUnit());
         OperationContextNoop opCtx(ru);
-        string uri = WiredTigerKVEngine::kTableUriPrefix + ns;
+        string uri = "table:" + ns;
 
         const bool prefixed = false;
         StatusWith<std::string> result = WiredTigerRecordStore::generateCreateString(
@@ -116,7 +114,7 @@ public:
 
         WiredTigerRecordStore::Params params;
         params.ns = ns;
-        params.ident = ns;
+        params.uri = uri;
         params.engineName = kWiredTigerEngineName;
         params.isCapped = false;
         params.isEphemeral = false;
@@ -124,9 +122,8 @@ public:
         params.cappedMaxDocs = -1;
         params.cappedCallback = nullptr;
         params.sizeStorer = nullptr;
-        params.tracksSizeAdjustments = true;
 
-        auto ret = std::make_unique<StandardWiredTigerRecordStore>(&_engine, &opCtx, params);
+        auto ret = stdx::make_unique<StandardWiredTigerRecordStore>(&_engine, &opCtx, params);
         ret->postConstructorInit(&opCtx);
         return std::move(ret);
     }
@@ -142,8 +139,7 @@ public:
         WiredTigerRecoveryUnit* ru =
             dynamic_cast<WiredTigerRecoveryUnit*>(_engine.newRecoveryUnit());
         OperationContextNoop opCtx(ru);
-        string ident = "a.b";
-        string uri = WiredTigerKVEngine::kTableUriPrefix + "a.b";
+        string uri = "table:a.b";
 
         CollectionOptions options;
         options.capped = true;
@@ -163,7 +159,7 @@ public:
 
         WiredTigerRecordStore::Params params;
         params.ns = ns;
-        params.ident = ident;
+        params.uri = uri;
         params.engineName = kWiredTigerEngineName;
         params.isCapped = true;
         params.isEphemeral = false;
@@ -171,9 +167,18 @@ public:
         params.cappedMaxDocs = cappedMaxDocs;
         params.cappedCallback = nullptr;
         params.sizeStorer = nullptr;
-        params.tracksSizeAdjustments = true;
 
-        auto ret = std::make_unique<StandardWiredTigerRecordStore>(&_engine, &opCtx, params);
+        auto ret = stdx::make_unique<StandardWiredTigerRecordStore>(&_engine, &opCtx, params);
+
+        // Opening this reverse cursor is not normally required, however the call to
+        // postConstructorInit depends on existing open transaction that is not reading at the oplog
+        // visibility timestamp (i.e. using a reverse cursor). This is here to comply with that
+        // assumption to make the test pass, but would otherwise not be an issue in a normal
+        // circumstances, because the WiredTigerOplogManager does this already.
+        {
+            std::unique_ptr<SeekableRecordCursor> cursor =
+                ret->getCursor(&opCtx, /*forward=*/false);
+        }
         ret->postConstructorInit(&opCtx);
         return std::move(ret);
     }
@@ -197,12 +202,12 @@ private:
     WiredTigerKVEngine _engine;
 };
 
-std::unique_ptr<RecordStoreHarnessHelper> makeWTRSHarnessHelper() {
-    return std::make_unique<WiredTigerHarnessHelper>();
+std::unique_ptr<HarnessHelper> makeHarnessHelper() {
+    return stdx::make_unique<WiredTigerHarnessHelper>();
 }
 
-MONGO_INITIALIZER(RegisterRecordStoreHarnessFactory)(InitializerContext* const) {
-    mongo::registerRecordStoreHarnessHelperFactory(makeWTRSHarnessHelper);
+MONGO_INITIALIZER(RegisterHarnessFactory)(InitializerContext* const) {
+    mongo::registerHarnessHelperFactory(makeHarnessHelper);
     return Status::OK();
 }
 
@@ -218,10 +223,9 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
     unique_ptr<WiredTigerHarnessHelper> harnessHelper(new WiredTigerHarnessHelper());
     unique_ptr<RecordStore> rs(harnessHelper->newNonCappedRecordStore());
 
-    string ident = rs->getIdent();
     string uri = checked_cast<WiredTigerRecordStore*>(rs.get())->getURI();
 
-    string indexUri = WiredTigerKVEngine::kTableUriPrefix + "myindex";
+    string indexUri = "table:myindex";
     const bool enableWtLogging = false;
     WiredTigerSizeStorer ss(harnessHelper->conn(), indexUri, enableWtLogging);
     checked_cast<WiredTigerRecordStore*>(rs.get())->setSizeStorer(&ss);
@@ -233,7 +237,8 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
         {
             WriteUnitOfWork uow(opCtx.get());
             for (int i = 0; i < N; i++) {
-                StatusWith<RecordId> res = rs->insertRecord(opCtx.get(), "a", 2, Timestamp());
+                StatusWith<RecordId> res =
+                    rs->insertRecord(opCtx.get(), "a", 2, Timestamp(), false);
                 ASSERT_OK(res.getStatus());
             }
             uow.commit();
@@ -245,11 +250,10 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
         ASSERT_EQUALS(N, rs->numRecords(opCtx.get()));
     }
 
-    rs.reset(nullptr);
+    rs.reset(NULL);
 
     {
-        ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-        auto& info = *ss.load(opCtx.get(), uri);
+        auto& info = *ss.load(uri);
         ASSERT_EQUALS(N, info.numRecords.load());
     }
 
@@ -257,7 +261,7 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
         ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
         WiredTigerRecordStore::Params params;
         params.ns = "a.b"_sd;
-        params.ident = ident;
+        params.uri = uri;
         params.engineName = kWiredTigerEngineName;
         params.isCapped = false;
         params.isEphemeral = false;
@@ -265,7 +269,6 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
         params.cappedMaxDocs = -1;
         params.cappedCallback = nullptr;
         params.sizeStorer = &ss;
-        params.tracksSizeAdjustments = true;
 
         auto ret = new StandardWiredTigerRecordStore(nullptr, opCtx.get(), params);
         ret->postConstructorInit(opCtx.get());
@@ -295,29 +298,60 @@ TEST(WiredTigerRecordStoreTest, SizeStorer1) {
         ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
         const bool enableWtLogging = false;
         WiredTigerSizeStorer ss2(harnessHelper->conn(), indexUri, enableWtLogging);
-        auto info = ss2.load(opCtx.get(), uri);
+        auto info = ss2.load(uri);
         ASSERT_EQUALS(N, info->numRecords.load());
     }
 
     rs.reset(nullptr);  // this has to be deleted before ss
 }
 
-class SizeStorerUpdateTest : public mongo::unittest::Test {
+class GoodValidateAdaptor : public ValidateAdaptor {
+public:
+    virtual Status validate(const RecordId& recordId, const RecordData& record, size_t* dataSize) {
+        *dataSize = static_cast<size_t>(record.size());
+        return Status::OK();
+    }
+};
+
+class BadValidateAdaptor : public ValidateAdaptor {
+public:
+    virtual Status validate(const RecordId& recordId, const RecordData& record, size_t* dataSize) {
+        *dataSize = static_cast<size_t>(record.size());
+        return Status(ErrorCodes::UnknownError, "");
+    }
+};
+
+class SizeStorerValidateTest : public mongo::unittest::Test {
 private:
     virtual void setUp() {
         harnessHelper.reset(new WiredTigerHarnessHelper());
         const bool enableWtLogging = false;
         sizeStorer.reset(
-            new WiredTigerSizeStorer(harnessHelper->conn(),
-                                     WiredTigerKVEngine::kTableUriPrefix + "sizeStorer",
-                                     enableWtLogging));
+            new WiredTigerSizeStorer(harnessHelper->conn(), "table:sizeStorer", enableWtLogging));
         rs = harnessHelper->newNonCappedRecordStore();
         WiredTigerRecordStore* wtrs = checked_cast<WiredTigerRecordStore*>(rs.get());
         wtrs->setSizeStorer(sizeStorer.get());
-        ident = wtrs->getIdent();
         uri = wtrs->getURI();
+
+        expectedNumRecords = 100;
+        expectedDataSize = expectedNumRecords * 2;
+        {
+            ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
+            WriteUnitOfWork uow(opCtx.get());
+            for (int i = 0; i < expectedNumRecords; i++) {
+                ASSERT_OK(rs->insertRecord(opCtx.get(), "a", 2, Timestamp(), false).getStatus());
+            }
+            uow.commit();
+        }
+        auto info = sizeStorer->load(uri);
+        info->numRecords.store(0);
+        info->dataSize.store(0);
+        sizeStorer->store(uri, info);
     }
     virtual void tearDown() {
+        expectedNumRecords = 0;
+        expectedDataSize = 0;
+
         rs.reset(nullptr);
         sizeStorer->flush(false);
         sizeStorer.reset(nullptr);
@@ -325,29 +359,103 @@ private:
     }
 
 protected:
-    long long getNumRecords(OperationContext* opCtx) const {
-        return sizeStorer->load(opCtx, uri)->numRecords.load();
+    long long getNumRecords() const {
+        return sizeStorer->load(uri)->numRecords.load();
     }
 
-    long long getDataSize(OperationContext* opCtx) const {
-        return sizeStorer->load(opCtx, uri)->dataSize.load();
+    long long getDataSize() const {
+        return sizeStorer->load(uri)->dataSize.load();
     }
 
     std::unique_ptr<WiredTigerHarnessHelper> harnessHelper;
     std::unique_ptr<WiredTigerSizeStorer> sizeStorer;
     std::unique_ptr<RecordStore> rs;
-    std::string ident;
     std::string uri;
+
+    long long expectedNumRecords;
+    long long expectedDataSize;
 };
 
 // Basic validation - size storer data is updated.
-TEST_F(SizeStorerUpdateTest, Basic) {
+TEST_F(SizeStorerValidateTest, Basic) {
     ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
-    long long val = 5;
-    rs->updateStatsAfterRepair(opCtx.get(), val, val);
-    ASSERT_EQUALS(getNumRecords(opCtx.get()), val);
-    ASSERT_EQUALS(getDataSize(opCtx.get()), val);
+    GoodValidateAdaptor adaptor;
+    ValidateResults results;
+    BSONObjBuilder output;
+    ASSERT_OK(rs->validate(opCtx.get(), kValidateIndex, &adaptor, &results, &output));
+    BSONObj obj = output.obj();
+    ASSERT_EQUALS(expectedNumRecords, obj.getIntField("nrecords"));
+    ASSERT_EQUALS(expectedNumRecords, getNumRecords());
+    ASSERT_EQUALS(expectedDataSize, getDataSize());
+}
+
+// Full validation - size storer data is updated.
+TEST_F(SizeStorerValidateTest, FullWithGoodAdaptor) {
+    ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
+    GoodValidateAdaptor adaptor;
+    ValidateResults results;
+    BSONObjBuilder output;
+    ASSERT_OK(rs->validate(opCtx.get(), kValidateFull, &adaptor, &results, &output));
+    BSONObj obj = output.obj();
+    ASSERT_EQUALS(expectedNumRecords, obj.getIntField("nrecords"));
+    ASSERT_EQUALS(expectedNumRecords, getNumRecords());
+    ASSERT_EQUALS(expectedDataSize, getDataSize());
+}
+
+// Full validation with a validation adaptor that fails - size storer data is not updated.
+TEST_F(SizeStorerValidateTest, FullWithBadAdapter) {
+    ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
+    BadValidateAdaptor adaptor;
+    ValidateResults results;
+    BSONObjBuilder output;
+    ASSERT_OK(rs->validate(opCtx.get(), kValidateFull, &adaptor, &results, &output));
+    BSONObj obj = output.obj();
+    ASSERT_EQUALS(expectedNumRecords, obj.getIntField("nrecords"));
+    ASSERT_EQUALS(0, getNumRecords());
+    ASSERT_EQUALS(0, getDataSize());
+}
+
+// Load bad _numRecords and _dataSize values at record store creation.
+TEST_F(SizeStorerValidateTest, InvalidSizeStorerAtCreation) {
+    rs.reset(NULL);
+
+    ServiceContext::UniqueOperationContext opCtx(harnessHelper->newOperationContext());
+    auto info = sizeStorer->load(uri);
+    info->numRecords.store(expectedNumRecords * 2);
+    info->dataSize.store(expectedDataSize * 2);
+    sizeStorer->store(uri, info);
+
+    WiredTigerRecordStore::Params params;
+    params.ns = "a.b"_sd;
+    params.uri = uri;
+    params.engineName = kWiredTigerEngineName;
+    params.isCapped = false;
+    params.isEphemeral = false;
+    params.cappedMaxSize = -1;
+    params.cappedMaxDocs = -1;
+    params.cappedCallback = nullptr;
+    params.sizeStorer = sizeStorer.get();
+
+    auto ret = new StandardWiredTigerRecordStore(nullptr, opCtx.get(), params);
+    ret->postConstructorInit(opCtx.get());
+    rs.reset(ret);
+
+    ASSERT_EQUALS(expectedNumRecords * 2, rs->numRecords(NULL));
+    ASSERT_EQUALS(expectedDataSize * 2, rs->dataSize(NULL));
+
+    // Full validation should fix record and size counters.
+    GoodValidateAdaptor adaptor;
+    ValidateResults results;
+    BSONObjBuilder output;
+    ASSERT_OK(rs->validate(opCtx.get(), kValidateFull, &adaptor, &results, &output));
+    BSONObj obj = output.obj();
+    ASSERT_EQUALS(expectedNumRecords, obj.getIntField("nrecords"));
+    ASSERT_EQUALS(expectedNumRecords, getNumRecords());
+    ASSERT_EQUALS(expectedDataSize, getDataSize());
+
+    ASSERT_EQUALS(expectedNumRecords, rs->numRecords(NULL));
+    ASSERT_EQUALS(expectedDataSize, rs->dataSize(NULL));
 }
 
 }  // namespace
-}  // namespace mongo
+}  // mongo
