@@ -1,32 +1,34 @@
 // ttl.cpp
 
+
 /**
-*    Copyright (C) 2008 10gen Inc.
-*
-*    This program is free software: you can redistribute it and/or  modify
-*    it under the terms of the GNU Affero General Public License, version 3,
-*    as published by the Free Software Foundation.
-*
-*    This program is distributed in the hope that it will be useful,
-*    but WITHOUT ANY WARRANTY; without even the implied warranty of
-*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*    GNU Affero General Public License for more details.
-*
-*    You should have received a copy of the GNU Affero General Public License
-*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*
-*    As a special exception, the copyright holders give permission to link the
-*    code of portions of this program with the OpenSSL library under certain
-*    conditions as described in each individual source file and distribute
-*    linked combinations including the program with the OpenSSL library. You
-*    must comply with the GNU Affero General Public License in all respects for
-*    all of the code used other than as permitted herein. If you modify file(s)
-*    with this exception, you may extend this exception to your version of the
-*    file(s), but you are not obligated to do so. If you do not wish to do so,
-*    delete this exception statement from your version. If you delete this
-*    exception statement from all source files in the program, then also delete
-*    it in the license file.
-*/
+ *    Copyright (C) 2018-present MongoDB, Inc.
+ *
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
+ *
+ *    This program is distributed in the hope that it will be useful,
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *    Server Side Public License for more details.
+ *
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
+ *
+ *    As a special exception, the copyright holders give permission to link the
+ *    code of portions of this program with the OpenSSL library under certain
+ *    conditions as described in each individual source file and distribute
+ *    linked combinations including the program with the OpenSSL library. You
+ *    must comply with the Server Side Public License in all respects for
+ *    all of the code used other than as permitted herein. If you modify file(s)
+ *    with this exception, you may extend this exception to your version of the
+ *    file(s), but you are not obligated to do so. If you do not wish to do so,
+ *    delete this exception statement from your version. If you delete this
+ *    exception statement from all source files in the program, then also delete
+ *    it in the license file.
+ */
 
 #define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kIndex
 
@@ -41,6 +43,7 @@
 #include "mongo/db/catalog/collection_catalog_entry.h"
 #include "mongo/db/catalog/database_catalog_entry.h"
 #include "mongo/db/catalog/database_holder.h"
+#include "mongo/db/catalog/index_catalog.h"
 #include "mongo/db/client.h"
 #include "mongo/db/commands/fsync.h"
 #include "mongo/db/commands/server_status_metric.h"
@@ -48,7 +51,6 @@
 #include "mongo/db/db_raii.h"
 #include "mongo/db/exec/delete.h"
 #include "mongo/db/index/index_descriptor.h"
-#include "mongo/db/matcher/extensions_callback_disallow_extensions.h"
 #include "mongo/db/namespace_string.h"
 #include "mongo/db/ops/insert.h"
 #include "mongo/db/query/internal_plans.h"
@@ -87,15 +89,15 @@ public:
         Client::initThread(name().c_str());
         AuthorizationSession::get(cc())->grantInternalAuthorization(&cc());
 
-        while (!inShutdown()) {
+        while (!globalInShutdownDeprecated()) {
             {
                 MONGO_IDLE_THREAD_BLOCK;
-                sleepsecs(ttlMonitorSleepSecs);
+                sleepsecs(ttlMonitorSleepSecs.load());
             }
 
             LOG(3) << "thread awake";
 
-            if (!ttlMonitorEnabled) {
+            if (!ttlMonitorEnabled.load()) {
                 LOG(1) << "disabled";
                 continue;
             }
@@ -109,7 +111,7 @@ public:
 
             try {
                 doTTLPass();
-            } catch (const WriteConflictException& e) {
+            } catch (const WriteConflictException&) {
                 LOG(1) << "got WriteConflictException";
             }
         }
@@ -117,8 +119,8 @@ public:
 
 private:
     void doTTLPass() {
-        const ServiceContext::UniqueOperationContext txnPtr = cc().makeOperationContext();
-        OperationContext& txn = *txnPtr;
+        const ServiceContext::UniqueOperationContext opCtxPtr = cc().makeOperationContext();
+        OperationContext& opCtx = *opCtxPtr;
 
         // If part of replSet but not in a readable state (e.g. during initial sync), skip.
         if (repl::getGlobalReplicationCoordinator()->getReplicationMode() ==
@@ -134,9 +136,8 @@ private:
 
         // Get all TTL indexes from every collection.
         for (const std::string& collectionNS : ttlCollections) {
-            ScopedTransaction st(&txn, MODE_IS);
             NamespaceString collectionNSS(collectionNS);
-            AutoGetCollection autoGetCollection(&txn, collectionNSS, MODE_IS);
+            AutoGetCollection autoGetCollection(&opCtx, collectionNSS, MODE_IS);
             Collection* coll = autoGetCollection.getCollection();
             if (!coll) {
                 // Skip since collection has been dropped.
@@ -145,9 +146,9 @@ private:
 
             CollectionCatalogEntry* collEntry = coll->getCatalogEntry();
             std::vector<std::string> indexNames;
-            collEntry->getAllIndexes(&txn, &indexNames);
+            collEntry->getAllIndexes(&opCtx, &indexNames);
             for (const std::string& name : indexNames) {
-                BSONObj spec = collEntry->getIndexSpec(&txn, name);
+                BSONObj spec = collEntry->getIndexSpec(&opCtx, name);
                 if (spec.hasField(secondsExpireField)) {
                     ttlIndexes.push_back(spec.getOwned());
                 }
@@ -156,7 +157,7 @@ private:
 
         for (const BSONObj& idx : ttlIndexes) {
             try {
-                doTTLForIndex(&txn, idx);
+                doTTLForIndex(&opCtx, idx);
             } catch (const DBException& dbex) {
                 error() << "Error processing ttl index: " << idx << " -- " << dbex.toString();
                 // Continue on to the next index.
@@ -169,8 +170,11 @@ private:
      * Remove documents from the collection using the specified TTL index after a sufficient amount
      * of time has passed according to its expiry specification.
      */
-    void doTTLForIndex(OperationContext* txn, BSONObj idx) {
+    void doTTLForIndex(OperationContext* opCtx, BSONObj idx) {
         const NamespaceString collectionNSS(idx["ns"].String());
+        if (collectionNSS.isDropPendingNamespace()) {
+            return;
+        }
         if (!userAllowedWriteNS(collectionNSS).isOK()) {
             error() << "namespace '" << collectionNSS
                     << "' doesn't allow deletes, skipping ttl job for: " << idx;
@@ -186,18 +190,18 @@ private:
 
         LOG(1) << "ns: " << collectionNSS << " key: " << key << " name: " << name;
 
-        AutoGetCollection autoGetCollection(txn, collectionNSS, MODE_IX);
+        AutoGetCollection autoGetCollection(opCtx, collectionNSS, MODE_IX);
         Collection* collection = autoGetCollection.getCollection();
         if (!collection) {
             // Collection was dropped.
             return;
         }
 
-        if (!repl::getGlobalReplicationCoordinator()->canAcceptWritesFor(collectionNSS)) {
+        if (!repl::getGlobalReplicationCoordinator()->canAcceptWritesFor(opCtx, collectionNSS)) {
             return;
         }
 
-        IndexDescriptor* desc = collection->getIndexCatalog()->findIndexByName(txn, name);
+        IndexDescriptor* desc = collection->getIndexCatalog()->findIndexByName(opCtx, name);
         if (!desc) {
             LOG(1) << "index not found (index build in progress? index dropped?), skipping "
                    << "ttl job for: " << idx;
@@ -240,16 +244,15 @@ private:
             BSON(keyFieldName << BSON("$gte" << kDawnOfTime << "$lte" << expirationTime));
         auto qr = stdx::make_unique<QueryRequest>(collectionNSS);
         qr->setFilter(query);
-        auto canonicalQuery = CanonicalQuery::canonicalize(
-            txn, std::move(qr), ExtensionsCallbackDisallowExtensions());
+        auto canonicalQuery = CanonicalQuery::canonicalize(opCtx, std::move(qr));
         invariantOK(canonicalQuery.getStatus());
 
         DeleteStageParams params;
         params.isMulti = true;
         params.canonicalQuery = canonicalQuery.getValue().get();
 
-        std::unique_ptr<PlanExecutor> exec =
-            InternalPlanner::deleteWithIndexScan(txn,
+        auto exec =
+            InternalPlanner::deleteWithIndexScan(opCtx,
                                                  collection,
                                                  params,
                                                  desc,
