@@ -1,32 +1,34 @@
 // basictests.cpp : basic unit tests
 //
 
+
 /**
- *    Copyright (C) 2009 10gen Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects
- *    for all of the code used other than as permitted herein. If you modify
- *    file(s) with this exception, you may extend this exception to your
- *    version of the file(s), but you are not obligated to do so. If you do not
- *    wish to do so, delete this exception statement from your version. If you
- *    delete this exception statement from all source files in the program,
- *    then also delete it in the license file.
+ *    must comply with the Server Side Public License in all respects for
+ *    all of the code used other than as permitted herein. If you modify file(s)
+ *    with this exception, you may extend this exception to your version of the
+ *    file(s), but you are not obligated to do so. If you do not wish to do so,
+ *    delete this exception statement from your version. If you delete this
+ *    exception statement from all source files in the program, then also delete
+ *    it in the license file.
  */
 
 #include "mongo/platform/basic.h"
@@ -35,7 +37,7 @@
 
 #include "mongo/db/client.h"
 #include "mongo/db/storage/mmap_v1/compress.h"
-#include "mongo/db/storage/paths.h"
+#include "mongo/db/storage/mmap_v1/paths.h"
 #include "mongo/dbtests/dbtests.h"
 #include "mongo/util/base64.h"
 #include "mongo/util/queue.h"
@@ -43,6 +45,7 @@
 #include "mongo/util/text.h"
 #include "mongo/util/thread_safe_string.h"
 #include "mongo/util/time_support.h"
+#include "mongo/util/timer.h"
 
 namespace BasicTests {
 
@@ -61,15 +64,12 @@ public:
     void run() {
         int first = 0;
         int second = 0;
-        int third = 0;
         for (int i = 0; i < 128; ++i) {
             incRarely(first);
             incRarely2(second);
-            ONCE++ third;
         }
         ASSERT_EQUALS(1, first);
         ASSERT_EQUALS(1, second);
-        ASSERT_EQUALS(1, third);
     }
 
 private:
@@ -215,7 +215,7 @@ public:
         ASSERT_EQUALS("999", sb.str());
     }
 };
-}
+}  // namespace stringbuildertests
 
 class SleepBackoffTest {
 public:
@@ -358,7 +358,7 @@ public:
         Timer t;
         int x;
         ASSERT(!q.blockingPop(x, 5));
-        ASSERT(t.seconds() > 3 && t.seconds() < 9);
+        ASSERT(t.seconds() > 3);
     }
 };
 
