@@ -1,51 +1,107 @@
+
 /**
- *    Copyright (C) 2010 10gen Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects
- *    for all of the code used other than as permitted herein. If you modify
- *    file(s) with this exception, you may extend this exception to your
- *    version of the file(s), but you are not obligated to do so. If you do not
- *    wish to do so, delete this exception statement from your version. If you
- *    delete this exception statement from all source files in the program,
- *    then also delete it in the license file.
+ *    must comply with the Server Side Public License in all respects for
+ *    all of the code used other than as permitted herein. If you modify file(s)
+ *    with this exception, you may extend this exception to your version of the
+ *    file(s), but you are not obligated to do so. If you do not wish to do so,
+ *    delete this exception statement from your version. If you delete this
+ *    exception statement from all source files in the program, then also delete
+ *    it in the license file.
  */
 
 #include "mongo/platform/basic.h"
 
+#include <unordered_set>
+
 #include "mongo/db/client.h"
+#include "mongo/db/commands.h"
 #include "mongo/db/concurrency/d_concurrency.h"
 #include "mongo/db/dbdirectclient.h"
 #include "mongo/db/operation_context.h"
 #include "mongo/dbtests/dbtests.h"
+#include "mongo/util/net/op_msg.h"
 
 using namespace mongo;
 
 namespace CommandTests {
 
+TEST(CommandTests, InputDocumentSequeceWorksEndToEnd) {
+    const auto opCtxHolder = cc().makeOperationContext();
+    auto opCtx = opCtxHolder.get();
+
+    NamespaceString ns("test", "doc_seq");
+    DBDirectClient db(opCtx);
+    db.dropCollection(ns.ns());
+    ASSERT_EQ(db.count(ns.ns()), 0u);
+
+    OpMsgRequest request;
+    request.body = BSON("insert" << ns.coll() << "$db" << ns.db());
+    request.sequences = {{"documents",
+                          {
+                              BSON("_id" << 1),
+                              BSON("_id" << 2),
+                              BSON("_id" << 3),
+                              BSON("_id" << 4),
+                              BSON("_id" << 5),
+                          }}};
+
+    const auto reply = db.runCommand(std::move(request));
+    ASSERT_EQ(int(reply->getProtocol()), int(rpc::Protocol::kOpMsg));
+    ASSERT_BSONOBJ_EQ(reply->getCommandReply(), BSON("n" << 5 << "ok" << 1.0));
+    ASSERT_EQ(db.count(ns.ns()), 5u);
+}
+
 using std::string;
 
+/**
+ * Default suite base, unless otherwise overridden in test specific namespace.
+ */
+class Base {
+public:
+    Base() : db(&_opCtx) {
+        db.dropCollection(ns());
+    }
+
+    const char* ns() {
+        return "test.testCollection";
+    }
+    const char* nsDb() {
+        return "test";
+    }
+    const char* nsColl() {
+        return "testCollection";
+    }
+
+    const ServiceContext::UniqueOperationContext _txnPtr = cc().makeOperationContext();
+    OperationContext& _opCtx = *_txnPtr;
+    DBDirectClient db;
+};
+
 // one namespace per command
 namespace FileMD5 {
 struct Base {
-    Base() : db(&_txn) {
+    Base() : db(&_opCtx) {
         db.dropCollection(ns());
-        ASSERT_OK(dbtests::createIndex(&_txn, ns(), BSON("files_id" << 1 << "n" << 1)));
+        ASSERT_OK(dbtests::createIndex(&_opCtx, ns(), BSON("files_id" << 1 << "n" << 1)));
     }
 
     const char* ns() {
@@ -53,7 +109,7 @@ struct Base {
     }
 
     const ServiceContext::UniqueOperationContext _txnPtr = cc().makeOperationContext();
-    OperationContext& _txn = *_txnPtr;
+    OperationContext& _opCtx = *_txnPtr;
     DBDirectClient db;
 };
 struct Type0 : Base {
@@ -112,27 +168,6 @@ namespace SymbolArgument {
 // This is a historical quirk that we shall support until corrected versions of the Ruby driver
 // can be distributed. Retain these tests until MongoDB 3.0
 
-class Base {
-public:
-    Base() : db(&_txn) {
-        db.dropCollection(ns());
-    }
-
-    const char* ns() {
-        return "test.symbolarg";
-    }
-    const char* nsDb() {
-        return "test";
-    }
-    const char* nsColl() {
-        return "symbolarg";
-    }
-
-    const ServiceContext::UniqueOperationContext _txnPtr = cc().makeOperationContext();
-    OperationContext& _txn = *_txnPtr;
-    DBDirectClient db;
-};
-
 class Drop : Base {
 public:
     void run() {
@@ -302,7 +337,25 @@ public:
     }
 };
 
-}  // SymbolArgument
+}  // namespace SymbolArgument
+
+/**
+ * Tests that the 'rolesInfo' command does not return duplicate field names.
+ */
+class RolesInfoShouldNotReturnDuplicateFieldNames : Base {
+public:
+    void run() {
+        BSONObj result;
+        bool ok = db.runCommand(nsDb(), BSON("rolesInfo" << 1), result);
+        ASSERT(ok);
+
+        stdx::unordered_set<std::string> observedFields;
+        for (const auto& field : result) {
+            ASSERT(observedFields.find(field) == observedFields.end());
+            observedFields.insert(field);
+        }
+    }
+};
 
 class All : public Suite {
 public:
@@ -319,6 +372,7 @@ public:
         add<SymbolArgument::GeoSearch>();
         add<SymbolArgument::CreateIndexWithNoKey>();
         add<SymbolArgument::CreateIndexWithDuplicateKey>();
+        add<RolesInfoShouldNotReturnDuplicateFieldNames>();
     }
 };
 
