@@ -1,32 +1,34 @@
 // jstests.cpp
 //
 
+
 /**
- *    Copyright (C) 2009-2014 MongoDB Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects
- *    for all of the code used other than as permitted herein. If you modify
- *    file(s) with this exception, you may extend this exception to your
- *    version of the file(s), but you are not obligated to do so. If you do not
- *    wish to do so, delete this exception statement from your version. If you
- *    delete this exception statement from all source files in the program,
- *    then also delete it in the license file.
+ *    must comply with the Server Side Public License in all respects for
+ *    all of the code used other than as permitted herein. If you modify file(s)
+ *    with this exception, you may extend this exception to your version of the
+ *    file(s), but you are not obligated to do so. If you do not wish to do so,
+ *    delete this exception statement from your version. If you delete this
+ *    exception statement from all source files in the program, then also delete
+ *    it in the license file.
  */
 
 #define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kDefault
@@ -37,14 +39,16 @@
 #include <limits>
 
 #include "mongo/base/parse_number.h"
+#include "mongo/db/client.h"
 #include "mongo/db/dbdirectclient.h"
 #include "mongo/db/json.h"
-#include "mongo/db/operation_context_impl.h"
 #include "mongo/dbtests/dbtests.h"
 #include "mongo/platform/decimal128.h"
 #include "mongo/scripting/engine.h"
 #include "mongo/util/concurrency/thread_name.h"
+#include "mongo/util/future.h"
 #include "mongo/util/log.h"
+#include "mongo/util/time_support.h"
 #include "mongo/util/timer.h"
 
 using std::cout;
@@ -60,7 +64,7 @@ class BuiltinTests {
 public:
     void run() {
         // Run any tests included with the scripting engine
-        globalScriptEngine->runTest();
+        getGlobalScriptEngine()->runTest();
     }
 };
 
@@ -68,7 +72,7 @@ class BasicScope {
 public:
     void run() {
         unique_ptr<Scope> s;
-        s.reset(globalScriptEngine->newScope());
+        s.reset(getGlobalScriptEngine()->newScope());
 
         s->setNumber("x", 5);
         ASSERT(5 == s->getNumber("x"));
@@ -92,7 +96,7 @@ public:
     void run() {
         /* Currently reset does not clear data in v8 or spidermonkey scopes.  See SECURITY-10
         unique_ptr<Scope> s;
-        s.reset( globalScriptEngine->newScope() );
+        s.reset( getGlobalScriptEngine()->newScope() );
 
         s->setBoolean( "x" , true );
         ASSERT( s->getBoolean( "x" ) );
@@ -108,7 +112,7 @@ public:
     void run() {
         // Test falsy javascript values
         unique_ptr<Scope> s;
-        s.reset(globalScriptEngine->newScope());
+        s.reset(getGlobalScriptEngine()->newScope());
 
         ASSERT(!s->getBoolean("notSet"));
 
@@ -130,7 +134,7 @@ public:
 class SimpleFunctions {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         s->invoke("x=5;", 0, 0);
         ASSERT(5 == s->getNumber("x"));
@@ -160,7 +164,7 @@ class LogRecordingScope {
 public:
     LogRecordingScope()
         : _logged(false),
-          _threadName(mongo::getThreadName()),
+          _threadName(mongo::getThreadName().toString()),
           _handle(mongo::logger::globalLogDomain()->attachAppender(
               mongo::logger::MessageLogDomain::AppenderAutoPtr(new Tee(this)))) {}
     ~LogRecordingScope() {
@@ -196,7 +200,7 @@ private:
 class ExecLogError {
 public:
     void run() {
-        unique_ptr<Scope> scope(globalScriptEngine->newScope());
+        unique_ptr<Scope> scope(getGlobalScriptEngine()->newScope());
 
         // No error is logged when reportError == false.
         ASSERT(!scope->exec("notAFunction()", "foo", false, false, false));
@@ -212,7 +216,7 @@ public:
         // Don't check if we're using SpiderMonkey. Our threading model breaks
         // this test
         // TODO: figure out a way to check for SpiderMonkey
-        auto ivs = globalScriptEngine->getInterpreterVersionString();
+        auto ivs = getGlobalScriptEngine()->getInterpreterVersionString();
         std::string prefix("MozJS");
         if (ivs.compare(0, prefix.length(), prefix) != 0) {
             ASSERT(_logger.logged());
@@ -227,7 +231,7 @@ private:
 class InvokeLogError {
 public:
     void run() {
-        unique_ptr<Scope> scope(globalScriptEngine->newScope());
+        unique_ptr<Scope> scope(getGlobalScriptEngine()->newScope());
 
         // No error is logged for a valid statement.
         ASSERT_EQUALS(0, scope->invoke("validStatement = true", 0, 0));
@@ -243,7 +247,7 @@ public:
         // Don't check if we're using SpiderMonkey. Our threading model breaks
         // this test
         // TODO: figure out a way to check for SpiderMonkey
-        auto ivs = globalScriptEngine->getInterpreterVersionString();
+        auto ivs = getGlobalScriptEngine()->getInterpreterVersionString();
         std::string prefix("MozJS");
         if (ivs.compare(0, prefix.length(), prefix) != 0) {
             ASSERT(_logger.logged());
@@ -257,7 +261,7 @@ private:
 class ObjectMapping {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         BSONObj o = BSON("x" << 17.0 << "y"
                              << "eliot"
@@ -314,7 +318,7 @@ public:
 class ObjectDecoding {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         s->invoke("z = { num : 1 };", 0, 0);
         BSONObj out = s->getObject("z");
@@ -337,7 +341,7 @@ class JSOIDTests {
 public:
     void run() {
 #ifdef MOZJS
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         s->localConnect("blah");
 
@@ -368,7 +372,7 @@ public:
 class SetImplicit {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         BSONObj o = BSON("foo"
                          << "bar");
@@ -390,22 +394,23 @@ public:
 class ObjectModReadonlyTests {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         BSONObj o = BSON("x" << 17 << "y"
                              << "eliot"
                              << "z"
                              << "sara"
-                             << "zz" << BSONObj());
+                             << "zz"
+                             << BSONObj());
         s->setObject("blah", o, true);
 
         BSONObj out;
 
-        ASSERT_THROWS(s->invoke("blah.y = 'e'", 0, 0), mongo::UserException);
-        ASSERT_THROWS(s->invoke("blah.a = 19;", 0, 0), mongo::UserException);
-        ASSERT_THROWS(s->invoke("blah.zz.a = 19;", 0, 0), mongo::UserException);
-        ASSERT_THROWS(s->invoke("blah.zz = { a : 19 };", 0, 0), mongo::UserException);
-        ASSERT_THROWS(s->invoke("delete blah['x']", 0, 0), mongo::UserException);
+        ASSERT_THROWS(s->invoke("blah.y = 'e'", 0, 0), mongo::AssertionException);
+        ASSERT_THROWS(s->invoke("blah.a = 19;", 0, 0), mongo::AssertionException);
+        ASSERT_THROWS(s->invoke("blah.zz.a = 19;", 0, 0), mongo::AssertionException);
+        ASSERT_THROWS(s->invoke("blah.zz = { a : 19 };", 0, 0), mongo::AssertionException);
+        ASSERT_THROWS(s->invoke("delete blah['x']", 0, 0), mongo::AssertionException);
 
         // read-only object itself can be overwritten
         s->invoke("blah = {}", 0, 0);
@@ -427,7 +432,7 @@ public:
 class OtherJSTypes {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         {
             // date
@@ -524,7 +529,7 @@ public:
 class SpecialDBTypes {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         BSONObjBuilder b;
         b.appendTimestamp("a", 123456789);
@@ -558,7 +563,7 @@ public:
 class TypeConservation {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         //  --  A  --
 
@@ -656,7 +661,7 @@ public:
 class NumberLong {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
         BSONObjBuilder b;
         long long val = (long long)(0xbabadeadbeefbaddULL);
         b.append("a", val);
@@ -698,7 +703,7 @@ public:
         s->setObject("z", BSON("z" << (long long)(4)));
         ASSERT(s->exec("y = {y:z.z.top}", "foo", false, true, false));
         out = s->getObject("y");
-        ASSERT_EQUALS(Undefined, out.firstElement().type());
+        ASSERT_EQUALS(NumberDouble, out.firstElement().type());
 
         ASSERT(s->exec("x = {x:z.z.floatApprox}", "foo", false, true, false));
         out = s->getObject("x");
@@ -715,7 +720,7 @@ public:
 class NumberLong2 {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         BSONObj in;
         {
@@ -735,14 +740,14 @@ public:
 
         ASSERT(s->exec((string) "y = " + outString, "foo2", false, true, false));
         BSONObj out = s->getObject("y");
-        ASSERT_EQUALS(in, out);
+        ASSERT_BSONOBJ_EQ(in, out);
     }
 };
 
 class NumberLongUnderLimit {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         BSONObjBuilder b;
         // limit is 2^53
@@ -788,7 +793,7 @@ public:
 class NumberDecimal {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
         BSONObjBuilder b;
         Decimal128 val = Decimal128("2.010");
         b.append("a", val);
@@ -817,7 +822,7 @@ public:
 class NumberDecimalGetFromScope {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
         ASSERT(s->exec("a = 5;", "a", false, true, false));
         ASSERT_TRUE(Decimal128(5).isEqual(s->getNumberDecimal("a")));
     }
@@ -826,7 +831,7 @@ public:
 class NumberDecimalBigObject {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         BSONObj in;
         {
@@ -846,14 +851,14 @@ public:
 
         ASSERT(s->exec((string) "y = " + outString, "foo2", false, true, false));
         BSONObj out = s->getObject("y");
-        ASSERT_EQUALS(in, out);
+        ASSERT_BSONOBJ_EQ(in, out);
     }
 };
 
 class MaxTimestamp {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         // Timestamp 't' component can exceed max for int32_t.
         BSONObj in;
@@ -882,7 +887,7 @@ public:
     }
 
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         for (int i = 5; i < 100; i += 10) {
             s->setObject("a", build(i), false);
@@ -900,7 +905,7 @@ public:
 class ExecTimeout {
 public:
     void run() {
-        unique_ptr<Scope> scope(globalScriptEngine->newScope());
+        unique_ptr<Scope> scope(getGlobalScriptEngine()->newScope());
 
         // assert timeout occurred
         ASSERT(!scope->exec("var a = 1; while (true) { ; }", "ExecTimeout", false, true, false, 1));
@@ -913,7 +918,7 @@ public:
 class ExecNoTimeout {
 public:
     void run() {
-        unique_ptr<Scope> scope(globalScriptEngine->newScope());
+        unique_ptr<Scope> scope(getGlobalScriptEngine()->newScope());
 
         // assert no timeout occurred
         ASSERT(scope->exec("var a = function() { return 1; }",
@@ -931,7 +936,7 @@ public:
 class InvokeTimeout {
 public:
     void run() {
-        unique_ptr<Scope> scope(globalScriptEngine->newScope());
+        unique_ptr<Scope> scope(getGlobalScriptEngine()->newScope());
 
         // scope timeout after 500ms
         bool caught = false;
@@ -950,13 +955,64 @@ public:
     }
 };
 
+class SleepInterruption {
+public:
+    void run() {
+        std::shared_ptr<Scope> scope(getGlobalScriptEngine()->newScope());
+
+        Promise<void> sleepPromise{};
+        auto sleepFuture = sleepPromise.getFuture();
+
+        Promise<void> awakenedPromise{};
+        auto awakenedFuture = awakenedPromise.getFuture();
+
+        // Spawn a thread which attempts to sleep indefinitely.
+        stdx::thread([
+            preSleep = std::move(sleepPromise),
+            onAwake = std::move(awakenedPromise),
+            scope
+        ]() mutable {
+            preSleep.emplaceValue();
+            onAwake.setWith([&] {
+                scope->exec(
+                    ""
+                    "  try {"
+                    "    sleep(99999999999);"
+                    "  } finally {"
+                    "    throw \"FAILURE\";"
+                    "  }"
+                    "",
+                    "test",
+                    false,
+                    false,
+                    true);
+            });
+        }).detach();
+
+        // Wait until just before the sleep begins.
+        sleepFuture.get();
+
+        // Attempt to wait until Javascript enters the sleep.
+        // It's OK if we kill the function prematurely, before it begins sleeping. Either cause of
+        // death will emit an error with the Interrupted code.
+        sleepsecs(1);
+
+        // Send the operation a kill signal.
+        scope->kill();
+
+        // Wait for the error.
+        auto result = awakenedFuture.getNoThrow();
+        ASSERT_EQ(ErrorCodes::Interrupted, result);
+    }
+};
+
 /**
  * Test invoke() timeout value does not terminate execution (SERVER-8053)
  */
 class InvokeNoTimeout {
 public:
     void run() {
-        unique_ptr<Scope> scope(globalScriptEngine->newScope());
+        unique_ptr<Scope> scope(getGlobalScriptEngine()->newScope());
 
         // invoke completes before timeout
         scope->invokeSafe(
@@ -979,15 +1035,16 @@ public:
         reset();
     }
     void run() {
-        if (!globalScriptEngine->utf8Ok()) {
+        if (!getGlobalScriptEngine()->utf8Ok()) {
             mongo::unittest::log() << "warning: utf8 not supported" << endl;
             return;
         }
         string utf8ObjSpec = "{'_id':'\\u0001\\u007f\\u07ff\\uffff'}";
         BSONObj utf8Obj = fromjson(utf8ObjSpec);
 
-        OperationContextImpl txn;
-        DBDirectClient client(&txn);
+        const ServiceContext::UniqueOperationContext opCtxPtr = cc().makeOperationContext();
+        OperationContext& opCtx = *opCtxPtr;
+        DBDirectClient client(&opCtx);
 
         client.insert(ns(), utf8Obj);
         client.eval("unittest",
@@ -1006,8 +1063,9 @@ private:
     }
 
     void reset() {
-        OperationContextImpl txn;
-        DBDirectClient client(&txn);
+        const ServiceContext::UniqueOperationContext opCtxPtr = cc().makeOperationContext();
+        OperationContext& opCtx = *opCtxPtr;
+        DBDirectClient client(&opCtx);
 
         client.dropCollection(ns());
     }
@@ -1026,11 +1084,12 @@ public:
         reset();
     }
     void run() {
-        if (!globalScriptEngine->utf8Ok())
+        if (!getGlobalScriptEngine()->utf8Ok())
             return;
 
-        OperationContextImpl txn;
-        DBDirectClient client(&txn);
+        const ServiceContext::UniqueOperationContext opCtxPtr = cc().makeOperationContext();
+        OperationContext& opCtx = *opCtxPtr;
+        DBDirectClient client(&opCtx);
 
         client.eval("unittest",
                     "db.jstests.longutf8string.save( {_id:'\\uffff\\uffff\\uffff\\uffff'} )");
@@ -1038,8 +1097,9 @@ public:
 
 private:
     void reset() {
-        OperationContextImpl txn;
-        DBDirectClient client(&txn);
+        const ServiceContext::UniqueOperationContext opCtxPtr = cc().makeOperationContext();
+        OperationContext& opCtx = *opCtxPtr;
+        DBDirectClient client(&opCtx);
 
         client.dropCollection(ns());
     }
@@ -1052,11 +1112,11 @@ private:
 class InvalidUTF8Check {
 public:
     void run() {
-        if (!globalScriptEngine->utf8Ok())
+        if (!getGlobalScriptEngine()->utf8Ok())
             return;
 
         unique_ptr<Scope> s;
-        s.reset(globalScriptEngine->newScope());
+        s.reset(getGlobalScriptEngine()->newScope());
 
         BSONObj b;
         {
@@ -1082,7 +1142,7 @@ public:
 class CodeTests {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         {
             BSONObjBuilder b;
@@ -1117,8 +1177,9 @@ public:
         // Insert in Javascript -> Find using DBDirectClient
 
         // Drop the collection
-        OperationContextImpl txn;
-        DBDirectClient client(&txn);
+        const ServiceContext::UniqueOperationContext opCtxPtr = cc().makeOperationContext();
+        OperationContext& opCtx = *opCtxPtr;
+        DBDirectClient client(&opCtx);
 
         client.dropCollection("unittest.testroundtrip");
 
@@ -2086,7 +2147,7 @@ public:
     }
 
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         const char* foo = "asdas\0asdasd";
         const char* base64 = "YXNkYXMAYXNkYXNk";
@@ -2136,7 +2197,7 @@ public:
 class VarTests {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         ASSERT(s->exec("a = 5;", "a", false, true, false));
         ASSERT_EQUALS(5, s->getNumber("a"));
@@ -2153,7 +2214,7 @@ public:
         BSONObj empty;
 
         unique_ptr<Scope> s;
-        s.reset(globalScriptEngine->newScope());
+        s.reset(getGlobalScriptEngine()->newScope());
 
         ScriptingFunction f = s->createFunction("return this.x + 6;");
 
@@ -2171,13 +2232,13 @@ class ScopeOut {
 public:
     void run() {
         unique_ptr<Scope> s;
-        s.reset(globalScriptEngine->newScope());
+        s.reset(getGlobalScriptEngine()->newScope());
 
         s->invokeSafe("x = 5;", 0, 0);
         {
             BSONObjBuilder b;
             s->append(b, "z", "x");
-            ASSERT_EQUALS(BSON("z" << 5), b.obj());
+            ASSERT_BSONOBJ_EQ(BSON("z" << 5), b.obj());
         }
 
         s->invokeSafe("x = function(){ return 17; }", 0, 0);
@@ -2197,7 +2258,7 @@ class RenameTest {
 public:
     void run() {
         unique_ptr<Scope> s;
-        s.reset(globalScriptEngine->newScope());
+        s.reset(getGlobalScriptEngine()->newScope());
 
         s->setNumber("x", 5);
         ASSERT_EQUALS(5, s->getNumber("x"));
@@ -2225,11 +2286,12 @@ public:
         update.appendCode("value",
                           "function () { db.test.find().forEach(function(obj) { continue; }); }");
 
-        OperationContextImpl txn;
-        DBDirectClient client(&txn);
+        const ServiceContext::UniqueOperationContext opCtxPtr = cc().makeOperationContext();
+        OperationContext& opCtx = *opCtxPtr;
+        DBDirectClient client(&opCtx);
         client.update("test.system.js", query.obj(), update.obj(), true /* upsert */);
 
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
         client.eval("test", "invalidstoredjs1()");
 
         BSONObj info;
@@ -2250,7 +2312,7 @@ public:
         uint8_t bits[] = {
             16, 0, 0, 0, 0x01, 'a', '\0', 0x61, 0x79, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0,
         };
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         s->setObject("val", BSONObj(reinterpret_cast<char*>(bits)).getOwned());
 
@@ -2262,7 +2324,7 @@ public:
 class NoReturnSpecified {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         s->invoke("x=5;", 0, 0);
         ASSERT_EQUALS(5, s->getNumber("__returnValue"));
@@ -2316,7 +2378,7 @@ public:
     }
 
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         s->injectNative("foo", callback, s.get());
         s->invoke("var x = 1; foo();", 0, 0);
@@ -2327,7 +2389,7 @@ public:
 class ErrorCodeFromInvoke {
 public:
     void run() {
-        unique_ptr<Scope> s(globalScriptEngine->newScope());
+        unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
 
         {
             bool threwException = false;
@@ -2373,14 +2435,14 @@ public:
 
         // Ensure that by default we can bind owned and unowned
         {
-            unique_ptr<Scope> s(globalScriptEngine->newScope());
+            unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
             s->setObject("unowned", unowned, true);
             s->setObject("owned", owned, true);
         }
 
         // After we set the flag, we should only be able to set owned
         {
-            unique_ptr<Scope> s(globalScriptEngine->newScope());
+            unique_ptr<Scope> s(getGlobalScriptEngine()->newScope());
             s->requireOwnedObjects();
             s->setObject("owned", owned, true);
 
@@ -2406,10 +2468,7 @@ public:
 
 class All : public Suite {
 public:
-    All() : Suite("js") {
-        // Initialize the Javascript interpreter
-        ScriptEngine::setup();
-    }
+    All() : Suite("js") {}
 
     void setupTests() {
         add<BuiltinTests>();
@@ -2422,6 +2481,7 @@ public:
         add<ExecTimeout>();
         add<ExecNoTimeout>();
         add<InvokeTimeout>();
+        add<SleepInterruption>();
         add<InvokeNoTimeout>();
 
         add<ObjectMapping>();
@@ -2435,11 +2495,9 @@ public:
         add<NumberLong>();
         add<NumberLong2>();
 
-        if (Decimal128::enabled) {
-            add<NumberDecimal>();
-            add<NumberDecimalGetFromScope>();
-            add<NumberDecimalBigObject>();
-        }
+        add<NumberDecimal>();
+        add<NumberDecimalGetFromScope>();
+        add<NumberDecimalBigObject>();
 
         add<MaxTimestamp>();
         add<RenameTest>();
@@ -2514,19 +2572,17 @@ public:
         add<RoundTripTests::NumberInt>();
         add<RoundTripTests::Number>();
 
-        if (Decimal128::enabled) {
-            add<RoundTripTests::NumberDecimal>();
-            add<RoundTripTests::NumberDecimalNegative>();
-            add<RoundTripTests::NumberDecimalMax>();
-            add<RoundTripTests::NumberDecimalMin>();
-            add<RoundTripTests::NumberDecimalPositiveZero>();
-            add<RoundTripTests::NumberDecimalNegativeZero>();
-            add<RoundTripTests::NumberDecimalPositiveNaN>();
-            add<RoundTripTests::NumberDecimalNegativeNaN>();
-            add<RoundTripTests::NumberDecimalPositiveInfinity>();
-            add<RoundTripTests::NumberDecimalNegativeInfinity>();
-            add<RoundTripTests::NumberDecimalPrecision>();
-        }
+        add<RoundTripTests::NumberDecimal>();
+        add<RoundTripTests::NumberDecimalNegative>();
+        add<RoundTripTests::NumberDecimalMax>();
+        add<RoundTripTests::NumberDecimalMin>();
+        add<RoundTripTests::NumberDecimalPositiveZero>();
+        add<RoundTripTests::NumberDecimalNegativeZero>();
+        add<RoundTripTests::NumberDecimalPositiveNaN>();
+        add<RoundTripTests::NumberDecimalNegativeNaN>();
+        add<RoundTripTests::NumberDecimalPositiveInfinity>();
+        add<RoundTripTests::NumberDecimalNegativeInfinity>();
+        add<RoundTripTests::NumberDecimalPrecision>();
 
         add<RoundTripTests::UUID>();
         add<RoundTripTests::HexData>();
@@ -2537,4 +2593,4 @@ public:
 
 SuiteInstance<All> myall;
 
-}  // namespace JavaJSTests
+}  // namespace JSTests
