@@ -1,3 +1,6 @@
+// namespacetests.cpp : namespace.{h,cpp} unit tests.
+//
+
 
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
@@ -168,11 +171,7 @@ namespace NamespaceDetailsTests {
         void create() {
             Lock::GlobalWrite lk;
             const ServiceContext::UniqueOperationContext opCtxPtr = cc().makeOperationContext(); OperationContext& opCtx = *opCtxPtr;
-
-            CollectionOptions collectionOptions;
-            ASSERT_OK(collectionOptions.parse(fromjson(spec()),
-                                              CollectionOptions::parseForCommand));
-            ASSERT_OK(userCreateNS(&opCtx, db(), ns(), collectionOptions, false));
+            ASSERT( userCreateNS( &opCtx, db(), ns(), fromjson( spec() ), false ).isOK() );
         }
         virtual string spec() const = 0;
         int nRecords() const {
@@ -554,7 +553,7 @@ public:
         Lock::DBLock lk(&opCtx, dbName, MODE_X);
 
         bool justCreated;
-        Database* db = DatabaseHolder::getDatabaseHolder().openDb(&opCtx, dbName, &justCreated);
+        Database* db = dbHolder().openDb(&opCtx, dbName, &justCreated);
         ASSERT(justCreated);
 
         Collection* committedColl;
@@ -598,7 +597,7 @@ public:
         Lock::DBLock lk(&opCtx, dbName, MODE_X);
 
         bool justCreated;
-        Database* db = DatabaseHolder::getDatabaseHolder().openDb(&opCtx, dbName, &justCreated);
+        Database* db = dbHolder().openDb(&opCtx, dbName, &justCreated);
         ASSERT(justCreated);
 
         {
