@@ -1229,6 +1229,126 @@ public:
     }
 };
 
+class ValidateDuplicateDocumentIndexKeySet : public ValidateBase {
+public:
+    ValidateDuplicateDocumentIndexKeySet() : ValidateBase(/*full=*/false, /*background=*/false) {}
+
+    void run() {
+        // Create a new collection.
+        lockDb(MODE_X);
+        Collection* coll;
+        {
+            WriteUnitOfWork wunit(&_opCtx);
+            ASSERT_OK(_db->dropCollection(&_opCtx, _ns));
+            coll = _db->createCollection(&_opCtx, _ns);
+            wunit.commit();
+        }
+
+        // Create two identical indexes only differing by key pattern and name.
+        {
+            const auto indexName = "a";
+            const auto indexKey = BSON("a" << 1);
+            auto status =
+                dbtests::createIndexFromSpec(&_opCtx,
+                                             coll->ns().ns(),
+                                             BSON("name" << indexName << "key" << indexKey << "v"
+                                                         << static_cast<int>(kIndexVersion)
+                                                         << "background"
+                                                         << false
+                                                         << "ns"
+                                                         << _ns));
+            ASSERT_OK(status);
+        }
+
+        {
+            const auto indexName = "b";
+            const auto indexKey = BSON("b" << 1);
+            auto status =
+                dbtests::createIndexFromSpec(&_opCtx,
+                                             coll->ns().ns(),
+                                             BSON("name" << indexName << "key" << indexKey << "v"
+                                                         << static_cast<int>(kIndexVersion)
+                                                         << "background"
+                                                         << false
+                                                         << "ns"
+                                                         << _ns));
+            ASSERT_OK(status);
+        }
+
+        // Insert a document.
+        OpDebug* const nullOpDebug = nullptr;
+        RecordId rid = RecordId::min();
+        lockDb(MODE_X);
+        {
+            WriteUnitOfWork wunit(&_opCtx);
+            ASSERT_OK(
+                coll->insertDocument(&_opCtx,
+                                     InsertStatement(BSON("_id" << 1 << "a" << 1 << "b" << 1)),
+                                     nullOpDebug,
+                                     true));
+            rid = coll->getCursor(&_opCtx)->next()->id;
+            wunit.commit();
+        }
+        releaseDb();
+        ASSERT_TRUE(checkValid());
+
+        // Remove the index entry for index "a".
+        {
+            lockDb(MODE_X);
+
+            IndexCatalog* indexCatalog = coll->getIndexCatalog();
+            const std::string indexName = "a";
+            auto descriptor = indexCatalog->findIndexByName(&_opCtx, indexName);
+            auto iam =
+                const_cast<IndexAccessMethod*>(indexCatalog->getEntry(descriptor)->accessMethod());
+
+            WriteUnitOfWork wunit(&_opCtx);
+            int64_t numDeleted;
+            const BSONObj actualKey = BSON("a" << 1);
+            InsertDeleteOptions options;
+            options.logIfError = true;
+            options.dupsAllowed = true;
+
+            ASSERT_OK(iam->remove(&_opCtx, actualKey, rid, options, &numDeleted));
+
+            ASSERT_EQUALS(numDeleted, 1);
+            wunit.commit();
+
+            releaseDb();
+        }
+
+        // Remove the index entry for index "b".
+        {
+            lockDb(MODE_X);
+
+            IndexCatalog* indexCatalog = coll->getIndexCatalog();
+            const std::string indexName = "b";
+            auto descriptor = indexCatalog->findIndexByName(&_opCtx, indexName);
+            auto iam =
+                const_cast<IndexAccessMethod*>(indexCatalog->getEntry(descriptor)->accessMethod());
+
+            WriteUnitOfWork wunit(&_opCtx);
+            int64_t numDeleted;
+            const BSONObj actualKey = BSON("b" << 1);
+            InsertDeleteOptions options;
+            options.logIfError = true;
+            options.dupsAllowed = true;
+
+            ASSERT_OK(iam->remove(&_opCtx, actualKey, rid, options, &numDeleted));
+            ASSERT_EQUALS(numDeleted, 1);
+            wunit.commit();
+
+            releaseDb();
+        }
+
+        {
+            // Now we have two missing index entries with the keys { : 1 } since the KeyStrings
+            // aren't hydrated with their field names.
+            ASSERT_TRUE(!checkValid());
+        }
+    }
+};
+
 class ValidateTests : public Suite {
 public:
     ValidateTests() : Suite("validate_tests") {}
@@ -1269,6 +1389,8 @@ public:
         add<ValidateMissingAndExtraIndexEntryResults<false, false>>();
         add<ValidateMissingIndexEntryResults<false, false>>();
         add<ValidateExtraIndexEntryResults<false, false>>();
+
+        add<ValidateDuplicateDocumentIndexKeySet>();
     }
 } validateTests;
 }  // namespace ValidateTests
