@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -55,22 +56,17 @@ public:
         kNetwork,
         kQuery,
         kReplication,
-        kReplicationElection,
         kReplicationHeartbeats,
-        kReplicationInitialSync,
         kReplicationRollback,
         kSharding,
         kShardingCatalogRefresh,
         kStorage,
-        kStorageRecovery,
         kJournal,
         kWrite,
         kFTDC,
         kASIO,
         kBridge,
         kTracking,
-        kTransaction,
-        kConnectionPool,
         kNumLogComponents
     };
 
