@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -31,9 +32,9 @@
 
 #include "mongo/client/connection_string.h"
 #include "mongo/db/repl/optime.h"
-#include "mongo/platform/mutex.h"
 #include "mongo/s/catalog/sharding_catalog_client.h"
 #include "mongo/s/client/shard_registry.h"
+#include "mongo/stdx/mutex.h"
 
 namespace mongo {
 
@@ -57,7 +58,7 @@ public:
      * described by "coll."
      */
     static Status updateShardingCatalogEntryForCollection(OperationContext* opCtx,
-                                                          const NamespaceString& nss,
+                                                          const std::string& collNs,
                                                           const CollectionType& coll,
                                                           const bool upsert);
 
@@ -72,40 +73,51 @@ public:
 
     void shutDown(OperationContext* opCtx) override;
 
+    Status updateDatabase(OperationContext* opCtx,
+                          const std::string& dbName,
+                          const DatabaseType& db) override;
+
+    Status logAction(OperationContext* opCtx,
+                     const std::string& what,
+                     const std::string& ns,
+                     const BSONObj& detail) override;
+
+    Status logChange(OperationContext* opCtx,
+                     const std::string& what,
+                     const std::string& ns,
+                     const BSONObj& detail,
+                     const WriteConcernOptions& writeConcern) override;
+
     StatusWith<repl::OpTimeWith<DatabaseType>> getDatabase(
         OperationContext* opCtx,
         const std::string& dbName,
         repl::ReadConcernLevel readConcernLevel) override;
 
-    StatusWith<repl::OpTimeWith<std::vector<DatabaseType>>> getAllDBs(
-        OperationContext* opCtx, repl::ReadConcernLevel readConcern) override;
+    StatusWith<repl::OpTimeWith<CollectionType>> getCollection(OperationContext* opCtx,
+                                                               const std::string& collNs) override;
 
-    StatusWith<repl::OpTimeWith<CollectionType>> getCollection(
-        OperationContext* opCtx,
-        const NamespaceString& nss,
-        repl::ReadConcernLevel readConcernLevel) override;
+    Status getCollections(OperationContext* opCtx,
+                          const std::string* dbName,
+                          std::vector<CollectionType>* collections,
+                          repl::OpTime* optime) override;
 
-    StatusWith<std::vector<CollectionType>> getCollections(
-        OperationContext* opCtx,
-        const std::string* dbName,
-        repl::OpTime* optime,
-        repl::ReadConcernLevel readConcernLevel) override;
+    Status dropCollection(OperationContext* opCtx, const NamespaceString& ns) override;
 
-    std::vector<NamespaceString> getAllShardedCollectionsForDb(
-        OperationContext* opCtx, StringData dbName, repl::ReadConcernLevel readConcern) override;
+    Status getDatabasesForShard(OperationContext* opCtx,
+                                const ShardId& shardName,
+                                std::vector<std::string>* dbs) override;
 
-    StatusWith<std::vector<std::string>> getDatabasesForShard(OperationContext* opCtx,
-                                                              const ShardId& shardName) override;
+    Status getChunks(OperationContext* opCtx,
+                     const BSONObj& query,
+                     const BSONObj& sort,
+                     boost::optional<int> limit,
+                     std::vector<ChunkType>* chunks,
+                     repl::OpTime* opTime,
+                     repl::ReadConcernLevel readConcern) override;
 
-    StatusWith<std::vector<ChunkType>> getChunks(OperationContext* opCtx,
-                                                 const BSONObj& query,
-                                                 const BSONObj& sort,
-                                                 boost::optional<int> limit,
-                                                 repl::OpTime* opTime,
-                                                 repl::ReadConcernLevel readConcern) override;
-
-    StatusWith<std::vector<TagsType>> getTagsForCollection(OperationContext* opCtx,
-                                                           const NamespaceString& nss) override;
+    Status getTagsForCollection(OperationContext* opCtx,
+                                const std::string& collectionNs,
+                                std::vector<TagsType>* tags) override;
 
     StatusWith<repl::OpTimeWith<std::vector<ShardType>>> getAllShards(
         OperationContext* opCtx, repl::ReadConcernLevel readConcern) override;
@@ -124,7 +136,7 @@ public:
     Status applyChunkOpsDeprecated(OperationContext* opCtx,
                                    const BSONArray& updateOps,
                                    const BSONArray& preCondition,
-                                   const NamespaceString& nss,
+                                   const std::string& nss,
                                    const ChunkVersion& lastChunkVersion,
                                    const WriteConcernOptions& writeConcern,
                                    repl::ReadConcernLevel readConcern) override;
@@ -139,29 +151,32 @@ public:
                                  BatchedCommandResponse* response) override;
 
     Status insertConfigDocument(OperationContext* opCtx,
-                                const NamespaceString& nss,
+                                const std::string& ns,
                                 const BSONObj& doc,
                                 const WriteConcernOptions& writeConcern) override;
 
-    void insertConfigDocumentsAsRetryableWrite(OperationContext* opCtx,
-                                               const NamespaceString& nss,
-                                               std::vector<BSONObj> docs,
-                                               const WriteConcernOptions& writeConcern) override;
-
     StatusWith<bool> updateConfigDocument(OperationContext* opCtx,
-                                          const NamespaceString& nss,
+                                          const std::string& ns,
                                           const BSONObj& query,
                                           const BSONObj& update,
                                           bool upsert,
                                           const WriteConcernOptions& writeConcern) override;
 
     Status removeConfigDocuments(OperationContext* opCtx,
-                                 const NamespaceString& nss,
+                                 const std::string& ns,
                                  const BSONObj& query,
                                  const WriteConcernOptions& writeConcern) override;
 
     DistLockManager* getDistLockManager() override;
 
+    /**
+     * Runs a read command against the config server with majority read concern.
+     */
+    bool runReadCommandForTest(OperationContext* opCtx,
+                               const std::string& dbname,
+                               const BSONObj& cmdObj,
+                               BSONObjBuilder* result);
+
     StatusWith<std::vector<KeysCollectionDocument>> getNewKeys(
         OperationContext* opCtx,
         StringData purpose,
@@ -173,7 +188,7 @@ private:
      * Updates a single document in the specified namespace on the config server. The document must
      * have an _id index. Must only be used for updates to the 'config' database.
      *
-     * This method retries the operation on NotPrimary or network errors, so it should only be used
+     * This method retries the operation on NotMaster or network errors, so it should only be used
      * with modifications which are idempotent.
      *
      * Returns non-OK status if the command failed to run for some reason. If the command was
@@ -182,12 +197,20 @@ private:
      * returns whether the update command's response update.n value is > 0).
      */
     static StatusWith<bool> _updateConfigDocument(OperationContext* opCtx,
-                                                  const NamespaceString& nss,
+                                                  const std::string& ns,
                                                   const BSONObj& query,
                                                   const BSONObj& update,
                                                   bool upsert,
                                                   const WriteConcernOptions& writeConcern);
 
+    /**
+     * Creates the specified collection name in the config database.
+     */
+    Status _createCappedConfigCollection(OperationContext* opCtx,
+                                         StringData collName,
+                                         int cappedSize,
+                                         const WriteConcernOptions& writeConcern);
+
     StatusWith<repl::OpTimeWith<std::vector<BSONObj>>> _exhaustiveFindOnConfig(
         OperationContext* opCtx,
         const ReadPreferenceSetting& readPref,
@@ -197,6 +220,11 @@ private:
         const BSONObj& sort,
         boost::optional<long long> limit) override;
 
+    /**
+     * Appends a read committed read concern to the request object.
+     */
+    void _appendReadConcern(BSONObjBuilder* builder);
+
     /**
      * Queries the config servers for the database metadata for the given database, using the
      * given read preference.  Returns NamespaceNotFound if no database metadata is found.
@@ -207,15 +235,35 @@ private:
         const ReadPreferenceSetting& readPref,
         repl::ReadConcernLevel readConcernLevel);
 
+    /**
+     * Best effort method, which logs diagnostic events on the config server. If the config server
+     * write fails for any reason a warning will be written to the local service log and the method
+     * will return a failed status.
+     *
+     * @param opCtx Operation context in which the call is running
+     * @param logCollName Which config collection to write to (excluding the database name)
+     * @param what E.g. "split", "migrate" (not interpreted)
+     * @param operationNS To which collection the metadata change is being applied (not interpreted)
+     * @param detail Additional info about the metadata change (not interpreted)
+     * @param writeConcern Write concern options to use for logging
+     */
+    Status _log(OperationContext* opCtx,
+                const StringData& logCollName,
+                const std::string& what,
+                const std::string& operationNS,
+                const BSONObj& detail,
+                const WriteConcernOptions& writeConcern);
+
     //
     // All member variables are labeled with one of the following codes indicating the
     // synchronization rules for accessing them.
     //
     // (M) Must hold _mutex for access.
     // (R) Read only, can only be written during initialization.
+    // (S) Self-synchronizing; access in any way from any context.
     //
 
-    Mutex _mutex = MONGO_MAKE_LATCH("ShardingCatalogClientImpl::_mutex");
+    stdx::mutex _mutex;
 
     // Distributed lock manager singleton.
     std::unique_ptr<DistLockManager> _distLockManager;  // (R)
@@ -225,6 +273,12 @@ private:
 
     // True if startup() has been called.
     bool _started = false;  // (M)
+
+    // Whether the logAction call should attempt to create the actionlog collection
+    AtomicInt32 _actionLogCollectionCreated{0};  // (S)
+
+    // Whether the logChange call should attempt to create the changelog collection
+    AtomicInt32 _changeLogCollectionCreated{0};  // (S)
 };
 
 }  // namespace mongo
