@@ -182,6 +182,12 @@ public:
 
     /**
      * Updates metadata in config.chunks collection to show the given chunk in its new shard.
+     *
+     * Returns a BSON object with the newly produced chunk versions after the migration:
+     *  - migratedChunkVersion - the version of the chunk, which was migrated
+     *  - controlChunkVersion (optional) - the version of the "control" chunk, which was changed in
+     *      order to reflect the change on the donor. This value will be missing if the last chunk
+     *      on the donor shard was migrated out.
      */
     StatusWith<BSONObj> commitChunkMigration(OperationContext* opCtx,
                                              const NamespaceString& nss,
@@ -259,6 +265,15 @@ public:
                          const bool distributeInitialChunks,
                          const ShardId& dbPrimaryShardId);
 
+    /**
+     * Attempts to sets the shard version to the given chunk version with authoritative: true on
+     * the primary shard. If it fails, emit a warning then move on.
+     */
+    void trySetShardVersionOnPrimaryShard(OperationContext* opCtx,
+                                          const NamespaceString& nss,
+                                          const ShardId& dbPrimaryShardId,
+                                          const ChunkVersion& collVersion);
+
     /**
      * Iterates through each entry in config.collections that does not have a UUID, generates a UUID
      * for the collection, and updates the entry with the generated UUID.
