@@ -1,23 +1,25 @@
+
 /**
- *    Copyright (C) 2015 MongoDB Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects for
+ *    must comply with the Server Side Public License in all respects for
  *    all of the code used other than as permitted herein. If you modify file(s)
  *    with this exception, you may extend this exception to your version of the
  *    file(s), but you are not obligated to do so. If you do not wish to do so,
@@ -39,13 +41,16 @@
 #include "mongo/client/connection_string.h"
 #include "mongo/client/replica_set_monitor.h"
 #include "mongo/db/client.h"
+#include "mongo/db/logical_time_metadata_hook.h"
 #include "mongo/db/operation_context.h"
 #include "mongo/db/server_options.h"
+#include "mongo/executor/network_connection_hook.h"
 #include "mongo/executor/network_interface_factory.h"
 #include "mongo/executor/network_interface_thread_pool.h"
 #include "mongo/executor/task_executor.h"
 #include "mongo/executor/task_executor_pool.h"
 #include "mongo/executor/thread_pool_task_executor.h"
+#include "mongo/rpc/metadata/egress_metadata_hook_list.h"
 #include "mongo/s/catalog/sharding_catalog_client.h"
 #include "mongo/s/catalog/type_shard.h"
 #include "mongo/s/client/shard.h"
@@ -54,6 +59,7 @@
 #include "mongo/s/grid.h"
 #include "mongo/stdx/memory.h"
 #include "mongo/stdx/mutex.h"
+#include "mongo/util/concurrency/with_lock.h"
 #include "mongo/util/log.h"
 #include "mongo/util/map_util.h"
 #include "mongo/util/mongoutils/str.h"
@@ -80,6 +86,8 @@ namespace {
 const Seconds kRefreshPeriod(30);
 }  // namespace
 
+const ShardId ShardRegistry::kConfigServerShardId = ShardId("config");
+
 ShardRegistry::ShardRegistry(std::unique_ptr<ShardFactory> shardFactory,
                              const ConnectionString& configServerCS)
     : _shardFactory(std::move(shardFactory)), _initConfigServerCS(configServerCS) {}
@@ -101,7 +109,7 @@ ConnectionString ShardRegistry::getConfigServerConnectionString() const {
     return getConfigShard()->getConnString();
 }
 
-StatusWith<shared_ptr<Shard>> ShardRegistry::getShard(OperationContext* txn,
+StatusWith<shared_ptr<Shard>> ShardRegistry::getShard(OperationContext* opCtx,
                                                       const ShardId& shardId) {
     // If we know about the shard, return it.
     auto shard = _data.findByShardId(shardId);
@@ -110,7 +118,7 @@ StatusWith<shared_ptr<Shard>> ShardRegistry::getShard(OperationContext* txn,
     }
 
     // If we can't find the shard, attempt to reload the ShardRegistry.
-    bool didReload = reload(txn);
+    bool didReload = reload(opCtx);
     shard = _data.findByShardId(shardId);
 
     // If we found the shard, return it.
@@ -126,7 +134,7 @@ StatusWith<shared_ptr<Shard>> ShardRegistry::getShard(OperationContext* txn,
 
     // If we did not perform the reload ourselves (because there was a concurrent reload), force a
     // reload again to ensure that we have seen data at least as up to date as our first reload.
-    reload(txn);
+    reload(opCtx);
     shard = _data.findByShardId(shardId);
 
     if (shard) {
@@ -164,6 +172,12 @@ void ShardRegistry::getAllShardIds(vector<ShardId>* all) const {
     all->assign(seen.begin(), seen.end());
 }
 
+int ShardRegistry::getNumShards() const {
+    std::set<ShardId> seen;
+    _data.getAllShardIds(seen);
+    return seen.size();
+}
+
 void ShardRegistry::toBSON(BSONObjBuilder* result) const {
     _data.toBSON(result);
 }
@@ -180,18 +194,22 @@ void ShardRegistry::updateReplSetHosts(const ConnectionString& newConnString) {
 void ShardRegistry::init() {
     stdx::unique_lock<stdx::mutex> reloadLock(_reloadMutex);
     invariant(_initConfigServerCS.isValid());
-    auto configShard = _shardFactory->createShard(ShardId("config"), _initConfigServerCS);
+    auto configShard =
+        _shardFactory->createShard(ShardRegistry::kConfigServerShardId, _initConfigServerCS);
     _data.addConfigShard(configShard);
     // set to invalid so it cant be started more than once.
     _initConfigServerCS = ConnectionString();
 }
 
-void ShardRegistry::startup() {
+void ShardRegistry::startup(OperationContext* opCtx) {
     // startup() must be called only once
     invariant(!_executor);
 
+    auto hookList = stdx::make_unique<rpc::EgressMetadataHookList>();
+    hookList->addHook(stdx::make_unique<rpc::LogicalTimeMetadataHook>(opCtx->getServiceContext()));
+
     // construct task executor
-    auto net = executor::makeNetworkInterface("ShardRegistryUpdater");
+    auto net = executor::makeNetworkInterface("ShardRegistryUpdater", nullptr, std::move(hookList));
     auto netPtr = net.get();
     _executor = stdx::make_unique<ThreadPoolTaskExecutor>(
         stdx::make_unique<NetworkInterfaceThreadPool>(netPtr), std::move(net));
@@ -221,10 +239,10 @@ void ShardRegistry::_internalReload(const CallbackArgs& cbArgs) {
     }
 
     Client::initThreadIfNotAlready("shard registry reload");
-    auto txn = cc().makeOperationContext();
+    auto opCtx = cc().makeOperationContext();
 
     try {
-        reload(txn.get());
+        reload(opCtx.get());
     } catch (const DBException& e) {
         log() << "Periodic reload of shard registry failed " << causedBy(e) << "; will retry after "
               << kRefreshPeriod;
@@ -252,7 +270,7 @@ bool ShardRegistry::isUp() const {
     return _isUp;
 }
 
-bool ShardRegistry::reload(OperationContext* txn) {
+bool ShardRegistry::reload(OperationContext* opCtx) {
     stdx::unique_lock<stdx::mutex> reloadLock(_reloadMutex);
 
     if (_reloadState == ReloadState::Reloading) {
@@ -261,7 +279,7 @@ bool ShardRegistry::reload(OperationContext* txn) {
         // simultaneously because there is no good way to determine which of the threads has the
         // more recent version of the data.
         do {
-            auto waitStatus = txn->waitForConditionOrInterruptNoAssert(_inReloadCV, reloadLock);
+            auto waitStatus = opCtx->waitForConditionOrInterruptNoAssert(_inReloadCV, reloadLock);
             if (!waitStatus.isOK()) {
                 LOG(1) << "ShardRegistry reload is interrupted due to: " << redact(waitStatus);
                 return false;
@@ -288,7 +306,7 @@ bool ShardRegistry::reload(OperationContext* txn) {
         _inReloadCV.notify_all();
     });
 
-    ShardRegistryData currData(txn, _shardFactory.get());
+    ShardRegistryData currData(opCtx, _shardFactory.get());
     currData.addConfigShard(_data.getConfigShard());
     _data.swap(currData);
 
@@ -323,10 +341,10 @@ void ShardRegistry::replicaSetChangeConfigServerUpdateHook(const std::string& se
                                                            const std::string& newConnectionString) {
     // This is run in it's own thread. Exceptions escaping would result in a call to terminate.
     Client::initThread("replSetChange");
-    auto txn = cc().makeOperationContext();
+    auto opCtx = cc().makeOperationContext();
 
     try {
-        std::shared_ptr<Shard> s = Grid::get(txn.get())->shardRegistry()->lookupRSName(setName);
+        std::shared_ptr<Shard> s = Grid::get(opCtx.get())->shardRegistry()->lookupRSName(setName);
         if (!s) {
             LOG(1) << "shard not found for set: " << newConnectionString
                    << " when attempting to inform config servers of updated set membership";
@@ -338,13 +356,15 @@ void ShardRegistry::replicaSetChangeConfigServerUpdateHook(const std::string& se
             return;
         }
 
-        auto status = Grid::get(txn.get())->catalogClient(txn.get())->updateConfigDocument(
-            txn.get(),
-            ShardType::ConfigNS,
-            BSON(ShardType::name(s->getId().toString())),
-            BSON("$set" << BSON(ShardType::host(newConnectionString))),
-            false,
-            ShardingCatalogClient::kMajorityWriteConcern);
+        auto status =
+            Grid::get(opCtx.get())
+                ->catalogClient()
+                ->updateConfigDocument(opCtx.get(),
+                                       ShardType::ConfigNS,
+                                       BSON(ShardType::name(s->getId().toString())),
+                                       BSON("$set" << BSON(ShardType::host(newConnectionString))),
+                                       false,
+                                       ShardingCatalogClient::kMajorityWriteConcern);
         if (!status.isOK()) {
             error() << "RSChangeWatcher: could not update config db for set: " << setName
                     << " to: " << newConnectionString << causedBy(status.getStatus());
@@ -358,13 +378,9 @@ void ShardRegistry::replicaSetChangeConfigServerUpdateHook(const std::string& se
 
 ////////////// ShardRegistryData //////////////////
 
-ShardRegistryData::ShardRegistryData(OperationContext* txn, ShardFactory* shardFactory) {
-    _init(txn, shardFactory);
-}
-
-void ShardRegistryData::_init(OperationContext* txn, ShardFactory* shardFactory) {
+ShardRegistryData::ShardRegistryData(OperationContext* opCtx, ShardFactory* shardFactory) {
     auto shardsStatus =
-        grid.catalogClient(txn)->getAllShards(txn, repl::ReadConcernLevel::kMajorityReadConcern);
+        grid.catalogClient()->getAllShards(opCtx, repl::ReadConcernLevel::kMajorityReadConcern);
 
     if (!shardsStatus.isOK()) {
         uasserted(shardsStatus.getStatus().code(),
@@ -404,7 +420,7 @@ void ShardRegistryData::_init(OperationContext* txn, ShardFactory* shardFactory)
         auto shard = shardFactory->createShard(std::move(std::get<0>(shardInfo)),
                                                std::move(std::get<1>(shardInfo)));
 
-        _addShard_inlock(std::move(shard), false);
+        _addShard(WithLock::withoutLock(), std::move(shard), false);
     }
 }
 
@@ -424,7 +440,7 @@ shared_ptr<Shard> ShardRegistryData::getConfigShard() const {
 void ShardRegistryData::addConfigShard(std::shared_ptr<Shard> shard) {
     stdx::lock_guard<stdx::mutex> lk(_mutex);
     _configShard = shard;
-    _addShard_inlock(shard, true);
+    _addShard(lk, shard, true);
 }
 
 shared_ptr<Shard> ShardRegistryData::findByRSName(const string& name) const {
@@ -440,10 +456,10 @@ shared_ptr<Shard> ShardRegistryData::findByHostAndPort(const HostAndPort& hostAn
 
 shared_ptr<Shard> ShardRegistryData::findByShardId(const ShardId& shardId) const {
     stdx::lock_guard<stdx::mutex> lk(_mutex);
-    return _findByShardId_inlock(shardId);
+    return _findByShardId(lk, shardId);
 }
 
-shared_ptr<Shard> ShardRegistryData::_findByShardId_inlock(const ShardId& shardId) const {
+shared_ptr<Shard> ShardRegistryData::_findByShardId(WithLock, ShardId const& shardId) const {
     auto i = _lookup.find(shardId);
     return (i != _lookup.end()) ? i->second : nullptr;
 }
@@ -497,28 +513,31 @@ void ShardRegistryData::rebuildShardIfExists(const ConnectionString& newConnStri
         return;
     }
 
-    _rebuildShard_inlock(newConnString, factory);
+    _rebuildShard(updateConnStringLock, newConnString, factory);
 }
 
 
-void ShardRegistryData::_rebuildShard_inlock(const ConnectionString& newConnString,
-                                             ShardFactory* factory) {
+void ShardRegistryData::_rebuildShard(WithLock lk,
+                                      ConnectionString const& newConnString,
+                                      ShardFactory* factory) {
     auto it = _rsLookup.find(newConnString.getSetName());
     invariant(it->second);
     auto shard = factory->createShard(it->second->getId(), newConnString);
-    _addShard_inlock(shard, true);
+    _addShard(lk, shard, true);
     if (shard->isConfig()) {
         _configShard = shard;
     }
 }
 
-void ShardRegistryData::_addShard_inlock(const std::shared_ptr<Shard>& shard, bool useOriginalCS) {
+void ShardRegistryData::_addShard(WithLock lk,
+                                  std::shared_ptr<Shard> const& shard,
+                                  bool useOriginalCS) {
     const ShardId shardId = shard->getId();
 
     const ConnectionString connString =
         useOriginalCS ? shard->originalConnString() : shard->getConnString();
 
-    auto currentShard = _findByShardId_inlock(shardId);
+    auto currentShard = _findByShardId(lk, shardId);
     if (currentShard) {
         auto oldConnString = currentShard->originalConnString();
 
