@@ -1,23 +1,25 @@
+
 /**
- *    Copyright (C) 2015 MongoDB Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- *    This program is free software: you can redistribute it and/or  modify
- *    it under the terms of the GNU Affero General Public License, version 3,
- *    as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU Affero General Public License for more details.
+ *    Server Side Public License for more details.
  *
- *    You should have received a copy of the GNU Affero General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
  *    As a special exception, the copyright holders give permission to link the
  *    code of portions of this program with the OpenSSL library under certain
  *    conditions as described in each individual source file and distribute
  *    linked combinations including the program with the OpenSSL library. You
- *    must comply with the GNU Affero General Public License in all respects for
+ *    must comply with the Server Side Public License in all respects for
  *    all of the code used other than as permitted herein. If you modify file(s)
  *    with this exception, you may extend this exception to your version of the
  *    file(s), but you are not obligated to do so. If you do not wish to do so,
@@ -470,18 +472,16 @@ public:
             // We need to determine whether we need to drop and shard the output collection and
             // send the UUID to the shards. We will always do this if we are using replace so we
             // can skip this check in that case. If using merge or reduce, we only want to do this
-            // if the output collection does not exist or if it exists and is an empty sharded
-            // collection.
-            int count;
+            // if the output collection does not exist.
+            bool shouldDropAndShard = replaceOutput;
             if (!replaceOutput && outputCollNss.isValid()) {
-                const auto primaryShard =
-                    uassertStatusOK(shardRegistry->getShard(opCtx, outputDbInfo.primaryId()));
-                ScopedDbConnection conn(primaryShard->getConnString());
-
                 if (!outputRoutingInfo.cm()) {
                     // The output collection either exists and is unsharded, or does not exist. If
                     // the output collection exists and is unsharded, fail because we should not go
                     // from unsharded to sharded.
+                    const auto primaryShard =
+                        uassertStatusOK(shardRegistry->getShard(opCtx, outputDbInfo.primaryId()));
+                    ScopedDbConnection conn(primaryShard->getConnString());
                     BSONObj listCollsCmdResponse;
                     ok = conn->runCommand(
                         outDB,
@@ -495,14 +495,11 @@ public:
                             "Cannot output to a sharded collection because "
                             "non-sharded collection exists already",
                             collections.isEmpty());
-                } else {
-                    // The output collection exists and is sharded. We need to determine whether the
-                    // collection is empty in order to decide whether we should drop and
-                    // re-shard it. We don't want to do this if the collection is not empty.
-                    count = conn->count(outputCollNss.ns());
-                }
 
-                conn.done();
+                    // If we reach here, the collection does not exist at all.
+                    shouldDropAndShard = true;
+                    conn.done();
+                }
             }
 
             // If we are using replace, the output collection exists and is sharded, or the output
@@ -510,8 +507,7 @@ public:
             // UUID generated during shardCollection to the shards to be used to create the temp
             // collections.
             boost::optional<UUID> shardedOutputCollUUID;
-            if (replaceOutput ||
-                (outputCollNss.isValid() && (!outputRoutingInfo.cm() || count == 0))) {
+            if (shouldDropAndShard) {
                 {
                     Seconds waitFor(DistLockManager::kDefaultLockTimeout);
                     auto backwardsCompatibleDbDistLock =
