@@ -92,29 +92,37 @@ public:
 
     Status checkAuthForCommand(Client* client,
                                const std::string& dbname,
-                               const BSONObj& cmdObj) override {
-        if (!AuthorizationSession::get(client)->isAuthorizedForActionsOnResource(
+                               const BSONObj& cmdObj) final {
+        auto* as = AuthorizationSession::get(client);
+
+        if (as->isAuthorizedForActionsOnResource(ResourcePattern::forClusterResource(),
+                                                 ActionType::enableSharding)) {
+            return Status::OK();
+        }
+
+        // Fallback on permissions to directly modify the shard config.
+        if (!as->isAuthorizedForActionsOnResource(
                 ResourcePattern::forExactNamespace(NamespaceString(ShardType::ConfigNS)),
                 ActionType::find)) {
-            return Status(ErrorCodes::Unauthorized, "Unauthorized");
+            return {ErrorCodes::Unauthorized, "Unauthorized"};
         }
 
-        if (!AuthorizationSession::get(client)->isAuthorizedForActionsOnResource(
+        if (!as->isAuthorizedForActionsOnResource(
                 ResourcePattern::forExactNamespace(NamespaceString(TagsType::ConfigNS)),
                 ActionType::find)) {
-            return Status(ErrorCodes::Unauthorized, "Unauthorized");
+            return {ErrorCodes::Unauthorized, "Unauthorized"};
         }
 
-        if (!AuthorizationSession::get(client)->isAuthorizedForActionsOnResource(
+        if (!as->isAuthorizedForActionsOnResource(
                 ResourcePattern::forExactNamespace(NamespaceString(TagsType::ConfigNS)),
                 ActionType::update)) {
-            return Status(ErrorCodes::Unauthorized, "Unauthorized");
+            return {ErrorCodes::Unauthorized, "Unauthorized"};
         }
 
-        if (!AuthorizationSession::get(client)->isAuthorizedForActionsOnResource(
+        if (!as->isAuthorizedForActionsOnResource(
                 ResourcePattern::forExactNamespace(NamespaceString(TagsType::ConfigNS)),
                 ActionType::remove)) {
-            return Status(ErrorCodes::Unauthorized, "Unauthorized");
+            return {ErrorCodes::Unauthorized, "Unauthorized"};
         }
 
         return Status::OK();
