@@ -37,7 +37,7 @@
 #include "mongo/s/catalog/type_shard.h"
 #include "mongo/s/client/shard_registry.h"
 #include "mongo/s/query/establish_cursors.h"
-#include "mongo/s/sharding_router_test_fixture.h"
+#include "mongo/s/sharding_test_fixture.h"
 #include "mongo/stdx/memory.h"
 #include "mongo/unittest/unittest.h"
 
@@ -91,29 +91,36 @@ protected:
 
 TEST_F(EstablishCursorsTest, NoRemotes) {
     std::vector<std::pair<ShardId, BSONObj>> remotes;
-    auto cursors = establishCursors(operationContext(),
-                                    executor(),
-                                    _nss,
-                                    ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                    remotes,
-                                    false);  // allowPartialResults
+    BSONObj viewDefinition;
+    auto swCursors = establishCursors(operationContext(),
+                                      executor(),
+                                      _nss,
+                                      ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                      remotes,
+                                      false,  // allowPartialResults
+                                      &viewDefinition);
 
-
-    ASSERT_EQUALS(remotes.size(), cursors.size());
+    ASSERT_OK(swCursors.getStatus());
+    ASSERT_EQUALS(remotes.size(), swCursors.getValue().size());
+    ASSERT_BSONOBJ_EQ({}, viewDefinition);
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithSuccess) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{{kTestShardIds[0], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        auto cursors = establishCursors(operationContext(),
-                                        executor(),
-                                        _nss,
-                                        ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                        remotes,
-                                        false);  // allowPartialResults
-        ASSERT_EQUALS(remotes.size(), cursors.size());
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          false,  // allowPartialResults
+                                          &viewDefinition);
+        ASSERT_OK(swCursors.getStatus());
+        ASSERT_EQUALS(remotes.size(), swCursors.getValue().size());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // Remote responds.
@@ -125,21 +132,24 @@ TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithSuccess) {
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithNonretriableError) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{{kTestShardIds[0], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        ASSERT_THROWS(establishCursors(operationContext(),
-                                       executor(),
-                                       _nss,
-                                       ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                       remotes,
-                                       false),  // allowPartialResults
-                      ExceptionFor<ErrorCodes::FailedToParse>);
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          false,  // allowPartialResults
+                                          &viewDefinition);
+        ASSERT_EQUALS(ErrorCodes::FailedToParse, swCursors.getStatus().code());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // Remote responds with non-retriable error.
@@ -147,22 +157,25 @@ TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithNonretriableError) {
         ASSERT_EQ(_nss.coll(), request.cmdObj.firstElement().valueStringData());
         return Status(ErrorCodes::FailedToParse, "failed to parse");
     });
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithNonretriableErrorAllowPartialResults) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{{kTestShardIds[0], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          true,  // allowPartialResults
+                                          &viewDefinition);
         // A non-retriable error is not ignored even though allowPartialResults is true.
-        ASSERT_THROWS(establishCursors(operationContext(),
-                                       executor(),
-                                       _nss,
-                                       ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                       remotes,
-                                       true),  // allowPartialResults
-                      ExceptionFor<ErrorCodes::FailedToParse>);
+        ASSERT_EQUALS(ErrorCodes::FailedToParse, swCursors.getStatus().code());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // Remote responds with non-retriable error.
@@ -170,21 +183,25 @@ TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithNonretriableErrorAllowParti
         ASSERT_EQ(_nss.coll(), request.cmdObj.firstElement().valueStringData());
         return Status(ErrorCodes::FailedToParse, "failed to parse");
     });
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithRetriableErrorThenSuccess) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{{kTestShardIds[0], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        auto cursors = establishCursors(operationContext(),
-                                        executor(),
-                                        _nss,
-                                        ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                        remotes,
-                                        false);  // allowPartialResults
-        ASSERT_EQUALS(remotes.size(), cursors.size());
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          false,  // allowPartialResults
+                                          &viewDefinition);
+        ASSERT_OK(swCursors.getStatus());
+        ASSERT_EQUALS(remotes.size(), swCursors.getValue().size());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // Remote responds with retriable error.
@@ -202,21 +219,25 @@ TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithRetriableErrorThenSuccess)
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithRetriableErrorThenSuccessAllowPartialResults) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{{kTestShardIds[0], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        auto cursors = establishCursors(operationContext(),
-                                        executor(),
-                                        _nss,
-                                        ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                        remotes,
-                                        true);  // allowPartialResults
-        ASSERT_EQUALS(remotes.size(), cursors.size());
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          true,  // allowPartialResults
+                                          &viewDefinition);
+        ASSERT_OK(swCursors.getStatus());
+        ASSERT_EQUALS(remotes.size(), swCursors.getValue().size());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // Remote responds with retriable error.
@@ -235,21 +256,24 @@ TEST_F(EstablishCursorsTest, SingleRemoteRespondsWithRetriableErrorThenSuccessAl
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteMaxesOutRetriableErrors) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{{kTestShardIds[0], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        ASSERT_THROWS(establishCursors(operationContext(),
-                                       executor(),
-                                       _nss,
-                                       ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                       remotes,
-                                       false),  // allowPartialResults
-                      ExceptionFor<ErrorCodes::HostUnreachable>);
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          false,  // allowPartialResults
+                                          &viewDefinition);
+        ASSERT_EQUALS(ErrorCodes::HostUnreachable, swCursors.getStatus().code());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // Remote repeatedly responds with retriable errors.
@@ -259,25 +283,29 @@ TEST_F(EstablishCursorsTest, SingleRemoteMaxesOutRetriableErrors) {
             return Status(ErrorCodes::HostUnreachable, "host unreachable");
         });
     }
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, SingleRemoteMaxesOutRetriableErrorsAllowPartialResults) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{{kTestShardIds[0], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        auto cursors = establishCursors(operationContext(),
-                                        executor(),
-                                        _nss,
-                                        ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                        remotes,
-                                        true);  // allowPartialResults
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          true,  // allowPartialResults
+                                          &viewDefinition);
 
         // Failure to establish a cursor due to maxing out retriable errors on one remote (in this
         // case, the only remote) was ignored, since allowPartialResults is true, and one less
         // cursor was established.
-        ASSERT_EQUALS(remotes.size() - 1, cursors.size());
+        ASSERT_OK(swCursors.getStatus());
+        ASSERT_EQUALS(remotes.size() - 1, swCursors.getValue().size());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // Remote repeatedly responds with retriable errors.
@@ -287,22 +315,26 @@ TEST_F(EstablishCursorsTest, SingleRemoteMaxesOutRetriableErrorsAllowPartialResu
             return Status(ErrorCodes::HostUnreachable, "host unreachable");
         });
     }
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, MultipleRemotesRespondWithSuccess) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{
         {kTestShardIds[0], cmdObj}, {kTestShardIds[1], cmdObj}, {kTestShardIds[2], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        auto cursors = establishCursors(operationContext(),
-                                        executor(),
-                                        _nss,
-                                        ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                        remotes,
-                                        false);  // allowPartialResults
-        ASSERT_EQUALS(remotes.size(), cursors.size());
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          false,  // allowPartialResults
+                                          &viewDefinition);
+        ASSERT_OK(swCursors.getStatus());
+        ASSERT_EQUALS(remotes.size(), swCursors.getValue().size());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // All remotes respond with success.
@@ -316,22 +348,25 @@ TEST_F(EstablishCursorsTest, MultipleRemotesRespondWithSuccess) {
         });
     }
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteRespondsWithNonretriableError) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{
         {kTestShardIds[0], cmdObj}, {kTestShardIds[1], cmdObj}, {kTestShardIds[2], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        ASSERT_THROWS(establishCursors(operationContext(),
-                                       executor(),
-                                       _nss,
-                                       ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                       remotes,
-                                       false),  // allowPartialResults
-                      ExceptionFor<ErrorCodes::FailedToParse>);
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          false,  // allowPartialResults
+                                          &viewDefinition);
+        ASSERT_EQUALS(ErrorCodes::FailedToParse, swCursors.getStatus());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // First remote responds with success.
@@ -358,7 +393,7 @@ TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteRespondsWithNonretriableErr
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest,
@@ -366,16 +401,19 @@ TEST_F(EstablishCursorsTest,
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{
         {kTestShardIds[0], cmdObj}, {kTestShardIds[1], cmdObj}, {kTestShardIds[2], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          true,  // allowPartialResults
+                                          &viewDefinition);
         // Failure is reported even though allowPartialResults was true.
-        ASSERT_THROWS(establishCursors(operationContext(),
-                                       executor(),
-                                       _nss,
-                                       ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                       remotes,
-                                       true),  // allowPartialResults
-                      ExceptionFor<ErrorCodes::FailedToParse>);
+        ASSERT_EQUALS(ErrorCodes::FailedToParse, swCursors.getStatus());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // First remote responds with success.
@@ -402,22 +440,26 @@ TEST_F(EstablishCursorsTest,
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteRespondsWithRetriableErrorThenSuccess) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{
         {kTestShardIds[0], cmdObj}, {kTestShardIds[1], cmdObj}, {kTestShardIds[2], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        auto cursors = establishCursors(operationContext(),
-                                        executor(),
-                                        _nss,
-                                        ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                        remotes,
-                                        false);  // allowPartialResults
-        ASSERT_EQUALS(remotes.size(), cursors.size());
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          false,  // allowPartialResults
+                                          &viewDefinition);
+        ASSERT_OK(swCursors.getStatus());
+        ASSERT_EQUALS(remotes.size(), swCursors.getValue().size());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // First remote responds with success.
@@ -453,7 +495,7 @@ TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteRespondsWithRetriableErrorT
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest,
@@ -461,16 +503,20 @@ TEST_F(EstablishCursorsTest,
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{
         {kTestShardIds[0], cmdObj}, {kTestShardIds[1], cmdObj}, {kTestShardIds[2], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        auto cursors = establishCursors(operationContext(),
-                                        executor(),
-                                        _nss,
-                                        ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                        remotes,
-                                        true);  // allowPartialResults
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          true,  // allowPartialResults
+                                          &viewDefinition);
+        ASSERT_OK(swCursors.getStatus());
         // We still retry up to the max retries, even if allowPartialResults is true.
-        ASSERT_EQUALS(remotes.size(), cursors.size());
+        ASSERT_EQUALS(remotes.size(), swCursors.getValue().size());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
     // First remote responds with success.
     onCommand([&](const RemoteCommandRequest& request) {
@@ -505,22 +551,25 @@ TEST_F(EstablishCursorsTest,
         return cursorResponse.toBSON(CursorResponse::ResponseType::InitialResponse);
     });
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteMaxesOutRetriableErrors) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{
         {kTestShardIds[0], cmdObj}, {kTestShardIds[1], cmdObj}, {kTestShardIds[2], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        ASSERT_THROWS(establishCursors(operationContext(),
-                                       executor(),
-                                       _nss,
-                                       ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                       remotes,
-                                       false),  // allowPartialResults
-                      ExceptionFor<ErrorCodes::HostUnreachable>);
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          false,  // allowPartialResults
+                                          &viewDefinition);
+        ASSERT_EQUALS(ErrorCodes::HostUnreachable, swCursors.getStatus().code());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // First remote responds with success.
@@ -555,24 +604,28 @@ TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteMaxesOutRetriableErrors) {
         });
     }
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteMaxesOutRetriableErrorsAllowPartialResults) {
     BSONObj cmdObj = fromjson("{find: 'testcoll'}");
     std::vector<std::pair<ShardId, BSONObj>> remotes{
         {kTestShardIds[0], cmdObj}, {kTestShardIds[1], cmdObj}, {kTestShardIds[2], cmdObj}};
+    BSONObj viewDefinition;
 
     auto future = launchAsync([&] {
-        auto cursors = establishCursors(operationContext(),
-                                        executor(),
-                                        _nss,
-                                        ReadPreferenceSetting{ReadPreference::PrimaryOnly},
-                                        remotes,
-                                        true);  // allowPartialResults
+        auto swCursors = establishCursors(operationContext(),
+                                          executor(),
+                                          _nss,
+                                          ReadPreferenceSetting{ReadPreference::PrimaryOnly},
+                                          remotes,
+                                          true,  // allowPartialResults
+                                          &viewDefinition);
         // Failure to establish a cursor due to maxing out retriable errors on one remote was
         // ignored, since allowPartialResults is true, and one less cursor was established.
-        ASSERT_EQUALS(remotes.size() - 1, cursors.size());
+        ASSERT_OK(swCursors.getStatus());
+        ASSERT_EQUALS(remotes.size() - 1, swCursors.getValue().size());
+        ASSERT_BSONOBJ_EQ({}, viewDefinition);
     });
 
     // First remote responds with success.
@@ -607,7 +660,7 @@ TEST_F(EstablishCursorsTest, MultipleRemotesOneRemoteMaxesOutRetriableErrorsAllo
         });
     }
 
-    future.default_timed_get();
+    future.timed_get(kFutureTimeout);
 }
 
 }  // namespace
