@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -29,64 +30,79 @@
 
 #pragma once
 
-#include <memory>
-
 #include "mongo/executor/task_executor.h"
-#include "mongo/s/query/blocking_results_merger.h"
+#include "mongo/s/query/async_results_merger.h"
 #include "mongo/s/query/cluster_client_cursor_params.h"
 #include "mongo/s/query/router_exec_stage.h"
 #include "mongo/util/net/hostandport.h"
 
 namespace mongo {
 
+namespace {
+using EventHandle = executor::TaskExecutor::EventHandle;
+}  // namespace
+
 /**
- * Serves as an adapter between the RouterExecStage interface and the BlockingResultsMerger
- * interface, providing a single stream of results populated from many remote streams.
+ * Draws results from the AsyncResultsMerger, which is the underlying source of the stream of merged
+ * documents manipulated by the RouterExecStage pipeline. Used to present a stream of documents
+ * merged from the shards to the stages later in the pipeline.
  */
 class RouterStageMerge final : public RouterExecStage {
 public:
     RouterStageMerge(OperationContext* opCtx,
-                     std::shared_ptr<executor::TaskExecutor> executor,
-                     AsyncResultsMergerParams&& armParams)
-        : RouterExecStage(opCtx),
-          _resultsMerger(opCtx, std::move(armParams), std::move(executor), nullptr) {}
+                     executor::TaskExecutor* executor,
+                     ClusterClientCursorParams* params);
 
-    StatusWith<ClusterQueryResult> next(ExecContext execCtx) final {
-        return _resultsMerger.next(getOpCtx(), execCtx);
-    }
+    StatusWith<ClusterQueryResult> next(ExecContext) final;
 
-    void kill(OperationContext* opCtx) final {
-        _resultsMerger.kill(opCtx);
-    }
+    void kill(OperationContext* opCtx) final;
 
-    bool remotesExhausted() final {
-        return _resultsMerger.remotesExhausted();
-    }
+    bool remotesExhausted() final;
 
-    bool partialResultsReturned() const final {
-        return _resultsMerger.partialResultsReturned();
-    }
-
-    std::size_t getNumRemotes() const final {
-        return _resultsMerger.getNumRemotes();
-    }
+    /**
+     * Adds the cursors in 'newShards' to those being merged by the ARM.
+     */
+    void addNewShardCursors(std::vector<ClusterClientCursorParams::RemoteCursor>&& newShards);
 
 protected:
-    Status doSetAwaitDataTimeout(Milliseconds awaitDataTimeout) final {
-        return _resultsMerger.setAwaitDataTimeout(awaitDataTimeout);
-    }
+    Status doSetAwaitDataTimeout(Milliseconds awaitDataTimeout) final;
 
     void doReattachToOperationContext() override {
-        _resultsMerger.reattachToOperationContext(getOpCtx());
+        _arm.reattachToOperationContext(getOpCtx());
     }
 
     virtual void doDetachFromOperationContext() {
-        _resultsMerger.detachFromOperationContext();
+        _arm.detachFromOperationContext();
     }
 
 private:
+    /**
+     * Returns the next document received by the ARM, blocking indefinitely until we either have a
+     * new result or exhaust the remote cursors.
+     */
+    StatusWith<ClusterQueryResult> blockForNextNoTimeout(ExecContext execCtx);
+
+    /**
+     * Awaits the next result from the ARM up to a specified time limit. If this is the user's
+     * initial find or we have already obtained at least one result for this batch, this method
+     * returns EOF immediately rather than blocking.
+     */
+    StatusWith<ClusterQueryResult> awaitNextWithTimeout(ExecContext execCtx);
+
+    /**
+     * Returns the next event to wait upon - either a new event from the ARM, or a valid preceding
+     * event which we scheduled during the previous call to next().
+     */
+    StatusWith<EventHandle> getNextEvent();
+
+    // Not owned here.
+    executor::TaskExecutor* _executor;
+    EventHandle _leftoverEventFromLastTimeout;
+
+    ClusterClientCursorParams* _params;
+
     // Schedules remote work and merges results from 'remotes'.
-    BlockingResultsMerger _resultsMerger;
+    AsyncResultsMerger _arm;
 };
 
 }  // namespace mongo
