@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -27,17 +28,17 @@
  *    it in the license file.
  */
 
-#define MONGO_LOGV2_DEFAULT_COMPONENT ::mongo::logv2::LogComponent::kSharding
+#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kSharding
 
 #include "mongo/platform/basic.h"
 
 #include <string>
 
 #include "mongo/base/status.h"
+#include "mongo/db/audit.h"
 #include "mongo/db/service_context.h"
 #include "mongo/rpc/metadata/client_metadata_ismaster.h"
 #include "mongo/rpc/metadata/config_server_metadata.h"
-#include "mongo/rpc/metadata/impersonated_user_metadata.h"
 #include "mongo/rpc/metadata/metadata_hook.h"
 #include "mongo/rpc/metadata/repl_set_metadata.h"
 #include "mongo/s/client/shard_registry.h"
@@ -56,6 +57,8 @@ ShardingEgressMetadataHook::ShardingEgressMetadataHook(ServiceContext* serviceCo
 Status ShardingEgressMetadataHook::writeRequestMetadata(OperationContext* opCtx,
                                                         BSONObjBuilder* metadataBob) {
     try {
+        audit::writeImpersonatedUsersToMetadata(opCtx, metadataBob);
+        ClientMetadataIsMasterState::writeToMetadata(opCtx, metadataBob);
         rpc::ConfigServerMetadata(_getConfigServerOpTime()).writeToMetadata(metadataBob);
         return Status::OK();
     } catch (...) {
@@ -89,7 +92,6 @@ Status ShardingEgressMetadataHook::_advanceConfigOpTimeFromShard(OperationContex
         if (shard->isConfig()) {
             // Config servers return the config opTime as part of their own metadata.
             if (metadataObj.hasField(rpc::kReplSetMetadataFieldName)) {
-                // Sharding users of ReplSetMetadata do not use the wall clock time field.
                 auto parseStatus = rpc::ReplSetMetadata::readFromMetadata(metadataObj);
                 if (!parseStatus.isOK()) {
                     return parseStatus.getStatus();
@@ -103,7 +105,7 @@ Status ShardingEgressMetadataHook::_advanceConfigOpTimeFromShard(OperationContex
                 // is safe to use.
                 const auto& replMetadata = parseStatus.getValue();
                 const auto opTime = replMetadata.getLastOpCommitted();
-                grid->advanceConfigOpTime(opCtx, opTime.opTime, "reply from config server node");
+                grid->advanceConfigOpTime(opCtx, opTime, "reply from config server node");
             }
         } else {
             // Regular shards return the config opTime as part of ConfigServerMetadata.
@@ -117,8 +119,8 @@ Status ShardingEgressMetadataHook::_advanceConfigOpTimeFromShard(OperationContex
             if (opTime.is_initialized()) {
                 grid->advanceConfigOpTime(opCtx,
                                           opTime.get(),
-                                          str::stream()
-                                              << "reply from shard " << shardId << " node");
+                                          str::stream() << "reply from shard " << shardId
+                                                        << " node");
             }
         }
         return Status::OK();
