@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -32,19 +33,16 @@
 #include <boost/optional.hpp>
 #include <string>
 
-#include "mongo/client/dbclient_base.h"
+#include "mongo/client/dbclientinterface.h"
 #include "mongo/db/jsobj.h"
-#include "mongo/db/logical_session_id.h"
-#include "mongo/db/ops/write_ops.h"
 #include "mongo/platform/atomic_word.h"
-#include "mongo/platform/mutex.h"
 #include "mongo/stdx/condition_variable.h"
-#include "mongo/stdx/thread.h"
+#include "mongo/stdx/mutex.h"
 #include "mongo/util/timer.h"
 
 namespace pcrecpp {
 class RE;
-}  // namespace pcrecpp
+}  // namespace pcrecpp;
 
 namespace mongo {
 
@@ -63,43 +61,11 @@ enum class OpType {
     CPULOAD
 };
 
-inline bool isReadOp(OpType opType) {
-    return opType == OpType::FINDONE || opType == OpType::FIND;
-}
-
-inline bool isWriteOp(OpType opType) {
-    return opType == OpType::UPDATE || opType == OpType::INSERT || opType == OpType::REMOVE;
-}
-
-class BenchRunConfig;
-struct BenchRunStats;
-class BsonTemplateEvaluator;
-class LogicalSessionIdToClient;
-
 /**
  * Object representing one operation passed to benchRun
  */
 struct BenchRunOp {
-    struct State {
-        State(PseudoRandom* rng_,
-              BsonTemplateEvaluator* bsonTemplateEvaluator_,
-              BenchRunStats* stats_)
-            : rng(rng_), bsonTemplateEvaluator(bsonTemplateEvaluator_), stats(stats_) {}
-
-        PseudoRandom* rng;
-        BsonTemplateEvaluator* bsonTemplateEvaluator;
-        BenchRunStats* stats;
-
-        // Transaction state
-        TxnNumber txnNumber = 0;
-        bool inProgressMultiStatementTxn = false;
-    };
-
-    void executeOnce(DBClientBase* conn,
-                     const boost::optional<LogicalSessionIdToClient>& lsid,
-                     const BenchRunConfig& config,
-                     State* state) const;
-
+public:
     int batchSize = 0;
     BSONElement check;
     BSONObj command;
@@ -118,12 +84,13 @@ struct BenchRunOp {
     int options = 0;
     BSONObj projection;
     BSONObj query;
+    bool safe = false;
     int skip = 0;
-    BSONObj sort;
     bool showError = false;
+    bool showResult = false;
     std::string target;
     bool throwGLE = false;
-    write_ops::UpdateModification update;
+    BSONObj update;
     bool upsert = false;
     bool useCheck = false;
     bool useReadCmd = false;
@@ -131,23 +98,6 @@ struct BenchRunOp {
     BSONObj writeConcern;
     BSONObj value;
 
-    // Only used for find cmds when set greater than 0. A find operation will retrieve the latest
-    // cluster time from the oplog and randomly chooses a time between that timestamp and
-    // 'useClusterTimeWithinSeconds' seconds in the past at which to read.
-    //
-    // Must be used with 'useSnapshotReads=true' BenchRunConfig because atClusterTime is only
-    // allowed within a transaction.
-    int useAClusterTimeWithinPastSeconds = 0;
-
-    // Delays getMore commands following a find cmd. A uniformly distributed random value between 0
-    // and maxRandomMillisecondDelayBeforeGetMore will be generated for each getMore call. Useful
-    // for keeping a snapshot read open for a longer time duration, say to simulate the basic
-    // resources that a snapshot transaction would hold for a time.
-    int maxRandomMillisecondDelayBeforeGetMore{0};
-
-    // Format: {$readPreference: {mode: modeStr}}.  Only mode field is allowed.
-    BSONObj readPrefObj;
-
     // This is an owned copy of the raw operation. All unowned members point into this.
     BSONObj myBsonOp;
 };
@@ -156,8 +106,7 @@ struct BenchRunOp {
  * Configuration object describing a bench run activity.
  */
 class BenchRunConfig {
-    BenchRunConfig(const BenchRunConfig&) = delete;
-    BenchRunConfig& operator=(const BenchRunConfig&) = delete;
+    MONGO_DISALLOW_COPYING(BenchRunConfig);
 
 public:
     /**
@@ -168,8 +117,6 @@ public:
      */
     static BenchRunConfig* createFromBson(const BSONObj& args);
 
-    static std::unique_ptr<DBClientBase> createConnectionImpl(const BenchRunConfig&);
-
     BenchRunConfig();
 
     void initializeFromBson(const BSONObj& args);
@@ -222,19 +169,10 @@ public:
      */
     bool useIdempotentWrites{false};
 
-    /**
-     * Whether read commands should be sent with a txnNumber and read concern level snapshot.
-     */
-    bool useSnapshotReads{false};
-
-    /**
-     * How many milliseconds to sleep for if an operation fails, before continuing to the next op.
-     */
-    Milliseconds delayMillisOnFailedOperation{0};
-
     /// Base random seed for threads
     int64_t randomSeed;
 
+    bool hideResults;
     bool handleErrors;
     bool hideErrors;
 
@@ -258,8 +196,6 @@ public:
     bool breakOnTrap;
 
 private:
-    static std::function<std::unique_ptr<DBClientBase>(const BenchRunConfig&)> _factory;
-
     /// Initialize a config object to its default values.
     void initializeToDefaults();
 };
@@ -282,10 +218,6 @@ public:
      * Count one instance of the event, which took "timeMicros" microseconds.
      */
     void countOne(long long timeMicros) {
-        if (_numEvents == std::numeric_limits<long long>::max()) {
-            fassertFailedWithStatus(50874,
-                                    {ErrorCodes::Overflow, "Overflowed the events counter."});
-        }
         ++_numEvents;
         _totalTimeMicros += timeMicros;
     }
@@ -300,13 +232,13 @@ public:
     /**
      * Get the number of observed events.
      */
-    long long getNumEvents() const {
+    unsigned long long getNumEvents() const {
         return _numEvents;
     }
 
 private:
     long long _totalTimeMicros{0};
-    long long _numEvents{0};
+    unsigned long long _numEvents{0};
 };
 
 /**
@@ -323,8 +255,7 @@ private:
  * In all cases, the counter objects must outlive the trace object.
  */
 class BenchRunEventTrace {
-    BenchRunEventTrace(const BenchRunEventTrace&) = delete;
-    BenchRunEventTrace& operator=(const BenchRunEventTrace&) = delete;
+    MONGO_DISALLOW_COPYING(BenchRunEventTrace);
 
 public:
     explicit BenchRunEventTrace(BenchRunEventCounter* eventCounter) {
@@ -391,8 +322,7 @@ struct BenchRunStats {
  * Logically, the states are "starting up", "running" and "finished."
  */
 class BenchRunState {
-    BenchRunState(const BenchRunState&) = delete;
-    BenchRunState& operator=(const BenchRunState&) = delete;
+    MONGO_DISALLOW_COPYING(BenchRunState);
 
 public:
     enum State { BRS_STARTING_UP, BRS_RUNNING, BRS_FINISHED };
@@ -438,9 +368,9 @@ public:
     bool shouldWorkerFinish() const;
 
     /**
-     * Predicate that workers call to see if they should start collecting stats (as a result
-     * of a call to tellWorkersToCollectStats()).
-     */
+    * Predicate that workers call to see if they should start collecting stats (as a result
+    * of a call to tellWorkersToCollectStats()).
+    */
     bool shouldWorkerCollectStats() const;
 
     /**
@@ -456,15 +386,15 @@ public:
     void onWorkerFinished();
 
 private:
-    mutable Mutex _mutex = MONGO_MAKE_LATCH("BenchRunState::_mutex");
+    mutable stdx::mutex _mutex;
 
     stdx::condition_variable _stateChangeCondition;
 
     unsigned _numUnstartedWorkers;
     unsigned _numActiveWorkers;
 
-    AtomicWord<unsigned> _isShuttingDown;
-    AtomicWord<unsigned> _isCollectingStats;
+    AtomicUInt32 _isShuttingDown;
+    AtomicUInt32 _isCollectingStats;
 };
 
 /**
@@ -473,8 +403,7 @@ private:
  * Represents the behavior of one thread working in a bench run activity.
  */
 class BenchRunWorker {
-    BenchRunWorker(const BenchRunWorker&) = delete;
-    BenchRunWorker& operator=(const BenchRunWorker&) = delete;
+    MONGO_DISALLOW_COPYING(BenchRunWorker);
 
 public:
     /**
@@ -517,15 +446,13 @@ private:
     /// Predicate, used to decide whether or not it's time to collect statistics
     bool shouldCollectStats() const;
 
-    stdx::thread _thread;
-
     const size_t _id;
 
     const BenchRunConfig* _config;
 
     BenchRunState& _brState;
 
-    PseudoRandom _rng;
+    const int64_t _randomSeed;
 
     // Dummy stats to use before observation period.
     BenchRunStats _statsBlackHole;
@@ -538,8 +465,7 @@ private:
  * Object representing a "bench run" activity.
  */
 class BenchRunner {
-    BenchRunner(const BenchRunner&) = delete;
-    BenchRunner& operator=(const BenchRunner&) = delete;
+    MONGO_DISALLOW_COPYING(BenchRunner);
 
 public:
     /**
@@ -606,7 +532,7 @@ public:
 
 private:
     // TODO: Same as for createWithConfig.
-    static Mutex _staticMutex;
+    static stdx::mutex _staticMutex;
     static std::map<OID, BenchRunner*> _activeRuns;
 
     OID _oid;
