@@ -40,14 +40,18 @@ Copyright (C) 2019-present Percona and/or its affiliates. All rights reserved.
 
 namespace mongo {
 MONGO_GENERAL_STARTUP_OPTIONS_REGISTER(PerconaDecryptOptions)(InitializerContext* context) {
-    uassertStatusOK(addPerconaDecryptOptions(&moe::startupOptions));
+    return addPerconaDecryptOptions(&moe::startupOptions);
 }
 
 MONGO_STARTUP_OPTIONS_VALIDATE(PerconaDecryptOptions)(InitializerContext* context) {
     if (!handlePreValidationPerconaDecryptOptions(moe::startupOptionsParsed)) {
-        quickExit(ExitCode::clean);
+        quickExit(EXIT_SUCCESS);
     }
-    uassertStatusOK(moe::startupOptionsParsed.validate());
+    Status ret = moe::startupOptionsParsed.validate();
+    if (!ret.isOK()) {
+        return ret;
+    }
+    return Status::OK();
 }
 
 MONGO_STARTUP_OPTIONS_STORE(PerconaDecryptOptions)(InitializerContext* context) {
@@ -55,7 +59,9 @@ MONGO_STARTUP_OPTIONS_STORE(PerconaDecryptOptions)(InitializerContext* context)
     if (!ret.isOK()) {
         std::cerr << ret.toString() << std::endl;
         std::cerr << "try '" << context->args()[0] << " --help' for more information" << std::endl;
-        quickExit(ExitCode::badOptions);
+        quickExit(EXIT_BADOPTIONS);
     }
+
+    return Status::OK();
 }
 }
