@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -27,7 +28,7 @@
  *    it in the license file.
  */
 
-#define MONGO_LOGV2_DEFAULT_COMPONENT ::mongo::logv2::LogComponent::kControl
+#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kControl
 
 #include "mongo/platform/basic.h"
 
@@ -38,7 +39,7 @@
 #endif
 #if defined(__APPLE__)
 #include <TargetConditionals.h>
-#if !TARGET_OS_TV && !TARGET_OS_IOS && !TARGET_OS_WATCH
+#if !TARGET_OS_TV && !TARGET_OS_IOS
 #include <sys/proc_info.h>
 #else
 #include <mach/thread_info.h>
@@ -51,12 +52,14 @@
 
 #include "mongo/base/init.h"
 #include "mongo/config.h"
-#include "mongo/logv2/log.h"
 #include "mongo/platform/atomic_word.h"
-#include "mongo/util/str.h"
+#include "mongo/util/log.h"
+#include "mongo/util/mongoutils/str.h"
 
 namespace mongo {
 
+using std::string;
+
 namespace {
 
 #ifdef _WIN32
@@ -89,7 +92,7 @@ void setWindowsThreadName(DWORD dwThreadID, const char* threadName) {
 }
 #endif
 
-AtomicWord<long long> nextUnnamedThreadId{1};
+AtomicInt64 nextUnnamedThreadId{1};
 
 // It is unsafe to access threadName before its dynamic initialization has completed. Use
 // the execution of mongo initializers (which only happens once we have entered main, and
@@ -104,38 +107,39 @@ MONGO_INITIALIZER(ThreadNameInitializer)(InitializerContext*) {
     return Status::OK();
 }
 
-thread_local std::string threadNameStorage;
+// TODO consider making threadName std::string and removing the size limit once we get real
+// thread_local.
+constexpr size_t kMaxThreadNameSize = 63;
+thread_local char threadNameStorage[kMaxThreadNameSize + 1];
+
 }  // namespace
 
 namespace for_debuggers {
 // This needs external linkage to ensure that debuggers can use it.
 thread_local StringData threadName;
-}  // namespace for_debuggers
+}
 using for_debuggers::threadName;
 
 void setThreadName(StringData name) {
     invariant(mongoInitializersHaveRun);
-    threadNameStorage = name.toString();
-    threadName = threadNameStorage;
+    if (name.size() > kMaxThreadNameSize) {
+        // Truncate unreasonably long thread names.
+        name = name.substr(0, kMaxThreadNameSize);
+    }
+    name.copyTo(threadNameStorage, /*null terminate=*/true);
+    threadName = StringData(threadNameStorage, name.size());
 
 #if defined(_WIN32)
     // Naming should not be expensive compared to thread creation and connection set up, but if
     // testing shows otherwise we should make this depend on DEBUG again.
-    setWindowsThreadName(GetCurrentThreadId(), threadNameStorage.c_str());
+    setWindowsThreadName(GetCurrentThreadId(), threadName.rawData());
 #elif defined(__APPLE__)
     // Maximum thread name length on OS X is MAXTHREADNAMESIZE (64 characters). This assumes
     // OS X 10.6 or later.
-    std::string threadNameCopy = threadNameStorage;
-    if (threadNameCopy.size() > MAXTHREADNAMESIZE) {
-        threadNameCopy.resize(MAXTHREADNAMESIZE - 4);
-        threadNameCopy += "...";
-    }
-    int error = pthread_setname_np(threadNameCopy.c_str());
+    MONGO_STATIC_ASSERT(MAXTHREADNAMESIZE >= kMaxThreadNameSize + 1);
+    int error = pthread_setname_np(threadName.rawData());
     if (error) {
-        LOGV2(23102,
-              "Ignoring error from setting thread name: {error}",
-              "Ignoring error from setting thread name",
-              "error"_attr = errnoWithDescription(error));
+        log() << "Ignoring error from setting thread name: " << errnoWithDescription(error);
     }
 #elif defined(__linux__) && defined(MONGO_CONFIG_HAVE_PTHREAD_SETNAME_NP)
     // Do not set thread name on the main() thread. Setting the name on main thread breaks
@@ -148,18 +152,15 @@ void setThreadName(StringData name) {
         //  limit, it's best to shorten long names.
         int error = 0;
         if (threadName.size() > 15) {
-            std::string shortName = str::stream()
-                << threadName.substr(0, 7) << '.' << threadName.substr(threadName.size() - 7);
+            std::string shortName = str::stream() << threadName.substr(0, 7) << '.'
+                                                  << threadName.substr(threadName.size() - 7);
             error = pthread_setname_np(pthread_self(), shortName.c_str());
         } else {
             error = pthread_setname_np(pthread_self(), threadName.rawData());
         }
 
         if (error) {
-            LOGV2(23103,
-                  "Ignoring error from setting thread name: {error}",
-                  "Ignoring error from setting thread name",
-                  "error"_attr = errnoWithDescription(error));
+            log() << "Ignoring error from setting thread name: " << errnoWithDescription(error);
         }
     }
 #endif
