@@ -1,3 +1,4 @@
+
 /**
  *    Copyright (C) 2018-present MongoDB, Inc.
  *
@@ -147,11 +148,13 @@ SocketPair socketPair(const int type, const int protocol) {
 
     Notification<void> accepted;
     SOCKET acceptSock = INVALID_SOCKET;
-    stdx::thread acceptor([&] { detail::awaitAccept(&acceptSock, listenSock, accepted); });
+    stdx::thread acceptor(
+        stdx::bind(&detail::awaitAccept, &acceptSock, listenSock, stdx::ref(accepted)));
 
     Notification<void> connected;
     SOCKET connectSock = INVALID_SOCKET;
-    stdx::thread connector([&] { detail::awaitConnect(&connectSock, *connectRes, connected); });
+    stdx::thread connector(
+        stdx::bind(&detail::awaitConnect, &connectSock, *connectRes, stdx::ref(connected)));
 
     connected.get();
     connector.join();
@@ -269,7 +272,7 @@ TEST_F(SocketFailPointTest, TestSend) {
     ASSERT_TRUE(tryRecv());
     {
         const ScopedFailPointEnabler enabled(*_failPoint);
-        ASSERT_THROWS(trySend(), NetworkException);
+        ASSERT_THROWS(trySend(), SocketException);
     }
     // Channel should be working again
     ASSERT_TRUE(trySend());
@@ -281,7 +284,7 @@ TEST_F(SocketFailPointTest, TestSendVector) {
     ASSERT_TRUE(tryRecv());
     {
         const ScopedFailPointEnabler enabled(*_failPoint);
-        ASSERT_THROWS(trySendVector(), NetworkException);
+        ASSERT_THROWS(trySendVector(), SocketException);
     }
     ASSERT_TRUE(trySendVector());
     ASSERT_TRUE(tryRecv());
@@ -293,7 +296,7 @@ TEST_F(SocketFailPointTest, TestRecv) {
     {
         ASSERT_TRUE(trySend());  // data for recv
         const ScopedFailPointEnabler enabled(*_failPoint);
-        ASSERT_THROWS(tryRecv(), NetworkException);
+        ASSERT_THROWS(tryRecv(), SocketException);
     }
     ASSERT_TRUE(trySend());  // data for recv
     ASSERT_TRUE(tryRecv());
@@ -306,7 +309,7 @@ TEST_F(SocketFailPointTest, TestFailedSendsDontSend) {
         ASSERT_TRUE(trySend());  // queue 1 byte
         const ScopedFailPointEnabler enabled(*_failPoint);
         // Fail to queue another byte
-        ASSERT_THROWS(trySend(), NetworkException);
+        ASSERT_THROWS(trySend(), SocketException);
     }
     // Failed byte should not have been transmitted.
     ASSERT_EQUALS(size_t(1), countRecvable(2));
@@ -320,7 +323,7 @@ TEST_F(SocketFailPointTest, TestFailedVectorSendsDontSend) {
         ASSERT_TRUE(trySend());  // queue 1 byte
         const ScopedFailPointEnabler enabled(*_failPoint);
         // Fail to queue another byte
-        ASSERT_THROWS(trySendVector(), NetworkException);
+        ASSERT_THROWS(trySendVector(), SocketException);
     }
     // Failed byte should not have been transmitted.
     ASSERT_EQUALS(size_t(1), countRecvable(2));
@@ -333,7 +336,7 @@ TEST_F(SocketFailPointTest, TestFailedRecvsDontRecv) {
         ASSERT_TRUE(trySend());
         const ScopedFailPointEnabler enabled(*_failPoint);
         // Fail to recv that byte
-        ASSERT_THROWS(tryRecv(), NetworkException);
+        ASSERT_THROWS(tryRecv(), SocketException);
     }
     // Failed byte should still be queued to recv.
     ASSERT_EQUALS(size_t(1), countRecvable(1));
