@@ -1,29 +1,31 @@
+
 /**
- * Copyright (C) 2016 MongoDB Inc.
+ *    Copyright (C) 2018-present MongoDB, Inc.
  *
- * This program is free software: you can redistribute it and/or  modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
+ *    This program is free software: you can redistribute it and/or modify
+ *    it under the terms of the Server Side Public License, version 1,
+ *    as published by MongoDB, Inc.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
+ *    This program is distributed in the hope that it will be useful,
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *    Server Side Public License for more details.
  *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *    You should have received a copy of the Server Side Public License
+ *    along with this program. If not, see
+ *    <http://www.mongodb.com/licensing/server-side-public-license>.
  *
- * As a special exception, the copyright holders give permission to link the
- * code of portions of this program with the OpenSSL library under certain
- * conditions as described in each individual source file and distribute
- * linked combinations including the program with the OpenSSL library. You
- * must comply with the GNU Affero General Public License in all respects
- * for all of the code used other than as permitted herein. If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so. If you do not
- * wish to do so, delete this exception statement from your version. If you
- * delete this exception statement from all source files in the program,
- * then also delete it in the license file.
+ *    As a special exception, the copyright holders give permission to link the
+ *    code of portions of this program with the OpenSSL library under certain
+ *    conditions as described in each individual source file and distribute
+ *    linked combinations including the program with the OpenSSL library. You
+ *    must comply with the Server Side Public License in all respects for
+ *    all of the code used other than as permitted herein. If you modify file(s)
+ *    with this exception, you may extend this exception to your version of the
+ *    file(s), but you are not obligated to do so. If you do not wish to do so,
+ *    delete this exception statement from your version. If you delete this
+ *    exception statement from all source files in the program, then also delete
+ *    it in the license file.
  */
 
 #define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kFTDC
@@ -95,6 +97,11 @@ StringMap toNestedStringMap(BSONObj& obj) {
     ASSERT_OK(procparser::parseProcDiskStats(_disks, _x, &builder)); \
     auto obj = builder.obj();                                        \
     auto stringMap = toNestedStringMap(obj);
+#define ASSERT_PARSE_VMSTAT(_keys, _x)                           \
+    BSONObjBuilder builder;                                      \
+    ASSERT_OK(procparser::parseProcVMStat(_keys, _x, &builder)); \
+    auto obj = builder.obj();                                    \
+    auto stringMap = toStringMap(obj);
 
 TEST(FTDCProcStat, TestStat) {
 
@@ -638,5 +645,73 @@ TEST(FTDCProcDiskStats, TestLocalDiskStats) {
     }
 }
 
+
+TEST(FTDCProcVMStat, TestVMStat) {
+
+    std::vector<StringData> keys{"Key1", "Key2", "Key3"};
+
+    // Normal case
+    {
+        ASSERT_PARSE_VMSTAT(keys, "Key1 123\nKey2 456");
+        ASSERT_KEY_AND_VALUE("Key1", 123UL);
+        ASSERT_KEY_AND_VALUE("Key2", 456UL);
+    }
+
+    // No newline
+    {
+        ASSERT_PARSE_VMSTAT(keys, "Key1 123 Key2 456");
+        ASSERT_KEY_AND_VALUE("Key1", 123UL);
+        ASSERT_NO_KEY("Key2");
+    }
+
+    // Key without value
+    {
+        ASSERT_PARSE_VMSTAT(keys, "Key1 123\nKey2");
+        ASSERT_KEY_AND_VALUE("Key1", 123UL);
+        ASSERT_NO_KEY("Key2");
+    }
+
+    // Empty string
+    {
+        BSONObjBuilder builder;
+        ASSERT_NOT_OK(procparser::parseProcVMStat(keys, "", &builder));
+    }
+}
+
+// Test we can parse the /proc/vmstat on this machine. Also assert we have the expected fields
+// This tests is designed to exercise our parsing code on various Linuxes and fail
+// Normally when run in the FTDC loop we return a non-fatal error so we may not notice the failure
+// otherwise.
+TEST(FTDCProcVMStat, TestLocalVMStat) {
+    std::vector<StringData> keys{
+        "balloon_deflate"_sd,
+        "balloon_inflate"_sd,
+        "nr_mlock"_sd,
+        "pgfault"_sd,
+        "pgmajfault"_sd,
+        "pswpin"_sd,
+        "pswpout"_sd,
+    };
+
+    BSONObjBuilder builder;
+
+    ASSERT_OK(procparser::parseProcVMStatFile("/proc/vmstat", keys, &builder));
+
+    BSONObj obj = builder.obj();
+    auto stringMap = toStringMap(obj);
+    ASSERT_KEY("nr_mlock");
+    ASSERT_KEY("pgmajfault");
+    ASSERT_KEY("pswpin");
+    ASSERT_KEY("pswpout");
+}
+
+
+TEST(FTDCProcVMStat, TestLocalNonExistentVMStat) {
+    std::vector<StringData> keys{};
+    BSONObjBuilder builder;
+
+    ASSERT_NOT_OK(procparser::parseProcVMStatFile("/proc/does_not_exist", keys, &builder));
+}
+
 }  // namespace
 }  // namespace mongo
